/* Mapping tables for GB18030 handling.
   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
   This file is part of the GNU C Library.
   GBK tables contributed by Sean Chen <seanc@turbolinux.com.cn>, 1999;
   GB18030 contributed by Wang ShouHua <shwang@sonata.iscas.ac.cn>, 2000;
                   and by Wu Jian <jwu@sonata.iscas.ac.cn>, 2000;
   Updated to November 2000 re-released GB18030 standard by
                          Yong Li <rigel863@yahoo.com>
   Optimizations by Ulrich Drepper <drepper@cygnus.com>, 1999-2001;
   Revisions by Bruno Haible <haible@ilog.fr>, 1999-2001;
   Contributed by James Su <suzhe@gnuchina.org>, 2001;
   Reimplemented by Anthony Fok <anthony@thizlinux.com>, 2002.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */

/* 	This file is added for supporting gb18030-2000 code.
	by Wang ShouHua & Wu Jian
	Redflag Linux company
	www.redflag-linux.com
*/

/* The GB18030 standard was re-released on Nov. 2000 and many code values
 * were changed. The reimplementation of this module is based on the info
 * from Markus Scherer's site:
 * http://oss.software.ibm.com/cvs/icu/~checkout~/icu/source/tools/makeconv/gb18030/gb18030.html
 *
 *   - Yong Li <rigel863@yahoo.com>  Jan. 28, 2001
 */

/* 
  GBK, formally the Chinese Internal Code Specification, is a commonly
  used extension of GB 2312-80.  Microsoft Windows uses it under the
  name codepage 936.

  GBK has been superceded by the new Chinese national standard
  GB 18030-2000, which added a 4-byte encoding while remaining
  compatible with GB2312 and GBK.  The new GB18030-2000 may be described
  as a special encoding of Unicode 3.x and ISO-10646-1.

  Special thanks to charset gurus Markus Scherer (IBM),
  Dirk Meyer (Adobe Systems) and Ken Lunde (Adobe Systems) for publishing
  excellent GB 18030-200 summary and specifications on the Internet.
  Some must-read documents are:
   * ftp://ftp.oreilly.com/pub/examples/nutshell/cjkv/pdf/GB18030_Summary.pdf
   * http://oss.software.ibm.com/cvs/icu/~checkout~/charset/source/gb18030/gb18030.html
   * http://oss.software.ibm.com/cvs/icu/~checkout~/charset/data/xml/gb-18030-2000.xml

  The GB18030 mapping tables are generated from gb-18030-2000.xml
  using a Perl script while merging contributions from other
  developers.  A copy of the source Perl script is available at:

      http://people.debian.org/~foka/gb18030/gen-glibc-gb18030.pl

  Revisions:
    2001-11-26  first fully working version for Qt
    2002-01-15  ported to glibc-2.2.4 and tested for U+0000 - U+10FFFF
		(sans surrogate area)
    2002-02-17  Use unsigned char[2] for __ucs_to_gb18030

   - Anthony Fok <anthony@thizlinux.com>  17 Feb 2002
     On behalf of ThizLinux Laboratory Ltd., Hong Kong SAR, China
*/

#include <dlfcn.h>
#include <gconv.h>
#include <stdint.h>
#include <wchar.h>

#define InRange(c, lower, upper)  (((c) >= (lower)) && ((c) <= (upper)))


typedef struct {
    uint8_t	tblbegin;
    uint8_t	tblend;
    uint16_t	tbloffset;
    uint16_t	algoffset;
} indextbl_t;

static const indextbl_t __gb18030_to_ucs_index[154] = {
  /* U+00__ */	{0x00, 0xFF, 0x0000, 0x0000},	{0x00, 0xFF, 0x0000, 0x0000},
  /* U+02__ */	{0x00, 0xFF, 0x0000, 0x0000},	{0x00, 0x33, 0x0000, 0x041E},
  /* U+04__ */	{0xFF, 0x00, 0x1BBE, 0x051E},	{0xFF, 0x00, 0x1BBE, 0x061E},
  /* U+06__ */	{0xFF, 0x00, 0x1BBE, 0x071E},	{0xFF, 0x00, 0x1BBE, 0x081E},
  /* U+08__ */	{0xFF, 0x00, 0x1BBE, 0x091E},	{0xFF, 0x00, 0x1BBE, 0x0A1E},
  /* U+0A__ */	{0xFF, 0x00, 0x1BBE, 0x0B1E},	{0xFF, 0x00, 0x1BBE, 0x0C1E},
  /* U+0C__ */	{0xFF, 0x00, 0x1BBE, 0x0D1E},	{0xFF, 0x00, 0x1BBE, 0x0E1E},
  /* U+0E__ */	{0xFF, 0x00, 0x1BBE, 0x0F1E},	{0xFF, 0x00, 0x1BBE, 0x101E},
  /* U+10__ */	{0xFF, 0x00, 0x1BBE, 0x111E},	{0xFF, 0x00, 0x1BBE, 0x121E},
  /* U+12__ */	{0xFF, 0x00, 0x1BBE, 0x131E},	{0xFF, 0x00, 0x1BBE, 0x141E},
  /* U+14__ */	{0xFF, 0x00, 0x1BBE, 0x151E},	{0xFF, 0x00, 0x1BBE, 0x161E},
  /* U+16__ */	{0xFF, 0x00, 0x1BBE, 0x171E},	{0xFF, 0x00, 0x1BBE, 0x181E},
  /* U+18__ */	{0xFF, 0x00, 0x1BBE, 0x191E},	{0xFF, 0x00, 0x1BBE, 0x1A1E},
  /* U+1A__ */	{0xFF, 0x00, 0x1BBE, 0x1B1E},	{0xFF, 0x00, 0x1BBE, 0x1C1E},
  /* U+1C__ */	{0xFF, 0x00, 0x1BBE, 0x1D1E},	{0xFF, 0x00, 0x1BBE, 0x1E1E},
  /* U+1E__ */	{0xF2, 0xFF, 0x1BBE, 0x1F1E},	{0x00, 0xFF, 0x1BBE, 0x0000},
  /* U+20__ */	{0x00, 0xFF, 0x1BBE, 0x0000},	{0x00, 0xFF, 0x1BBE, 0x0000},
  /* U+22__ */	{0x00, 0xFF, 0x1BBE, 0x0000},	{0x00, 0xFF, 0x1BBE, 0x0000},
  /* U+24__ */	{0x00, 0x02, 0x1BBE, 0x2640},	{0xFF, 0x00, 0x23FC, 0x2740},
  /* U+26__ */	{0xFF, 0x00, 0x23FC, 0x2840},	{0xFF, 0x00, 0x23FC, 0x2940},
  /* U+28__ */	{0xFF, 0x00, 0x23FC, 0x2A40},	{0xFF, 0x00, 0x23FC, 0x2B40},
  /* U+2A__ */	{0xFF, 0x00, 0x23FC, 0x2C40},	{0xFF, 0x00, 0x23FC, 0x2D40},
  /* U+2C__ */	{0x41, 0xFF, 0x23FC, 0x2E40},	{0x00, 0xFF, 0x23FC, 0x0000},
  /* U+2E__ */	{0x00, 0xFF, 0x23FC, 0x0000},	{0x00, 0xFF, 0x23FC, 0x0000},
  /* U+30__ */	{0x00, 0xFF, 0x23FC, 0x0000},	{0x00, 0xFF, 0x23FC, 0x0000},
  /* U+32__ */	{0x00, 0xAC, 0x23FC, 0x356E},	{0xFF, 0x00, 0x26F9, 0x366E},
  /* U+34__ */	{0xFF, 0x00, 0x26F9, 0x376E},	{0xAA, 0xFF, 0x26F9, 0x386E},
  /* U+36__ */	{0x00, 0xFF, 0x26F9, 0x0000},	{0x00, 0xFF, 0x26F9, 0x0000},
  /* U+38__ */	{0x00, 0xFF, 0x26F9, 0x0000},	{0x00, 0x69, 0x26F9, 0x3C77},
  /* U+3A__ */	{0xFF, 0x00, 0x2A6E, 0x3D77},	{0xFF, 0x00, 0x2A6E, 0x3E77},
  /* U+3C__ */	{0xDF, 0xFF, 0x2A6E, 0x3F77},	{0x00, 0xE6, 0x2A6E, 0x4079},
  /* U+3E__ */	{0xFF, 0x00, 0x2C45, 0x4179},	{0xBE, 0xFF, 0x2C45, 0x4279},
  /* U+40__ */	{0x00, 0xFF, 0x2C45, 0x0000},	{0x00, 0x58, 0x2C45, 0x447E},
  /* U+42__ */	{0xCE, 0xFF, 0x2DBA, 0x457E},	{0x00, 0xFF, 0x2DBA, 0x0000},
  /* U+44__ */	{0x00, 0x09, 0x2DBA, 0x4784},	{0xC3, 0xFF, 0x2F73, 0x4884},
  /* U+46__ */	{0x00, 0x28, 0x2F73, 0x498F},	{0xFF, 0x00, 0x3232, 0x4A8F},
  /* U+48__ */	{0xE8, 0xFF, 0x3232, 0x4B8F},	{0x00, 0xFF, 0x3232, 0x0000},
  /* U+4A__ */	{0x00, 0x62, 0x3232, 0x9F43},	{0xFF, 0x00, 0x6A8C, 0xA043},
  /* U+4C__ */	{0xFF, 0x00, 0x6A8C, 0xA143},	{0xFF, 0x00, 0x6A8C, 0xA243},
  /* U+4E__ */	{0xFF, 0x00, 0x6A8C, 0xA343},	{0xFF, 0x00, 0x6A8C, 0xA443},
  /* U+50__ */	{0xFF, 0x00, 0x6A8C, 0xA543},	{0xFF, 0x00, 0x6A8C, 0xA643},
  /* U+52__ */	{0xFF, 0x00, 0x6A8C, 0xA743},	{0xFF, 0x00, 0x6A8C, 0xA843},
  /* U+54__ */	{0xFF, 0x00, 0x6A8C, 0xA943},	{0xFF, 0x00, 0x6A8C, 0xAA43},
  /* U+56__ */	{0xFF, 0x00, 0x6A8C, 0xAB43},	{0xFF, 0x00, 0x6A8C, 0xAC43},
  /* U+58__ */	{0xFF, 0x00, 0x6A8C, 0xAD43},	{0xFF, 0x00, 0x6A8C, 0xAE43},
  /* U+5A__ */	{0xFF, 0x00, 0x6A8C, 0xAF43},	{0xFF, 0x00, 0x6A8C, 0xB043},
  /* U+5C__ */	{0xFF, 0x00, 0x6A8C, 0xB143},	{0xFF, 0x00, 0x6A8C, 0xB243},
  /* U+5E__ */	{0xFF, 0x00, 0x6A8C, 0xB343},	{0xFF, 0x00, 0x6A8C, 0xB443},
  /* U+60__ */	{0xFF, 0x00, 0x6A8C, 0xB543},	{0xFF, 0x00, 0x6A8C, 0xB643},
  /* U+62__ */	{0xFF, 0x00, 0x6A8C, 0xB743},	{0xFF, 0x00, 0x6A8C, 0xB843},
  /* U+64__ */	{0xFF, 0x00, 0x6A8C, 0xB943},	{0xFF, 0x00, 0x6A8C, 0xBA43},
  /* U+66__ */	{0xFF, 0x00, 0x6A8C, 0xBB43},	{0xFF, 0x00, 0x6A8C, 0xBC43},
  /* U+68__ */	{0xFF, 0x00, 0x6A8C, 0xBD43},	{0xFF, 0x00, 0x6A8C, 0xBE43},
  /* U+6A__ */	{0xFF, 0x00, 0x6A8C, 0xBF43},	{0xFF, 0x00, 0x6A8C, 0xC043},
  /* U+6C__ */	{0xFF, 0x00, 0x6A8C, 0xC143},	{0xFF, 0x00, 0x6A8C, 0xC243},
  /* U+6E__ */	{0xFF, 0x00, 0x6A8C, 0xC343},	{0xFF, 0x00, 0x6A8C, 0xC443},
  /* U+70__ */	{0xFF, 0x00, 0x6A8C, 0xC543},	{0xFF, 0x00, 0x6A8C, 0xC643},
  /* U+72__ */	{0xFF, 0x00, 0x6A8C, 0xC743},	{0xFF, 0x00, 0x6A8C, 0xC843},
  /* U+74__ */	{0xFF, 0x00, 0x6A8C, 0xC943},	{0xFF, 0x00, 0x6A8C, 0xCA43},
  /* U+76__ */	{0xFF, 0x00, 0x6A8C, 0xCB43},	{0xFF, 0x00, 0x6A8C, 0xCC43},
  /* U+78__ */	{0xFF, 0x00, 0x6A8C, 0xCD43},	{0xFF, 0x00, 0x6A8C, 0xCE43},
  /* U+7A__ */	{0xFF, 0x00, 0x6A8C, 0xCF43},	{0xFF, 0x00, 0x6A8C, 0xD043},
  /* U+7C__ */	{0xFF, 0x00, 0x6A8C, 0xD143},	{0xFF, 0x00, 0x6A8C, 0xD243},
  /* U+7E__ */	{0xFF, 0x00, 0x6A8C, 0xD343},	{0xFF, 0x00, 0x6A8C, 0xD443},
  /* U+80__ */	{0xFF, 0x00, 0x6A8C, 0xD543},	{0xFF, 0x00, 0x6A8C, 0xD643},
  /* U+82__ */	{0xBD, 0xFF, 0x6A8C, 0xD743},	{0x00, 0x0D, 0x6A8C, 0xE857},
  /* U+84__ */	{0xFF, 0x00, 0x7B53, 0xE957},	{0xFF, 0x00, 0x7B53, 0xEA57},
  /* U+86__ */	{0xFF, 0x00, 0x7B53, 0xEB57},	{0xFF, 0x00, 0x7B53, 0xEC57},
  /* U+88__ */	{0xFF, 0x00, 0x7B53, 0xED57},	{0xFF, 0x00, 0x7B53, 0xEE57},
  /* U+8A__ */	{0xFF, 0x00, 0x7B53, 0xEF57},	{0xFF, 0x00, 0x7B53, 0xF057},
  /* U+8C__ */	{0xFF, 0x00, 0x7B53, 0xF157},	{0xFF, 0x00, 0x7B53, 0xF257},
  /* U+8E__ */	{0xFF, 0x00, 0x7B53, 0xF357},	{0xFF, 0x00, 0x7B53, 0xF457},
  /* U+90__ */	{0xFF, 0x00, 0x7B53, 0xF557},	{0xFF, 0x00, 0x7B53, 0xF657},
  /* U+92__ */	{0xFF, 0x00, 0x7B53, 0xF757},	{0xD5, 0xFF, 0x7B53, 0xF857},
  /* U+94__ */	{0x00, 0xBD, 0x7B53, 0xF96C},	{0xFF, 0x00, 0x7F59, 0xFA6C},
  /* U+96__ */	{0xFF, 0x00, 0x7F59, 0xFB6C},	{0xFF, 0x00, 0x7F59, 0xFC6C},
  /* U+98__ */	{0xC4, 0xFF, 0x7F59, 0xFD6C},	{0x00, 0xE1, 0x7F59, 0xFF04},
};

static const indextbl_t __ucs_to_gb18030_index[256] = {
  /* 0x00__ */	{0x80, 0xFF, 0x0080, 0x0000},	{0x00, 0xFF, 0x0080, 0x0000},
  /* 0x02__ */	{0x00, 0xFF, 0x0080, 0x0000},	{0x00, 0xFF, 0x0080, 0x0000},
  /* 0x04__ */	{0x00, 0x51, 0x0080, 0x02E2},	{0xFF, 0x00, 0x1C3E, 0x03E2},
  /* 0x06__ */	{0xFF, 0x00, 0x1C3E, 0x04E2},	{0xFF, 0x00, 0x1C3E, 0x05E2},
  /* 0x08__ */	{0xFF, 0x00, 0x1C3E, 0x06E2},	{0xFF, 0x00, 0x1C3E, 0x07E2},
  /* 0x0A__ */	{0xFF, 0x00, 0x1C3E, 0x08E2},	{0xFF, 0x00, 0x1C3E, 0x09E2},
  /* 0x0C__ */	{0xFF, 0x00, 0x1C3E, 0x0AE2},	{0xFF, 0x00, 0x1C3E, 0x0BE2},
  /* 0x0E__ */	{0xFF, 0x00, 0x1C3E, 0x0CE2},	{0xFF, 0x00, 0x1C3E, 0x0DE2},
  /* 0x10__ */	{0xFF, 0x00, 0x1C3E, 0x0EE2},	{0xFF, 0x00, 0x1C3E, 0x0FE2},
  /* 0x12__ */	{0xFF, 0x00, 0x1C3E, 0x10E2},	{0xFF, 0x00, 0x1C3E, 0x11E2},
  /* 0x14__ */	{0xFF, 0x00, 0x1C3E, 0x12E2},	{0xFF, 0x00, 0x1C3E, 0x13E2},
  /* 0x16__ */	{0xFF, 0x00, 0x1C3E, 0x14E2},	{0xFF, 0x00, 0x1C3E, 0x15E2},
  /* 0x18__ */	{0xFF, 0x00, 0x1C3E, 0x16E2},	{0xFF, 0x00, 0x1C3E, 0x17E2},
  /* 0x1A__ */	{0xFF, 0x00, 0x1C3E, 0x18E2},	{0xFF, 0x00, 0x1C3E, 0x19E2},
  /* 0x1C__ */	{0xFF, 0x00, 0x1C3E, 0x1AE2},	{0xFF, 0x00, 0x1C3E, 0x1BE2},
  /* 0x1E__ */	{0xFF, 0x00, 0x1C3E, 0x1CE2},	{0xFF, 0x00, 0x1C3E, 0x1DE2},
  /* 0x20__ */	{0x10, 0xFF, 0x1C3E, 0x1EE2},	{0x00, 0xFF, 0x1C3E, 0x0000},
  /* 0x22__ */	{0x00, 0xFF, 0x1C3E, 0x0000},	{0x00, 0xFF, 0x1C3E, 0x0000},
  /* 0x24__ */	{0x00, 0xFF, 0x1C3E, 0x0000},	{0x00, 0xFF, 0x1C3E, 0x0000},
  /* 0x26__ */	{0x00, 0x42, 0x1C3E, 0x23C0},	{0xFF, 0x00, 0x247C, 0x24C0},
  /* 0x28__ */	{0xFF, 0x00, 0x247C, 0x25C0},	{0xFF, 0x00, 0x247C, 0x26C0},
  /* 0x2A__ */	{0xFF, 0x00, 0x247C, 0x27C0},	{0xFF, 0x00, 0x247C, 0x28C0},
  /* 0x2C__ */	{0xFF, 0x00, 0x247C, 0x29C0},	{0xFF, 0x00, 0x247C, 0x2AC0},
  /* 0x2E__ */	{0x81, 0xFF, 0x247C, 0x2BC0},	{0x00, 0xFF, 0x247C, 0x0000},
  /* 0x30__ */	{0x00, 0xFF, 0x247C, 0x0000},	{0x00, 0xFF, 0x247C, 0x0000},
  /* 0x32__ */	{0x00, 0xFF, 0x247C, 0x0000},	{0x00, 0xFF, 0x247C, 0x0000},
  /* 0x34__ */	{0x00, 0xFF, 0x247C, 0x0000},	{0x00, 0xFF, 0x247C, 0x0000},
  /* 0x36__ */	{0x00, 0x1A, 0x247C, 0x3292},	{0xFF, 0x00, 0x2779, 0x3392},
  /* 0x38__ */	{0xFF, 0x00, 0x2779, 0x3492},	{0x18, 0xFF, 0x2779, 0x3592},
  /* 0x3A__ */	{0x00, 0xFF, 0x2779, 0x0000},	{0x00, 0xFF, 0x2779, 0x0000},
  /* 0x3C__ */	{0x00, 0xE0, 0x2779, 0x3889},	{0xFF, 0x00, 0x2AEE, 0x3989},
  /* 0x3E__ */	{0xFF, 0x00, 0x2AEE, 0x3A89},	{0xFF, 0x00, 0x2AEE, 0x3B89},
  /* 0x40__ */	{0x56, 0xFF, 0x2AEE, 0x3C89},	{0x00, 0x5F, 0x2AEE, 0x3D87},
  /* 0x42__ */	{0xFF, 0x00, 0x2CC5, 0x3E87},	{0x37, 0xFF, 0x2CC5, 0x3F87},
  /* 0x44__ */	{0x00, 0xD6, 0x2CC5, 0x4082},	{0xFF, 0x00, 0x2E3A, 0x4182},
  /* 0x46__ */	{0x4C, 0xFF, 0x2E3A, 0x4282},	{0x00, 0x8D, 0x2E3A, 0x437C},
  /* 0x48__ */	{0xFF, 0x00, 0x2FF3, 0x447C},	{0x47, 0xB7, 0x2FF3, 0x457C},
  /* 0x4A__ */	{0xFF, 0x00, 0x32B2, 0x4671},	{0xFF, 0x00, 0x32B2, 0x4771},
  /* 0x4C__ */	{0x77, 0xFF, 0x32B2, 0x4871},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x4E__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x50__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x52__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x54__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x56__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x58__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x5A__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x5C__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x5E__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x60__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x62__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x64__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x66__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x68__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x6A__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x6C__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x6E__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x70__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x72__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x74__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x76__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x78__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x7A__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x7C__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x7E__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x80__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x82__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x84__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x86__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x88__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x8A__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x8C__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x8E__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x90__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x92__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x94__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x96__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x98__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x9A__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x9C__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xFF, 0x32B2, 0x0000},
  /* 0x9E__ */	{0x00, 0xFF, 0x32B2, 0x0000},	{0x00, 0xA5, 0x32B2, 0x49BD},
  /* 0xA0__ */	{0xFF, 0x00, 0x6B0C, 0x4ABD},	{0xFF, 0x00, 0x6B0C, 0x4BBD},
  /* 0xA2__ */	{0xFF, 0x00, 0x6B0C, 0x4CBD},	{0xFF, 0x00, 0x6B0C, 0x4DBD},
  /* 0xA4__ */	{0xFF, 0x00, 0x6B0C, 0x4EBD},	{0xFF, 0x00, 0x6B0C, 0x4FBD},
  /* 0xA6__ */	{0xFF, 0x00, 0x6B0C, 0x50BD},	{0xFF, 0x00, 0x6B0C, 0x51BD},
  /* 0xA8__ */	{0xFF, 0x00, 0x6B0C, 0x52BD},	{0xFF, 0x00, 0x6B0C, 0x53BD},
  /* 0xAA__ */	{0xFF, 0x00, 0x6B0C, 0x54BD},	{0xFF, 0x00, 0x6B0C, 0x55BD},
  /* 0xAC__ */	{0xFF, 0x00, 0x6B0C, 0x56BD},	{0xFF, 0x00, 0x6B0C, 0x57BD},
  /* 0xAE__ */	{0xFF, 0x00, 0x6B0C, 0x58BD},	{0xFF, 0x00, 0x6B0C, 0x59BD},
  /* 0xB0__ */	{0xFF, 0x00, 0x6B0C, 0x5ABD},	{0xFF, 0x00, 0x6B0C, 0x5BBD},
  /* 0xB2__ */	{0xFF, 0x00, 0x6B0C, 0x5CBD},	{0xFF, 0x00, 0x6B0C, 0x5DBD},
  /* 0xB4__ */	{0xFF, 0x00, 0x6B0C, 0x5EBD},	{0xFF, 0x00, 0x6B0C, 0x5FBD},
  /* 0xB6__ */	{0xFF, 0x00, 0x6B0C, 0x60BD},	{0xFF, 0x00, 0x6B0C, 0x61BD},
  /* 0xB8__ */	{0xFF, 0x00, 0x6B0C, 0x62BD},	{0xFF, 0x00, 0x6B0C, 0x63BD},
  /* 0xBA__ */	{0xFF, 0x00, 0x6B0C, 0x64BD},	{0xFF, 0x00, 0x6B0C, 0x65BD},
  /* 0xBC__ */	{0xFF, 0x00, 0x6B0C, 0x66BD},	{0xFF, 0x00, 0x6B0C, 0x67BD},
  /* 0xBE__ */	{0xFF, 0x00, 0x6B0C, 0x68BD},	{0xFF, 0x00, 0x6B0C, 0x69BD},
  /* 0xC0__ */	{0xFF, 0x00, 0x6B0C, 0x6ABD},	{0xFF, 0x00, 0x6B0C, 0x6BBD},
  /* 0xC2__ */	{0xFF, 0x00, 0x6B0C, 0x6CBD},	{0xFF, 0x00, 0x6B0C, 0x6DBD},
  /* 0xC4__ */	{0xFF, 0x00, 0x6B0C, 0x6EBD},	{0xFF, 0x00, 0x6B0C, 0x6FBD},
  /* 0xC6__ */	{0xFF, 0x00, 0x6B0C, 0x70BD},	{0xFF, 0x00, 0x6B0C, 0x71BD},
  /* 0xC8__ */	{0xFF, 0x00, 0x6B0C, 0x72BD},	{0xFF, 0x00, 0x6B0C, 0x73BD},
  /* 0xCA__ */	{0xFF, 0x00, 0x6B0C, 0x74BD},	{0xFF, 0x00, 0x6B0C, 0x75BD},
  /* 0xCC__ */	{0xFF, 0x00, 0x6B0C, 0x76BD},	{0xFF, 0x00, 0x6B0C, 0x77BD},
  /* 0xCE__ */	{0xFF, 0x00, 0x6B0C, 0x78BD},	{0xFF, 0x00, 0x6B0C, 0x79BD},
  /* 0xD0__ */	{0xFF, 0x00, 0x6B0C, 0x7ABD},	{0xFF, 0x00, 0x6B0C, 0x7BBD},
  /* 0xD2__ */	{0xFF, 0x00, 0x6B0C, 0x7CBD},	{0xFF, 0x00, 0x6B0C, 0x7DBD},
  /* 0xD4__ */	{0xFF, 0x00, 0x6B0C, 0x7EBD},	{0xFF, 0x00, 0x6B0C, 0x7FBD},
  /* 0xD6__ */	{0xFF, 0x00, 0x6B0C, 0x80BD},	{0xFF, 0x00, 0x6B0C, 0x81BD},
  /* 0xD8__ */	{0xFF, 0x00, 0x6B0C, 0x0000},	{0xFF, 0x00, 0x6B0C, 0x0000},
  /* 0xDA__ */	{0xFF, 0x00, 0x6B0C, 0x0000},	{0xFF, 0x00, 0x6B0C, 0x0000},
  /* 0xDC__ */	{0xFF, 0x00, 0x6B0C, 0x0000},	{0xFF, 0x00, 0x6B0C, 0x0000},
  /* 0xDE__ */	{0xFF, 0x00, 0x6B0C, 0x0000},	{0xFF, 0x00, 0x6B0C, 0x0000},
  /* 0xE0__ */	{0xFF, 0x00, 0x7A72, 0x0000},	{0xFF, 0x00, 0x7A72, 0x0000},
  /* 0xE2__ */	{0xFF, 0x00, 0x7A72, 0x0000},	{0xFF, 0x00, 0x7A72, 0x0000},
  /* 0xE4__ */	{0xFF, 0x00, 0x7A72, 0x0000},	{0xFF, 0x00, 0x7A72, 0x0000},
  /* 0xE6__ */	{0xFF, 0x00, 0x7A72, 0x0000},	{0x66, 0xFF, 0x7A72, 0x0000},
  /* 0xE8__ */	{0x00, 0x64, 0x7A72, 0x82A9},	{0xFF, 0x00, 0x8B39, 0x83A9},
  /* 0xEA__ */	{0xFF, 0x00, 0x8B39, 0x84A9},	{0xFF, 0x00, 0x8B39, 0x85A9},
  /* 0xEC__ */	{0xFF, 0x00, 0x8B39, 0x86A9},	{0xFF, 0x00, 0x8B39, 0x87A9},
  /* 0xEE__ */	{0xFF, 0x00, 0x8B39, 0x88A9},	{0xFF, 0x00, 0x8B39, 0x89A9},
  /* 0xF0__ */	{0xFF, 0x00, 0x8B39, 0x8AA9},	{0xFF, 0x00, 0x8B39, 0x8BA9},
  /* 0xF2__ */	{0xFF, 0x00, 0x8B39, 0x8CA9},	{0xFF, 0x00, 0x8B39, 0x8DA9},
  /* 0xF4__ */	{0xFF, 0x00, 0x8B39, 0x8EA9},	{0xFF, 0x00, 0x8B39, 0x8FA9},
  /* 0xF6__ */	{0xFF, 0x00, 0x8B39, 0x90A9},	{0xFF, 0x00, 0x8B39, 0x91A9},
  /* 0xF8__ */	{0xFF, 0x00, 0x8B39, 0x92A9},	{0x2C, 0xFF, 0x8B39, 0x93A9},
  /* 0xFA__ */	{0x00, 0x29, 0x8B39, 0x9494},	{0xFF, 0x00, 0x8F3F, 0x9594},
  /* 0xFC__ */	{0xFF, 0x00, 0x8F3F, 0x9694},	{0xFF, 0x00, 0x8F3F, 0x9794},
  /* 0xFE__ */	{0x30, 0xFF, 0x8F3F, 0x9894},	{0x00, 0xE5, 0x8F3F, 0x98FC},
};

static const unsigned char __ucs_to_gb18030[28839][2] = {
  /* Contiguous area: U+0080 .. U+0451 */
  /* U+0080 */	"\x00\x00", "\x00\x01", "\x00\x02", "\x00\x03",
  /* U+0084 */	"\x00\x04", "\x00\x05", "\x00\x06", "\x00\x07",
  /* U+0088 */	"\x00\x08", "\x00\x09", "\x00\x10", "\x00\x11",
  /* U+008C */	"\x00\x12", "\x00\x13", "\x00\x14", "\x00\x15",
  /* U+0090 */	"\x00\x16", "\x00\x17", "\x00\x18", "\x00\x19",
  /* U+0094 */	"\x00\x20", "\x00\x21", "\x00\x22", "\x00\x23",
  /* U+0098 */	"\x00\x24", "\x00\x25", "\x00\x26", "\x00\x27",
  /* U+009C */	"\x00\x28", "\x00\x29", "\x00\x30", "\x00\x31",
  /* U+00A0 */	"\x00\x32", "\x00\x33", "\x00\x34", "\x00\x35",
  /* U+00A4 */	"\xA1\xE8", "\x00\x36", "\x00\x37", "\xA1\xEC",
  /* U+00A8 */	"\xA1\xA7", "\x00\x38", "\x00\x39", "\x00\x40",
  /* U+00AC */	"\x00\x41", "\x00\x42", "\x00\x43", "\x00\x44",
  /* U+00B0 */	"\xA1\xE3", "\xA1\xC0", "\x00\x45", "\x00\x46",
  /* U+00B4 */	"\x00\x47", "\x00\x48", "\x00\x49", "\xA1\xA4",
  /* U+00B8 */	"\x00\x50", "\x00\x51", "\x00\x52", "\x00\x53",
  /* U+00BC */	"\x00\x54", "\x00\x55", "\x00\x56", "\x00\x57",
  /* U+00C0 */	"\x00\x58", "\x00\x59", "\x00\x60", "\x00\x61",
  /* U+00C4 */	"\x00\x62", "\x00\x63", "\x00\x64", "\x00\x65",
  /* U+00C8 */	"\x00\x66", "\x00\x67", "\x00\x68", "\x00\x69",
  /* U+00CC */	"\x00\x70", "\x00\x71", "\x00\x72", "\x00\x73",
  /* U+00D0 */	"\x00\x74", "\x00\x75", "\x00\x76", "\x00\x77",
  /* U+00D4 */	"\x00\x78", "\x00\x79", "\x00\x80", "\xA1\xC1",
  /* U+00D8 */	"\x00\x81", "\x00\x82", "\x00\x83", "\x00\x84",
  /* U+00DC */	"\x00\x85", "\x00\x86", "\x00\x87", "\x00\x88",
  /* U+00E0 */	"\xA8\xA4", "\xA8\xA2", "\x00\x89", "\x00\x90",
  /* U+00E4 */	"\x00\x91", "\x00\x92", "\x00\x93", "\x00\x94",
  /* U+00E8 */	"\xA8\xA8", "\xA8\xA6", "\xA8\xBA", "\x00\x95",
  /* U+00EC */	"\xA8\xAC", "\xA8\xAA", "\x00\x96", "\x00\x97",
  /* U+00F0 */	"\x00\x98", "\x00\x99", "\xA8\xB0", "\xA8\xAE",
  /* U+00F4 */	"\x00\xA0", "\x00\xA1", "\x00\xA2", "\xA1\xC2",
  /* U+00F8 */	"\x00\xA3", "\xA8\xB4", "\xA8\xB2", "\x00\xA4",
  /* U+00FC */	"\xA8\xB9", "\x00\xA5", "\x00\xA6", "\x00\xA7",
  /* U+0100 */	"\x00\xA8", "\xA8\xA1", "\x00\xA9", "\x00\xB0",
  /* U+0104 */	"\x00\xB1", "\x00\xB2", "\x00\xB3", "\x00\xB4",
  /* U+0108 */	"\x00\xB5", "\x00\xB6", "\x00\xB7", "\x00\xB8",
  /* U+010C */	"\x00\xB9", "\x00\xC0", "\x00\xC1", "\x00\xC2",
  /* U+0110 */	"\x00\xC3", "\x00\xC4", "\x00\xC5", "\xA8\xA5",
  /* U+0114 */	"\x00\xC6", "\x00\xC7", "\x00\xC8", "\x00\xC9",
  /* U+0118 */	"\x00\xD0", "\x00\xD1", "\x00\xD2", "\xA8\xA7",
  /* U+011C */	"\x00\xD3", "\x00\xD4", "\x00\xD5", "\x00\xD6",
  /* U+0120 */	"\x00\xD7", "\x00\xD8", "\x00\xD9", "\x00\xE0",
  /* U+0124 */	"\x00\xE1", "\x00\xE2", "\x00\xE3", "\x00\xE4",
  /* U+0128 */	"\x00\xE5", "\x00\xE6", "\x00\xE7", "\xA8\xA9",
  /* U+012C */	"\x00\xE8", "\x00\xE9", "\x00\xF0", "\x00\xF1",
  /* U+0130 */	"\x00\xF2", "\x00\xF3", "\x00\xF4", "\x00\xF5",
  /* U+0134 */	"\x00\xF6", "\x00\xF7", "\x00\xF8", "\x00\xF9",
  /* U+0138 */	"\x01\x00", "\x01\x01", "\x01\x02", "\x01\x03",
  /* U+013C */	"\x01\x04", "\x01\x05", "\x01\x06", "\x01\x07",
  /* U+0140 */	"\x01\x08", "\x01\x09", "\x01\x10", "\x01\x11",
  /* U+0144 */	"\xA8\xBD", "\x01\x12", "\x01\x13", "\x01\x14",
  /* U+0148 */	"\xA8\xBE", "\x01\x15", "\x01\x16", "\x01\x17",
  /* U+014C */	"\x01\x18", "\xA8\xAD", "\x01\x19", "\x01\x20",
  /* U+0150 */	"\x01\x21", "\x01\x22", "\x01\x23", "\x01\x24",
  /* U+0154 */	"\x01\x25", "\x01\x26", "\x01\x27", "\x01\x28",
  /* U+0158 */	"\x01\x29", "\x01\x30", "\x01\x31", "\x01\x32",
  /* U+015C */	"\x01\x33", "\x01\x34", "\x01\x35", "\x01\x36",
  /* U+0160 */	"\x01\x37", "\x01\x38", "\x01\x39", "\x01\x40",
  /* U+0164 */	"\x01\x41", "\x01\x42", "\x01\x43", "\x01\x44",
  /* U+0168 */	"\x01\x45", "\x01\x46", "\x01\x47", "\xA8\xB1",
  /* U+016C */	"\x01\x48", "\x01\x49", "\x01\x50", "\x01\x51",
  /* U+0170 */	"\x01\x52", "\x01\x53", "\x01\x54", "\x01\x55",
  /* U+0174 */	"\x01\x56", "\x01\x57", "\x01\x58", "\x01\x59",
  /* U+0178 */	"\x01\x60", "\x01\x61", "\x01\x62", "\x01\x63",
  /* U+017C */	"\x01\x64", "\x01\x65", "\x01\x66", "\x01\x67",
  /* U+0180 */	"\x01\x68", "\x01\x69", "\x01\x70", "\x01\x71",
  /* U+0184 */	"\x01\x72", "\x01\x73", "\x01\x74", "\x01\x75",
  /* U+0188 */	"\x01\x76", "\x01\x77", "\x01\x78", "\x01\x79",
  /* U+018C */	"\x01\x80", "\x01\x81", "\x01\x82", "\x01\x83",
  /* U+0190 */	"\x01\x84", "\x01\x85", "\x01\x86", "\x01\x87",
  /* U+0194 */	"\x01\x88", "\x01\x89", "\x01\x90", "\x01\x91",
  /* U+0198 */	"\x01\x92", "\x01\x93", "\x01\x94", "\x01\x95",
  /* U+019C */	"\x01\x96", "\x01\x97", "\x01\x98", "\x01\x99",
  /* U+01A0 */	"\x01\xA0", "\x01\xA1", "\x01\xA2", "\x01\xA3",
  /* U+01A4 */	"\x01\xA4", "\x01\xA5", "\x01\xA6", "\x01\xA7",
  /* U+01A8 */	"\x01\xA8", "\x01\xA9", "\x01\xB0", "\x01\xB1",
  /* U+01AC */	"\x01\xB2", "\x01\xB3", "\x01\xB4", "\x01\xB5",
  /* U+01B0 */	"\x01\xB6", "\x01\xB7", "\x01\xB8", "\x01\xB9",
  /* U+01B4 */	"\x01\xC0", "\x01\xC1", "\x01\xC2", "\x01\xC3",
  /* U+01B8 */	"\x01\xC4", "\x01\xC5", "\x01\xC6", "\x01\xC7",
  /* U+01BC */	"\x01\xC8", "\x01\xC9", "\x01\xD0", "\x01\xD1",
  /* U+01C0 */	"\x01\xD2", "\x01\xD3", "\x01\xD4", "\x01\xD5",
  /* U+01C4 */	"\x01\xD6", "\x01\xD7", "\x01\xD8", "\x01\xD9",
  /* U+01C8 */	"\x01\xE0", "\x01\xE1", "\x01\xE2", "\x01\xE3",
  /* U+01CC */	"\x01\xE4", "\x01\xE5", "\xA8\xA3", "\x01\xE6",
  /* U+01D0 */	"\xA8\xAB", "\x01\xE7", "\xA8\xAF", "\x01\xE8",
  /* U+01D4 */	"\xA8\xB3", "\x01\xE9", "\xA8\xB5", "\x01\xF0",
  /* U+01D8 */	"\xA8\xB6", "\x01\xF1", "\xA8\xB7", "\x01\xF2",
  /* U+01DC */	"\xA8\xB8", "\x01\xF3", "\x01\xF4", "\x01\xF5",
  /* U+01E0 */	"\x01\xF6", "\x01\xF7", "\x01\xF8", "\x01\xF9",
  /* U+01E4 */	"\x02\x00", "\x02\x01", "\x02\x02", "\x02\x03",
  /* U+01E8 */	"\x02\x04", "\x02\x05", "\x02\x06", "\x02\x07",
  /* U+01EC */	"\x02\x08", "\x02\x09", "\x02\x10", "\x02\x11",
  /* U+01F0 */	"\x02\x12", "\x02\x13", "\x02\x14", "\x02\x15",
  /* U+01F4 */	"\x02\x16", "\x02\x17", "\x02\x18", "\x02\x19",
  /* U+01F8 */	"\x02\x20", "\xA8\xBF", "\x02\x21", "\x02\x22",
  /* U+01FC */	"\x02\x23", "\x02\x24", "\x02\x25", "\x02\x26",
  /* U+0200 */	"\x02\x27", "\x02\x28", "\x02\x29", "\x02\x30",
  /* U+0204 */	"\x02\x31", "\x02\x32", "\x02\x33", "\x02\x34",
  /* U+0208 */	"\x02\x35", "\x02\x36", "\x02\x37", "\x02\x38",
  /* U+020C */	"\x02\x39", "\x02\x40", "\x02\x41", "\x02\x42",
  /* U+0210 */	"\x02\x43", "\x02\x44", "\x02\x45", "\x02\x46",
  /* U+0214 */	"\x02\x47", "\x02\x48", "\x02\x49", "\x02\x50",
  /* U+0218 */	"\x02\x51", "\x02\x52", "\x02\x53", "\x02\x54",
  /* U+021C */	"\x02\x55", "\x02\x56", "\x02\x57", "\x02\x58",
  /* U+0220 */	"\x02\x59", "\x02\x60", "\x02\x61", "\x02\x62",
  /* U+0224 */	"\x02\x63", "\x02\x64", "\x02\x65", "\x02\x66",
  /* U+0228 */	"\x02\x67", "\x02\x68", "\x02\x69", "\x02\x70",
  /* U+022C */	"\x02\x71", "\x02\x72", "\x02\x73", "\x02\x74",
  /* U+0230 */	"\x02\x75", "\x02\x76", "\x02\x77", "\x02\x78",
  /* U+0234 */	"\x02\x79", "\x02\x80", "\x02\x81", "\x02\x82",
  /* U+0238 */	"\x02\x83", "\x02\x84", "\x02\x85", "\x02\x86",
  /* U+023C */	"\x02\x87", "\x02\x88", "\x02\x89", "\x02\x90",
  /* U+0240 */	"\x02\x91", "\x02\x92", "\x02\x93", "\x02\x94",
  /* U+0244 */	"\x02\x95", "\x02\x96", "\x02\x97", "\x02\x98",
  /* U+0248 */	"\x02\x99", "\x02\xA0", "\x02\xA1", "\x02\xA2",
  /* U+024C */	"\x02\xA3", "\x02\xA4", "\x02\xA5", "\x02\xA6",
  /* U+0250 */	"\x02\xA7", "\xA8\xBB", "\x02\xA8", "\x02\xA9",
  /* U+0254 */	"\x02\xB0", "\x02\xB1", "\x02\xB2", "\x02\xB3",
  /* U+0258 */	"\x02\xB4", "\x02\xB5", "\x02\xB6", "\x02\xB7",
  /* U+025C */	"\x02\xB8", "\x02\xB9", "\x02\xC0", "\x02\xC1",
  /* U+0260 */	"\x02\xC2", "\xA8\xC0", "\x02\xC3", "\x02\xC4",
  /* U+0264 */	"\x02\xC5", "\x02\xC6", "\x02\xC7", "\x02\xC8",
  /* U+0268 */	"\x02\xC9", "\x02\xD0", "\x02\xD1", "\x02\xD2",
  /* U+026C */	"\x02\xD3", "\x02\xD4", "\x02\xD5", "\x02\xD6",
  /* U+0270 */	"\x02\xD7", "\x02\xD8", "\x02\xD9", "\x02\xE0",
  /* U+0274 */	"\x02\xE1", "\x02\xE2", "\x02\xE3", "\x02\xE4",
  /* U+0278 */	"\x02\xE5", "\x02\xE6", "\x02\xE7", "\x02\xE8",
  /* U+027C */	"\x02\xE9", "\x02\xF0", "\x02\xF1", "\x02\xF2",
  /* U+0280 */	"\x02\xF3", "\x02\xF4", "\x02\xF5", "\x02\xF6",
  /* U+0284 */	"\x02\xF7", "\x02\xF8", "\x02\xF9", "\x03\x00",
  /* U+0288 */	"\x03\x01", "\x03\x02", "\x03\x03", "\x03\x04",
  /* U+028C */	"\x03\x05", "\x03\x06", "\x03\x07", "\x03\x08",
  /* U+0290 */	"\x03\x09", "\x03\x10", "\x03\x11", "\x03\x12",
  /* U+0294 */	"\x03\x13", "\x03\x14", "\x03\x15", "\x03\x16",
  /* U+0298 */	"\x03\x17", "\x03\x18", "\x03\x19", "\x03\x20",
  /* U+029C */	"\x03\x21", "\x03\x22", "\x03\x23", "\x03\x24",
  /* U+02A0 */	"\x03\x25", "\x03\x26", "\x03\x27", "\x03\x28",
  /* U+02A4 */	"\x03\x29", "\x03\x30", "\x03\x31", "\x03\x32",
  /* U+02A8 */	"\x03\x33", "\x03\x34", "\x03\x35", "\x03\x36",
  /* U+02AC */	"\x03\x37", "\x03\x38", "\x03\x39", "\x03\x40",
  /* U+02B0 */	"\x03\x41", "\x03\x42", "\x03\x43", "\x03\x44",
  /* U+02B4 */	"\x03\x45", "\x03\x46", "\x03\x47", "\x03\x48",
  /* U+02B8 */	"\x03\x49", "\x03\x50", "\x03\x51", "\x03\x52",
  /* U+02BC */	"\x03\x53", "\x03\x54", "\x03\x55", "\x03\x56",
  /* U+02C0 */	"\x03\x57", "\x03\x58", "\x03\x59", "\x03\x60",
  /* U+02C4 */	"\x03\x61", "\x03\x62", "\x03\x63", "\xA1\xA6",
  /* U+02C8 */	"\x03\x64", "\xA1\xA5", "\xA8\x40", "\xA8\x41",
  /* U+02CC */	"\x03\x65", "\x03\x66", "\x03\x67", "\x03\x68",
  /* U+02D0 */	"\x03\x69", "\x03\x70", "\x03\x71", "\x03\x72",
  /* U+02D4 */	"\x03\x73", "\x03\x74", "\x03\x75", "\x03\x76",
  /* U+02D8 */	"\x03\x77", "\xA8\x42", "\x03\x78", "\x03\x79",
  /* U+02DC */	"\x03\x80", "\x03\x81", "\x03\x82", "\x03\x83",
  /* U+02E0 */	"\x03\x84", "\x03\x85", "\x03\x86", "\x03\x87",
  /* U+02E4 */	"\x03\x88", "\x03\x89", "\x03\x90", "\x03\x91",
  /* U+02E8 */	"\x03\x92", "\x03\x93", "\x03\x94", "\x03\x95",
  /* U+02EC */	"\x03\x96", "\x03\x97", "\x03\x98", "\x03\x99",
  /* U+02F0 */	"\x03\xA0", "\x03\xA1", "\x03\xA2", "\x03\xA3",
  /* U+02F4 */	"\x03\xA4", "\x03\xA5", "\x03\xA6", "\x03\xA7",
  /* U+02F8 */	"\x03\xA8", "\x03\xA9", "\x03\xB0", "\x03\xB1",
  /* U+02FC */	"\x03\xB2", "\x03\xB3", "\x03\xB4", "\x03\xB5",
  /* U+0300 */	"\x03\xB6", "\x03\xB7", "\x03\xB8", "\x03\xB9",
  /* U+0304 */	"\x03\xC0", "\x03\xC1", "\x03\xC2", "\x03\xC3",
  /* U+0308 */	"\x03\xC4", "\x03\xC5", "\x03\xC6", "\x03\xC7",
  /* U+030C */	"\x03\xC8", "\x03\xC9", "\x03\xD0", "\x03\xD1",
  /* U+0310 */	"\x03\xD2", "\x03\xD3", "\x03\xD4", "\x03\xD5",
  /* U+0314 */	"\x03\xD6", "\x03\xD7", "\x03\xD8", "\x03\xD9",
  /* U+0318 */	"\x03\xE0", "\x03\xE1", "\x03\xE2", "\x03\xE3",
  /* U+031C */	"\x03\xE4", "\x03\xE5", "\x03\xE6", "\x03\xE7",
  /* U+0320 */	"\x03\xE8", "\x03\xE9", "\x03\xF0", "\x03\xF1",
  /* U+0324 */	"\x03\xF2", "\x03\xF3", "\x03\xF4", "\x03\xF5",
  /* U+0328 */	"\x03\xF6", "\x03\xF7", "\x03\xF8", "\x03\xF9",
  /* U+032C */	"\x04\x00", "\x04\x01", "\x04\x02", "\x04\x03",
  /* U+0330 */	"\x04\x04", "\x04\x05", "\x04\x06", "\x04\x07",
  /* U+0334 */	"\x04\x08", "\x04\x09", "\x04\x10", "\x04\x11",
  /* U+0338 */	"\x04\x12", "\x04\x13", "\x04\x14", "\x04\x15",
  /* U+033C */	"\x04\x16", "\x04\x17", "\x04\x18", "\x04\x19",
  /* U+0340 */	"\x04\x20", "\x04\x21", "\x04\x22", "\x04\x23",
  /* U+0344 */	"\x04\x24", "\x04\x25", "\x04\x26", "\x04\x27",
  /* U+0348 */	"\x04\x28", "\x04\x29", "\x04\x30", "\x04\x31",
  /* U+034C */	"\x04\x32", "\x04\x33", "\x04\x34", "\x04\x35",
  /* U+0350 */	"\x04\x36", "\x04\x37", "\x04\x38", "\x04\x39",
  /* U+0354 */	"\x04\x40", "\x04\x41", "\x04\x42", "\x04\x43",
  /* U+0358 */	"\x04\x44", "\x04\x45", "\x04\x46", "\x04\x47",
  /* U+035C */	"\x04\x48", "\x04\x49", "\x04\x50", "\x04\x51",
  /* U+0360 */	"\x04\x52", "\x04\x53", "\x04\x54", "\x04\x55",
  /* U+0364 */	"\x04\x56", "\x04\x57", "\x04\x58", "\x04\x59",
  /* U+0368 */	"\x04\x60", "\x04\x61", "\x04\x62", "\x04\x63",
  /* U+036C */	"\x04\x64", "\x04\x65", "\x04\x66", "\x04\x67",
  /* U+0370 */	"\x04\x68", "\x04\x69", "\x04\x70", "\x04\x71",
  /* U+0374 */	"\x04\x72", "\x04\x73", "\x04\x74", "\x04\x75",
  /* U+0378 */	"\x04\x76", "\x04\x77", "\x04\x78", "\x04\x79",
  /* U+037C */	"\x04\x80", "\x04\x81", "\x04\x82", "\x04\x83",
  /* U+0380 */	"\x04\x84", "\x04\x85", "\x04\x86", "\x04\x87",
  /* U+0384 */	"\x04\x88", "\x04\x89", "\x04\x90", "\x04\x91",
  /* U+0388 */	"\x04\x92", "\x04\x93", "\x04\x94", "\x04\x95",
  /* U+038C */	"\x04\x96", "\x04\x97", "\x04\x98", "\x04\x99",
  /* U+0390 */	"\x04\xA0", "\xA6\xA1", "\xA6\xA2", "\xA6\xA3",
  /* U+0394 */	"\xA6\xA4", "\xA6\xA5", "\xA6\xA6", "\xA6\xA7",
  /* U+0398 */	"\xA6\xA8", "\xA6\xA9", "\xA6\xAA", "\xA6\xAB",
  /* U+039C */	"\xA6\xAC", "\xA6\xAD", "\xA6\xAE", "\xA6\xAF",
  /* U+03A0 */	"\xA6\xB0", "\xA6\xB1", "\x04\xA1", "\xA6\xB2",
  /* U+03A4 */	"\xA6\xB3", "\xA6\xB4", "\xA6\xB5", "\xA6\xB6",
  /* U+03A8 */	"\xA6\xB7", "\xA6\xB8", "\x04\xA2", "\x04\xA3",
  /* U+03AC */	"\x04\xA4", "\x04\xA5", "\x04\xA6", "\x04\xA7",
  /* U+03B0 */	"\x04\xA8", "\xA6\xC1", "\xA6\xC2", "\xA6\xC3",
  /* U+03B4 */	"\xA6\xC4", "\xA6\xC5", "\xA6\xC6", "\xA6\xC7",
  /* U+03B8 */	"\xA6\xC8", "\xA6\xC9", "\xA6\xCA", "\xA6\xCB",
  /* U+03BC */	"\xA6\xCC", "\xA6\xCD", "\xA6\xCE", "\xA6\xCF",
  /* U+03C0 */	"\xA6\xD0", "\xA6\xD1", "\x04\xA9", "\xA6\xD2",
  /* U+03C4 */	"\xA6\xD3", "\xA6\xD4", "\xA6\xD5", "\xA6\xD6",
  /* U+03C8 */	"\xA6\xD7", "\xA6\xD8", "\x04\xB0", "\x04\xB1",
  /* U+03CC */	"\x04\xB2", "\x04\xB3", "\x04\xB4", "\x04\xB5",
  /* U+03D0 */	"\x04\xB6", "\x04\xB7", "\x04\xB8", "\x04\xB9",
  /* U+03D4 */	"\x04\xC0", "\x04\xC1", "\x04\xC2", "\x04\xC3",
  /* U+03D8 */	"\x04\xC4", "\x04\xC5", "\x04\xC6", "\x04\xC7",
  /* U+03DC */	"\x04\xC8", "\x04\xC9", "\x04\xD0", "\x04\xD1",
  /* U+03E0 */	"\x04\xD2", "\x04\xD3", "\x04\xD4", "\x04\xD5",
  /* U+03E4 */	"\x04\xD6", "\x04\xD7", "\x04\xD8", "\x04\xD9",
  /* U+03E8 */	"\x04\xE0", "\x04\xE1", "\x04\xE2", "\x04\xE3",
  /* U+03EC */	"\x04\xE4", "\x04\xE5", "\x04\xE6", "\x04\xE7",
  /* U+03F0 */	"\x04\xE8", "\x04\xE9", "\x04\xF0", "\x04\xF1",
  /* U+03F4 */	"\x04\xF2", "\x04\xF3", "\x04\xF4", "\x04\xF5",
  /* U+03F8 */	"\x04\xF6", "\x04\xF7", "\x04\xF8", "\x04\xF9",
  /* U+03FC */	"\x05\x00", "\x05\x01", "\x05\x02", "\x05\x03",
  /* U+0400 */	"\x05\x04", "\xA7\xA7", "\x05\x05", "\x05\x06",
  /* U+0404 */	"\x05\x07", "\x05\x08", "\x05\x09", "\x05\x10",
  /* U+0408 */	"\x05\x11", "\x05\x12", "\x05\x13", "\x05\x14",
  /* U+040C */	"\x05\x15", "\x05\x16", "\x05\x17", "\x05\x18",
  /* U+0410 */	"\xA7\xA1", "\xA7\xA2", "\xA7\xA3", "\xA7\xA4",
  /* U+0414 */	"\xA7\xA5", "\xA7\xA6", "\xA7\xA8", "\xA7\xA9",
  /* U+0418 */	"\xA7\xAA", "\xA7\xAB", "\xA7\xAC", "\xA7\xAD",
  /* U+041C */	"\xA7\xAE", "\xA7\xAF", "\xA7\xB0", "\xA7\xB1",
  /* U+0420 */	"\xA7\xB2", "\xA7\xB3", "\xA7\xB4", "\xA7\xB5",
  /* U+0424 */	"\xA7\xB6", "\xA7\xB7", "\xA7\xB8", "\xA7\xB9",
  /* U+0428 */	"\xA7\xBA", "\xA7\xBB", "\xA7\xBC", "\xA7\xBD",
  /* U+042C */	"\xA7\xBE", "\xA7\xBF", "\xA7\xC0", "\xA7\xC1",
  /* U+0430 */	"\xA7\xD1", "\xA7\xD2", "\xA7\xD3", "\xA7\xD4",
  /* U+0434 */	"\xA7\xD5", "\xA7\xD6", "\xA7\xD8", "\xA7\xD9",
  /* U+0438 */	"\xA7\xDA", "\xA7\xDB", "\xA7\xDC", "\xA7\xDD",
  /* U+043C */	"\xA7\xDE", "\xA7\xDF", "\xA7\xE0", "\xA7\xE1",
  /* U+0440 */	"\xA7\xE2", "\xA7\xE3", "\xA7\xE4", "\xA7\xE5",
  /* U+0444 */	"\xA7\xE6", "\xA7\xE7", "\xA7\xE8", "\xA7\xE9",
  /* U+0448 */	"\xA7\xEA", "\xA7\xEB", "\xA7\xEC", "\xA7\xED",
  /* U+044C */	"\xA7\xEE", "\xA7\xEF", "\xA7\xF0", "\xA7\xF1",
  /* U+0450 */	"\x05\x19", "\xA7\xD7", 
  /* Contiguous area: U+2010 .. U+2642 */
  /* U+2010 */	"\xA9\x5C", "\x0A\x42", "\x0A\x43", "\xA8\x43",
  /* U+2014 */	"\xA1\xAA", "\xA8\x44", "\xA1\xAC", "\x0A\x44",
  /* U+2018 */	"\xA1\xAE", "\xA1\xAF", "\x0A\x45", "\x0A\x46",
  /* U+201C */	"\xA1\xB0", "\xA1\xB1", "\x0A\x47", "\x0A\x48",
  /* U+2020 */	"\x0A\x49", "\x0A\x50", "\x0A\x51", "\x0A\x52",
  /* U+2024 */	"\x0A\x53", "\xA8\x45", "\xA1\xAD", "\x0A\x54",
  /* U+2028 */	"\x0A\x55", "\x0A\x56", "\x0A\x57", "\x0A\x58",
  /* U+202C */	"\x0A\x59", "\x0A\x60", "\x0A\x61", "\x0A\x62",
  /* U+2030 */	"\xA1\xEB", "\x0A\x63", "\xA1\xE4", "\xA1\xE5",
  /* U+2034 */	"\x0A\x64", "\xA8\x46", "\x0A\x65", "\x0A\x66",
  /* U+2038 */	"\x0A\x67", "\x0A\x68", "\x0A\x69", "\xA1\xF9",
  /* U+203C */	"\x0A\x70", "\x0A\x71", "\x0A\x72", "\x0A\x73",
  /* U+2040 */	"\x0A\x74", "\x0A\x75", "\x0A\x76", "\x0A\x77",
  /* U+2044 */	"\x0A\x78", "\x0A\x79", "\x0A\x80", "\x0A\x81",
  /* U+2048 */	"\x0A\x82", "\x0A\x83", "\x0A\x84", "\x0A\x85",
  /* U+204C */	"\x0A\x86", "\x0A\x87", "\x0A\x88", "\x0A\x89",
  /* U+2050 */	"\x0A\x90", "\x0A\x91", "\x0A\x92", "\x0A\x93",
  /* U+2054 */	"\x0A\x94", "\x0A\x95", "\x0A\x96", "\x0A\x97",
  /* U+2058 */	"\x0A\x98", "\x0A\x99", "\x0A\xA0", "\x0A\xA1",
  /* U+205C */	"\x0A\xA2", "\x0A\xA3", "\x0A\xA4", "\x0A\xA5",
  /* U+2060 */	"\x0A\xA6", "\x0A\xA7", "\x0A\xA8", "\x0A\xA9",
  /* U+2064 */	"\x0A\xB0", "\x0A\xB1", "\x0A\xB2", "\x0A\xB3",
  /* U+2068 */	"\x0A\xB4", "\x0A\xB5", "\x0A\xB6", "\x0A\xB7",
  /* U+206C */	"\x0A\xB8", "\x0A\xB9", "\x0A\xC0", "\x0A\xC1",
  /* U+2070 */	"\x0A\xC2", "\x0A\xC3", "\x0A\xC4", "\x0A\xC5",
  /* U+2074 */	"\x0A\xC6", "\x0A\xC7", "\x0A\xC8", "\x0A\xC9",
  /* U+2078 */	"\x0A\xD0", "\x0A\xD1", "\x0A\xD2", "\x0A\xD3",
  /* U+207C */	"\x0A\xD4", "\x0A\xD5", "\x0A\xD6", "\x0A\xD7",
  /* U+2080 */	"\x0A\xD8", "\x0A\xD9", "\x0A\xE0", "\x0A\xE1",
  /* U+2084 */	"\x0A\xE2", "\x0A\xE3", "\x0A\xE4", "\x0A\xE5",
  /* U+2088 */	"\x0A\xE6", "\x0A\xE7", "\x0A\xE8", "\x0A\xE9",
  /* U+208C */	"\x0A\xF0", "\x0A\xF1", "\x0A\xF2", "\x0A\xF3",
  /* U+2090 */	"\x0A\xF4", "\x0A\xF5", "\x0A\xF6", "\x0A\xF7",
  /* U+2094 */	"\x0A\xF8", "\x0A\xF9", "\x0B\x00", "\x0B\x01",
  /* U+2098 */	"\x0B\x02", "\x0B\x03", "\x0B\x04", "\x0B\x05",
  /* U+209C */	"\x0B\x06", "\x0B\x07", "\x0B\x08", "\x0B\x09",
  /* U+20A0 */	"\x0B\x10", "\x0B\x11", "\x0B\x12", "\x0B\x13",
  /* U+20A4 */	"\x0B\x14", "\x0B\x15", "\x0B\x16", "\x0B\x17",
  /* U+20A8 */	"\x0B\x18", "\x0B\x19", "\x0B\x20", "\x0B\x21",
  /* U+20AC */	"\xA2\xE3", "\x0B\x22", "\x0B\x23", "\x0B\x24",
  /* U+20B0 */	"\x0B\x25", "\x0B\x26", "\x0B\x27", "\x0B\x28",
  /* U+20B4 */	"\x0B\x29", "\x0B\x30", "\x0B\x31", "\x0B\x32",
  /* U+20B8 */	"\x0B\x33", "\x0B\x34", "\x0B\x35", "\x0B\x36",
  /* U+20BC */	"\x0B\x37", "\x0B\x38", "\x0B\x39", "\x0B\x40",
  /* U+20C0 */	"\x0B\x41", "\x0B\x42", "\x0B\x43", "\x0B\x44",
  /* U+20C4 */	"\x0B\x45", "\x0B\x46", "\x0B\x47", "\x0B\x48",
  /* U+20C8 */	"\x0B\x49", "\x0B\x50", "\x0B\x51", "\x0B\x52",
  /* U+20CC */	"\x0B\x53", "\x0B\x54", "\x0B\x55", "\x0B\x56",
  /* U+20D0 */	"\x0B\x57", "\x0B\x58", "\x0B\x59", "\x0B\x60",
  /* U+20D4 */	"\x0B\x61", "\x0B\x62", "\x0B\x63", "\x0B\x64",
  /* U+20D8 */	"\x0B\x65", "\x0B\x66", "\x0B\x67", "\x0B\x68",
  /* U+20DC */	"\x0B\x69", "\x0B\x70", "\x0B\x71", "\x0B\x72",
  /* U+20E0 */	"\x0B\x73", "\x0B\x74", "\x0B\x75", "\x0B\x76",
  /* U+20E4 */	"\x0B\x77", "\x0B\x78", "\x0B\x79", "\x0B\x80",
  /* U+20E8 */	"\x0B\x81", "\x0B\x82", "\x0B\x83", "\x0B\x84",
  /* U+20EC */	"\x0B\x85", "\x0B\x86", "\x0B\x87", "\x0B\x88",
  /* U+20F0 */	"\x0B\x89", "\x0B\x90", "\x0B\x91", "\x0B\x92",
  /* U+20F4 */	"\x0B\x93", "\x0B\x94", "\x0B\x95", "\x0B\x96",
  /* U+20F8 */	"\x0B\x97", "\x0B\x98", "\x0B\x99", "\x0B\xA0",
  /* U+20FC */	"\x0B\xA1", "\x0B\xA2", "\x0B\xA3", "\x0B\xA4",
  /* U+2100 */	"\x0B\xA5", "\x0B\xA6", "\x0B\xA7", "\xA1\xE6",
  /* U+2104 */	"\x0B\xA8", "\xA8\x47", "\x0B\xA9", "\x0B\xB0",
  /* U+2108 */	"\x0B\xB1", "\xA8\x48", "\x0B\xB2", "\x0B\xB3",
  /* U+210C */	"\x0B\xB4", "\x0B\xB5", "\x0B\xB6", "\x0B\xB7",
  /* U+2110 */	"\x0B\xB8", "\x0B\xB9", "\x0B\xC0", "\x0B\xC1",
  /* U+2114 */	"\x0B\xC2", "\x0B\xC3", "\xA1\xED", "\x0B\xC4",
  /* U+2118 */	"\x0B\xC5", "\x0B\xC6", "\x0B\xC7", "\x0B\xC8",
  /* U+211C */	"\x0B\xC9", "\x0B\xD0", "\x0B\xD1", "\x0B\xD2",
  /* U+2120 */	"\x0B\xD3", "\xA9\x59", "\x0B\xD4", "\x0B\xD5",
  /* U+2124 */	"\x0B\xD6", "\x0B\xD7", "\x0B\xD8", "\x0B\xD9",
  /* U+2128 */	"\x0B\xE0", "\x0B\xE1", "\x0B\xE2", "\x0B\xE3",
  /* U+212C */	"\x0B\xE4", "\x0B\xE5", "\x0B\xE6", "\x0B\xE7",
  /* U+2130 */	"\x0B\xE8", "\x0B\xE9", "\x0B\xF0", "\x0B\xF1",
  /* U+2134 */	"\x0B\xF2", "\x0B\xF3", "\x0B\xF4", "\x0B\xF5",
  /* U+2138 */	"\x0B\xF6", "\x0B\xF7", "\x0B\xF8", "\x0B\xF9",
  /* U+213C */	"\x0C\x00", "\x0C\x01", "\x0C\x02", "\x0C\x03",
  /* U+2140 */	"\x0C\x04", "\x0C\x05", "\x0C\x06", "\x0C\x07",
  /* U+2144 */	"\x0C\x08", "\x0C\x09", "\x0C\x10", "\x0C\x11",
  /* U+2148 */	"\x0C\x12", "\x0C\x13", "\x0C\x14", "\x0C\x15",
  /* U+214C */	"\x0C\x16", "\x0C\x17", "\x0C\x18", "\x0C\x19",
  /* U+2150 */	"\x0C\x20", "\x0C\x21", "\x0C\x22", "\x0C\x23",
  /* U+2154 */	"\x0C\x24", "\x0C\x25", "\x0C\x26", "\x0C\x27",
  /* U+2158 */	"\x0C\x28", "\x0C\x29", "\x0C\x30", "\x0C\x31",
  /* U+215C */	"\x0C\x32", "\x0C\x33", "\x0C\x34", "\x0C\x35",
  /* U+2160 */	"\xA2\xF1", "\xA2\xF2", "\xA2\xF3", "\xA2\xF4",
  /* U+2164 */	"\xA2\xF5", "\xA2\xF6", "\xA2\xF7", "\xA2\xF8",
  /* U+2168 */	"\xA2\xF9", "\xA2\xFA", "\xA2\xFB", "\xA2\xFC",
  /* U+216C */	"\x0C\x36", "\x0C\x37", "\x0C\x38", "\x0C\x39",
  /* U+2170 */	"\xA2\xA1", "\xA2\xA2", "\xA2\xA3", "\xA2\xA4",
  /* U+2174 */	"\xA2\xA5", "\xA2\xA6", "\xA2\xA7", "\xA2\xA8",
  /* U+2178 */	"\xA2\xA9", "\xA2\xAA", "\x0C\x40", "\x0C\x41",
  /* U+217C */	"\x0C\x42", "\x0C\x43", "\x0C\x44", "\x0C\x45",
  /* U+2180 */	"\x0C\x46", "\x0C\x47", "\x0C\x48", "\x0C\x49",
  /* U+2184 */	"\x0C\x50", "\x0C\x51", "\x0C\x52", "\x0C\x53",
  /* U+2188 */	"\x0C\x54", "\x0C\x55", "\x0C\x56", "\x0C\x57",
  /* U+218C */	"\x0C\x58", "\x0C\x59", "\x0C\x60", "\x0C\x61",
  /* U+2190 */	"\xA1\xFB", "\xA1\xFC", "\xA1\xFA", "\xA1\xFD",
  /* U+2194 */	"\x0C\x62", "\x0C\x63", "\xA8\x49", "\xA8\x4A",
  /* U+2198 */	"\xA8\x4B", "\xA8\x4C", "\x0C\x64", "\x0C\x65",
  /* U+219C */	"\x0C\x66", "\x0C\x67", "\x0C\x68", "\x0C\x69",
  /* U+21A0 */	"\x0C\x70", "\x0C\x71", "\x0C\x72", "\x0C\x73",
  /* U+21A4 */	"\x0C\x74", "\x0C\x75", "\x0C\x76", "\x0C\x77",
  /* U+21A8 */	"\x0C\x78", "\x0C\x79", "\x0C\x80", "\x0C\x81",
  /* U+21AC */	"\x0C\x82", "\x0C\x83", "\x0C\x84", "\x0C\x85",
  /* U+21B0 */	"\x0C\x86", "\x0C\x87", "\x0C\x88", "\x0C\x89",
  /* U+21B4 */	"\x0C\x90", "\x0C\x91", "\x0C\x92", "\x0C\x93",
  /* U+21B8 */	"\x0C\x94", "\x0C\x95", "\x0C\x96", "\x0C\x97",
  /* U+21BC */	"\x0C\x98", "\x0C\x99", "\x0C\xA0", "\x0C\xA1",
  /* U+21C0 */	"\x0C\xA2", "\x0C\xA3", "\x0C\xA4", "\x0C\xA5",
  /* U+21C4 */	"\x0C\xA6", "\x0C\xA7", "\x0C\xA8", "\x0C\xA9",
  /* U+21C8 */	"\x0C\xB0", "\x0C\xB1", "\x0C\xB2", "\x0C\xB3",
  /* U+21CC */	"\x0C\xB4", "\x0C\xB5", "\x0C\xB6", "\x0C\xB7",
  /* U+21D0 */	"\x0C\xB8", "\x0C\xB9", "\x0C\xC0", "\x0C\xC1",
  /* U+21D4 */	"\x0C\xC2", "\x0C\xC3", "\x0C\xC4", "\x0C\xC5",
  /* U+21D8 */	"\x0C\xC6", "\x0C\xC7", "\x0C\xC8", "\x0C\xC9",
  /* U+21DC */	"\x0C\xD0", "\x0C\xD1", "\x0C\xD2", "\x0C\xD3",
  /* U+21E0 */	"\x0C\xD4", "\x0C\xD5", "\x0C\xD6", "\x0C\xD7",
  /* U+21E4 */	"\x0C\xD8", "\x0C\xD9", "\x0C\xE0", "\x0C\xE1",
  /* U+21E8 */	"\x0C\xE2", "\x0C\xE3", "\x0C\xE4", "\x0C\xE5",
  /* U+21EC */	"\x0C\xE6", "\x0C\xE7", "\x0C\xE8", "\x0C\xE9",
  /* U+21F0 */	"\x0C\xF0", "\x0C\xF1", "\x0C\xF2", "\x0C\xF3",
  /* U+21F4 */	"\x0C\xF4", "\x0C\xF5", "\x0C\xF6", "\x0C\xF7",
  /* U+21F8 */	"\x0C\xF8", "\x0C\xF9", "\x0D\x00", "\x0D\x01",
  /* U+21FC */	"\x0D\x02", "\x0D\x03", "\x0D\x04", "\x0D\x05",
  /* U+2200 */	"\x0D\x06", "\x0D\x07", "\x0D\x08", "\x0D\x09",
  /* U+2204 */	"\x0D\x10", "\x0D\x11", "\x0D\x12", "\x0D\x13",
  /* U+2208 */	"\xA1\xCA", "\x0D\x14", "\x0D\x15", "\x0D\x16",
  /* U+220C */	"\x0D\x17", "\x0D\x18", "\x0D\x19", "\xA1\xC7",
  /* U+2210 */	"\x0D\x20", "\xA1\xC6", "\x0D\x21", "\x0D\x22",
  /* U+2214 */	"\x0D\x23", "\xA8\x4D", "\x0D\x24", "\x0D\x25",
  /* U+2218 */	"\x0D\x26", "\x0D\x27", "\xA1\xCC", "\x0D\x28",
  /* U+221C */	"\x0D\x29", "\xA1\xD8", "\xA1\xDE", "\xA8\x4E",
  /* U+2220 */	"\xA1\xCF", "\x0D\x30", "\x0D\x31", "\xA8\x4F",
  /* U+2224 */	"\x0D\x32", "\xA1\xCE", "\x0D\x33", "\xA1\xC4",
  /* U+2228 */	"\xA1\xC5", "\xA1\xC9", "\xA1\xC8", "\xA1\xD2",
  /* U+222C */	"\x0D\x34", "\x0D\x35", "\xA1\xD3", "\x0D\x36",
  /* U+2230 */	"\x0D\x37", "\x0D\x38", "\x0D\x39", "\x0D\x40",
  /* U+2234 */	"\xA1\xE0", "\xA1\xDF", "\xA1\xC3", "\xA1\xCB",
  /* U+2238 */	"\x0D\x41", "\x0D\x42", "\x0D\x43", "\x0D\x44",
  /* U+223C */	"\x0D\x45", "\xA1\xD7", "\x0D\x46", "\x0D\x47",
  /* U+2240 */	"\x0D\x48", "\x0D\x49", "\x0D\x50", "\x0D\x51",
  /* U+2244 */	"\x0D\x52", "\x0D\x53", "\x0D\x54", "\x0D\x55",
  /* U+2248 */	"\xA1\xD6", "\x0D\x56", "\x0D\x57", "\x0D\x58",
  /* U+224C */	"\xA1\xD5", "\x0D\x59", "\x0D\x60", "\x0D\x61",
  /* U+2250 */	"\x0D\x62", "\x0D\x63", "\xA8\x50", "\x0D\x64",
  /* U+2254 */	"\x0D\x65", "\x0D\x66", "\x0D\x67", "\x0D\x68",
  /* U+2258 */	"\x0D\x69", "\x0D\x70", "\x0D\x71", "\x0D\x72",
  /* U+225C */	"\x0D\x73", "\x0D\x74", "\x0D\x75", "\x0D\x76",
  /* U+2260 */	"\xA1\xD9", "\xA1\xD4", "\x0D\x77", "\x0D\x78",
  /* U+2264 */	"\xA1\xDC", "\xA1\xDD", "\xA8\x51", "\xA8\x52",
  /* U+2268 */	"\x0D\x79", "\x0D\x80", "\x0D\x81", "\x0D\x82",
  /* U+226C */	"\x0D\x83", "\x0D\x84", "\xA1\xDA", "\xA1\xDB",
  /* U+2270 */	"\x0D\x85", "\x0D\x86", "\x0D\x87", "\x0D\x88",
  /* U+2274 */	"\x0D\x89", "\x0D\x90", "\x0D\x91", "\x0D\x92",
  /* U+2278 */	"\x0D\x93", "\x0D\x94", "\x0D\x95", "\x0D\x96",
  /* U+227C */	"\x0D\x97", "\x0D\x98", "\x0D\x99", "\x0D\xA0",
  /* U+2280 */	"\x0D\xA1", "\x0D\xA2", "\x0D\xA3", "\x0D\xA4",
  /* U+2284 */	"\x0D\xA5", "\x0D\xA6", "\x0D\xA7", "\x0D\xA8",
  /* U+2288 */	"\x0D\xA9", "\x0D\xB0", "\x0D\xB1", "\x0D\xB2",
  /* U+228C */	"\x0D\xB3", "\x0D\xB4", "\x0D\xB5", "\x0D\xB6",
  /* U+2290 */	"\x0D\xB7", "\x0D\xB8", "\x0D\xB9", "\x0D\xC0",
  /* U+2294 */	"\x0D\xC1", "\xA8\x92", "\x0D\xC2", "\x0D\xC3",
  /* U+2298 */	"\x0D\xC4", "\xA1\xD1", "\x0D\xC5", "\x0D\xC6",
  /* U+229C */	"\x0D\xC7", "\x0D\xC8", "\x0D\xC9", "\x0D\xD0",
  /* U+22A0 */	"\x0D\xD1", "\x0D\xD2", "\x0D\xD3", "\x0D\xD4",
  /* U+22A4 */	"\x0D\xD5", "\xA1\xCD", "\x0D\xD6", "\x0D\xD7",
  /* U+22A8 */	"\x0D\xD8", "\x0D\xD9", "\x0D\xE0", "\x0D\xE1",
  /* U+22AC */	"\x0D\xE2", "\x0D\xE3", "\x0D\xE4", "\x0D\xE5",
  /* U+22B0 */	"\x0D\xE6", "\x0D\xE7", "\x0D\xE8", "\x0D\xE9",
  /* U+22B4 */	"\x0D\xF0", "\x0D\xF1", "\x0D\xF2", "\x0D\xF3",
  /* U+22B8 */	"\x0D\xF4", "\x0D\xF5", "\x0D\xF6", "\x0D\xF7",
  /* U+22BC */	"\x0D\xF8", "\x0D\xF9", "\x0E\x00", "\xA8\x53",
  /* U+22C0 */	"\x0E\x01", "\x0E\x02", "\x0E\x03", "\x0E\x04",
  /* U+22C4 */	"\x0E\x05", "\x0E\x06", "\x0E\x07", "\x0E\x08",
  /* U+22C8 */	"\x0E\x09", "\x0E\x10", "\x0E\x11", "\x0E\x12",
  /* U+22CC */	"\x0E\x13", "\x0E\x14", "\x0E\x15", "\x0E\x16",
  /* U+22D0 */	"\x0E\x17", "\x0E\x18", "\x0E\x19", "\x0E\x20",
  /* U+22D4 */	"\x0E\x21", "\x0E\x22", "\x0E\x23", "\x0E\x24",
  /* U+22D8 */	"\x0E\x25", "\x0E\x26", "\x0E\x27", "\x0E\x28",
  /* U+22DC */	"\x0E\x29", "\x0E\x30", "\x0E\x31", "\x0E\x32",
  /* U+22E0 */	"\x0E\x33", "\x0E\x34", "\x0E\x35", "\x0E\x36",
  /* U+22E4 */	"\x0E\x37", "\x0E\x38", "\x0E\x39", "\x0E\x40",
  /* U+22E8 */	"\x0E\x41", "\x0E\x42", "\x0E\x43", "\x0E\x44",
  /* U+22EC */	"\x0E\x45", "\x0E\x46", "\x0E\x47", "\x0E\x48",
  /* U+22F0 */	"\x0E\x49", "\x0E\x50", "\x0E\x51", "\x0E\x52",
  /* U+22F4 */	"\x0E\x53", "\x0E\x54", "\x0E\x55", "\x0E\x56",
  /* U+22F8 */	"\x0E\x57", "\x0E\x58", "\x0E\x59", "\x0E\x60",
  /* U+22FC */	"\x0E\x61", "\x0E\x62", "\x0E\x63", "\x0E\x64",
  /* U+2300 */	"\x0E\x65", "\x0E\x66", "\x0E\x67", "\x0E\x68",
  /* U+2304 */	"\x0E\x69", "\x0E\x70", "\x0E\x71", "\x0E\x72",
  /* U+2308 */	"\x0E\x73", "\x0E\x74", "\x0E\x75", "\x0E\x76",
  /* U+230C */	"\x0E\x77", "\x0E\x78", "\x0E\x79", "\x0E\x80",
  /* U+2310 */	"\x0E\x81", "\x0E\x82", "\xA1\xD0", "\x0E\x83",
  /* U+2314 */	"\x0E\x84", "\x0E\x85", "\x0E\x86", "\x0E\x87",
  /* U+2318 */	"\x0E\x88", "\x0E\x89", "\x0E\x90", "\x0E\x91",
  /* U+231C */	"\x0E\x92", "\x0E\x93", "\x0E\x94", "\x0E\x95",
  /* U+2320 */	"\x0E\x96", "\x0E\x97", "\x0E\x98", "\x0E\x99",
  /* U+2324 */	"\x0E\xA0", "\x0E\xA1", "\x0E\xA2", "\x0E\xA3",
  /* U+2328 */	"\x0E\xA4", "\x0E\xA5", "\x0E\xA6", "\x0E\xA7",
  /* U+232C */	"\x0E\xA8", "\x0E\xA9", "\x0E\xB0", "\x0E\xB1",
  /* U+2330 */	"\x0E\xB2", "\x0E\xB3", "\x0E\xB4", "\x0E\xB5",
  /* U+2334 */	"\x0E\xB6", "\x0E\xB7", "\x0E\xB8", "\x0E\xB9",
  /* U+2338 */	"\x0E\xC0", "\x0E\xC1", "\x0E\xC2", "\x0E\xC3",
  /* U+233C */	"\x0E\xC4", "\x0E\xC5", "\x0E\xC6", "\x0E\xC7",
  /* U+2340 */	"\x0E\xC8", "\x0E\xC9", "\x0E\xD0", "\x0E\xD1",
  /* U+2344 */	"\x0E\xD2", "\x0E\xD3", "\x0E\xD4", "\x0E\xD5",
  /* U+2348 */	"\x0E\xD6", "\x0E\xD7", "\x0E\xD8", "\x0E\xD9",
  /* U+234C */	"\x0E\xE0", "\x0E\xE1", "\x0E\xE2", "\x0E\xE3",
  /* U+2350 */	"\x0E\xE4", "\x0E\xE5", "\x0E\xE6", "\x0E\xE7",
  /* U+2354 */	"\x0E\xE8", "\x0E\xE9", "\x0E\xF0", "\x0E\xF1",
  /* U+2358 */	"\x0E\xF2", "\x0E\xF3", "\x0E\xF4", "\x0E\xF5",
  /* U+235C */	"\x0E\xF6", "\x0E\xF7", "\x0E\xF8", "\x0E\xF9",
  /* U+2360 */	"\x0F\x00", "\x0F\x01", "\x0F\x02", "\x0F\x03",
  /* U+2364 */	"\x0F\x04", "\x0F\x05", "\x0F\x06", "\x0F\x07",
  /* U+2368 */	"\x0F\x08", "\x0F\x09", "\x0F\x10", "\x0F\x11",
  /* U+236C */	"\x0F\x12", "\x0F\x13", "\x0F\x14", "\x0F\x15",
  /* U+2370 */	"\x0F\x16", "\x0F\x17", "\x0F\x18", "\x0F\x19",
  /* U+2374 */	"\x0F\x20", "\x0F\x21", "\x0F\x22", "\x0F\x23",
  /* U+2378 */	"\x0F\x24", "\x0F\x25", "\x0F\x26", "\x0F\x27",
  /* U+237C */	"\x0F\x28", "\x0F\x29", "\x0F\x30", "\x0F\x31",
  /* U+2380 */	"\x0F\x32", "\x0F\x33", "\x0F\x34", "\x0F\x35",
  /* U+2384 */	"\x0F\x36", "\x0F\x37", "\x0F\x38", "\x0F\x39",
  /* U+2388 */	"\x0F\x40", "\x0F\x41", "\x0F\x42", "\x0F\x43",
  /* U+238C */	"\x0F\x44", "\x0F\x45", "\x0F\x46", "\x0F\x47",
  /* U+2390 */	"\x0F\x48", "\x0F\x49", "\x0F\x50", "\x0F\x51",
  /* U+2394 */	"\x0F\x52", "\x0F\x53", "\x0F\x54", "\x0F\x55",
  /* U+2398 */	"\x0F\x56", "\x0F\x57", "\x0F\x58", "\x0F\x59",
  /* U+239C */	"\x0F\x60", "\x0F\x61", "\x0F\x62", "\x0F\x63",
  /* U+23A0 */	"\x0F\x64", "\x0F\x65", "\x0F\x66", "\x0F\x67",
  /* U+23A4 */	"\x0F\x68", "\x0F\x69", "\x0F\x70", "\x0F\x71",
  /* U+23A8 */	"\x0F\x72", "\x0F\x73", "\x0F\x74", "\x0F\x75",
  /* U+23AC */	"\x0F\x76", "\x0F\x77", "\x0F\x78", "\x0F\x79",
  /* U+23B0 */	"\x0F\x80", "\x0F\x81", "\x0F\x82", "\x0F\x83",
  /* U+23B4 */	"\x0F\x84", "\x0F\x85", "\x0F\x86", "\x0F\x87",
  /* U+23B8 */	"\x0F\x88", "\x0F\x89", "\x0F\x90", "\x0F\x91",
  /* U+23BC */	"\x0F\x92", "\x0F\x93", "\x0F\x94", "\x0F\x95",
  /* U+23C0 */	"\x0F\x96", "\x0F\x97", "\x0F\x98", "\x0F\x99",
  /* U+23C4 */	"\x0F\xA0", "\x0F\xA1", "\x0F\xA2", "\x0F\xA3",
  /* U+23C8 */	"\x0F\xA4", "\x0F\xA5", "\x0F\xA6", "\x0F\xA7",
  /* U+23CC */	"\x0F\xA8", "\x0F\xA9", "\x0F\xB0", "\x0F\xB1",
  /* U+23D0 */	"\x0F\xB2", "\x0F\xB3", "\x0F\xB4", "\x0F\xB5",
  /* U+23D4 */	"\x0F\xB6", "\x0F\xB7", "\x0F\xB8", "\x0F\xB9",
  /* U+23D8 */	"\x0F\xC0", "\x0F\xC1", "\x0F\xC2", "\x0F\xC3",
  /* U+23DC */	"\x0F\xC4", "\x0F\xC5", "\x0F\xC6", "\x0F\xC7",
  /* U+23E0 */	"\x0F\xC8", "\x0F\xC9", "\x0F\xD0", "\x0F\xD1",
  /* U+23E4 */	"\x0F\xD2", "\x0F\xD3", "\x0F\xD4", "\x0F\xD5",
  /* U+23E8 */	"\x0F\xD6", "\x0F\xD7", "\x0F\xD8", "\x0F\xD9",
  /* U+23EC */	"\x10\x00", "\x10\x01", "\x10\x02", "\x10\x03",
  /* U+23F0 */	"\x10\x04", "\x10\x05", "\x10\x06", "\x10\x07",
  /* U+23F4 */	"\x10\x08", "\x10\x09", "\x10\x10", "\x10\x11",
  /* U+23F8 */	"\x10\x12", "\x10\x13", "\x10\x14", "\x10\x15",
  /* U+23FC */	"\x10\x16", "\x10\x17", "\x10\x18", "\x10\x19",
  /* U+2400 */	"\x10\x20", "\x10\x21", "\x10\x22", "\x10\x23",
  /* U+2404 */	"\x10\x24", "\x10\x25", "\x10\x26", "\x10\x27",
  /* U+2408 */	"\x10\x28", "\x10\x29", "\x10\x30", "\x10\x31",
  /* U+240C */	"\x10\x32", "\x10\x33", "\x10\x34", "\x10\x35",
  /* U+2410 */	"\x10\x36", "\x10\x37", "\x10\x38", "\x10\x39",
  /* U+2414 */	"\x10\x40", "\x10\x41", "\x10\x42", "\x10\x43",
  /* U+2418 */	"\x10\x44", "\x10\x45", "\x10\x46", "\x10\x47",
  /* U+241C */	"\x10\x48", "\x10\x49", "\x10\x50", "\x10\x51",
  /* U+2420 */	"\x10\x52", "\x10\x53", "\x10\x54", "\x10\x55",
  /* U+2424 */	"\x10\x56", "\x10\x57", "\x10\x58", "\x10\x59",
  /* U+2428 */	"\x10\x60", "\x10\x61", "\x10\x62", "\x10\x63",
  /* U+242C */	"\x10\x64", "\x10\x65", "\x10\x66", "\x10\x67",
  /* U+2430 */	"\x10\x68", "\x10\x69", "\x10\x70", "\x10\x71",
  /* U+2434 */	"\x10\x72", "\x10\x73", "\x10\x74", "\x10\x75",
  /* U+2438 */	"\x10\x76", "\x10\x77", "\x10\x78", "\x10\x79",
  /* U+243C */	"\x10\x80", "\x10\x81", "\x10\x82", "\x10\x83",
  /* U+2440 */	"\x10\x84", "\x10\x85", "\x10\x86", "\x10\x87",
  /* U+2444 */	"\x10\x88", "\x10\x89", "\x10\x90", "\x10\x91",
  /* U+2448 */	"\x10\x92", "\x10\x93", "\x10\x94", "\x10\x95",
  /* U+244C */	"\x10\x96", "\x10\x97", "\x10\x98", "\x10\x99",
  /* U+2450 */	"\x10\xA0", "\x10\xA1", "\x10\xA2", "\x10\xA3",
  /* U+2454 */	"\x10\xA4", "\x10\xA5", "\x10\xA6", "\x10\xA7",
  /* U+2458 */	"\x10\xA8", "\x10\xA9", "\x10\xB0", "\x10\xB1",
  /* U+245C */	"\x10\xB2", "\x10\xB3", "\x10\xB4", "\x10\xB5",
  /* U+2460 */	"\xA2\xD9", "\xA2\xDA", "\xA2\xDB", "\xA2\xDC",
  /* U+2464 */	"\xA2\xDD", "\xA2\xDE", "\xA2\xDF", "\xA2\xE0",
  /* U+2468 */	"\xA2\xE1", "\xA2\xE2", "\x10\xB6", "\x10\xB7",
  /* U+246C */	"\x10\xB8", "\x10\xB9", "\x10\xC0", "\x10\xC1",
  /* U+2470 */	"\x10\xC2", "\x10\xC3", "\x10\xC4", "\x10\xC5",
  /* U+2474 */	"\xA2\xC5", "\xA2\xC6", "\xA2\xC7", "\xA2\xC8",
  /* U+2478 */	"\xA2\xC9", "\xA2\xCA", "\xA2\xCB", "\xA2\xCC",
  /* U+247C */	"\xA2\xCD", "\xA2\xCE", "\xA2\xCF", "\xA2\xD0",
  /* U+2480 */	"\xA2\xD1", "\xA2\xD2", "\xA2\xD3", "\xA2\xD4",
  /* U+2484 */	"\xA2\xD5", "\xA2\xD6", "\xA2\xD7", "\xA2\xD8",
  /* U+2488 */	"\xA2\xB1", "\xA2\xB2", "\xA2\xB3", "\xA2\xB4",
  /* U+248C */	"\xA2\xB5", "\xA2\xB6", "\xA2\xB7", "\xA2\xB8",
  /* U+2490 */	"\xA2\xB9", "\xA2\xBA", "\xA2\xBB", "\xA2\xBC",
  /* U+2494 */	"\xA2\xBD", "\xA2\xBE", "\xA2\xBF", "\xA2\xC0",
  /* U+2498 */	"\xA2\xC1", "\xA2\xC2", "\xA2\xC3", "\xA2\xC4",
  /* U+249C */	"\x10\xC6", "\x10\xC7", "\x10\xC8", "\x10\xC9",
  /* U+24A0 */	"\x10\xD0", "\x10\xD1", "\x10\xD2", "\x10\xD3",
  /* U+24A4 */	"\x10\xD4", "\x10\xD5", "\x10\xD6", "\x10\xD7",
  /* U+24A8 */	"\x10\xD8", "\x10\xD9", "\x10\xE0", "\x10\xE1",
  /* U+24AC */	"\x10\xE2", "\x10\xE3", "\x10\xE4", "\x10\xE5",
  /* U+24B0 */	"\x10\xE6", "\x10\xE7", "\x10\xE8", "\x10\xE9",
  /* U+24B4 */	"\x10\xF0", "\x10\xF1", "\x10\xF2", "\x10\xF3",
  /* U+24B8 */	"\x10\xF4", "\x10\xF5", "\x10\xF6", "\x10\xF7",
  /* U+24BC */	"\x10\xF8", "\x10\xF9", "\x11\x00", "\x11\x01",
  /* U+24C0 */	"\x11\x02", "\x11\x03", "\x11\x04", "\x11\x05",
  /* U+24C4 */	"\x11\x06", "\x11\x07", "\x11\x08", "\x11\x09",
  /* U+24C8 */	"\x11\x10", "\x11\x11", "\x11\x12", "\x11\x13",
  /* U+24CC */	"\x11\x14", "\x11\x15", "\x11\x16", "\x11\x17",
  /* U+24D0 */	"\x11\x18", "\x11\x19", "\x11\x20", "\x11\x21",
  /* U+24D4 */	"\x11\x22", "\x11\x23", "\x11\x24", "\x11\x25",
  /* U+24D8 */	"\x11\x26", "\x11\x27", "\x11\x28", "\x11\x29",
  /* U+24DC */	"\x11\x30", "\x11\x31", "\x11\x32", "\x11\x33",
  /* U+24E0 */	"\x11\x34", "\x11\x35", "\x11\x36", "\x11\x37",
  /* U+24E4 */	"\x11\x38", "\x11\x39", "\x11\x40", "\x11\x41",
  /* U+24E8 */	"\x11\x42", "\x11\x43", "\x11\x44", "\x11\x45",
  /* U+24EC */	"\x11\x46", "\x11\x47", "\x11\x48", "\x11\x49",
  /* U+24F0 */	"\x11\x50", "\x11\x51", "\x11\x52", "\x11\x53",
  /* U+24F4 */	"\x11\x54", "\x11\x55", "\x11\x56", "\x11\x57",
  /* U+24F8 */	"\x11\x58", "\x11\x59", "\x11\x60", "\x11\x61",
  /* U+24FC */	"\x11\x62", "\x11\x63", "\x11\x64", "\x11\x65",
  /* U+2500 */	"\xA9\xA4", "\xA9\xA5", "\xA9\xA6", "\xA9\xA7",
  /* U+2504 */	"\xA9\xA8", "\xA9\xA9", "\xA9\xAA", "\xA9\xAB",
  /* U+2508 */	"\xA9\xAC", "\xA9\xAD", "\xA9\xAE", "\xA9\xAF",
  /* U+250C */	"\xA9\xB0", "\xA9\xB1", "\xA9\xB2", "\xA9\xB3",
  /* U+2510 */	"\xA9\xB4", "\xA9\xB5", "\xA9\xB6", "\xA9\xB7",
  /* U+2514 */	"\xA9\xB8", "\xA9\xB9", "\xA9\xBA", "\xA9\xBB",
  /* U+2518 */	"\xA9\xBC", "\xA9\xBD", "\xA9\xBE", "\xA9\xBF",
  /* U+251C */	"\xA9\xC0", "\xA9\xC1", "\xA9\xC2", "\xA9\xC3",
  /* U+2520 */	"\xA9\xC4", "\xA9\xC5", "\xA9\xC6", "\xA9\xC7",
  /* U+2524 */	"\xA9\xC8", "\xA9\xC9", "\xA9\xCA", "\xA9\xCB",
  /* U+2528 */	"\xA9\xCC", "\xA9\xCD", "\xA9\xCE", "\xA9\xCF",
  /* U+252C */	"\xA9\xD0", "\xA9\xD1", "\xA9\xD2", "\xA9\xD3",
  /* U+2530 */	"\xA9\xD4", "\xA9\xD5", "\xA9\xD6", "\xA9\xD7",
  /* U+2534 */	"\xA9\xD8", "\xA9\xD9", "\xA9\xDA", "\xA9\xDB",
  /* U+2538 */	"\xA9\xDC", "\xA9\xDD", "\xA9\xDE", "\xA9\xDF",
  /* U+253C */	"\xA9\xE0", "\xA9\xE1", "\xA9\xE2", "\xA9\xE3",
  /* U+2540 */	"\xA9\xE4", "\xA9\xE5", "\xA9\xE6", "\xA9\xE7",
  /* U+2544 */	"\xA9\xE8", "\xA9\xE9", "\xA9\xEA", "\xA9\xEB",
  /* U+2548 */	"\xA9\xEC", "\xA9\xED", "\xA9\xEE", "\xA9\xEF",
  /* U+254C */	"\x11\x66", "\x11\x67", "\x11\x68", "\x11\x69",
  /* U+2550 */	"\xA8\x54", "\xA8\x55", "\xA8\x56", "\xA8\x57",
  /* U+2554 */	"\xA8\x58", "\xA8\x59", "\xA8\x5A", "\xA8\x5B",
  /* U+2558 */	"\xA8\x5C", "\xA8\x5D", "\xA8\x5E", "\xA8\x5F",
  /* U+255C */	"\xA8\x60", "\xA8\x61", "\xA8\x62", "\xA8\x63",
  /* U+2560 */	"\xA8\x64", "\xA8\x65", "\xA8\x66", "\xA8\x67",
  /* U+2564 */	"\xA8\x68", "\xA8\x69", "\xA8\x6A", "\xA8\x6B",
  /* U+2568 */	"\xA8\x6C", "\xA8\x6D", "\xA8\x6E", "\xA8\x6F",
  /* U+256C */	"\xA8\x70", "\xA8\x71", "\xA8\x72", "\xA8\x73",
  /* U+2570 */	"\xA8\x74", "\xA8\x75", "\xA8\x76", "\xA8\x77",
  /* U+2574 */	"\x11\x70", "\x11\x71", "\x11\x72", "\x11\x73",
  /* U+2578 */	"\x11\x74", "\x11\x75", "\x11\x76", "\x11\x77",
  /* U+257C */	"\x11\x78", "\x11\x79", "\x11\x80", "\x11\x81",
  /* U+2580 */	"\x11\x82", "\xA8\x78", "\xA8\x79", "\xA8\x7A",
  /* U+2584 */	"\xA8\x7B", "\xA8\x7C", "\xA8\x7D", "\xA8\x7E",
  /* U+2588 */	"\xA8\x80", "\xA8\x81", "\xA8\x82", "\xA8\x83",
  /* U+258C */	"\xA8\x84", "\xA8\x85", "\xA8\x86", "\xA8\x87",
  /* U+2590 */	"\x11\x83", "\x11\x84", "\x11\x85", "\xA8\x88",
  /* U+2594 */	"\xA8\x89", "\xA8\x8A", "\x11\x86", "\x11\x87",
  /* U+2598 */	"\x11\x88", "\x11\x89", "\x11\x90", "\x11\x91",
  /* U+259C */	"\x11\x92", "\x11\x93", "\x11\x94", "\x11\x95",
  /* U+25A0 */	"\xA1\xF6", "\xA1\xF5", "\x11\x96", "\x11\x97",
  /* U+25A4 */	"\x11\x98", "\x11\x99", "\x11\xA0", "\x11\xA1",
  /* U+25A8 */	"\x11\xA2", "\x11\xA3", "\x11\xA4", "\x11\xA5",
  /* U+25AC */	"\x11\xA6", "\x11\xA7", "\x11\xA8", "\x11\xA9",
  /* U+25B0 */	"\x11\xB0", "\x11\xB1", "\xA1\xF8", "\xA1\xF7",
  /* U+25B4 */	"\x11\xB2", "\x11\xB3", "\x11\xB4", "\x11\xB5",
  /* U+25B8 */	"\x11\xB6", "\x11\xB7", "\x11\xB8", "\x11\xB9",
  /* U+25BC */	"\xA8\x8B", "\xA8\x8C", "\x11\xC0", "\x11\xC1",
  /* U+25C0 */	"\x11\xC2", "\x11\xC3", "\x11\xC4", "\x11\xC5",
  /* U+25C4 */	"\x11\xC6", "\x11\xC7", "\xA1\xF4", "\xA1\xF3",
  /* U+25C8 */	"\x11\xC8", "\x11\xC9", "\x11\xD0", "\xA1\xF0",
  /* U+25CC */	"\x11\xD1", "\x11\xD2", "\xA1\xF2", "\xA1\xF1",
  /* U+25D0 */	"\x11\xD3", "\x11\xD4", "\x11\xD5", "\x11\xD6",
  /* U+25D4 */	"\x11\xD7", "\x11\xD8", "\x11\xD9", "\x11\xE0",
  /* U+25D8 */	"\x11\xE1", "\x11\xE2", "\x11\xE3", "\x11\xE4",
  /* U+25DC */	"\x11\xE5", "\x11\xE6", "\x11\xE7", "\x11\xE8",
  /* U+25E0 */	"\x11\xE9", "\x11\xF0", "\xA8\x8D", "\xA8\x8E",
  /* U+25E4 */	"\xA8\x8F", "\xA8\x90", "\x11\xF1", "\x11\xF2",
  /* U+25E8 */	"\x11\xF3", "\x11\xF4", "\x11\xF5", "\x11\xF6",
  /* U+25EC */	"\x11\xF7", "\x11\xF8", "\x11\xF9", "\x12\x00",
  /* U+25F0 */	"\x12\x01", "\x12\x02", "\x12\x03", "\x12\x04",
  /* U+25F4 */	"\x12\x05", "\x12\x06", "\x12\x07", "\x12\x08",
  /* U+25F8 */	"\x12\x09", "\x12\x10", "\x12\x11", "\x12\x12",
  /* U+25FC */	"\x12\x13", "\x12\x14", "\x12\x15", "\x12\x16",
  /* U+2600 */	"\x12\x17", "\x12\x18", "\x12\x19", "\x12\x20",
  /* U+2604 */	"\x12\x21", "\xA1\xEF", "\xA1\xEE", "\x12\x22",
  /* U+2608 */	"\x12\x23", "\xA8\x91", "\x12\x24", "\x12\x25",
  /* U+260C */	"\x12\x26", "\x12\x27", "\x12\x28", "\x12\x29",
  /* U+2610 */	"\x12\x30", "\x12\x31", "\x12\x32", "\x12\x33",
  /* U+2614 */	"\x12\x34", "\x12\x35", "\x12\x36", "\x12\x37",
  /* U+2618 */	"\x12\x38", "\x12\x39", "\x12\x40", "\x12\x41",
  /* U+261C */	"\x12\x42", "\x12\x43", "\x12\x44", "\x12\x45",
  /* U+2620 */	"\x12\x46", "\x12\x47", "\x12\x48", "\x12\x49",
  /* U+2624 */	"\x12\x50", "\x12\x51", "\x12\x52", "\x12\x53",
  /* U+2628 */	"\x12\x54", "\x12\x55", "\x12\x56", "\x12\x57",
  /* U+262C */	"\x12\x58", "\x12\x59", "\x12\x60", "\x12\x61",
  /* U+2630 */	"\x12\x62", "\x12\x63", "\x12\x64", "\x12\x65",
  /* U+2634 */	"\x12\x66", "\x12\x67", "\x12\x68", "\x12\x69",
  /* U+2638 */	"\x12\x70", "\x12\x71", "\x12\x72", "\x12\x73",
  /* U+263C */	"\x12\x74", "\x12\x75", "\x12\x76", "\x12\x77",
  /* U+2640 */	"\xA1\xE2", "\x12\x78", "\xA1\xE1", 
  /* Contiguous area: U+2E81 .. U+361A */
  /* U+2E81 */		    "\xFE\x50", "\x1F\xC9", "\x1F\xD0",
  /* U+2E84 */	"\xFE\x54", "\x1F\xD1", "\x1F\xD2", "\x1F\xD3",
  /* U+2E88 */	"\xFE\x57", "\x1F\xD4", "\x1F\xD5", "\xFE\x58",
  /* U+2E8C */	"\xFE\x5D", "\x1F\xD6", "\x1F\xD7", "\x1F\xD8",
  /* U+2E90 */	"\x1F\xD9", "\x20\x00", "\x20\x01", "\x20\x02",
  /* U+2E94 */	"\x20\x03", "\x20\x04", "\x20\x05", "\xFE\x5E",
  /* U+2E98 */	"\x20\x06", "\x20\x07", "\x20\x08", "\x20\x09",
  /* U+2E9C */	"\x20\x10", "\x20\x11", "\x20\x12", "\x20\x13",
  /* U+2EA0 */	"\x20\x14", "\x20\x15", "\x20\x16", "\x20\x17",
  /* U+2EA4 */	"\x20\x18", "\x20\x19", "\x20\x20", "\xFE\x6B",
  /* U+2EA8 */	"\x20\x21", "\x20\x22", "\xFE\x6E", "\x20\x23",
  /* U+2EAC */	"\x20\x24", "\x20\x25", "\xFE\x71", "\x20\x26",
  /* U+2EB0 */	"\x20\x27", "\x20\x28", "\x20\x29", "\xFE\x73",
  /* U+2EB4 */	"\x20\x30", "\x20\x31", "\xFE\x74", "\xFE\x75",
  /* U+2EB8 */	"\x20\x32", "\x20\x33", "\x20\x34", "\xFE\x79",
  /* U+2EBC */	"\x20\x35", "\x20\x36", "\x20\x37", "\x20\x38",
  /* U+2EC0 */	"\x20\x39", "\x20\x40", "\x20\x41", "\x20\x42",
  /* U+2EC4 */	"\x20\x43", "\x20\x44", "\x20\x45", "\x20\x46",
  /* U+2EC8 */	"\x20\x47", "\x20\x48", "\xFE\x84", "\x20\x49",
  /* U+2ECC */	"\x20\x50", "\x20\x51", "\x20\x52", "\x20\x53",
  /* U+2ED0 */	"\x20\x54", "\x20\x55", "\x20\x56", "\x20\x57",
  /* U+2ED4 */	"\x20\x58", "\x20\x59", "\x20\x60", "\x20\x61",
  /* U+2ED8 */	"\x20\x62", "\x20\x63", "\x20\x64", "\x20\x65",
  /* U+2EDC */	"\x20\x66", "\x20\x67", "\x20\x68", "\x20\x69",
  /* U+2EE0 */	"\x20\x70", "\x20\x71", "\x20\x72", "\x20\x73",
  /* U+2EE4 */	"\x20\x74", "\x20\x75", "\x20\x76", "\x20\x77",
  /* U+2EE8 */	"\x20\x78", "\x20\x79", "\x20\x80", "\x20\x81",
  /* U+2EEC */	"\x20\x82", "\x20\x83", "\x20\x84", "\x20\x85",
  /* U+2EF0 */	"\x20\x86", "\x20\x87", "\x20\x88", "\x20\x89",
  /* U+2EF4 */	"\x20\x90", "\x20\x91", "\x20\x92", "\x20\x93",
  /* U+2EF8 */	"\x20\x94", "\x20\x95", "\x20\x96", "\x20\x97",
  /* U+2EFC */	"\x20\x98", "\x20\x99", "\x20\xA0", "\x20\xA1",
  /* U+2F00 */	"\x20\xA2", "\x20\xA3", "\x20\xA4", "\x20\xA5",
  /* U+2F04 */	"\x20\xA6", "\x20\xA7", "\x20\xA8", "\x20\xA9",
  /* U+2F08 */	"\x20\xB0", "\x20\xB1", "\x20\xB2", "\x20\xB3",
  /* U+2F0C */	"\x20\xB4", "\x20\xB5", "\x20\xB6", "\x20\xB7",
  /* U+2F10 */	"\x20\xB8", "\x20\xB9", "\x20\xC0", "\x20\xC1",
  /* U+2F14 */	"\x20\xC2", "\x20\xC3", "\x20\xC4", "\x20\xC5",
  /* U+2F18 */	"\x20\xC6", "\x20\xC7", "\x20\xC8", "\x20\xC9",
  /* U+2F1C */	"\x20\xD0", "\x20\xD1", "\x20\xD2", "\x20\xD3",
  /* U+2F20 */	"\x20\xD4", "\x20\xD5", "\x20\xD6", "\x20\xD7",
  /* U+2F24 */	"\x20\xD8", "\x20\xD9", "\x20\xE0", "\x20\xE1",
  /* U+2F28 */	"\x20\xE2", "\x20\xE3", "\x20\xE4", "\x20\xE5",
  /* U+2F2C */	"\x20\xE6", "\x20\xE7", "\x20\xE8", "\x20\xE9",
  /* U+2F30 */	"\x20\xF0", "\x20\xF1", "\x20\xF2", "\x20\xF3",
  /* U+2F34 */	"\x20\xF4", "\x20\xF5", "\x20\xF6", "\x20\xF7",
  /* U+2F38 */	"\x20\xF8", "\x20\xF9", "\x21\x00", "\x21\x01",
  /* U+2F3C */	"\x21\x02", "\x21\x03", "\x21\x04", "\x21\x05",
  /* U+2F40 */	"\x21\x06", "\x21\x07", "\x21\x08", "\x21\x09",
  /* U+2F44 */	"\x21\x10", "\x21\x11", "\x21\x12", "\x21\x13",
  /* U+2F48 */	"\x21\x14", "\x21\x15", "\x21\x16", "\x21\x17",
  /* U+2F4C */	"\x21\x18", "\x21\x19", "\x21\x20", "\x21\x21",
  /* U+2F50 */	"\x21\x22", "\x21\x23", "\x21\x24", "\x21\x25",
  /* U+2F54 */	"\x21\x26", "\x21\x27", "\x21\x28", "\x21\x29",
  /* U+2F58 */	"\x21\x30", "\x21\x31", "\x21\x32", "\x21\x33",
  /* U+2F5C */	"\x21\x34", "\x21\x35", "\x21\x36", "\x21\x37",
  /* U+2F60 */	"\x21\x38", "\x21\x39", "\x21\x40", "\x21\x41",
  /* U+2F64 */	"\x21\x42", "\x21\x43", "\x21\x44", "\x21\x45",
  /* U+2F68 */	"\x21\x46", "\x21\x47", "\x21\x48", "\x21\x49",
  /* U+2F6C */	"\x21\x50", "\x21\x51", "\x21\x52", "\x21\x53",
  /* U+2F70 */	"\x21\x54", "\x21\x55", "\x21\x56", "\x21\x57",
  /* U+2F74 */	"\x21\x58", "\x21\x59", "\x21\x60", "\x21\x61",
  /* U+2F78 */	"\x21\x62", "\x21\x63", "\x21\x64", "\x21\x65",
  /* U+2F7C */	"\x21\x66", "\x21\x67", "\x21\x68", "\x21\x69",
  /* U+2F80 */	"\x21\x70", "\x21\x71", "\x21\x72", "\x21\x73",
  /* U+2F84 */	"\x21\x74", "\x21\x75", "\x21\x76", "\x21\x77",
  /* U+2F88 */	"\x21\x78", "\x21\x79", "\x21\x80", "\x21\x81",
  /* U+2F8C */	"\x21\x82", "\x21\x83", "\x21\x84", "\x21\x85",
  /* U+2F90 */	"\x21\x86", "\x21\x87", "\x21\x88", "\x21\x89",
  /* U+2F94 */	"\x21\x90", "\x21\x91", "\x21\x92", "\x21\x93",
  /* U+2F98 */	"\x21\x94", "\x21\x95", "\x21\x96", "\x21\x97",
  /* U+2F9C */	"\x21\x98", "\x21\x99", "\x21\xA0", "\x21\xA1",
  /* U+2FA0 */	"\x21\xA2", "\x21\xA3", "\x21\xA4", "\x21\xA5",
  /* U+2FA4 */	"\x21\xA6", "\x21\xA7", "\x21\xA8", "\x21\xA9",
  /* U+2FA8 */	"\x21\xB0", "\x21\xB1", "\x21\xB2", "\x21\xB3",
  /* U+2FAC */	"\x21\xB4", "\x21\xB5", "\x21\xB6", "\x21\xB7",
  /* U+2FB0 */	"\x21\xB8", "\x21\xB9", "\x21\xC0", "\x21\xC1",
  /* U+2FB4 */	"\x21\xC2", "\x21\xC3", "\x21\xC4", "\x21\xC5",
  /* U+2FB8 */	"\x21\xC6", "\x21\xC7", "\x21\xC8", "\x21\xC9",
  /* U+2FBC */	"\x21\xD0", "\x21\xD1", "\x21\xD2", "\x21\xD3",
  /* U+2FC0 */	"\x21\xD4", "\x21\xD5", "\x21\xD6", "\x21\xD7",
  /* U+2FC4 */	"\x21\xD8", "\x21\xD9", "\x21\xE0", "\x21\xE1",
  /* U+2FC8 */	"\x21\xE2", "\x21\xE3", "\x21\xE4", "\x21\xE5",
  /* U+2FCC */	"\x21\xE6", "\x21\xE7", "\x21\xE8", "\x21\xE9",
  /* U+2FD0 */	"\x21\xF0", "\x21\xF1", "\x21\xF2", "\x21\xF3",
  /* U+2FD4 */	"\x21\xF4", "\x21\xF5", "\x21\xF6", "\x21\xF7",
  /* U+2FD8 */	"\x21\xF8", "\x21\xF9", "\x22\x00", "\x22\x01",
  /* U+2FDC */	"\x22\x02", "\x22\x03", "\x22\x04", "\x22\x05",
  /* U+2FE0 */	"\x22\x06", "\x22\x07", "\x22\x08", "\x22\x09",
  /* U+2FE4 */	"\x22\x10", "\x22\x11", "\x22\x12", "\x22\x13",
  /* U+2FE8 */	"\x22\x14", "\x22\x15", "\x22\x16", "\x22\x17",
  /* U+2FEC */	"\x22\x18", "\x22\x19", "\x22\x20", "\x22\x21",
  /* U+2FF0 */	"\xA9\x8A", "\xA9\x8B", "\xA9\x8C", "\xA9\x8D",
  /* U+2FF4 */	"\xA9\x8E", "\xA9\x8F", "\xA9\x90", "\xA9\x91",
  /* U+2FF8 */	"\xA9\x92", "\xA9\x93", "\xA9\x94", "\xA9\x95",
  /* U+2FFC */	"\x22\x22", "\x22\x23", "\x22\x24", "\x22\x25",
  /* U+3000 */	"\xA1\xA1", "\xA1\xA2", "\xA1\xA3", "\xA1\xA8",
  /* U+3004 */	"\x22\x26", "\xA1\xA9", "\xA9\x65", "\xA9\x96",
  /* U+3008 */	"\xA1\xB4", "\xA1\xB5", "\xA1\xB6", "\xA1\xB7",
  /* U+300C */	"\xA1\xB8", "\xA1\xB9", "\xA1\xBA", "\xA1\xBB",
  /* U+3010 */	"\xA1\xBE", "\xA1\xBF", "\xA8\x93", "\xA1\xFE",
  /* U+3014 */	"\xA1\xB2", "\xA1\xB3", "\xA1\xBC", "\xA1\xBD",
  /* U+3018 */	"\x22\x27", "\x22\x28", "\x22\x29", "\x22\x30",
  /* U+301C */	"\x22\x31", "\xA8\x94", "\xA8\x95", "\x22\x32",
  /* U+3020 */	"\x22\x33", "\xA9\x40", "\xA9\x41", "\xA9\x42",
  /* U+3024 */	"\xA9\x43", "\xA9\x44", "\xA9\x45", "\xA9\x46",
  /* U+3028 */	"\xA9\x47", "\xA9\x48", "\x22\x34", "\x22\x35",
  /* U+302C */	"\x22\x36", "\x22\x37", "\x22\x38", "\x22\x39",
  /* U+3030 */	"\x22\x40", "\x22\x41", "\x22\x42", "\x22\x43",
  /* U+3034 */	"\x22\x44", "\x22\x45", "\x22\x46", "\x22\x47",
  /* U+3038 */	"\x22\x48", "\x22\x49", "\x22\x50", "\x22\x51",
  /* U+303C */	"\x22\x52", "\x22\x53", "\xA9\x89", "\x22\x54",
  /* U+3040 */	"\x22\x55", "\xA4\xA1", "\xA4\xA2", "\xA4\xA3",
  /* U+3044 */	"\xA4\xA4", "\xA4\xA5", "\xA4\xA6", "\xA4\xA7",
  /* U+3048 */	"\xA4\xA8", "\xA4\xA9", "\xA4\xAA", "\xA4\xAB",
  /* U+304C */	"\xA4\xAC", "\xA4\xAD", "\xA4\xAE", "\xA4\xAF",
  /* U+3050 */	"\xA4\xB0", "\xA4\xB1", "\xA4\xB2", "\xA4\xB3",
  /* U+3054 */	"\xA4\xB4", "\xA4\xB5", "\xA4\xB6", "\xA4\xB7",
  /* U+3058 */	"\xA4\xB8", "\xA4\xB9", "\xA4\xBA", "\xA4\xBB",
  /* U+305C */	"\xA4\xBC", "\xA4\xBD", "\xA4\xBE", "\xA4\xBF",
  /* U+3060 */	"\xA4\xC0", "\xA4\xC1", "\xA4\xC2", "\xA4\xC3",
  /* U+3064 */	"\xA4\xC4", "\xA4\xC5", "\xA4\xC6", "\xA4\xC7",
  /* U+3068 */	"\xA4\xC8", "\xA4\xC9", "\xA4\xCA", "\xA4\xCB",
  /* U+306C */	"\xA4\xCC", "\xA4\xCD", "\xA4\xCE", "\xA4\xCF",
  /* U+3070 */	"\xA4\xD0", "\xA4\xD1", "\xA4\xD2", "\xA4\xD3",
  /* U+3074 */	"\xA4\xD4", "\xA4\xD5", "\xA4\xD6", "\xA4\xD7",
  /* U+3078 */	"\xA4\xD8", "\xA4\xD9", "\xA4\xDA", "\xA4\xDB",
  /* U+307C */	"\xA4\xDC", "\xA4\xDD", "\xA4\xDE", "\xA4\xDF",
  /* U+3080 */	"\xA4\xE0", "\xA4\xE1", "\xA4\xE2", "\xA4\xE3",
  /* U+3084 */	"\xA4\xE4", "\xA4\xE5", "\xA4\xE6", "\xA4\xE7",
  /* U+3088 */	"\xA4\xE8", "\xA4\xE9", "\xA4\xEA", "\xA4\xEB",
  /* U+308C */	"\xA4\xEC", "\xA4\xED", "\xA4\xEE", "\xA4\xEF",
  /* U+3090 */	"\xA4\xF0", "\xA4\xF1", "\xA4\xF2", "\xA4\xF3",
  /* U+3094 */	"\x22\x56", "\x22\x57", "\x22\x58", "\x22\x59",
  /* U+3098 */	"\x22\x60", "\x22\x61", "\x22\x62", "\xA9\x61",
  /* U+309C */	"\xA9\x62", "\xA9\x66", "\xA9\x67", "\x22\x63",
  /* U+30A0 */	"\x22\x64", "\xA5\xA1", "\xA5\xA2", "\xA5\xA3",
  /* U+30A4 */	"\xA5\xA4", "\xA5\xA5", "\xA5\xA6", "\xA5\xA7",
  /* U+30A8 */	"\xA5\xA8", "\xA5\xA9", "\xA5\xAA", "\xA5\xAB",
  /* U+30AC */	"\xA5\xAC", "\xA5\xAD", "\xA5\xAE", "\xA5\xAF",
  /* U+30B0 */	"\xA5\xB0", "\xA5\xB1", "\xA5\xB2", "\xA5\xB3",
  /* U+30B4 */	"\xA5\xB4", "\xA5\xB5", "\xA5\xB6", "\xA5\xB7",
  /* U+30B8 */	"\xA5\xB8", "\xA5\xB9", "\xA5\xBA", "\xA5\xBB",
  /* U+30BC */	"\xA5\xBC", "\xA5\xBD", "\xA5\xBE", "\xA5\xBF",
  /* U+30C0 */	"\xA5\xC0", "\xA5\xC1", "\xA5\xC2", "\xA5\xC3",
  /* U+30C4 */	"\xA5\xC4", "\xA5\xC5", "\xA5\xC6", "\xA5\xC7",
  /* U+30C8 */	"\xA5\xC8", "\xA5\xC9", "\xA5\xCA", "\xA5\xCB",
  /* U+30CC */	"\xA5\xCC", "\xA5\xCD", "\xA5\xCE", "\xA5\xCF",
  /* U+30D0 */	"\xA5\xD0", "\xA5\xD1", "\xA5\xD2", "\xA5\xD3",
  /* U+30D4 */	"\xA5\xD4", "\xA5\xD5", "\xA5\xD6", "\xA5\xD7",
  /* U+30D8 */	"\xA5\xD8", "\xA5\xD9", "\xA5\xDA", "\xA5\xDB",
  /* U+30DC */	"\xA5\xDC", "\xA5\xDD", "\xA5\xDE", "\xA5\xDF",
  /* U+30E0 */	"\xA5\xE0", "\xA5\xE1", "\xA5\xE2", "\xA5\xE3",
  /* U+30E4 */	"\xA5\xE4", "\xA5\xE5", "\xA5\xE6", "\xA5\xE7",
  /* U+30E8 */	"\xA5\xE8", "\xA5\xE9", "\xA5\xEA", "\xA5\xEB",
  /* U+30EC */	"\xA5\xEC", "\xA5\xED", "\xA5\xEE", "\xA5\xEF",
  /* U+30F0 */	"\xA5\xF0", "\xA5\xF1", "\xA5\xF2", "\xA5\xF3",
  /* U+30F4 */	"\xA5\xF4", "\xA5\xF5", "\xA5\xF6", "\x22\x65",
  /* U+30F8 */	"\x22\x66", "\x22\x67", "\x22\x68", "\x22\x69",
  /* U+30FC */	"\xA9\x60", "\xA9\x63", "\xA9\x64", "\x22\x70",
  /* U+3100 */	"\x22\x71", "\x22\x72", "\x22\x73", "\x22\x74",
  /* U+3104 */	"\x22\x75", "\xA8\xC5", "\xA8\xC6", "\xA8\xC7",
  /* U+3108 */	"\xA8\xC8", "\xA8\xC9", "\xA8\xCA", "\xA8\xCB",
  /* U+310C */	"\xA8\xCC", "\xA8\xCD", "\xA8\xCE", "\xA8\xCF",
  /* U+3110 */	"\xA8\xD0", "\xA8\xD1", "\xA8\xD2", "\xA8\xD3",
  /* U+3114 */	"\xA8\xD4", "\xA8\xD5", "\xA8\xD6", "\xA8\xD7",
  /* U+3118 */	"\xA8\xD8", "\xA8\xD9", "\xA8\xDA", "\xA8\xDB",
  /* U+311C */	"\xA8\xDC", "\xA8\xDD", "\xA8\xDE", "\xA8\xDF",
  /* U+3120 */	"\xA8\xE0", "\xA8\xE1", "\xA8\xE2", "\xA8\xE3",
  /* U+3124 */	"\xA8\xE4", "\xA8\xE5", "\xA8\xE6", "\xA8\xE7",
  /* U+3128 */	"\xA8\xE8", "\xA8\xE9", "\x22\x76", "\x22\x77",
  /* U+312C */	"\x22\x78", "\x22\x79", "\x22\x80", "\x22\x81",
  /* U+3130 */	"\x22\x82", "\x22\x83", "\x22\x84", "\x22\x85",
  /* U+3134 */	"\x22\x86", "\x22\x87", "\x22\x88", "\x22\x89",
  /* U+3138 */	"\x22\x90", "\x22\x91", "\x22\x92", "\x22\x93",
  /* U+313C */	"\x22\x94", "\x22\x95", "\x22\x96", "\x22\x97",
  /* U+3140 */	"\x22\x98", "\x22\x99", "\x22\xA0", "\x22\xA1",
  /* U+3144 */	"\x22\xA2", "\x22\xA3", "\x22\xA4", "\x22\xA5",
  /* U+3148 */	"\x22\xA6", "\x22\xA7", "\x22\xA8", "\x22\xA9",
  /* U+314C */	"\x22\xB0", "\x22\xB1", "\x22\xB2", "\x22\xB3",
  /* U+3150 */	"\x22\xB4", "\x22\xB5", "\x22\xB6", "\x22\xB7",
  /* U+3154 */	"\x22\xB8", "\x22\xB9", "\x22\xC0", "\x22\xC1",
  /* U+3158 */	"\x22\xC2", "\x22\xC3", "\x22\xC4", "\x22\xC5",
  /* U+315C */	"\x22\xC6", "\x22\xC7", "\x22\xC8", "\x22\xC9",
  /* U+3160 */	"\x22\xD0", "\x22\xD1", "\x22\xD2", "\x22\xD3",
  /* U+3164 */	"\x22\xD4", "\x22\xD5", "\x22\xD6", "\x22\xD7",
  /* U+3168 */	"\x22\xD8", "\x22\xD9", "\x22\xE0", "\x22\xE1",
  /* U+316C */	"\x22\xE2", "\x22\xE3", "\x22\xE4", "\x22\xE5",
  /* U+3170 */	"\x22\xE6", "\x22\xE7", "\x22\xE8", "\x22\xE9",
  /* U+3174 */	"\x22\xF0", "\x22\xF1", "\x22\xF2", "\x22\xF3",
  /* U+3178 */	"\x22\xF4", "\x22\xF5", "\x22\xF6", "\x22\xF7",
  /* U+317C */	"\x22\xF8", "\x22\xF9", "\x23\x00", "\x23\x01",
  /* U+3180 */	"\x23\x02", "\x23\x03", "\x23\x04", "\x23\x05",
  /* U+3184 */	"\x23\x06", "\x23\x07", "\x23\x08", "\x23\x09",
  /* U+3188 */	"\x23\x10", "\x23\x11", "\x23\x12", "\x23\x13",
  /* U+318C */	"\x23\x14", "\x23\x15", "\x23\x16", "\x23\x17",
  /* U+3190 */	"\x23\x18", "\x23\x19", "\x23\x20", "\x23\x21",
  /* U+3194 */	"\x23\x22", "\x23\x23", "\x23\x24", "\x23\x25",
  /* U+3198 */	"\x23\x26", "\x23\x27", "\x23\x28", "\x23\x29",
  /* U+319C */	"\x23\x30", "\x23\x31", "\x23\x32", "\x23\x33",
  /* U+31A0 */	"\x23\x34", "\x23\x35", "\x23\x36", "\x23\x37",
  /* U+31A4 */	"\x23\x38", "\x23\x39", "\x23\x40", "\x23\x41",
  /* U+31A8 */	"\x23\x42", "\x23\x43", "\x23\x44", "\x23\x45",
  /* U+31AC */	"\x23\x46", "\x23\x47", "\x23\x48", "\x23\x49",
  /* U+31B0 */	"\x23\x50", "\x23\x51", "\x23\x52", "\x23\x53",
  /* U+31B4 */	"\x23\x54", "\x23\x55", "\x23\x56", "\x23\x57",
  /* U+31B8 */	"\x23\x58", "\x23\x59", "\x23\x60", "\x23\x61",
  /* U+31BC */	"\x23\x62", "\x23\x63", "\x23\x64", "\x23\x65",
  /* U+31C0 */	"\x23\x66", "\x23\x67", "\x23\x68", "\x23\x69",
  /* U+31C4 */	"\x23\x70", "\x23\x71", "\x23\x72", "\x23\x73",
  /* U+31C8 */	"\x23\x74", "\x23\x75", "\x23\x76", "\x23\x77",
  /* U+31CC */	"\x23\x78", "\x23\x79", "\x23\x80", "\x23\x81",
  /* U+31D0 */	"\x23\x82", "\x23\x83", "\x23\x84", "\x23\x85",
  /* U+31D4 */	"\x23\x86", "\x23\x87", "\x23\x88", "\x23\x89",
  /* U+31D8 */	"\x23\x90", "\x23\x91", "\x23\x92", "\x23\x93",
  /* U+31DC */	"\x23\x94", "\x23\x95", "\x23\x96", "\x23\x97",
  /* U+31E0 */	"\x23\x98", "\x23\x99", "\x23\xA0", "\x23\xA1",
  /* U+31E4 */	"\x23\xA2", "\x23\xA3", "\x23\xA4", "\x23\xA5",
  /* U+31E8 */	"\x23\xA6", "\x23\xA7", "\x23\xA8", "\x23\xA9",
  /* U+31EC */	"\x23\xB0", "\x23\xB1", "\x23\xB2", "\x23\xB3",
  /* U+31F0 */	"\x23\xB4", "\x23\xB5", "\x23\xB6", "\x23\xB7",
  /* U+31F4 */	"\x23\xB8", "\x23\xB9", "\x23\xC0", "\x23\xC1",
  /* U+31F8 */	"\x23\xC2", "\x23\xC3", "\x23\xC4", "\x23\xC5",
  /* U+31FC */	"\x23\xC6", "\x23\xC7", "\x23\xC8", "\x23\xC9",
  /* U+3200 */	"\x23\xD0", "\x23\xD1", "\x23\xD2", "\x23\xD3",
  /* U+3204 */	"\x23\xD4", "\x23\xD5", "\x23\xD6", "\x23\xD7",
  /* U+3208 */	"\x23\xD8", "\x23\xD9", "\x23\xE0", "\x23\xE1",
  /* U+320C */	"\x23\xE2", "\x23\xE3", "\x23\xE4", "\x23\xE5",
  /* U+3210 */	"\x23\xE6", "\x23\xE7", "\x23\xE8", "\x23\xE9",
  /* U+3214 */	"\x23\xF0", "\x23\xF1", "\x23\xF2", "\x23\xF3",
  /* U+3218 */	"\x23\xF4", "\x23\xF5", "\x23\xF6", "\x23\xF7",
  /* U+321C */	"\x23\xF8", "\x23\xF9", "\x24\x00", "\x24\x01",
  /* U+3220 */	"\xA2\xE5", "\xA2\xE6", "\xA2\xE7", "\xA2\xE8",
  /* U+3224 */	"\xA2\xE9", "\xA2\xEA", "\xA2\xEB", "\xA2\xEC",
  /* U+3228 */	"\xA2\xED", "\xA2\xEE", "\x24\x02", "\x24\x03",
  /* U+322C */	"\x24\x04", "\x24\x05", "\x24\x06", "\x24\x07",
  /* U+3230 */	"\x24\x08", "\xA9\x5A", "\x24\x09", "\x24\x10",
  /* U+3234 */	"\x24\x11", "\x24\x12", "\x24\x13", "\x24\x14",
  /* U+3238 */	"\x24\x15", "\x24\x16", "\x24\x17", "\x24\x18",
  /* U+323C */	"\x24\x19", "\x24\x20", "\x24\x21", "\x24\x22",
  /* U+3240 */	"\x24\x23", "\x24\x24", "\x24\x25", "\x24\x26",
  /* U+3244 */	"\x24\x27", "\x24\x28", "\x24\x29", "\x24\x30",
  /* U+3248 */	"\x24\x31", "\x24\x32", "\x24\x33", "\x24\x34",
  /* U+324C */	"\x24\x35", "\x24\x36", "\x24\x37", "\x24\x38",
  /* U+3250 */	"\x24\x39", "\x24\x40", "\x24\x41", "\x24\x42",
  /* U+3254 */	"\x24\x43", "\x24\x44", "\x24\x45", "\x24\x46",
  /* U+3258 */	"\x24\x47", "\x24\x48", "\x24\x49", "\x24\x50",
  /* U+325C */	"\x24\x51", "\x24\x52", "\x24\x53", "\x24\x54",
  /* U+3260 */	"\x24\x55", "\x24\x56", "\x24\x57", "\x24\x58",
  /* U+3264 */	"\x24\x59", "\x24\x60", "\x24\x61", "\x24\x62",
  /* U+3268 */	"\x24\x63", "\x24\x64", "\x24\x65", "\x24\x66",
  /* U+326C */	"\x24\x67", "\x24\x68", "\x24\x69", "\x24\x70",
  /* U+3270 */	"\x24\x71", "\x24\x72", "\x24\x73", "\x24\x74",
  /* U+3274 */	"\x24\x75", "\x24\x76", "\x24\x77", "\x24\x78",
  /* U+3278 */	"\x24\x79", "\x24\x80", "\x24\x81", "\x24\x82",
  /* U+327C */	"\x24\x83", "\x24\x84", "\x24\x85", "\x24\x86",
  /* U+3280 */	"\x24\x87", "\x24\x88", "\x24\x89", "\x24\x90",
  /* U+3284 */	"\x24\x91", "\x24\x92", "\x24\x93", "\x24\x94",
  /* U+3288 */	"\x24\x95", "\x24\x96", "\x24\x97", "\x24\x98",
  /* U+328C */	"\x24\x99", "\x24\xA0", "\x24\xA1", "\x24\xA2",
  /* U+3290 */	"\x24\xA3", "\x24\xA4", "\x24\xA5", "\x24\xA6",
  /* U+3294 */	"\x24\xA7", "\x24\xA8", "\x24\xA9", "\x24\xB0",
  /* U+3298 */	"\x24\xB1", "\x24\xB2", "\x24\xB3", "\x24\xB4",
  /* U+329C */	"\x24\xB5", "\x24\xB6", "\x24\xB7", "\x24\xB8",
  /* U+32A0 */	"\x24\xB9", "\x24\xC0", "\x24\xC1", "\xA9\x49",
  /* U+32A4 */	"\x24\xC2", "\x24\xC3", "\x24\xC4", "\x24\xC5",
  /* U+32A8 */	"\x24\xC6", "\x24\xC7", "\x24\xC8", "\x24\xC9",
  /* U+32AC */	"\x24\xD0", "\x24\xD1", "\x24\xD2", "\x24\xD3",
  /* U+32B0 */	"\x24\xD4", "\x24\xD5", "\x24\xD6", "\x24\xD7",
  /* U+32B4 */	"\x24\xD8", "\x24\xD9", "\x24\xE0", "\x24\xE1",
  /* U+32B8 */	"\x24\xE2", "\x24\xE3", "\x24\xE4", "\x24\xE5",
  /* U+32BC */	"\x24\xE6", "\x24\xE7", "\x24\xE8", "\x24\xE9",
  /* U+32C0 */	"\x24\xF0", "\x24\xF1", "\x24\xF2", "\x24\xF3",
  /* U+32C4 */	"\x24\xF4", "\x24\xF5", "\x24\xF6", "\x24\xF7",
  /* U+32C8 */	"\x24\xF8", "\x24\xF9", "\x25\x00", "\x25\x01",
  /* U+32CC */	"\x25\x02", "\x25\x03", "\x25\x04", "\x25\x05",
  /* U+32D0 */	"\x25\x06", "\x25\x07", "\x25\x08", "\x25\x09",
  /* U+32D4 */	"\x25\x10", "\x25\x11", "\x25\x12", "\x25\x13",
  /* U+32D8 */	"\x25\x14", "\x25\x15", "\x25\x16", "\x25\x17",
  /* U+32DC */	"\x25\x18", "\x25\x19", "\x25\x20", "\x25\x21",
  /* U+32E0 */	"\x25\x22", "\x25\x23", "\x25\x24", "\x25\x25",
  /* U+32E4 */	"\x25\x26", "\x25\x27", "\x25\x28", "\x25\x29",
  /* U+32E8 */	"\x25\x30", "\x25\x31", "\x25\x32", "\x25\x33",
  /* U+32EC */	"\x25\x34", "\x25\x35", "\x25\x36", "\x25\x37",
  /* U+32F0 */	"\x25\x38", "\x25\x39", "\x25\x40", "\x25\x41",
  /* U+32F4 */	"\x25\x42", "\x25\x43", "\x25\x44", "\x25\x45",
  /* U+32F8 */	"\x25\x46", "\x25\x47", "\x25\x48", "\x25\x49",
  /* U+32FC */	"\x25\x50", "\x25\x51", "\x25\x52", "\x25\x53",
  /* U+3300 */	"\x25\x54", "\x25\x55", "\x25\x56", "\x25\x57",
  /* U+3304 */	"\x25\x58", "\x25\x59", "\x25\x60", "\x25\x61",
  /* U+3308 */	"\x25\x62", "\x25\x63", "\x25\x64", "\x25\x65",
  /* U+330C */	"\x25\x66", "\x25\x67", "\x25\x68", "\x25\x69",
  /* U+3310 */	"\x25\x70", "\x25\x71", "\x25\x72", "\x25\x73",
  /* U+3314 */	"\x25\x74", "\x25\x75", "\x25\x76", "\x25\x77",
  /* U+3318 */	"\x25\x78", "\x25\x79", "\x25\x80", "\x25\x81",
  /* U+331C */	"\x25\x82", "\x25\x83", "\x25\x84", "\x25\x85",
  /* U+3320 */	"\x25\x86", "\x25\x87", "\x25\x88", "\x25\x89",
  /* U+3324 */	"\x25\x90", "\x25\x91", "\x25\x92", "\x25\x93",
  /* U+3328 */	"\x25\x94", "\x25\x95", "\x25\x96", "\x25\x97",
  /* U+332C */	"\x25\x98", "\x25\x99", "\x25\xA0", "\x25\xA1",
  /* U+3330 */	"\x25\xA2", "\x25\xA3", "\x25\xA4", "\x25\xA5",
  /* U+3334 */	"\x25\xA6", "\x25\xA7", "\x25\xA8", "\x25\xA9",
  /* U+3338 */	"\x25\xB0", "\x25\xB1", "\x25\xB2", "\x25\xB3",
  /* U+333C */	"\x25\xB4", "\x25\xB5", "\x25\xB6", "\x25\xB7",
  /* U+3340 */	"\x25\xB8", "\x25\xB9", "\x25\xC0", "\x25\xC1",
  /* U+3344 */	"\x25\xC2", "\x25\xC3", "\x25\xC4", "\x25\xC5",
  /* U+3348 */	"\x25\xC6", "\x25\xC7", "\x25\xC8", "\x25\xC9",
  /* U+334C */	"\x25\xD0", "\x25\xD1", "\x25\xD2", "\x25\xD3",
  /* U+3350 */	"\x25\xD4", "\x25\xD5", "\x25\xD6", "\x25\xD7",
  /* U+3354 */	"\x25\xD8", "\x25\xD9", "\x25\xE0", "\x25\xE1",
  /* U+3358 */	"\x25\xE2", "\x25\xE3", "\x25\xE4", "\x25\xE5",
  /* U+335C */	"\x25\xE6", "\x25\xE7", "\x25\xE8", "\x25\xE9",
  /* U+3360 */	"\x25\xF0", "\x25\xF1", "\x25\xF2", "\x25\xF3",
  /* U+3364 */	"\x25\xF4", "\x25\xF5", "\x25\xF6", "\x25\xF7",
  /* U+3368 */	"\x25\xF8", "\x25\xF9", "\x26\x00", "\x26\x01",
  /* U+336C */	"\x26\x02", "\x26\x03", "\x26\x04", "\x26\x05",
  /* U+3370 */	"\x26\x06", "\x26\x07", "\x26\x08", "\x26\x09",
  /* U+3374 */	"\x26\x10", "\x26\x11", "\x26\x12", "\x26\x13",
  /* U+3378 */	"\x26\x14", "\x26\x15", "\x26\x16", "\x26\x17",
  /* U+337C */	"\x26\x18", "\x26\x19", "\x26\x20", "\x26\x21",
  /* U+3380 */	"\x26\x22", "\x26\x23", "\x26\x24", "\x26\x25",
  /* U+3384 */	"\x26\x26", "\x26\x27", "\x26\x28", "\x26\x29",
  /* U+3388 */	"\x26\x30", "\x26\x31", "\x26\x32", "\x26\x33",
  /* U+338C */	"\x26\x34", "\x26\x35", "\xA9\x4A", "\xA9\x4B",
  /* U+3390 */	"\x26\x36", "\x26\x37", "\x26\x38", "\x26\x39",
  /* U+3394 */	"\x26\x40", "\x26\x41", "\x26\x42", "\x26\x43",
  /* U+3398 */	"\x26\x44", "\x26\x45", "\x26\x46", "\x26\x47",
  /* U+339C */	"\xA9\x4C", "\xA9\x4D", "\xA9\x4E", "\x26\x48",
  /* U+33A0 */	"\x26\x49", "\xA9\x4F", "\x26\x50", "\x26\x51",
  /* U+33A4 */	"\x26\x52", "\x26\x53", "\x26\x54", "\x26\x55",
  /* U+33A8 */	"\x26\x56", "\x26\x57", "\x26\x58", "\x26\x59",
  /* U+33AC */	"\x26\x60", "\x26\x61", "\x26\x62", "\x26\x63",
  /* U+33B0 */	"\x26\x64", "\x26\x65", "\x26\x66", "\x26\x67",
  /* U+33B4 */	"\x26\x68", "\x26\x69", "\x26\x70", "\x26\x71",
  /* U+33B8 */	"\x26\x72", "\x26\x73", "\x26\x74", "\x26\x75",
  /* U+33BC */	"\x26\x76", "\x26\x77", "\x26\x78", "\x26\x79",
  /* U+33C0 */	"\x26\x80", "\x26\x81", "\x26\x82", "\x26\x83",
  /* U+33C4 */	"\xA9\x50", "\x26\x84", "\x26\x85", "\x26\x86",
  /* U+33C8 */	"\x26\x87", "\x26\x88", "\x26\x89", "\x26\x90",
  /* U+33CC */	"\x26\x91", "\x26\x92", "\xA9\x51", "\x26\x93",
  /* U+33D0 */	"\x26\x94", "\xA9\x52", "\xA9\x53", "\x26\x95",
  /* U+33D4 */	"\x26\x96", "\xA9\x54", "\x26\x97", "\x26\x98",
  /* U+33D8 */	"\x26\x99", "\x26\xA0", "\x26\xA1", "\x26\xA2",
  /* U+33DC */	"\x26\xA3", "\x26\xA4", "\x26\xA5", "\x26\xA6",
  /* U+33E0 */	"\x26\xA7", "\x26\xA8", "\x26\xA9", "\x26\xB0",
  /* U+33E4 */	"\x26\xB1", "\x26\xB2", "\x26\xB3", "\x26\xB4",
  /* U+33E8 */	"\x26\xB5", "\x26\xB6", "\x26\xB7", "\x26\xB8",
  /* U+33EC */	"\x26\xB9", "\x26\xC0", "\x26\xC1", "\x26\xC2",
  /* U+33F0 */	"\x26\xC3", "\x26\xC4", "\x26\xC5", "\x26\xC6",
  /* U+33F4 */	"\x26\xC7", "\x26\xC8", "\x26\xC9", "\x26\xD0",
  /* U+33F8 */	"\x26\xD1", "\x26\xD2", "\x26\xD3", "\x26\xD4",
  /* U+33FC */	"\x26\xD5", "\x26\xD6", "\x26\xD7", "\x26\xD8",
  /* U+3400 */	"\x26\xD9", "\x26\xE0", "\x26\xE1", "\x26\xE2",
  /* U+3404 */	"\x26\xE3", "\x26\xE4", "\x26\xE5", "\x26\xE6",
  /* U+3408 */	"\x26\xE7", "\x26\xE8", "\x26\xE9", "\x26\xF0",
  /* U+340C */	"\x26\xF1", "\x26\xF2", "\x26\xF3", "\x26\xF4",
  /* U+3410 */	"\x26\xF5", "\x26\xF6", "\x26\xF7", "\x26\xF8",
  /* U+3414 */	"\x26\xF9", "\x27\x00", "\x27\x01", "\x27\x02",
  /* U+3418 */	"\x27\x03", "\x27\x04", "\x27\x05", "\x27\x06",
  /* U+341C */	"\x27\x07", "\x27\x08", "\x27\x09", "\x27\x10",
  /* U+3420 */	"\x27\x11", "\x27\x12", "\x27\x13", "\x27\x14",
  /* U+3424 */	"\x27\x15", "\x27\x16", "\x27\x17", "\x27\x18",
  /* U+3428 */	"\x27\x19", "\x27\x20", "\x27\x21", "\x27\x22",
  /* U+342C */	"\x27\x23", "\x27\x24", "\x27\x25", "\x27\x26",
  /* U+3430 */	"\x27\x27", "\x27\x28", "\x27\x29", "\x27\x30",
  /* U+3434 */	"\x27\x31", "\x27\x32", "\x27\x33", "\x27\x34",
  /* U+3438 */	"\x27\x35", "\x27\x36", "\x27\x37", "\x27\x38",
  /* U+343C */	"\x27\x39", "\x27\x40", "\x27\x41", "\x27\x42",
  /* U+3440 */	"\x27\x43", "\x27\x44", "\x27\x45", "\x27\x46",
  /* U+3444 */	"\x27\x47", "\x27\x48", "\x27\x49", "\xFE\x56",
  /* U+3448 */	"\x27\x50", "\x27\x51", "\x27\x52", "\x27\x53",
  /* U+344C */	"\x27\x54", "\x27\x55", "\x27\x56", "\x27\x57",
  /* U+3450 */	"\x27\x58", "\x27\x59", "\x27\x60", "\x27\x61",
  /* U+3454 */	"\x27\x62", "\x27\x63", "\x27\x64", "\x27\x65",
  /* U+3458 */	"\x27\x66", "\x27\x67", "\x27\x68", "\x27\x69",
  /* U+345C */	"\x27\x70", "\x27\x71", "\x27\x72", "\x27\x73",
  /* U+3460 */	"\x27\x74", "\x27\x75", "\x27\x76", "\x27\x77",
  /* U+3464 */	"\x27\x78", "\x27\x79", "\x27\x80", "\x27\x81",
  /* U+3468 */	"\x27\x82", "\x27\x83", "\x27\x84", "\x27\x85",
  /* U+346C */	"\x27\x86", "\x27\x87", "\x27\x88", "\x27\x89",
  /* U+3470 */	"\x27\x90", "\x27\x91", "\x27\x92", "\xFE\x55",
  /* U+3474 */	"\x27\x93", "\x27\x94", "\x27\x95", "\x27\x96",
  /* U+3478 */	"\x27\x97", "\x27\x98", "\x27\x99", "\x27\xA0",
  /* U+347C */	"\x27\xA1", "\x27\xA2", "\x27\xA3", "\x27\xA4",
  /* U+3480 */	"\x27\xA5", "\x27\xA6", "\x27\xA7", "\x27\xA8",
  /* U+3484 */	"\x27\xA9", "\x27\xB0", "\x27\xB1", "\x27\xB2",
  /* U+3488 */	"\x27\xB3", "\x27\xB4", "\x27\xB5", "\x27\xB6",
  /* U+348C */	"\x27\xB7", "\x27\xB8", "\x27\xB9", "\x27\xC0",
  /* U+3490 */	"\x27\xC1", "\x27\xC2", "\x27\xC3", "\x27\xC4",
  /* U+3494 */	"\x27\xC5", "\x27\xC6", "\x27\xC7", "\x27\xC8",
  /* U+3498 */	"\x27\xC9", "\x27\xD0", "\x27\xD1", "\x27\xD2",
  /* U+349C */	"\x27\xD3", "\x27\xD4", "\x27\xD5", "\x27\xD6",
  /* U+34A0 */	"\x27\xD7", "\x27\xD8", "\x27\xD9", "\x30\x00",
  /* U+34A4 */	"\x30\x01", "\x30\x02", "\x30\x03", "\x30\x04",
  /* U+34A8 */	"\x30\x05", "\x30\x06", "\x30\x07", "\x30\x08",
  /* U+34AC */	"\x30\x09", "\x30\x10", "\x30\x11", "\x30\x12",
  /* U+34B0 */	"\x30\x13", "\x30\x14", "\x30\x15", "\x30\x16",
  /* U+34B4 */	"\x30\x17", "\x30\x18", "\x30\x19", "\x30\x20",
  /* U+34B8 */	"\x30\x21", "\x30\x22", "\x30\x23", "\x30\x24",
  /* U+34BC */	"\x30\x25", "\x30\x26", "\x30\x27", "\x30\x28",
  /* U+34C0 */	"\x30\x29", "\x30\x30", "\x30\x31", "\x30\x32",
  /* U+34C4 */	"\x30\x33", "\x30\x34", "\x30\x35", "\x30\x36",
  /* U+34C8 */	"\x30\x37", "\x30\x38", "\x30\x39", "\x30\x40",
  /* U+34CC */	"\x30\x41", "\x30\x42", "\x30\x43", "\x30\x44",
  /* U+34D0 */	"\x30\x45", "\x30\x46", "\x30\x47", "\x30\x48",
  /* U+34D4 */	"\x30\x49", "\x30\x50", "\x30\x51", "\x30\x52",
  /* U+34D8 */	"\x30\x53", "\x30\x54", "\x30\x55", "\x30\x56",
  /* U+34DC */	"\x30\x57", "\x30\x58", "\x30\x59", "\x30\x60",
  /* U+34E0 */	"\x30\x61", "\x30\x62", "\x30\x63", "\x30\x64",
  /* U+34E4 */	"\x30\x65", "\x30\x66", "\x30\x67", "\x30\x68",
  /* U+34E8 */	"\x30\x69", "\x30\x70", "\x30\x71", "\x30\x72",
  /* U+34EC */	"\x30\x73", "\x30\x74", "\x30\x75", "\x30\x76",
  /* U+34F0 */	"\x30\x77", "\x30\x78", "\x30\x79", "\x30\x80",
  /* U+34F4 */	"\x30\x81", "\x30\x82", "\x30\x83", "\x30\x84",
  /* U+34F8 */	"\x30\x85", "\x30\x86", "\x30\x87", "\x30\x88",
  /* U+34FC */	"\x30\x89", "\x30\x90", "\x30\x91", "\x30\x92",
  /* U+3500 */	"\x30\x93", "\x30\x94", "\x30\x95", "\x30\x96",
  /* U+3504 */	"\x30\x97", "\x30\x98", "\x30\x99", "\x30\xA0",
  /* U+3508 */	"\x30\xA1", "\x30\xA2", "\x30\xA3", "\x30\xA4",
  /* U+350C */	"\x30\xA5", "\x30\xA6", "\x30\xA7", "\x30\xA8",
  /* U+3510 */	"\x30\xA9", "\x30\xB0", "\x30\xB1", "\x30\xB2",
  /* U+3514 */	"\x30\xB3", "\x30\xB4", "\x30\xB5", "\x30\xB6",
  /* U+3518 */	"\x30\xB7", "\x30\xB8", "\x30\xB9", "\x30\xC0",
  /* U+351C */	"\x30\xC1", "\x30\xC2", "\x30\xC3", "\x30\xC4",
  /* U+3520 */	"\x30\xC5", "\x30\xC6", "\x30\xC7", "\x30\xC8",
  /* U+3524 */	"\x30\xC9", "\x30\xD0", "\x30\xD1", "\x30\xD2",
  /* U+3528 */	"\x30\xD3", "\x30\xD4", "\x30\xD5", "\x30\xD6",
  /* U+352C */	"\x30\xD7", "\x30\xD8", "\x30\xD9", "\x30\xE0",
  /* U+3530 */	"\x30\xE1", "\x30\xE2", "\x30\xE3", "\x30\xE4",
  /* U+3534 */	"\x30\xE5", "\x30\xE6", "\x30\xE7", "\x30\xE8",
  /* U+3538 */	"\x30\xE9", "\x30\xF0", "\x30\xF1", "\x30\xF2",
  /* U+353C */	"\x30\xF3", "\x30\xF4", "\x30\xF5", "\x30\xF6",
  /* U+3540 */	"\x30\xF7", "\x30\xF8", "\x30\xF9", "\x31\x00",
  /* U+3544 */	"\x31\x01", "\x31\x02", "\x31\x03", "\x31\x04",
  /* U+3548 */	"\x31\x05", "\x31\x06", "\x31\x07", "\x31\x08",
  /* U+354C */	"\x31\x09", "\x31\x10", "\x31\x11", "\x31\x12",
  /* U+3550 */	"\x31\x13", "\x31\x14", "\x31\x15", "\x31\x16",
  /* U+3554 */	"\x31\x17", "\x31\x18", "\x31\x19", "\x31\x20",
  /* U+3558 */	"\x31\x21", "\x31\x22", "\x31\x23", "\x31\x24",
  /* U+355C */	"\x31\x25", "\x31\x26", "\x31\x27", "\x31\x28",
  /* U+3560 */	"\x31\x29", "\x31\x30", "\x31\x31", "\x31\x32",
  /* U+3564 */	"\x31\x33", "\x31\x34", "\x31\x35", "\x31\x36",
  /* U+3568 */	"\x31\x37", "\x31\x38", "\x31\x39", "\x31\x40",
  /* U+356C */	"\x31\x41", "\x31\x42", "\x31\x43", "\x31\x44",
  /* U+3570 */	"\x31\x45", "\x31\x46", "\x31\x47", "\x31\x48",
  /* U+3574 */	"\x31\x49", "\x31\x50", "\x31\x51", "\x31\x52",
  /* U+3578 */	"\x31\x53", "\x31\x54", "\x31\x55", "\x31\x56",
  /* U+357C */	"\x31\x57", "\x31\x58", "\x31\x59", "\x31\x60",
  /* U+3580 */	"\x31\x61", "\x31\x62", "\x31\x63", "\x31\x64",
  /* U+3584 */	"\x31\x65", "\x31\x66", "\x31\x67", "\x31\x68",
  /* U+3588 */	"\x31\x69", "\x31\x70", "\x31\x71", "\x31\x72",
  /* U+358C */	"\x31\x73", "\x31\x74", "\x31\x75", "\x31\x76",
  /* U+3590 */	"\x31\x77", "\x31\x78", "\x31\x79", "\x31\x80",
  /* U+3594 */	"\x31\x81", "\x31\x82", "\x31\x83", "\x31\x84",
  /* U+3598 */	"\x31\x85", "\x31\x86", "\x31\x87", "\x31\x88",
  /* U+359C */	"\x31\x89", "\x31\x90", "\xFE\x5A", "\x31\x91",
  /* U+35A0 */	"\x31\x92", "\x31\x93", "\x31\x94", "\x31\x95",
  /* U+35A4 */	"\x31\x96", "\x31\x97", "\x31\x98", "\x31\x99",
  /* U+35A8 */	"\x31\xA0", "\x31\xA1", "\x31\xA2", "\x31\xA3",
  /* U+35AC */	"\x31\xA4", "\x31\xA5", "\x31\xA6", "\x31\xA7",
  /* U+35B0 */	"\x31\xA8", "\x31\xA9", "\x31\xB0", "\x31\xB1",
  /* U+35B4 */	"\x31\xB2", "\x31\xB3", "\x31\xB4", "\x31\xB5",
  /* U+35B8 */	"\x31\xB6", "\x31\xB7", "\x31\xB8", "\x31\xB9",
  /* U+35BC */	"\x31\xC0", "\x31\xC1", "\x31\xC2", "\x31\xC3",
  /* U+35C0 */	"\x31\xC4", "\x31\xC5", "\x31\xC6", "\x31\xC7",
  /* U+35C4 */	"\x31\xC8", "\x31\xC9", "\x31\xD0", "\x31\xD1",
  /* U+35C8 */	"\x31\xD2", "\x31\xD3", "\x31\xD4", "\x31\xD5",
  /* U+35CC */	"\x31\xD6", "\x31\xD7", "\x31\xD8", "\x31\xD9",
  /* U+35D0 */	"\x31\xE0", "\x31\xE1", "\x31\xE2", "\x31\xE3",
  /* U+35D4 */	"\x31\xE4", "\x31\xE5", "\x31\xE6", "\x31\xE7",
  /* U+35D8 */	"\x31\xE8", "\x31\xE9", "\x31\xF0", "\x31\xF1",
  /* U+35DC */	"\x31\xF2", "\x31\xF3", "\x31\xF4", "\x31\xF5",
  /* U+35E0 */	"\x31\xF6", "\x31\xF7", "\x31\xF8", "\x31\xF9",
  /* U+35E4 */	"\x32\x00", "\x32\x01", "\x32\x02", "\x32\x03",
  /* U+35E8 */	"\x32\x04", "\x32\x05", "\x32\x06", "\x32\x07",
  /* U+35EC */	"\x32\x08", "\x32\x09", "\x32\x10", "\x32\x11",
  /* U+35F0 */	"\x32\x12", "\x32\x13", "\x32\x14", "\x32\x15",
  /* U+35F4 */	"\x32\x16", "\x32\x17", "\x32\x18", "\x32\x19",
  /* U+35F8 */	"\x32\x20", "\x32\x21", "\x32\x22", "\x32\x23",
  /* U+35FC */	"\x32\x24", "\x32\x25", "\x32\x26", "\x32\x27",
  /* U+3600 */	"\x32\x28", "\x32\x29", "\x32\x30", "\x32\x31",
  /* U+3604 */	"\x32\x32", "\x32\x33", "\x32\x34", "\x32\x35",
  /* U+3608 */	"\x32\x36", "\x32\x37", "\x32\x38", "\x32\x39",
  /* U+360C */	"\x32\x40", "\x32\x41", "\xFE\x5C", "\x32\x42",
  /* U+3610 */	"\x32\x43", "\x32\x44", "\x32\x45", "\x32\x46",
  /* U+3614 */	"\x32\x47", "\x32\x48", "\x32\x49", "\x32\x50",
  /* U+3618 */	"\x32\x51", "\x32\x52", "\xFE\x5B", 
  /* Contiguous area: U+3918 .. U+3CE0 */
  /* U+3918 */	"\xFE\x60", "\x37\x18", "\x37\x19", "\x37\x20",
  /* U+391C */	"\x37\x21", "\x37\x22", "\x37\x23", "\x37\x24",
  /* U+3920 */	"\x37\x25", "\x37\x26", "\x37\x27", "\x37\x28",
  /* U+3924 */	"\x37\x29", "\x37\x30", "\x37\x31", "\x37\x32",
  /* U+3928 */	"\x37\x33", "\x37\x34", "\x37\x35", "\x37\x36",
  /* U+392C */	"\x37\x37", "\x37\x38", "\x37\x39", "\x37\x40",
  /* U+3930 */	"\x37\x41", "\x37\x42", "\x37\x43", "\x37\x44",
  /* U+3934 */	"\x37\x45", "\x37\x46", "\x37\x47", "\x37\x48",
  /* U+3938 */	"\x37\x49", "\x37\x50", "\x37\x51", "\x37\x52",
  /* U+393C */	"\x37\x53", "\x37\x54", "\x37\x55", "\x37\x56",
  /* U+3940 */	"\x37\x57", "\x37\x58", "\x37\x59", "\x37\x60",
  /* U+3944 */	"\x37\x61", "\x37\x62", "\x37\x63", "\x37\x64",
  /* U+3948 */	"\x37\x65", "\x37\x66", "\x37\x67", "\x37\x68",
  /* U+394C */	"\x37\x69", "\x37\x70", "\x37\x71", "\x37\x72",
  /* U+3950 */	"\x37\x73", "\x37\x74", "\x37\x75", "\x37\x76",
  /* U+3954 */	"\x37\x77", "\x37\x78", "\x37\x79", "\x37\x80",
  /* U+3958 */	"\x37\x81", "\x37\x82", "\x37\x83", "\x37\x84",
  /* U+395C */	"\x37\x85", "\x37\x86", "\x37\x87", "\x37\x88",
  /* U+3960 */	"\x37\x89", "\x37\x90", "\x37\x91", "\x37\x92",
  /* U+3964 */	"\x37\x93", "\x37\x94", "\x37\x95", "\x37\x96",
  /* U+3968 */	"\x37\x97", "\x37\x98", "\x37\x99", "\x37\xA0",
  /* U+396C */	"\x37\xA1", "\x37\xA2", "\xFE\x5F", "\x37\xA3",
  /* U+3970 */	"\x37\xA4", "\x37\xA5", "\x37\xA6", "\x37\xA7",
  /* U+3974 */	"\x37\xA8", "\x37\xA9", "\x37\xB0", "\x37\xB1",
  /* U+3978 */	"\x37\xB2", "\x37\xB3", "\x37\xB4", "\x37\xB5",
  /* U+397C */	"\x37\xB6", "\x37\xB7", "\x37\xB8", "\x37\xB9",
  /* U+3980 */	"\x37\xC0", "\x37\xC1", "\x37\xC2", "\x37\xC3",
  /* U+3984 */	"\x37\xC4", "\x37\xC5", "\x37\xC6", "\x37\xC7",
  /* U+3988 */	"\x37\xC8", "\x37\xC9", "\x37\xD0", "\x37\xD1",
  /* U+398C */	"\x37\xD2", "\x37\xD3", "\x37\xD4", "\x37\xD5",
  /* U+3990 */	"\x37\xD6", "\x37\xD7", "\x37\xD8", "\x37\xD9",
  /* U+3994 */	"\x38\x00", "\x38\x01", "\x38\x02", "\x38\x03",
  /* U+3998 */	"\x38\x04", "\x38\x05", "\x38\x06", "\x38\x07",
  /* U+399C */	"\x38\x08", "\x38\x09", "\x38\x10", "\x38\x11",
  /* U+39A0 */	"\x38\x12", "\x38\x13", "\x38\x14", "\x38\x15",
  /* U+39A4 */	"\x38\x16", "\x38\x17", "\x38\x18", "\x38\x19",
  /* U+39A8 */	"\x38\x20", "\x38\x21", "\x38\x22", "\x38\x23",
  /* U+39AC */	"\x38\x24", "\x38\x25", "\x38\x26", "\x38\x27",
  /* U+39B0 */	"\x38\x28", "\x38\x29", "\x38\x30", "\x38\x31",
  /* U+39B4 */	"\x38\x32", "\x38\x33", "\x38\x34", "\x38\x35",
  /* U+39B8 */	"\x38\x36", "\x38\x37", "\x38\x38", "\x38\x39",
  /* U+39BC */	"\x38\x40", "\x38\x41", "\x38\x42", "\x38\x43",
  /* U+39C0 */	"\x38\x44", "\x38\x45", "\x38\x46", "\x38\x47",
  /* U+39C4 */	"\x38\x48", "\x38\x49", "\x38\x50", "\x38\x51",
  /* U+39C8 */	"\x38\x52", "\x38\x53", "\x38\x54", "\x38\x55",
  /* U+39CC */	"\x38\x56", "\x38\x57", "\x38\x58", "\xFE\x62",
  /* U+39D0 */	"\xFE\x65", "\x38\x59", "\x38\x60", "\x38\x61",
  /* U+39D4 */	"\x38\x62", "\x38\x63", "\x38\x64", "\x38\x65",
  /* U+39D8 */	"\x38\x66", "\x38\x67", "\x38\x68", "\x38\x69",
  /* U+39DC */	"\x38\x70", "\x38\x71", "\x38\x72", "\xFE\x63",
  /* U+39E0 */	"\x38\x73", "\x38\x74", "\x38\x75", "\x38\x76",
  /* U+39E4 */	"\x38\x77", "\x38\x78", "\x38\x79", "\x38\x80",
  /* U+39E8 */	"\x38\x81", "\x38\x82", "\x38\x83", "\x38\x84",
  /* U+39EC */	"\x38\x85", "\x38\x86", "\x38\x87", "\x38\x88",
  /* U+39F0 */	"\x38\x89", "\x38\x90", "\x38\x91", "\x38\x92",
  /* U+39F4 */	"\x38\x93", "\x38\x94", "\x38\x95", "\x38\x96",
  /* U+39F8 */	"\x38\x97", "\x38\x98", "\x38\x99", "\x38\xA0",
  /* U+39FC */	"\x38\xA1", "\x38\xA2", "\x38\xA3", "\x38\xA4",
  /* U+3A00 */	"\x38\xA5", "\x38\xA6", "\x38\xA7", "\x38\xA8",
  /* U+3A04 */	"\x38\xA9", "\x38\xB0", "\x38\xB1", "\x38\xB2",
  /* U+3A08 */	"\x38\xB3", "\x38\xB4", "\x38\xB5", "\x38\xB6",
  /* U+3A0C */	"\x38\xB7", "\x38\xB8", "\x38\xB9", "\x38\xC0",
  /* U+3A10 */	"\x38\xC1", "\x38\xC2", "\x38\xC3", "\x38\xC4",
  /* U+3A14 */	"\x38\xC5", "\x38\xC6", "\x38\xC7", "\x38\xC8",
  /* U+3A18 */	"\x38\xC9", "\x38\xD0", "\x38\xD1", "\x38\xD2",
  /* U+3A1C */	"\x38\xD3", "\x38\xD4", "\x38\xD5", "\x38\xD6",
  /* U+3A20 */	"\x38\xD7", "\x38\xD8", "\x38\xD9", "\x38\xE0",
  /* U+3A24 */	"\x38\xE1", "\x38\xE2", "\x38\xE3", "\x38\xE4",
  /* U+3A28 */	"\x38\xE5", "\x38\xE6", "\x38\xE7", "\x38\xE8",
  /* U+3A2C */	"\x38\xE9", "\x38\xF0", "\x38\xF1", "\x38\xF2",
  /* U+3A30 */	"\x38\xF3", "\x38\xF4", "\x38\xF5", "\x38\xF6",
  /* U+3A34 */	"\x38\xF7", "\x38\xF8", "\x38\xF9", "\x39\x00",
  /* U+3A38 */	"\x39\x01", "\x39\x02", "\x39\x03", "\x39\x04",
  /* U+3A3C */	"\x39\x05", "\x39\x06", "\x39\x07", "\x39\x08",
  /* U+3A40 */	"\x39\x09", "\x39\x10", "\x39\x11", "\x39\x12",
  /* U+3A44 */	"\x39\x13", "\x39\x14", "\x39\x15", "\x39\x16",
  /* U+3A48 */	"\x39\x17", "\x39\x18", "\x39\x19", "\x39\x20",
  /* U+3A4C */	"\x39\x21", "\x39\x22", "\x39\x23", "\x39\x24",
  /* U+3A50 */	"\x39\x25", "\x39\x26", "\x39\x27", "\x39\x28",
  /* U+3A54 */	"\x39\x29", "\x39\x30", "\x39\x31", "\x39\x32",
  /* U+3A58 */	"\x39\x33", "\x39\x34", "\x39\x35", "\x39\x36",
  /* U+3A5C */	"\x39\x37", "\x39\x38", "\x39\x39", "\x39\x40",
  /* U+3A60 */	"\x39\x41", "\x39\x42", "\x39\x43", "\x39\x44",
  /* U+3A64 */	"\x39\x45", "\x39\x46", "\x39\x47", "\x39\x48",
  /* U+3A68 */	"\x39\x49", "\x39\x50", "\x39\x51", "\x39\x52",
  /* U+3A6C */	"\x39\x53", "\x39\x54", "\x39\x55", "\x39\x56",
  /* U+3A70 */	"\x39\x57", "\x39\x58", "\x39\x59", "\xFE\x64",
  /* U+3A74 */	"\x39\x60", "\x39\x61", "\x39\x62", "\x39\x63",
  /* U+3A78 */	"\x39\x64", "\x39\x65", "\x39\x66", "\x39\x67",
  /* U+3A7C */	"\x39\x68", "\x39\x69", "\x39\x70", "\x39\x71",
  /* U+3A80 */	"\x39\x72", "\x39\x73", "\x39\x74", "\x39\x75",
  /* U+3A84 */	"\x39\x76", "\x39\x77", "\x39\x78", "\x39\x79",
  /* U+3A88 */	"\x39\x80", "\x39\x81", "\x39\x82", "\x39\x83",
  /* U+3A8C */	"\x39\x84", "\x39\x85", "\x39\x86", "\x39\x87",
  /* U+3A90 */	"\x39\x88", "\x39\x89", "\x39\x90", "\x39\x91",
  /* U+3A94 */	"\x39\x92", "\x39\x93", "\x39\x94", "\x39\x95",
  /* U+3A98 */	"\x39\x96", "\x39\x97", "\x39\x98", "\x39\x99",
  /* U+3A9C */	"\x39\xA0", "\x39\xA1", "\x39\xA2", "\x39\xA3",
  /* U+3AA0 */	"\x39\xA4", "\x39\xA5", "\x39\xA6", "\x39\xA7",
  /* U+3AA4 */	"\x39\xA8", "\x39\xA9", "\x39\xB0", "\x39\xB1",
  /* U+3AA8 */	"\x39\xB2", "\x39\xB3", "\x39\xB4", "\x39\xB5",
  /* U+3AAC */	"\x39\xB6", "\x39\xB7", "\x39\xB8", "\x39\xB9",
  /* U+3AB0 */	"\x39\xC0", "\x39\xC1", "\x39\xC2", "\x39\xC3",
  /* U+3AB4 */	"\x39\xC4", "\x39\xC5", "\x39\xC6", "\x39\xC7",
  /* U+3AB8 */	"\x39\xC8", "\x39\xC9", "\x39\xD0", "\x39\xD1",
  /* U+3ABC */	"\x39\xD2", "\x39\xD3", "\x39\xD4", "\x39\xD5",
  /* U+3AC0 */	"\x39\xD6", "\x39\xD7", "\x39\xD8", "\x39\xD9",
  /* U+3AC4 */	"\x39\xE0", "\x39\xE1", "\x39\xE2", "\x39\xE3",
  /* U+3AC8 */	"\x39\xE4", "\x39\xE5", "\x39\xE6", "\x39\xE7",
  /* U+3ACC */	"\x39\xE8", "\x39\xE9", "\x39\xF0", "\x39\xF1",
  /* U+3AD0 */	"\x39\xF2", "\x39\xF3", "\x39\xF4", "\x39\xF5",
  /* U+3AD4 */	"\x39\xF6", "\x39\xF7", "\x39\xF8", "\x39\xF9",
  /* U+3AD8 */	"\x3A\x00", "\x3A\x01", "\x3A\x02", "\x3A\x03",
  /* U+3ADC */	"\x3A\x04", "\x3A\x05", "\x3A\x06", "\x3A\x07",
  /* U+3AE0 */	"\x3A\x08", "\x3A\x09", "\x3A\x10", "\x3A\x11",
  /* U+3AE4 */	"\x3A\x12", "\x3A\x13", "\x3A\x14", "\x3A\x15",
  /* U+3AE8 */	"\x3A\x16", "\x3A\x17", "\x3A\x18", "\x3A\x19",
  /* U+3AEC */	"\x3A\x20", "\x3A\x21", "\x3A\x22", "\x3A\x23",
  /* U+3AF0 */	"\x3A\x24", "\x3A\x25", "\x3A\x26", "\x3A\x27",
  /* U+3AF4 */	"\x3A\x28", "\x3A\x29", "\x3A\x30", "\x3A\x31",
  /* U+3AF8 */	"\x3A\x32", "\x3A\x33", "\x3A\x34", "\x3A\x35",
  /* U+3AFC */	"\x3A\x36", "\x3A\x37", "\x3A\x38", "\x3A\x39",
  /* U+3B00 */	"\x3A\x40", "\x3A\x41", "\x3A\x42", "\x3A\x43",
  /* U+3B04 */	"\x3A\x44", "\x3A\x45", "\x3A\x46", "\x3A\x47",
  /* U+3B08 */	"\x3A\x48", "\x3A\x49", "\x3A\x50", "\x3A\x51",
  /* U+3B0C */	"\x3A\x52", "\x3A\x53", "\x3A\x54", "\x3A\x55",
  /* U+3B10 */	"\x3A\x56", "\x3A\x57", "\x3A\x58", "\x3A\x59",
  /* U+3B14 */	"\x3A\x60", "\x3A\x61", "\x3A\x62", "\x3A\x63",
  /* U+3B18 */	"\x3A\x64", "\x3A\x65", "\x3A\x66", "\x3A\x67",
  /* U+3B1C */	"\x3A\x68", "\x3A\x69", "\x3A\x70", "\x3A\x71",
  /* U+3B20 */	"\x3A\x72", "\x3A\x73", "\x3A\x74", "\x3A\x75",
  /* U+3B24 */	"\x3A\x76", "\x3A\x77", "\x3A\x78", "\x3A\x79",
  /* U+3B28 */	"\x3A\x80", "\x3A\x81", "\x3A\x82", "\x3A\x83",
  /* U+3B2C */	"\x3A\x84", "\x3A\x85", "\x3A\x86", "\x3A\x87",
  /* U+3B30 */	"\x3A\x88", "\x3A\x89", "\x3A\x90", "\x3A\x91",
  /* U+3B34 */	"\x3A\x92", "\x3A\x93", "\x3A\x94", "\x3A\x95",
  /* U+3B38 */	"\x3A\x96", "\x3A\x97", "\x3A\x98", "\x3A\x99",
  /* U+3B3C */	"\x3A\xA0", "\x3A\xA1", "\x3A\xA2", "\x3A\xA3",
  /* U+3B40 */	"\x3A\xA4", "\x3A\xA5", "\x3A\xA6", "\x3A\xA7",
  /* U+3B44 */	"\x3A\xA8", "\x3A\xA9", "\x3A\xB0", "\x3A\xB1",
  /* U+3B48 */	"\x3A\xB2", "\x3A\xB3", "\x3A\xB4", "\x3A\xB5",
  /* U+3B4C */	"\x3A\xB6", "\x3A\xB7", "\xFE\x68", "\x3A\xB8",
  /* U+3B50 */	"\x3A\xB9", "\x3A\xC0", "\x3A\xC1", "\x3A\xC2",
  /* U+3B54 */	"\x3A\xC3", "\x3A\xC4", "\x3A\xC5", "\x3A\xC6",
  /* U+3B58 */	"\x3A\xC7", "\x3A\xC8", "\x3A\xC9", "\x3A\xD0",
  /* U+3B5C */	"\x3A\xD1", "\x3A\xD2", "\x3A\xD3", "\x3A\xD4",
  /* U+3B60 */	"\x3A\xD5", "\x3A\xD6", "\x3A\xD7", "\x3A\xD8",
  /* U+3B64 */	"\x3A\xD9", "\x3A\xE0", "\x3A\xE1", "\x3A\xE2",
  /* U+3B68 */	"\x3A\xE3", "\x3A\xE4", "\x3A\xE5", "\x3A\xE6",
  /* U+3B6C */	"\x3A\xE7", "\x3A\xE8", "\x3A\xE9", "\x3A\xF0",
  /* U+3B70 */	"\x3A\xF1", "\x3A\xF2", "\x3A\xF3", "\x3A\xF4",
  /* U+3B74 */	"\x3A\xF5", "\x3A\xF6", "\x3A\xF7", "\x3A\xF8",
  /* U+3B78 */	"\x3A\xF9", "\x3B\x00", "\x3B\x01", "\x3B\x02",
  /* U+3B7C */	"\x3B\x03", "\x3B\x04", "\x3B\x05", "\x3B\x06",
  /* U+3B80 */	"\x3B\x07", "\x3B\x08", "\x3B\x09", "\x3B\x10",
  /* U+3B84 */	"\x3B\x11", "\x3B\x12", "\x3B\x13", "\x3B\x14",
  /* U+3B88 */	"\x3B\x15", "\x3B\x16", "\x3B\x17", "\x3B\x18",
  /* U+3B8C */	"\x3B\x19", "\x3B\x20", "\x3B\x21", "\x3B\x22",
  /* U+3B90 */	"\x3B\x23", "\x3B\x24", "\x3B\x25", "\x3B\x26",
  /* U+3B94 */	"\x3B\x27", "\x3B\x28", "\x3B\x29", "\x3B\x30",
  /* U+3B98 */	"\x3B\x31", "\x3B\x32", "\x3B\x33", "\x3B\x34",
  /* U+3B9C */	"\x3B\x35", "\x3B\x36", "\x3B\x37", "\x3B\x38",
  /* U+3BA0 */	"\x3B\x39", "\x3B\x40", "\x3B\x41", "\x3B\x42",
  /* U+3BA4 */	"\x3B\x43", "\x3B\x44", "\x3B\x45", "\x3B\x46",
  /* U+3BA8 */	"\x3B\x47", "\x3B\x48", "\x3B\x49", "\x3B\x50",
  /* U+3BAC */	"\x3B\x51", "\x3B\x52", "\x3B\x53", "\x3B\x54",
  /* U+3BB0 */	"\x3B\x55", "\x3B\x56", "\x3B\x57", "\x3B\x58",
  /* U+3BB4 */	"\x3B\x59", "\x3B\x60", "\x3B\x61", "\x3B\x62",
  /* U+3BB8 */	"\x3B\x63", "\x3B\x64", "\x3B\x65", "\x3B\x66",
  /* U+3BBC */	"\x3B\x67", "\x3B\x68", "\x3B\x69", "\x3B\x70",
  /* U+3BC0 */	"\x3B\x71", "\x3B\x72", "\x3B\x73", "\x3B\x74",
  /* U+3BC4 */	"\x3B\x75", "\x3B\x76", "\x3B\x77", "\x3B\x78",
  /* U+3BC8 */	"\x3B\x79", "\x3B\x80", "\x3B\x81", "\x3B\x82",
  /* U+3BCC */	"\x3B\x83", "\x3B\x84", "\x3B\x85", "\x3B\x86",
  /* U+3BD0 */	"\x3B\x87", "\x3B\x88", "\x3B\x89", "\x3B\x90",
  /* U+3BD4 */	"\x3B\x91", "\x3B\x92", "\x3B\x93", "\x3B\x94",
  /* U+3BD8 */	"\x3B\x95", "\x3B\x96", "\x3B\x97", "\x3B\x98",
  /* U+3BDC */	"\x3B\x99", "\x3B\xA0", "\x3B\xA1", "\x3B\xA2",
  /* U+3BE0 */	"\x3B\xA3", "\x3B\xA4", "\x3B\xA5", "\x3B\xA6",
  /* U+3BE4 */	"\x3B\xA7", "\x3B\xA8", "\x3B\xA9", "\x3B\xB0",
  /* U+3BE8 */	"\x3B\xB1", "\x3B\xB2", "\x3B\xB3", "\x3B\xB4",
  /* U+3BEC */	"\x3B\xB5", "\x3B\xB6", "\x3B\xB7", "\x3B\xB8",
  /* U+3BF0 */	"\x3B\xB9", "\x3B\xC0", "\x3B\xC1", "\x3B\xC2",
  /* U+3BF4 */	"\x3B\xC3", "\x3B\xC4", "\x3B\xC5", "\x3B\xC6",
  /* U+3BF8 */	"\x3B\xC7", "\x3B\xC8", "\x3B\xC9", "\x3B\xD0",
  /* U+3BFC */	"\x3B\xD1", "\x3B\xD2", "\x3B\xD3", "\x3B\xD4",
  /* U+3C00 */	"\x3B\xD5", "\x3B\xD6", "\x3B\xD7", "\x3B\xD8",
  /* U+3C04 */	"\x3B\xD9", "\x3B\xE0", "\x3B\xE1", "\x3B\xE2",
  /* U+3C08 */	"\x3B\xE3", "\x3B\xE4", "\x3B\xE5", "\x3B\xE6",
  /* U+3C0C */	"\x3B\xE7", "\x3B\xE8", "\x3B\xE9", "\x3B\xF0",
  /* U+3C10 */	"\x3B\xF1", "\x3B\xF2", "\x3B\xF3", "\x3B\xF4",
  /* U+3C14 */	"\x3B\xF5", "\x3B\xF6", "\x3B\xF7", "\x3B\xF8",
  /* U+3C18 */	"\x3B\xF9", "\x3C\x00", "\x3C\x01", "\x3C\x02",
  /* U+3C1C */	"\x3C\x03", "\x3C\x04", "\x3C\x05", "\x3C\x06",
  /* U+3C20 */	"\x3C\x07", "\x3C\x08", "\x3C\x09", "\x3C\x10",
  /* U+3C24 */	"\x3C\x11", "\x3C\x12", "\x3C\x13", "\x3C\x14",
  /* U+3C28 */	"\x3C\x15", "\x3C\x16", "\x3C\x17", "\x3C\x18",
  /* U+3C2C */	"\x3C\x19", "\x3C\x20", "\x3C\x21", "\x3C\x22",
  /* U+3C30 */	"\x3C\x23", "\x3C\x24", "\x3C\x25", "\x3C\x26",
  /* U+3C34 */	"\x3C\x27", "\x3C\x28", "\x3C\x29", "\x3C\x30",
  /* U+3C38 */	"\x3C\x31", "\x3C\x32", "\x3C\x33", "\x3C\x34",
  /* U+3C3C */	"\x3C\x35", "\x3C\x36", "\x3C\x37", "\x3C\x38",
  /* U+3C40 */	"\x3C\x39", "\x3C\x40", "\x3C\x41", "\x3C\x42",
  /* U+3C44 */	"\x3C\x43", "\x3C\x44", "\x3C\x45", "\x3C\x46",
  /* U+3C48 */	"\x3C\x47", "\x3C\x48", "\x3C\x49", "\x3C\x50",
  /* U+3C4C */	"\x3C\x51", "\x3C\x52", "\x3C\x53", "\x3C\x54",
  /* U+3C50 */	"\x3C\x55", "\x3C\x56", "\x3C\x57", "\x3C\x58",
  /* U+3C54 */	"\x3C\x59", "\x3C\x60", "\x3C\x61", "\x3C\x62",
  /* U+3C58 */	"\x3C\x63", "\x3C\x64", "\x3C\x65", "\x3C\x66",
  /* U+3C5C */	"\x3C\x67", "\x3C\x68", "\x3C\x69", "\x3C\x70",
  /* U+3C60 */	"\x3C\x71", "\x3C\x72", "\x3C\x73", "\x3C\x74",
  /* U+3C64 */	"\x3C\x75", "\x3C\x76", "\x3C\x77", "\x3C\x78",
  /* U+3C68 */	"\x3C\x79", "\x3C\x80", "\x3C\x81", "\x3C\x82",
  /* U+3C6C */	"\x3C\x83", "\x3C\x84", "\xFE\x69", "\x3C\x85",
  /* U+3C70 */	"\x3C\x86", "\x3C\x87", "\x3C\x88", "\x3C\x89",
  /* U+3C74 */	"\x3C\x90", "\x3C\x91", "\x3C\x92", "\x3C\x93",
  /* U+3C78 */	"\x3C\x94", "\x3C\x95", "\x3C\x96", "\x3C\x97",
  /* U+3C7C */	"\x3C\x98", "\x3C\x99", "\x3C\xA0", "\x3C\xA1",
  /* U+3C80 */	"\x3C\xA2", "\x3C\xA3", "\x3C\xA4", "\x3C\xA5",
  /* U+3C84 */	"\x3C\xA6", "\x3C\xA7", "\x3C\xA8", "\x3C\xA9",
  /* U+3C88 */	"\x3C\xB0", "\x3C\xB1", "\x3C\xB2", "\x3C\xB3",
  /* U+3C8C */	"\x3C\xB4", "\x3C\xB5", "\x3C\xB6", "\x3C\xB7",
  /* U+3C90 */	"\x3C\xB8", "\x3C\xB9", "\x3C\xC0", "\x3C\xC1",
  /* U+3C94 */	"\x3C\xC2", "\x3C\xC3", "\x3C\xC4", "\x3C\xC5",
  /* U+3C98 */	"\x3C\xC6", "\x3C\xC7", "\x3C\xC8", "\x3C\xC9",
  /* U+3C9C */	"\x3C\xD0", "\x3C\xD1", "\x3C\xD2", "\x3C\xD3",
  /* U+3CA0 */	"\x3C\xD4", "\x3C\xD5", "\x3C\xD6", "\x3C\xD7",
  /* U+3CA4 */	"\x3C\xD8", "\x3C\xD9", "\x3C\xE0", "\x3C\xE1",
  /* U+3CA8 */	"\x3C\xE2", "\x3C\xE3", "\x3C\xE4", "\x3C\xE5",
  /* U+3CAC */	"\x3C\xE6", "\x3C\xE7", "\x3C\xE8", "\x3C\xE9",
  /* U+3CB0 */	"\x3C\xF0", "\x3C\xF1", "\x3C\xF2", "\x3C\xF3",
  /* U+3CB4 */	"\x3C\xF4", "\x3C\xF5", "\x3C\xF6", "\x3C\xF7",
  /* U+3CB8 */	"\x3C\xF8", "\x3C\xF9", "\x3D\x00", "\x3D\x01",
  /* U+3CBC */	"\x3D\x02", "\x3D\x03", "\x3D\x04", "\x3D\x05",
  /* U+3CC0 */	"\x3D\x06", "\x3D\x07", "\x3D\x08", "\x3D\x09",
  /* U+3CC4 */	"\x3D\x10", "\x3D\x11", "\x3D\x12", "\x3D\x13",
  /* U+3CC8 */	"\x3D\x14", "\x3D\x15", "\x3D\x16", "\x3D\x17",
  /* U+3CCC */	"\x3D\x18", "\x3D\x19", "\x3D\x20", "\x3D\x21",
  /* U+3CD0 */	"\x3D\x22", "\x3D\x23", "\x3D\x24", "\x3D\x25",
  /* U+3CD4 */	"\x3D\x26", "\x3D\x27", "\x3D\x28", "\x3D\x29",
  /* U+3CD8 */	"\x3D\x30", "\x3D\x31", "\x3D\x32", "\x3D\x33",
  /* U+3CDC */	"\x3D\x34", "\x3D\x35", "\x3D\x36", "\x3D\x37",
  /* U+3CE0 */	"\xFE\x6A", 
  /* Contiguous area: U+4056 .. U+415F */
  /* U+4056 */				"\xFE\x6F", "\x42\xE3",
  /* U+4058 */	"\x42\xE4", "\x42\xE5", "\x42\xE6", "\x42\xE7",
  /* U+405C */	"\x42\xE8", "\x42\xE9", "\x42\xF0", "\x42\xF1",
  /* U+4060 */	"\x42\xF2", "\x42\xF3", "\x42\xF4", "\x42\xF5",
  /* U+4064 */	"\x42\xF6", "\x42\xF7", "\x42\xF8", "\x42\xF9",
  /* U+4068 */	"\x43\x00", "\x43\x01", "\x43\x02", "\x43\x03",
  /* U+406C */	"\x43\x04", "\x43\x05", "\x43\x06", "\x43\x07",
  /* U+4070 */	"\x43\x08", "\x43\x09", "\x43\x10", "\x43\x11",
  /* U+4074 */	"\x43\x12", "\x43\x13", "\x43\x14", "\x43\x15",
  /* U+4078 */	"\x43\x16", "\x43\x17", "\x43\x18", "\x43\x19",
  /* U+407C */	"\x43\x20", "\x43\x21", "\x43\x22", "\x43\x23",
  /* U+4080 */	"\x43\x24", "\x43\x25", "\x43\x26", "\x43\x27",
  /* U+4084 */	"\x43\x28", "\x43\x29", "\x43\x30", "\x43\x31",
  /* U+4088 */	"\x43\x32", "\x43\x33", "\x43\x34", "\x43\x35",
  /* U+408C */	"\x43\x36", "\x43\x37", "\x43\x38", "\x43\x39",
  /* U+4090 */	"\x43\x40", "\x43\x41", "\x43\x42", "\x43\x43",
  /* U+4094 */	"\x43\x44", "\x43\x45", "\x43\x46", "\x43\x47",
  /* U+4098 */	"\x43\x48", "\x43\x49", "\x43\x50", "\x43\x51",
  /* U+409C */	"\x43\x52", "\x43\x53", "\x43\x54", "\x43\x55",
  /* U+40A0 */	"\x43\x56", "\x43\x57", "\x43\x58", "\x43\x59",
  /* U+40A4 */	"\x43\x60", "\x43\x61", "\x43\x62", "\x43\x63",
  /* U+40A8 */	"\x43\x64", "\x43\x65", "\x43\x66", "\x43\x67",
  /* U+40AC */	"\x43\x68", "\x43\x69", "\x43\x70", "\x43\x71",
  /* U+40B0 */	"\x43\x72", "\x43\x73", "\x43\x74", "\x43\x75",
  /* U+40B4 */	"\x43\x76", "\x43\x77", "\x43\x78", "\x43\x79",
  /* U+40B8 */	"\x43\x80", "\x43\x81", "\x43\x82", "\x43\x83",
  /* U+40BC */	"\x43\x84", "\x43\x85", "\x43\x86", "\x43\x87",
  /* U+40C0 */	"\x43\x88", "\x43\x89", "\x43\x90", "\x43\x91",
  /* U+40C4 */	"\x43\x92", "\x43\x93", "\x43\x94", "\x43\x95",
  /* U+40C8 */	"\x43\x96", "\x43\x97", "\x43\x98", "\x43\x99",
  /* U+40CC */	"\x43\xA0", "\x43\xA1", "\x43\xA2", "\x43\xA3",
  /* U+40D0 */	"\x43\xA4", "\x43\xA5", "\x43\xA6", "\x43\xA7",
  /* U+40D4 */	"\x43\xA8", "\x43\xA9", "\x43\xB0", "\x43\xB1",
  /* U+40D8 */	"\x43\xB2", "\x43\xB3", "\x43\xB4", "\x43\xB5",
  /* U+40DC */	"\x43\xB6", "\x43\xB7", "\x43\xB8", "\x43\xB9",
  /* U+40E0 */	"\x43\xC0", "\x43\xC1", "\x43\xC2", "\x43\xC3",
  /* U+40E4 */	"\x43\xC4", "\x43\xC5", "\x43\xC6", "\x43\xC7",
  /* U+40E8 */	"\x43\xC8", "\x43\xC9", "\x43\xD0", "\x43\xD1",
  /* U+40EC */	"\x43\xD2", "\x43\xD3", "\x43\xD4", "\x43\xD5",
  /* U+40F0 */	"\x43\xD6", "\x43\xD7", "\x43\xD8", "\x43\xD9",
  /* U+40F4 */	"\x43\xE0", "\x43\xE1", "\x43\xE2", "\x43\xE3",
  /* U+40F8 */	"\x43\xE4", "\x43\xE5", "\x43\xE6", "\x43\xE7",
  /* U+40FC */	"\x43\xE8", "\x43\xE9", "\x43\xF0", "\x43\xF1",
  /* U+4100 */	"\x43\xF2", "\x43\xF3", "\x43\xF4", "\x43\xF5",
  /* U+4104 */	"\x43\xF6", "\x43\xF7", "\x43\xF8", "\x43\xF9",
  /* U+4108 */	"\x44\x00", "\x44\x01", "\x44\x02", "\x44\x03",
  /* U+410C */	"\x44\x04", "\x44\x05", "\x44\x06", "\x44\x07",
  /* U+4110 */	"\x44\x08", "\x44\x09", "\x44\x10", "\x44\x11",
  /* U+4114 */	"\x44\x12", "\x44\x13", "\x44\x14", "\x44\x15",
  /* U+4118 */	"\x44\x16", "\x44\x17", "\x44\x18", "\x44\x19",
  /* U+411C */	"\x44\x20", "\x44\x21", "\x44\x22", "\x44\x23",
  /* U+4120 */	"\x44\x24", "\x44\x25", "\x44\x26", "\x44\x27",
  /* U+4124 */	"\x44\x28", "\x44\x29", "\x44\x30", "\x44\x31",
  /* U+4128 */	"\x44\x32", "\x44\x33", "\x44\x34", "\x44\x35",
  /* U+412C */	"\x44\x36", "\x44\x37", "\x44\x38", "\x44\x39",
  /* U+4130 */	"\x44\x40", "\x44\x41", "\x44\x42", "\x44\x43",
  /* U+4134 */	"\x44\x44", "\x44\x45", "\x44\x46", "\x44\x47",
  /* U+4138 */	"\x44\x48", "\x44\x49", "\x44\x50", "\x44\x51",
  /* U+413C */	"\x44\x52", "\x44\x53", "\x44\x54", "\x44\x55",
  /* U+4140 */	"\x44\x56", "\x44\x57", "\x44\x58", "\x44\x59",
  /* U+4144 */	"\x44\x60", "\x44\x61", "\x44\x62", "\x44\x63",
  /* U+4148 */	"\x44\x64", "\x44\x65", "\x44\x66", "\x44\x67",
  /* U+414C */	"\x44\x68", "\x44\x69", "\x44\x70", "\x44\x71",
  /* U+4150 */	"\x44\x72", "\x44\x73", "\x44\x74", "\x44\x75",
  /* U+4154 */	"\x44\x76", "\x44\x77", "\x44\x78", "\x44\x79",
  /* U+4158 */	"\x44\x80", "\x44\x81", "\x44\x82", "\x44\x83",
  /* U+415C */	"\x44\x84", "\x44\x85", "\x44\x86", "\xFE\x70",
  /* Contiguous area: U+4337 .. U+44D6 */
  /* U+4337 */					    "\xFE\x72",
  /* U+4338 */	"\x47\x78", "\x47\x79", "\x47\x80", "\x47\x81",
  /* U+433C */	"\x47\x82", "\x47\x83", "\x47\x84", "\x47\x85",
  /* U+4340 */	"\x47\x86", "\x47\x87", "\x47\x88", "\x47\x89",
  /* U+4344 */	"\x47\x90", "\x47\x91", "\x47\x92", "\x47\x93",
  /* U+4348 */	"\x47\x94", "\x47\x95", "\x47\x96", "\x47\x97",
  /* U+434C */	"\x47\x98", "\x47\x99", "\x47\xA0", "\x47\xA1",
  /* U+4350 */	"\x47\xA2", "\x47\xA3", "\x47\xA4", "\x47\xA5",
  /* U+4354 */	"\x47\xA6", "\x47\xA7", "\x47\xA8", "\x47\xA9",
  /* U+4358 */	"\x47\xB0", "\x47\xB1", "\x47\xB2", "\x47\xB3",
  /* U+435C */	"\x47\xB4", "\x47\xB5", "\x47\xB6", "\x47\xB7",
  /* U+4360 */	"\x47\xB8", "\x47\xB9", "\x47\xC0", "\x47\xC1",
  /* U+4364 */	"\x47\xC2", "\x47\xC3", "\x47\xC4", "\x47\xC5",
  /* U+4368 */	"\x47\xC6", "\x47\xC7", "\x47\xC8", "\x47\xC9",
  /* U+436C */	"\x47\xD0", "\x47\xD1", "\x47\xD2", "\x47\xD3",
  /* U+4370 */	"\x47\xD4", "\x47\xD5", "\x47\xD6", "\x47\xD7",
  /* U+4374 */	"\x47\xD8", "\x47\xD9", "\x48\x00", "\x48\x01",
  /* U+4378 */	"\x48\x02", "\x48\x03", "\x48\x04", "\x48\x05",
  /* U+437C */	"\x48\x06", "\x48\x07", "\x48\x08", "\x48\x09",
  /* U+4380 */	"\x48\x10", "\x48\x11", "\x48\x12", "\x48\x13",
  /* U+4384 */	"\x48\x14", "\x48\x15", "\x48\x16", "\x48\x17",
  /* U+4388 */	"\x48\x18", "\x48\x19", "\x48\x20", "\x48\x21",
  /* U+438C */	"\x48\x22", "\x48\x23", "\x48\x24", "\x48\x25",
  /* U+4390 */	"\x48\x26", "\x48\x27", "\x48\x28", "\x48\x29",
  /* U+4394 */	"\x48\x30", "\x48\x31", "\x48\x32", "\x48\x33",
  /* U+4398 */	"\x48\x34", "\x48\x35", "\x48\x36", "\x48\x37",
  /* U+439C */	"\x48\x38", "\x48\x39", "\x48\x40", "\x48\x41",
  /* U+43A0 */	"\x48\x42", "\x48\x43", "\x48\x44", "\x48\x45",
  /* U+43A4 */	"\x48\x46", "\x48\x47", "\x48\x48", "\x48\x49",
  /* U+43A8 */	"\x48\x50", "\x48\x51", "\x48\x52", "\x48\x53",
  /* U+43AC */	"\xFE\x78", "\x48\x54", "\x48\x55", "\x48\x56",
  /* U+43B0 */	"\x48\x57", "\xFE\x77", "\x48\x58", "\x48\x59",
  /* U+43B4 */	"\x48\x60", "\x48\x61", "\x48\x62", "\x48\x63",
  /* U+43B8 */	"\x48\x64", "\x48\x65", "\x48\x66", "\x48\x67",
  /* U+43BC */	"\x48\x68", "\x48\x69", "\x48\x70", "\x48\x71",
  /* U+43C0 */	"\x48\x72", "\x48\x73", "\x48\x74", "\x48\x75",
  /* U+43C4 */	"\x48\x76", "\x48\x77", "\x48\x78", "\x48\x79",
  /* U+43C8 */	"\x48\x80", "\x48\x81", "\x48\x82", "\x48\x83",
  /* U+43CC */	"\x48\x84", "\x48\x85", "\x48\x86", "\x48\x87",
  /* U+43D0 */	"\x48\x88", "\x48\x89", "\x48\x90", "\x48\x91",
  /* U+43D4 */	"\x48\x92", "\x48\x93", "\x48\x94", "\x48\x95",
  /* U+43D8 */	"\x48\x96", "\x48\x97", "\x48\x98", "\x48\x99",
  /* U+43DC */	"\x48\xA0", "\xFE\x7A", "\x48\xA1", "\x48\xA2",
  /* U+43E0 */	"\x48\xA3", "\x48\xA4", "\x48\xA5", "\x48\xA6",
  /* U+43E4 */	"\x48\xA7", "\x48\xA8", "\x48\xA9", "\x48\xB0",
  /* U+43E8 */	"\x48\xB1", "\x48\xB2", "\x48\xB3", "\x48\xB4",
  /* U+43EC */	"\x48\xB5", "\x48\xB6", "\x48\xB7", "\x48\xB8",
  /* U+43F0 */	"\x48\xB9", "\x48\xC0", "\x48\xC1", "\x48\xC2",
  /* U+43F4 */	"\x48\xC3", "\x48\xC4", "\x48\xC5", "\x48\xC6",
  /* U+43F8 */	"\x48\xC7", "\x48\xC8", "\x48\xC9", "\x48\xD0",
  /* U+43FC */	"\x48\xD1", "\x48\xD2", "\x48\xD3", "\x48\xD4",
  /* U+4400 */	"\x48\xD5", "\x48\xD6", "\x48\xD7", "\x48\xD8",
  /* U+4404 */	"\x48\xD9", "\x48\xE0", "\x48\xE1", "\x48\xE2",
  /* U+4408 */	"\x48\xE3", "\x48\xE4", "\x48\xE5", "\x48\xE6",
  /* U+440C */	"\x48\xE7", "\x48\xE8", "\x48\xE9", "\x48\xF0",
  /* U+4410 */	"\x48\xF1", "\x48\xF2", "\x48\xF3", "\x48\xF4",
  /* U+4414 */	"\x48\xF5", "\x48\xF6", "\x48\xF7", "\x48\xF8",
  /* U+4418 */	"\x48\xF9", "\x49\x00", "\x49\x01", "\x49\x02",
  /* U+441C */	"\x49\x03", "\x49\x04", "\x49\x05", "\x49\x06",
  /* U+4420 */	"\x49\x07", "\x49\x08", "\x49\x09", "\x49\x10",
  /* U+4424 */	"\x49\x11", "\x49\x12", "\x49\x13", "\x49\x14",
  /* U+4428 */	"\x49\x15", "\x49\x16", "\x49\x17", "\x49\x18",
  /* U+442C */	"\x49\x19", "\x49\x20", "\x49\x21", "\x49\x22",
  /* U+4430 */	"\x49\x23", "\x49\x24", "\x49\x25", "\x49\x26",
  /* U+4434 */	"\x49\x27", "\x49\x28", "\x49\x29", "\x49\x30",
  /* U+4438 */	"\x49\x31", "\x49\x32", "\x49\x33", "\x49\x34",
  /* U+443C */	"\x49\x35", "\x49\x36", "\x49\x37", "\x49\x38",
  /* U+4440 */	"\x49\x39", "\x49\x40", "\x49\x41", "\x49\x42",
  /* U+4444 */	"\x49\x43", "\x49\x44", "\x49\x45", "\x49\x46",
  /* U+4448 */	"\x49\x47", "\x49\x48", "\x49\x49", "\x49\x50",
  /* U+444C */	"\x49\x51", "\x49\x52", "\x49\x53", "\x49\x54",
  /* U+4450 */	"\x49\x55", "\x49\x56", "\x49\x57", "\x49\x58",
  /* U+4454 */	"\x49\x59", "\x49\x60", "\x49\x61", "\x49\x62",
  /* U+4458 */	"\x49\x63", "\x49\x64", "\x49\x65", "\x49\x66",
  /* U+445C */	"\x49\x67", "\x49\x68", "\x49\x69", "\x49\x70",
  /* U+4460 */	"\x49\x71", "\x49\x72", "\x49\x73", "\x49\x74",
  /* U+4464 */	"\x49\x75", "\x49\x76", "\x49\x77", "\x49\x78",
  /* U+4468 */	"\x49\x79", "\x49\x80", "\x49\x81", "\x49\x82",
  /* U+446C */	"\x49\x83", "\x49\x84", "\x49\x85", "\x49\x86",
  /* U+4470 */	"\x49\x87", "\x49\x88", "\x49\x89", "\x49\x90",
  /* U+4474 */	"\x49\x91", "\x49\x92", "\x49\x93", "\x49\x94",
  /* U+4478 */	"\x49\x95", "\x49\x96", "\x49\x97", "\x49\x98",
  /* U+447C */	"\x49\x99", "\x49\xA0", "\x49\xA1", "\x49\xA2",
  /* U+4480 */	"\x49\xA3", "\x49\xA4", "\x49\xA5", "\x49\xA6",
  /* U+4484 */	"\x49\xA7", "\x49\xA8", "\x49\xA9", "\x49\xB0",
  /* U+4488 */	"\x49\xB1", "\x49\xB2", "\x49\xB3", "\x49\xB4",
  /* U+448C */	"\x49\xB5", "\x49\xB6", "\x49\xB7", "\x49\xB8",
  /* U+4490 */	"\x49\xB9", "\x49\xC0", "\x49\xC1", "\x49\xC2",
  /* U+4494 */	"\x49\xC3", "\x49\xC4", "\x49\xC5", "\x49\xC6",
  /* U+4498 */	"\x49\xC7", "\x49\xC8", "\x49\xC9", "\x49\xD0",
  /* U+449C */	"\x49\xD1", "\x49\xD2", "\x49\xD3", "\x49\xD4",
  /* U+44A0 */	"\x49\xD5", "\x49\xD6", "\x49\xD7", "\x49\xD8",
  /* U+44A4 */	"\x49\xD9", "\x49\xE0", "\x49\xE1", "\x49\xE2",
  /* U+44A8 */	"\x49\xE3", "\x49\xE4", "\x49\xE5", "\x49\xE6",
  /* U+44AC */	"\x49\xE7", "\x49\xE8", "\x49\xE9", "\x49\xF0",
  /* U+44B0 */	"\x49\xF1", "\x49\xF2", "\x49\xF3", "\x49\xF4",
  /* U+44B4 */	"\x49\xF5", "\x49\xF6", "\x49\xF7", "\x49\xF8",
  /* U+44B8 */	"\x49\xF9", "\x4A\x00", "\x4A\x01", "\x4A\x02",
  /* U+44BC */	"\x4A\x03", "\x4A\x04", "\x4A\x05", "\x4A\x06",
  /* U+44C0 */	"\x4A\x07", "\x4A\x08", "\x4A\x09", "\x4A\x10",
  /* U+44C4 */	"\x4A\x11", "\x4A\x12", "\x4A\x13", "\x4A\x14",
  /* U+44C8 */	"\x4A\x15", "\x4A\x16", "\x4A\x17", "\x4A\x18",
  /* U+44CC */	"\x4A\x19", "\x4A\x20", "\x4A\x21", "\x4A\x22",
  /* U+44D0 */	"\x4A\x23", "\x4A\x24", "\x4A\x25", "\x4A\x26",
  /* U+44D4 */	"\x4A\x27", "\x4A\x28", "\xFE\x7B", 
  /* Contiguous area: U+464C .. U+478D */
  /* U+464C */	"\xFE\x7D", "\x4C\x82", "\x4C\x83", "\x4C\x84",
  /* U+4650 */	"\x4C\x85", "\x4C\x86", "\x4C\x87", "\x4C\x88",
  /* U+4654 */	"\x4C\x89", "\x4C\x90", "\x4C\x91", "\x4C\x92",
  /* U+4658 */	"\x4C\x93", "\x4C\x94", "\x4C\x95", "\x4C\x96",
  /* U+465C */	"\x4C\x97", "\x4C\x98", "\x4C\x99", "\x4C\xA0",
  /* U+4660 */	"\x4C\xA1", "\xFE\x7C", "\x4C\xA2", "\x4C\xA3",
  /* U+4664 */	"\x4C\xA4", "\x4C\xA5", "\x4C\xA6", "\x4C\xA7",
  /* U+4668 */	"\x4C\xA8", "\x4C\xA9", "\x4C\xB0", "\x4C\xB1",
  /* U+466C */	"\x4C\xB2", "\x4C\xB3", "\x4C\xB4", "\x4C\xB5",
  /* U+4670 */	"\x4C\xB6", "\x4C\xB7", "\x4C\xB8", "\x4C\xB9",
  /* U+4674 */	"\x4C\xC0", "\x4C\xC1", "\x4C\xC2", "\x4C\xC3",
  /* U+4678 */	"\x4C\xC4", "\x4C\xC5", "\x4C\xC6", "\x4C\xC7",
  /* U+467C */	"\x4C\xC8", "\x4C\xC9", "\x4C\xD0", "\x4C\xD1",
  /* U+4680 */	"\x4C\xD2", "\x4C\xD3", "\x4C\xD4", "\x4C\xD5",
  /* U+4684 */	"\x4C\xD6", "\x4C\xD7", "\x4C\xD8", "\x4C\xD9",
  /* U+4688 */	"\x4C\xE0", "\x4C\xE1", "\x4C\xE2", "\x4C\xE3",
  /* U+468C */	"\x4C\xE4", "\x4C\xE5", "\x4C\xE6", "\x4C\xE7",
  /* U+4690 */	"\x4C\xE8", "\x4C\xE9", "\x4C\xF0", "\x4C\xF1",
  /* U+4694 */	"\x4C\xF2", "\x4C\xF3", "\x4C\xF4", "\x4C\xF5",
  /* U+4698 */	"\x4C\xF6", "\x4C\xF7", "\x4C\xF8", "\x4C\xF9",
  /* U+469C */	"\x4D\x00", "\x4D\x01", "\x4D\x02", "\x4D\x03",
  /* U+46A0 */	"\x4D\x04", "\x4D\x05", "\x4D\x06", "\x4D\x07",
  /* U+46A4 */	"\x4D\x08", "\x4D\x09", "\x4D\x10", "\x4D\x11",
  /* U+46A8 */	"\x4D\x12", "\x4D\x13", "\x4D\x14", "\x4D\x15",
  /* U+46AC */	"\x4D\x16", "\x4D\x17", "\x4D\x18", "\x4D\x19",
  /* U+46B0 */	"\x4D\x20", "\x4D\x21", "\x4D\x22", "\x4D\x23",
  /* U+46B4 */	"\x4D\x24", "\x4D\x25", "\x4D\x26", "\x4D\x27",
  /* U+46B8 */	"\x4D\x28", "\x4D\x29", "\x4D\x30", "\x4D\x31",
  /* U+46BC */	"\x4D\x32", "\x4D\x33", "\x4D\x34", "\x4D\x35",
  /* U+46C0 */	"\x4D\x36", "\x4D\x37", "\x4D\x38", "\x4D\x39",
  /* U+46C4 */	"\x4D\x40", "\x4D\x41", "\x4D\x42", "\x4D\x43",
  /* U+46C8 */	"\x4D\x44", "\x4D\x45", "\x4D\x46", "\x4D\x47",
  /* U+46CC */	"\x4D\x48", "\x4D\x49", "\x4D\x50", "\x4D\x51",
  /* U+46D0 */	"\x4D\x52", "\x4D\x53", "\x4D\x54", "\x4D\x55",
  /* U+46D4 */	"\x4D\x56", "\x4D\x57", "\x4D\x58", "\x4D\x59",
  /* U+46D8 */	"\x4D\x60", "\x4D\x61", "\x4D\x62", "\x4D\x63",
  /* U+46DC */	"\x4D\x64", "\x4D\x65", "\x4D\x66", "\x4D\x67",
  /* U+46E0 */	"\x4D\x68", "\x4D\x69", "\x4D\x70", "\x4D\x71",
  /* U+46E4 */	"\x4D\x72", "\x4D\x73", "\x4D\x74", "\x4D\x75",
  /* U+46E8 */	"\x4D\x76", "\x4D\x77", "\x4D\x78", "\x4D\x79",
  /* U+46EC */	"\x4D\x80", "\x4D\x81", "\x4D\x82", "\x4D\x83",
  /* U+46F0 */	"\x4D\x84", "\x4D\x85", "\x4D\x86", "\x4D\x87",
  /* U+46F4 */	"\x4D\x88", "\x4D\x89", "\x4D\x90", "\x4D\x91",
  /* U+46F8 */	"\x4D\x92", "\x4D\x93", "\x4D\x94", "\x4D\x95",
  /* U+46FC */	"\x4D\x96", "\x4D\x97", "\x4D\x98", "\x4D\x99",
  /* U+4700 */	"\x4D\xA0", "\x4D\xA1", "\x4D\xA2", "\x4D\xA3",
  /* U+4704 */	"\x4D\xA4", "\x4D\xA5", "\x4D\xA6", "\x4D\xA7",
  /* U+4708 */	"\x4D\xA8", "\x4D\xA9", "\x4D\xB0", "\x4D\xB1",
  /* U+470C */	"\x4D\xB2", "\x4D\xB3", "\x4D\xB4", "\x4D\xB5",
  /* U+4710 */	"\x4D\xB6", "\x4D\xB7", "\x4D\xB8", "\x4D\xB9",
  /* U+4714 */	"\x4D\xC0", "\x4D\xC1", "\x4D\xC2", "\x4D\xC3",
  /* U+4718 */	"\x4D\xC4", "\x4D\xC5", "\x4D\xC6", "\x4D\xC7",
  /* U+471C */	"\x4D\xC8", "\x4D\xC9", "\x4D\xD0", "\x4D\xD1",
  /* U+4720 */	"\x4D\xD2", "\x4D\xD3", "\x4D\xD4", "\xFE\x80",
  /* U+4724 */	"\x4D\xD5", "\x4D\xD6", "\x4D\xD7", "\x4D\xD8",
  /* U+4728 */	"\x4D\xD9", "\xFE\x81", "\x4D\xE0", "\x4D\xE1",
  /* U+472C */	"\x4D\xE2", "\x4D\xE3", "\x4D\xE4", "\x4D\xE5",
  /* U+4730 */	"\x4D\xE6", "\x4D\xE7", "\x4D\xE8", "\x4D\xE9",
  /* U+4734 */	"\x4D\xF0", "\x4D\xF1", "\x4D\xF2", "\x4D\xF3",
  /* U+4738 */	"\x4D\xF4", "\x4D\xF5", "\x4D\xF6", "\x4D\xF7",
  /* U+473C */	"\x4D\xF8", "\x4D\xF9", "\x4E\x00", "\x4E\x01",
  /* U+4740 */	"\x4E\x02", "\x4E\x03", "\x4E\x04", "\x4E\x05",
  /* U+4744 */	"\x4E\x06", "\x4E\x07", "\x4E\x08", "\x4E\x09",
  /* U+4748 */	"\x4E\x10", "\x4E\x11", "\x4E\x12", "\x4E\x13",
  /* U+474C */	"\x4E\x14", "\x4E\x15", "\x4E\x16", "\x4E\x17",
  /* U+4750 */	"\x4E\x18", "\x4E\x19", "\x4E\x20", "\x4E\x21",
  /* U+4754 */	"\x4E\x22", "\x4E\x23", "\x4E\x24", "\x4E\x25",
  /* U+4758 */	"\x4E\x26", "\x4E\x27", "\x4E\x28", "\x4E\x29",
  /* U+475C */	"\x4E\x30", "\x4E\x31", "\x4E\x32", "\x4E\x33",
  /* U+4760 */	"\x4E\x34", "\x4E\x35", "\x4E\x36", "\x4E\x37",
  /* U+4764 */	"\x4E\x38", "\x4E\x39", "\x4E\x40", "\x4E\x41",
  /* U+4768 */	"\x4E\x42", "\x4E\x43", "\x4E\x44", "\x4E\x45",
  /* U+476C */	"\x4E\x46", "\x4E\x47", "\x4E\x48", "\x4E\x49",
  /* U+4770 */	"\x4E\x50", "\x4E\x51", "\x4E\x52", "\x4E\x53",
  /* U+4774 */	"\x4E\x54", "\x4E\x55", "\x4E\x56", "\x4E\x57",
  /* U+4778 */	"\x4E\x58", "\x4E\x59", "\x4E\x60", "\x4E\x61",
  /* U+477C */	"\xFE\x82", "\x4E\x62", "\x4E\x63", "\x4E\x64",
  /* U+4780 */	"\x4E\x65", "\x4E\x66", "\x4E\x67", "\x4E\x68",
  /* U+4784 */	"\x4E\x69", "\x4E\x70", "\x4E\x71", "\x4E\x72",
  /* U+4788 */	"\x4E\x73", "\x4E\x74", "\x4E\x75", "\x4E\x76",
  /* U+478C */	"\x4E\x77", "\xFE\x83", 
  /* Contiguous area: U+4947 .. U+49B7 */
  /* U+4947 */					    "\xFE\x85",
  /* U+4948 */	"\x51\x59", "\x51\x60", "\x51\x61", "\x51\x62",
  /* U+494C */	"\x51\x63", "\x51\x64", "\x51\x65", "\x51\x66",
  /* U+4950 */	"\x51\x67", "\x51\x68", "\x51\x69", "\x51\x70",
  /* U+4954 */	"\x51\x71", "\x51\x72", "\x51\x73", "\x51\x74",
  /* U+4958 */	"\x51\x75", "\x51\x76", "\x51\x77", "\x51\x78",
  /* U+495C */	"\x51\x79", "\x51\x80", "\x51\x81", "\x51\x82",
  /* U+4960 */	"\x51\x83", "\x51\x84", "\x51\x85", "\x51\x86",
  /* U+4964 */	"\x51\x87", "\x51\x88", "\x51\x89", "\x51\x90",
  /* U+4968 */	"\x51\x91", "\x51\x92", "\x51\x93", "\x51\x94",
  /* U+496C */	"\x51\x95", "\x51\x96", "\x51\x97", "\x51\x98",
  /* U+4970 */	"\x51\x99", "\x51\xA0", "\x51\xA1", "\x51\xA2",
  /* U+4974 */	"\x51\xA3", "\x51\xA4", "\x51\xA5", "\x51\xA6",
  /* U+4978 */	"\x51\xA7", "\x51\xA8", "\xFE\x86", "\x51\xA9",
  /* U+497C */	"\x51\xB0", "\xFE\x87", "\x51\xB1", "\x51\xB2",
  /* U+4980 */	"\x51\xB3", "\x51\xB4", "\xFE\x88", "\xFE\x89",
  /* U+4984 */	"\x51\xB5", "\xFE\x8A", "\xFE\x8B", "\x51\xB6",
  /* U+4988 */	"\x51\xB7", "\x51\xB8", "\x51\xB9", "\x51\xC0",
  /* U+498C */	"\x51\xC1", "\x51\xC2", "\x51\xC3", "\x51\xC4",
  /* U+4990 */	"\x51\xC5", "\x51\xC6", "\x51\xC7", "\x51\xC8",
  /* U+4994 */	"\x51\xC9", "\x51\xD0", "\x51\xD1", "\x51\xD2",
  /* U+4998 */	"\x51\xD3", "\x51\xD4", "\x51\xD5", "\xFE\x8D",
  /* U+499C */	"\x51\xD6", "\x51\xD7", "\x51\xD8", "\xFE\x8C",
  /* U+49A0 */	"\x51\xD9", "\x51\xE0", "\x51\xE1", "\x51\xE2",
  /* U+49A4 */	"\x51\xE3", "\x51\xE4", "\x51\xE5", "\x51\xE6",
  /* U+49A8 */	"\x51\xE7", "\x51\xE8", "\x51\xE9", "\x51\xF0",
  /* U+49AC */	"\x51\xF1", "\x51\xF2", "\x51\xF3", "\x51\xF4",
  /* U+49B0 */	"\x51\xF5", "\x51\xF6", "\x51\xF7", "\x51\xF8",
  /* U+49B4 */	"\x51\xF9", "\x52\x00", "\xFE\x8F", "\xFE\x8E",
  /* Contiguous area: U+4C77 .. U+9FA5 */
  /* U+4C77 */					    "\xFE\x96",
  /* U+4C78 */	"\x56\x64", "\x56\x65", "\x56\x66", "\x56\x67",
  /* U+4C7C */	"\x56\x68", "\x56\x69", "\x56\x70", "\x56\x71",
  /* U+4C80 */	"\x56\x72", "\x56\x73", "\x56\x74", "\x56\x75",
  /* U+4C84 */	"\x56\x76", "\x56\x77", "\x56\x78", "\x56\x79",
  /* U+4C88 */	"\x56\x80", "\x56\x81", "\x56\x82", "\x56\x83",
  /* U+4C8C */	"\x56\x84", "\x56\x85", "\x56\x86", "\x56\x87",
  /* U+4C90 */	"\x56\x88", "\x56\x89", "\x56\x90", "\x56\x91",
  /* U+4C94 */	"\x56\x92", "\x56\x93", "\x56\x94", "\x56\x95",
  /* U+4C98 */	"\x56\x96", "\x56\x97", "\x56\x98", "\x56\x99",
  /* U+4C9C */	"\x56\xA0", "\x56\xA1", "\x56\xA2", "\xFE\x93",
  /* U+4CA0 */	"\xFE\x94", "\xFE\x95", "\xFE\x97", "\xFE\x92",
  /* U+4CA4 */	"\x56\xA3", "\x56\xA4", "\x56\xA5", "\x56\xA6",
  /* U+4CA8 */	"\x56\xA7", "\x56\xA8", "\x56\xA9", "\x56\xB0",
  /* U+4CAC */	"\x56\xB1", "\x56\xB2", "\x56\xB3", "\x56\xB4",
  /* U+4CB0 */	"\x56\xB5", "\x56\xB6", "\x56\xB7", "\x56\xB8",
  /* U+4CB4 */	"\x56\xB9", "\x56\xC0", "\x56\xC1", "\x56\xC2",
  /* U+4CB8 */	"\x56\xC3", "\x56\xC4", "\x56\xC5", "\x56\xC6",
  /* U+4CBC */	"\x56\xC7", "\x56\xC8", "\x56\xC9", "\x56\xD0",
  /* U+4CC0 */	"\x56\xD1", "\x56\xD2", "\x56\xD3", "\x56\xD4",
  /* U+4CC4 */	"\x56\xD5", "\x56\xD6", "\x56\xD7", "\x56\xD8",
  /* U+4CC8 */	"\x56\xD9", "\x56\xE0", "\x56\xE1", "\x56\xE2",
  /* U+4CCC */	"\x56\xE3", "\x56\xE4", "\x56\xE5", "\x56\xE6",
  /* U+4CD0 */	"\x56\xE7", "\x56\xE8", "\x56\xE9", "\x56\xF0",
  /* U+4CD4 */	"\x56\xF1", "\x56\xF2", "\x56\xF3", "\x56\xF4",
  /* U+4CD8 */	"\x56\xF5", "\x56\xF6", "\x56\xF7", "\x56\xF8",
  /* U+4CDC */	"\x56\xF9", "\x57\x00", "\x57\x01", "\x57\x02",
  /* U+4CE0 */	"\x57\x03", "\x57\x04", "\x57\x05", "\x57\x06",
  /* U+4CE4 */	"\x57\x07", "\x57\x08", "\x57\x09", "\x57\x10",
  /* U+4CE8 */	"\x57\x11", "\x57\x12", "\x57\x13", "\x57\x14",
  /* U+4CEC */	"\x57\x15", "\x57\x16", "\x57\x17", "\x57\x18",
  /* U+4CF0 */	"\x57\x19", "\x57\x20", "\x57\x21", "\x57\x22",
  /* U+4CF4 */	"\x57\x23", "\x57\x24", "\x57\x25", "\x57\x26",
  /* U+4CF8 */	"\x57\x27", "\x57\x28", "\x57\x29", "\x57\x30",
  /* U+4CFC */	"\x57\x31", "\x57\x32", "\x57\x33", "\x57\x34",
  /* U+4D00 */	"\x57\x35", "\x57\x36", "\x57\x37", "\x57\x38",
  /* U+4D04 */	"\x57\x39", "\x57\x40", "\x57\x41", "\x57\x42",
  /* U+4D08 */	"\x57\x43", "\x57\x44", "\x57\x45", "\x57\x46",
  /* U+4D0C */	"\x57\x47", "\x57\x48", "\x57\x49", "\x57\x50",
  /* U+4D10 */	"\x57\x51", "\x57\x52", "\x57\x53", "\xFE\x98",
  /* U+4D14 */	"\xFE\x99", "\xFE\x9A", "\xFE\x9B", "\xFE\x9C",
  /* U+4D18 */	"\xFE\x9D", "\xFE\x9E", "\x57\x54", "\x57\x55",
  /* U+4D1C */	"\x57\x56", "\x57\x57", "\x57\x58", "\x57\x59",
  /* U+4D20 */	"\x57\x60", "\x57\x61", "\x57\x62", "\x57\x63",
  /* U+4D24 */	"\x57\x64", "\x57\x65", "\x57\x66", "\x57\x67",
  /* U+4D28 */	"\x57\x68", "\x57\x69", "\x57\x70", "\x57\x71",
  /* U+4D2C */	"\x57\x72", "\x57\x73", "\x57\x74", "\x57\x75",
  /* U+4D30 */	"\x57\x76", "\x57\x77", "\x57\x78", "\x57\x79",
  /* U+4D34 */	"\x57\x80", "\x57\x81", "\x57\x82", "\x57\x83",
  /* U+4D38 */	"\x57\x84", "\x57\x85", "\x57\x86", "\x57\x87",
  /* U+4D3C */	"\x57\x88", "\x57\x89", "\x57\x90", "\x57\x91",
  /* U+4D40 */	"\x57\x92", "\x57\x93", "\x57\x94", "\x57\x95",
  /* U+4D44 */	"\x57\x96", "\x57\x97", "\x57\x98", "\x57\x99",
  /* U+4D48 */	"\x57\xA0", "\x57\xA1", "\x57\xA2", "\x57\xA3",
  /* U+4D4C */	"\x57\xA4", "\x57\xA5", "\x57\xA6", "\x57\xA7",
  /* U+4D50 */	"\x57\xA8", "\x57\xA9", "\x57\xB0", "\x57\xB1",
  /* U+4D54 */	"\x57\xB2", "\x57\xB3", "\x57\xB4", "\x57\xB5",
  /* U+4D58 */	"\x57\xB6", "\x57\xB7", "\x57\xB8", "\x57\xB9",
  /* U+4D5C */	"\x57\xC0", "\x57\xC1", "\x57\xC2", "\x57\xC3",
  /* U+4D60 */	"\x57\xC4", "\x57\xC5", "\x57\xC6", "\x57\xC7",
  /* U+4D64 */	"\x57\xC8", "\x57\xC9", "\x57\xD0", "\x57\xD1",
  /* U+4D68 */	"\x57\xD2", "\x57\xD3", "\x57\xD4", "\x57\xD5",
  /* U+4D6C */	"\x57\xD6", "\x57\xD7", "\x57\xD8", "\x57\xD9",
  /* U+4D70 */	"\x58\x00", "\x58\x01", "\x58\x02", "\x58\x03",
  /* U+4D74 */	"\x58\x04", "\x58\x05", "\x58\x06", "\x58\x07",
  /* U+4D78 */	"\x58\x08", "\x58\x09", "\x58\x10", "\x58\x11",
  /* U+4D7C */	"\x58\x12", "\x58\x13", "\x58\x14", "\x58\x15",
  /* U+4D80 */	"\x58\x16", "\x58\x17", "\x58\x18", "\x58\x19",
  /* U+4D84 */	"\x58\x20", "\x58\x21", "\x58\x22", "\x58\x23",
  /* U+4D88 */	"\x58\x24", "\x58\x25", "\x58\x26", "\x58\x27",
  /* U+4D8C */	"\x58\x28", "\x58\x29", "\x58\x30", "\x58\x31",
  /* U+4D90 */	"\x58\x32", "\x58\x33", "\x58\x34", "\x58\x35",
  /* U+4D94 */	"\x58\x36", "\x58\x37", "\x58\x38", "\x58\x39",
  /* U+4D98 */	"\x58\x40", "\x58\x41", "\x58\x42", "\x58\x43",
  /* U+4D9C */	"\x58\x44", "\x58\x45", "\x58\x46", "\x58\x47",
  /* U+4DA0 */	"\x58\x48", "\x58\x49", "\x58\x50", "\x58\x51",
  /* U+4DA4 */	"\x58\x52", "\x58\x53", "\x58\x54", "\x58\x55",
  /* U+4DA8 */	"\x58\x56", "\x58\x57", "\x58\x58", "\x58\x59",
  /* U+4DAC */	"\x58\x60", "\x58\x61", "\xFE\x9F", "\x58\x62",
  /* U+4DB0 */	"\x58\x63", "\x58\x64", "\x58\x65", "\x58\x66",
  /* U+4DB4 */	"\x58\x67", "\x58\x68", "\x58\x69", "\x58\x70",
  /* U+4DB8 */	"\x58\x71", "\x58\x72", "\x58\x73", "\x58\x74",
  /* U+4DBC */	"\x58\x75", "\x58\x76", "\x58\x77", "\x58\x78",
  /* U+4DC0 */	"\x58\x79", "\x58\x80", "\x58\x81", "\x58\x82",
  /* U+4DC4 */	"\x58\x83", "\x58\x84", "\x58\x85", "\x58\x86",
  /* U+4DC8 */	"\x58\x87", "\x58\x88", "\x58\x89", "\x58\x90",
  /* U+4DCC */	"\x58\x91", "\x58\x92", "\x58\x93", "\x58\x94",
  /* U+4DD0 */	"\x58\x95", "\x58\x96", "\x58\x97", "\x58\x98",
  /* U+4DD4 */	"\x58\x99", "\x58\xA0", "\x58\xA1", "\x58\xA2",
  /* U+4DD8 */	"\x58\xA3", "\x58\xA4", "\x58\xA5", "\x58\xA6",
  /* U+4DDC */	"\x58\xA7", "\x58\xA8", "\x58\xA9", "\x58\xB0",
  /* U+4DE0 */	"\x58\xB1", "\x58\xB2", "\x58\xB3", "\x58\xB4",
  /* U+4DE4 */	"\x58\xB5", "\x58\xB6", "\x58\xB7", "\x58\xB8",
  /* U+4DE8 */	"\x58\xB9", "\x58\xC0", "\x58\xC1", "\x58\xC2",
  /* U+4DEC */	"\x58\xC3", "\x58\xC4", "\x58\xC5", "\x58\xC6",
  /* U+4DF0 */	"\x58\xC7", "\x58\xC8", "\x58\xC9", "\x58\xD0",
  /* U+4DF4 */	"\x58\xD1", "\x58\xD2", "\x58\xD3", "\x58\xD4",
  /* U+4DF8 */	"\x58\xD5", "\x58\xD6", "\x58\xD7", "\x58\xD8",
  /* U+4DFC */	"\x58\xD9", "\x58\xE0", "\x58\xE1", "\x58\xE2",
  /* U+4E00 */	"\xD2\xBB", "\xB6\xA1", "\x81\x40", "\xC6\xDF",
  /* U+4E04 */	"\x81\x41", "\x81\x42", "\x81\x43", "\xCD\xF2",
  /* U+4E08 */	"\xD5\xC9", "\xC8\xFD", "\xC9\xCF", "\xCF\xC2",
  /* U+4E0C */	"\xD8\xA2", "\xB2\xBB", "\xD3\xEB", "\x81\x44",
  /* U+4E10 */	"\xD8\xA4", "\xB3\xF3", "\x81\x45", "\xD7\xA8",
  /* U+4E14 */	"\xC7\xD2", "\xD8\xA7", "\xCA\xC0", "\x81\x46",
  /* U+4E18 */	"\xC7\xF0", "\xB1\xFB", "\xD2\xB5", "\xB4\xD4",
  /* U+4E1C */	"\xB6\xAB", "\xCB\xBF", "\xD8\xA9", "\x81\x47",
  /* U+4E20 */	"\x81\x48", "\x81\x49", "\xB6\xAA", "\x81\x4A",
  /* U+4E24 */	"\xC1\xBD", "\xD1\xCF", "\x81\x4B", "\xC9\xA5",
  /* U+4E28 */	"\xD8\xAD", "\x81\x4C", "\xB8\xF6", "\xD1\xBE",
  /* U+4E2C */	"\xE3\xDC", "\xD6\xD0", "\x81\x4D", "\x81\x4E",
  /* U+4E30 */	"\xB7\xE1", "\x81\x4F", "\xB4\xAE", "\x81\x50",
  /* U+4E34 */	"\xC1\xD9", "\x81\x51", "\xD8\xBC", "\x81\x52",
  /* U+4E38 */	"\xCD\xE8", "\xB5\xA4", "\xCE\xAA", "\xD6\xF7",
  /* U+4E3C */	"\x81\x53", "\xC0\xF6", "\xBE\xD9", "\xD8\xAF",
  /* U+4E40 */	"\x81\x54", "\x81\x55", "\x81\x56", "\xC4\xCB",
  /* U+4E44 */	"\x81\x57", "\xBE\xC3", "\x81\x58", "\xD8\xB1",
  /* U+4E48 */	"\xC3\xB4", "\xD2\xE5", "\x81\x59", "\xD6\xAE",
  /* U+4E4C */	"\xCE\xDA", "\xD5\xA7", "\xBA\xF5", "\xB7\xA6",
  /* U+4E50 */	"\xC0\xD6", "\x81\x5A", "\xC6\xB9", "\xC5\xD2",
  /* U+4E54 */	"\xC7\xC7", "\x81\x5B", "\xB9\xD4", "\x81\x5C",
  /* U+4E58 */	"\xB3\xCB", "\xD2\xD2", "\x81\x5D", "\x81\x5E",
  /* U+4E5C */	"\xD8\xBF", "\xBE\xC5", "\xC6\xF2", "\xD2\xB2",
  /* U+4E60 */	"\xCF\xB0", "\xCF\xE7", "\x81\x5F", "\x81\x60",
  /* U+4E64 */	"\x81\x61", "\x81\x62", "\xCA\xE9", "\x81\x63",
  /* U+4E68 */	"\x81\x64", "\xD8\xC0", "\x81\x65", "\x81\x66",
  /* U+4E6C */	"\x81\x67", "\x81\x68", "\x81\x69", "\x81\x6A",
  /* U+4E70 */	"\xC2\xF2", "\xC2\xD2", "\x81\x6B", "\xC8\xE9",
  /* U+4E74 */	"\x81\x6C", "\x81\x6D", "\x81\x6E", "\x81\x6F",
  /* U+4E78 */	"\x81\x70", "\x81\x71", "\x81\x72", "\x81\x73",
  /* U+4E7C */	"\x81\x74", "\x81\x75", "\xC7\xAC", "\x81\x76",
  /* U+4E80 */	"\x81\x77", "\x81\x78", "\x81\x79", "\x81\x7A",
  /* U+4E84 */	"\x81\x7B", "\x81\x7C", "\xC1\xCB", "\x81\x7D",
  /* U+4E88 */	"\xD3\xE8", "\xD5\xF9", "\x81\x7E", "\xCA\xC2",
  /* U+4E8C */	"\xB6\xFE", "\xD8\xA1", "\xD3\xDA", "\xBF\xF7",
  /* U+4E90 */	"\x81\x80", "\xD4\xC6", "\xBB\xA5", "\xD8\xC1",
  /* U+4E94 */	"\xCE\xE5", "\xBE\xAE", "\x81\x81", "\x81\x82",
  /* U+4E98 */	"\xD8\xA8", "\x81\x83", "\xD1\xC7", "\xD0\xA9",
  /* U+4E9C */	"\x81\x84", "\x81\x85", "\x81\x86", "\xD8\xBD",
  /* U+4EA0 */	"\xD9\xEF", "\xCD\xF6", "\xBF\xBA", "\x81\x87",
  /* U+4EA4 */	"\xBD\xBB", "\xBA\xA5", "\xD2\xE0", "\xB2\xFA",
  /* U+4EA8 */	"\xBA\xE0", "\xC4\xB6", "\x81\x88", "\xCF\xED",
  /* U+4EAC */	"\xBE\xA9", "\xCD\xA4", "\xC1\xC1", "\x81\x89",
  /* U+4EB0 */	"\x81\x8A", "\x81\x8B", "\xC7\xD7", "\xD9\xF1",
  /* U+4EB4 */	"\x81\x8C", "\xD9\xF4", "\x81\x8D", "\x81\x8E",
  /* U+4EB8 */	"\x81\x8F", "\x81\x90", "\xC8\xCB", "\xD8\xE9",
  /* U+4EBC */	"\x81\x91", "\x81\x92", "\x81\x93", "\xD2\xDA",
  /* U+4EC0 */	"\xCA\xB2", "\xC8\xCA", "\xD8\xEC", "\xD8\xEA",
  /* U+4EC4 */	"\xD8\xC6", "\xBD\xF6", "\xC6\xCD", "\xB3\xF0",
  /* U+4EC8 */	"\x81\x94", "\xD8\xEB", "\xBD\xF1", "\xBD\xE9",
  /* U+4ECC */	"\x81\x95", "\xC8\xD4", "\xB4\xD3", "\x81\x96",
  /* U+4ED0 */	"\x81\x97", "\xC2\xD8", "\x81\x98", "\xB2\xD6",
  /* U+4ED4 */	"\xD7\xD0", "\xCA\xCB", "\xCB\xFB", "\xD5\xCC",
  /* U+4ED8 */	"\xB8\xB6", "\xCF\xC9", "\x81\x99", "\x81\x9A",
  /* U+4EDC */	"\x81\x9B", "\xD9\xDA", "\xD8\xF0", "\xC7\xAA",
  /* U+4EE0 */	"\x81\x9C", "\xD8\xEE", "\x81\x9D", "\xB4\xFA",
  /* U+4EE4 */	"\xC1\xEE", "\xD2\xD4", "\x81\x9E", "\x81\x9F",
  /* U+4EE8 */	"\xD8\xED", "\x81\xA0", "\xD2\xC7", "\xD8\xEF",
  /* U+4EEC */	"\xC3\xC7", "\x81\xA1", "\x81\xA2", "\x81\xA3",
  /* U+4EF0 */	"\xD1\xF6", "\x81\xA4", "\xD6\xD9", "\xD8\xF2",
  /* U+4EF4 */	"\x81\xA5", "\xD8\xF5", "\xBC\xFE", "\xBC\xDB",
  /* U+4EF8 */	"\x81\xA6", "\x81\xA7", "\x81\xA8", "\xC8\xCE",
  /* U+4EFC */	"\x81\xA9", "\xB7\xDD", "\x81\xAA", "\xB7\xC2",
  /* U+4F00 */	"\x81\xAB", "\xC6\xF3", "\x81\xAC", "\x81\xAD",
  /* U+4F04 */	"\x81\xAE", "\x81\xAF", "\x81\xB0", "\x81\xB1",
  /* U+4F08 */	"\x81\xB2", "\xD8\xF8", "\xD2\xC1", "\x81\xB3",
  /* U+4F0C */	"\x81\xB4", "\xCE\xE9", "\xBC\xBF", "\xB7\xFC",
  /* U+4F10 */	"\xB7\xA5", "\xD0\xDD", "\x81\xB5", "\x81\xB6",
  /* U+4F14 */	"\x81\xB7", "\x81\xB8", "\x81\xB9", "\xD6\xDA",
  /* U+4F18 */	"\xD3\xC5", "\xBB\xEF", "\xBB\xE1", "\xD8\xF1",
  /* U+4F1C */	"\x81\xBA", "\x81\xBB", "\xC9\xA1", "\xCE\xB0",
  /* U+4F20 */	"\xB4\xAB", "\x81\xBC", "\xD8\xF3", "\x81\xBD",
  /* U+4F24 */	"\xC9\xCB", "\xD8\xF6", "\xC2\xD7", "\xD8\xF7",
  /* U+4F28 */	"\x81\xBE", "\x81\xBF", "\xCE\xB1", "\xD8\xF9",
  /* U+4F2C */	"\x81\xC0", "\x81\xC1", "\x81\xC2", "\xB2\xAE",
  /* U+4F30 */	"\xB9\xC0", "\x81\xC3", "\xD9\xA3", "\x81\xC4",
  /* U+4F34 */	"\xB0\xE9", "\x81\xC5", "\xC1\xE6", "\x81\xC6",
  /* U+4F38 */	"\xC9\xEC", "\x81\xC7", "\xCB\xC5", "\x81\xC8",
  /* U+4F3C */	"\xCB\xC6", "\xD9\xA4", "\x81\xC9", "\x81\xCA",
  /* U+4F40 */	"\x81\xCB", "\x81\xCC", "\x81\xCD", "\xB5\xE8",
  /* U+4F44 */	"\x81\xCE", "\x81\xCF", "\xB5\xAB", "\x81\xD0",
  /* U+4F48 */	"\x81\xD1", "\x81\xD2", "\x81\xD3", "\x81\xD4",
  /* U+4F4C */	"\x81\xD5", "\xCE\xBB", "\xB5\xCD", "\xD7\xA1",
  /* U+4F50 */	"\xD7\xF4", "\xD3\xD3", "\x81\xD6", "\xCC\xE5",
  /* U+4F54 */	"\x81\xD7", "\xBA\xCE", "\x81\xD8", "\xD9\xA2",
  /* U+4F58 */	"\xD9\xDC", "\xD3\xE0", "\xD8\xFD", "\xB7\xF0",
  /* U+4F5C */	"\xD7\xF7", "\xD8\xFE", "\xD8\xFA", "\xD9\xA1",
  /* U+4F60 */	"\xC4\xE3", "\x81\xD9", "\x81\xDA", "\xD3\xB6",
  /* U+4F64 */	"\xD8\xF4", "\xD9\xDD", "\x81\xDB", "\xD8\xFB",
  /* U+4F68 */	"\x81\xDC", "\xC5\xE5", "\x81\xDD", "\x81\xDE",
  /* U+4F6C */	"\xC0\xD0", "\x81\xDF", "\x81\xE0", "\xD1\xF0",
  /* U+4F70 */	"\xB0\xDB", "\x81\xE1", "\x81\xE2", "\xBC\xD1",
  /* U+4F74 */	"\xD9\xA6", "\x81\xE3", "\xD9\xA5", "\x81\xE4",
  /* U+4F78 */	"\x81\xE5", "\x81\xE6", "\x81\xE7", "\xD9\xAC",
  /* U+4F7C */	"\xD9\xAE", "\x81\xE8", "\xD9\xAB", "\xCA\xB9",
  /* U+4F80 */	"\x81\xE9", "\x81\xEA", "\x81\xEB", "\xD9\xA9",
  /* U+4F84 */	"\xD6\xB6", "\x81\xEC", "\x81\xED", "\x81\xEE",
  /* U+4F88 */	"\xB3\xDE", "\xD9\xA8", "\x81\xEF", "\xC0\xFD",
  /* U+4F8C */	"\x81\xF0", "\xCA\xCC", "\x81\xF1", "\xD9\xAA",
  /* U+4F90 */	"\x81\xF2", "\xD9\xA7", "\x81\xF3", "\x81\xF4",
  /* U+4F94 */	"\xD9\xB0", "\x81\xF5", "\x81\xF6", "\xB6\xB1",
  /* U+4F98 */	"\x81\xF7", "\x81\xF8", "\x81\xF9", "\xB9\xA9",
  /* U+4F9C */	"\x81\xFA", "\xD2\xC0", "\x81\xFB", "\x81\xFC",
  /* U+4FA0 */	"\xCF\xC0", "\x81\xFD", "\x81\xFE", "\xC2\xC2",
  /* U+4FA4 */	"\x82\x40", "\xBD\xC4", "\xD5\xEC", "\xB2\xE0",
  /* U+4FA8 */	"\xC7\xC8", "\xBF\xEB", "\xD9\xAD", "\x82\x41",
  /* U+4FAC */	"\xD9\xAF", "\x82\x42", "\xCE\xEA", "\xBA\xEE",
  /* U+4FB0 */	"\x82\x43", "\x82\x44", "\x82\x45", "\x82\x46",
  /* U+4FB4 */	"\x82\x47", "\xC7\xD6", "\x82\x48", "\x82\x49",
  /* U+4FB8 */	"\x82\x4A", "\x82\x4B", "\x82\x4C", "\x82\x4D",
  /* U+4FBC */	"\x82\x4E", "\x82\x4F", "\x82\x50", "\xB1\xE3",
  /* U+4FC0 */	"\x82\x51", "\x82\x52", "\x82\x53", "\xB4\xD9",
  /* U+4FC4 */	"\xB6\xED", "\xD9\xB4", "\x82\x54", "\x82\x55",
  /* U+4FC8 */	"\x82\x56", "\x82\x57", "\xBF\xA1", "\x82\x58",
  /* U+4FCC */	"\x82\x59", "\x82\x5A", "\xD9\xDE", "\xC7\xCE",
  /* U+4FD0 */	"\xC0\xFE", "\xD9\xB8", "\x82\x5B", "\x82\x5C",
  /* U+4FD4 */	"\x82\x5D", "\x82\x5E", "\x82\x5F", "\xCB\xD7",
  /* U+4FD8 */	"\xB7\xFD", "\x82\x60", "\xD9\xB5", "\x82\x61",
  /* U+4FDC */	"\xD9\xB7", "\xB1\xA3", "\xD3\xE1", "\xD9\xB9",
  /* U+4FE0 */	"\x82\x62", "\xD0\xC5", "\x82\x63", "\xD9\xB6",
  /* U+4FE4 */	"\x82\x64", "\x82\x65", "\xD9\xB1", "\x82\x66",
  /* U+4FE8 */	"\xD9\xB2", "\xC1\xA9", "\xD9\xB3", "\x82\x67",
  /* U+4FEC */	"\x82\x68", "\xBC\xF3", "\xD0\xDE", "\xB8\xA9",
  /* U+4FF0 */	"\x82\x69", "\xBE\xE3", "\x82\x6A", "\xD9\xBD",
  /* U+4FF4 */	"\x82\x6B", "\x82\x6C", "\x82\x6D", "\x82\x6E",
  /* U+4FF8 */	"\xD9\xBA", "\x82\x6F", "\xB0\xB3", "\x82\x70",
  /* U+4FFC */	"\x82\x71", "\x82\x72", "\xD9\xC2", "\x82\x73",
  /* U+5000 */	"\x82\x74", "\x82\x75", "\x82\x76", "\x82\x77",
  /* U+5004 */	"\x82\x78", "\x82\x79", "\x82\x7A", "\x82\x7B",
  /* U+5008 */	"\x82\x7C", "\x82\x7D", "\x82\x7E", "\x82\x80",
  /* U+500C */	"\xD9\xC4", "\xB1\xB6", "\x82\x81", "\xD9\xBF",
  /* U+5010 */	"\x82\x82", "\x82\x83", "\xB5\xB9", "\x82\x84",
  /* U+5014 */	"\xBE\xF3", "\x82\x85", "\x82\x86", "\x82\x87",
  /* U+5018 */	"\xCC\xC8", "\xBA\xF2", "\xD2\xD0", "\x82\x88",
  /* U+501C */	"\xD9\xC3", "\x82\x89", "\x82\x8A", "\xBD\xE8",
  /* U+5020 */	"\x82\x8B", "\xB3\xAB", "\x82\x8C", "\x82\x8D",
  /* U+5024 */	"\x82\x8E", "\xD9\xC5", "\xBE\xEB", "\x82\x8F",
  /* U+5028 */	"\xD9\xC6", "\xD9\xBB", "\xC4\xDF", "\x82\x90",
  /* U+502C */	"\xD9\xBE", "\xD9\xC1", "\xD9\xC0", "\x82\x91",
  /* U+5030 */	"\x82\x92", "\x82\x93", "\x82\x94", "\x82\x95",
  /* U+5034 */	"\x82\x96", "\x82\x97", "\x82\x98", "\x82\x99",
  /* U+5038 */	"\x82\x9A", "\x82\x9B", "\xD5\xAE", "\x82\x9C",
  /* U+503C */	"\xD6\xB5", "\x82\x9D", "\xC7\xE3", "\x82\x9E",
  /* U+5040 */	"\x82\x9F", "\x82\xA0", "\x82\xA1", "\xD9\xC8",
  /* U+5044 */	"\x82\xA2", "\x82\xA3", "\x82\xA4", "\xBC\xD9",
  /* U+5048 */	"\xD9\xCA", "\x82\xA5", "\x82\xA6", "\x82\xA7",
  /* U+504C */	"\xD9\xBC", "\x82\xA8", "\xD9\xCB", "\xC6\xAB",
  /* U+5050 */	"\x82\xA9", "\x82\xAA", "\x82\xAB", "\x82\xAC",
  /* U+5054 */	"\x82\xAD", "\xD9\xC9", "\x82\xAE", "\x82\xAF",
  /* U+5058 */	"\x82\xB0", "\x82\xB1", "\xD7\xF6", "\x82\xB2",
  /* U+505C */	"\xCD\xA3", "\x82\xB3", "\x82\xB4", "\x82\xB5",
  /* U+5060 */	"\x82\xB6", "\x82\xB7", "\x82\xB8", "\x82\xB9",
  /* U+5064 */	"\x82\xBA", "\xBD\xA1", "\x82\xBB", "\x82\xBC",
  /* U+5068 */	"\x82\xBD", "\x82\xBE", "\x82\xBF", "\x82\xC0",
  /* U+506C */	"\xD9\xCC", "\x82\xC1", "\x82\xC2", "\x82\xC3",
  /* U+5070 */	"\x82\xC4", "\x82\xC5", "\x82\xC6", "\x82\xC7",
  /* U+5074 */	"\x82\xC8", "\x82\xC9", "\xC5\xBC", "\xCD\xB5",
  /* U+5078 */	"\x82\xCA", "\x82\xCB", "\x82\xCC", "\xD9\xCD",
  /* U+507C */	"\x82\xCD", "\x82\xCE", "\xD9\xC7", "\xB3\xA5",
  /* U+5080 */	"\xBF\xFE", "\x82\xCF", "\x82\xD0", "\x82\xD1",
  /* U+5084 */	"\x82\xD2", "\xB8\xB5", "\x82\xD3", "\x82\xD4",
  /* U+5088 */	"\xC0\xFC", "\x82\xD5", "\x82\xD6", "\x82\xD7",
  /* U+508C */	"\x82\xD8", "\xB0\xF8", "\x82\xD9", "\x82\xDA",
  /* U+5090 */	"\x82\xDB", "\x82\xDC", "\x82\xDD", "\x82\xDE",
  /* U+5094 */	"\x82\xDF", "\x82\xE0", "\x82\xE1", "\x82\xE2",
  /* U+5098 */	"\x82\xE3", "\x82\xE4", "\x82\xE5", "\x82\xE6",
  /* U+509C */	"\x82\xE7", "\x82\xE8", "\x82\xE9", "\x82\xEA",
  /* U+50A0 */	"\x82\xEB", "\x82\xEC", "\x82\xED", "\xB4\xF6",
  /* U+50A4 */	"\x82\xEE", "\xD9\xCE", "\x82\xEF", "\xD9\xCF",
  /* U+50A8 */	"\xB4\xA2", "\xD9\xD0", "\x82\xF0", "\x82\xF1",
  /* U+50AC */	"\xB4\xDF", "\x82\xF2", "\x82\xF3", "\x82\xF4",
  /* U+50B0 */	"\x82\xF5", "\x82\xF6", "\xB0\xC1", "\x82\xF7",
  /* U+50B4 */	"\x82\xF8", "\x82\xF9", "\x82\xFA", "\x82\xFB",
  /* U+50B8 */	"\x82\xFC", "\x82\xFD", "\xD9\xD1", "\xC9\xB5",
  /* U+50BC */	"\x82\xFE", "\x83\x40", "\x83\x41", "\x83\x42",
  /* U+50C0 */	"\x83\x43", "\x83\x44", "\x83\x45", "\x83\x46",
  /* U+50C4 */	"\x83\x47", "\x83\x48", "\x83\x49", "\x83\x4A",
  /* U+50C8 */	"\x83\x4B", "\x83\x4C", "\x83\x4D", "\x83\x4E",
  /* U+50CC */	"\x83\x4F", "\x83\x50", "\x83\x51", "\xCF\xF1",
  /* U+50D0 */	"\x83\x52", "\x83\x53", "\x83\x54", "\x83\x55",
  /* U+50D4 */	"\x83\x56", "\x83\x57", "\xD9\xD2", "\x83\x58",
  /* U+50D8 */	"\x83\x59", "\x83\x5A", "\xC1\xC5", "\x83\x5B",
  /* U+50DC */	"\x83\x5C", "\x83\x5D", "\x83\x5E", "\x83\x5F",
  /* U+50E0 */	"\x83\x60", "\x83\x61", "\x83\x62", "\x83\x63",
  /* U+50E4 */	"\x83\x64", "\x83\x65", "\xD9\xD6", "\xC9\xAE",
  /* U+50E8 */	"\x83\x66", "\x83\x67", "\x83\x68", "\x83\x69",
  /* U+50EC */	"\xD9\xD5", "\xD9\xD4", "\xD9\xD7", "\x83\x6A",
  /* U+50F0 */	"\x83\x6B", "\x83\x6C", "\x83\x6D", "\xCB\xDB",
  /* U+50F4 */	"\x83\x6E", "\xBD\xA9", "\x83\x6F", "\x83\x70",
  /* U+50F8 */	"\x83\x71", "\x83\x72", "\x83\x73", "\xC6\xA7",
  /* U+50FC */	"\x83\x74", "\x83\x75", "\x83\x76", "\x83\x77",
  /* U+5100 */	"\x83\x78", "\x83\x79", "\x83\x7A", "\x83\x7B",
  /* U+5104 */	"\x83\x7C", "\x83\x7D", "\xD9\xD3", "\xD9\xD8",
  /* U+5108 */	"\x83\x7E", "\x83\x80", "\x83\x81", "\xD9\xD9",
  /* U+510C */	"\x83\x82", "\x83\x83", "\x83\x84", "\x83\x85",
  /* U+5110 */	"\x83\x86", "\x83\x87", "\xC8\xE5", "\x83\x88",
  /* U+5114 */	"\x83\x89", "\x83\x8A", "\x83\x8B", "\x83\x8C",
  /* U+5118 */	"\x83\x8D", "\x83\x8E", "\x83\x8F", "\x83\x90",
  /* U+511C */	"\x83\x91", "\x83\x92", "\x83\x93", "\x83\x94",
  /* U+5120 */	"\x83\x95", "\xC0\xDC", "\x83\x96", "\x83\x97",
  /* U+5124 */	"\x83\x98", "\x83\x99", "\x83\x9A", "\x83\x9B",
  /* U+5128 */	"\x83\x9C", "\x83\x9D", "\x83\x9E", "\x83\x9F",
  /* U+512C */	"\x83\xA0", "\x83\xA1", "\x83\xA2", "\x83\xA3",
  /* U+5130 */	"\x83\xA4", "\x83\xA5", "\x83\xA6", "\x83\xA7",
  /* U+5134 */	"\x83\xA8", "\x83\xA9", "\x83\xAA", "\x83\xAB",
  /* U+5138 */	"\x83\xAC", "\x83\xAD", "\x83\xAE", "\x83\xAF",
  /* U+513C */	"\x83\xB0", "\x83\xB1", "\x83\xB2", "\xB6\xF9",
  /* U+5140 */	"\xD8\xA3", "\xD4\xCA", "\x83\xB3", "\xD4\xAA",
  /* U+5144 */	"\xD0\xD6", "\xB3\xE4", "\xD5\xD7", "\x83\xB4",
  /* U+5148 */	"\xCF\xC8", "\xB9\xE2", "\x83\xB5", "\xBF\xCB",
  /* U+514C */	"\x83\xB6", "\xC3\xE2", "\x83\xB7", "\x83\xB8",
  /* U+5150 */	"\x83\xB9", "\xB6\xD2", "\x83\xBA", "\x83\xBB",
  /* U+5154 */	"\xCD\xC3", "\xD9\xEE", "\xD9\xF0", "\x83\xBC",
  /* U+5158 */	"\x83\xBD", "\x83\xBE", "\xB5\xB3", "\x83\xBF",
  /* U+515C */	"\xB6\xB5", "\x83\xC0", "\x83\xC1", "\x83\xC2",
  /* U+5160 */	"\x83\xC3", "\x83\xC4", "\xBE\xA4", "\x83\xC5",
  /* U+5164 */	"\x83\xC6", "\xC8\xEB", "\x83\xC7", "\x83\xC8",
  /* U+5168 */	"\xC8\xAB", "\x83\xC9", "\x83\xCA", "\xB0\xCB",
  /* U+516C */	"\xB9\xAB", "\xC1\xF9", "\xD9\xE2", "\x83\xCB",
  /* U+5170 */	"\xC0\xBC", "\xB9\xB2", "\x83\xCC", "\xB9\xD8",
  /* U+5174 */	"\xD0\xCB", "\xB1\xF8", "\xC6\xE4", "\xBE\xDF",
  /* U+5178 */	"\xB5\xE4", "\xD7\xC8", "\x83\xCD", "\xD1\xF8",
  /* U+517C */	"\xBC\xE6", "\xCA\xDE", "\x83\xCE", "\x83\xCF",
  /* U+5180 */	"\xBC\xBD", "\xD9\xE6", "\xD8\xE7", "\x83\xD0",
  /* U+5184 */	"\x83\xD1", "\xC4\xDA", "\x83\xD2", "\x83\xD3",
  /* U+5188 */	"\xB8\xD4", "\xC8\xBD", "\x83\xD4", "\x83\xD5",
  /* U+518C */	"\xB2\xE1", "\xD4\xD9", "\x83\xD6", "\x83\xD7",
  /* U+5190 */	"\x83\xD8", "\x83\xD9", "\xC3\xB0", "\x83\xDA",
  /* U+5194 */	"\x83\xDB", "\xC3\xE1", "\xDA\xA2", "\xC8\xDF",
  /* U+5198 */	"\x83\xDC", "\xD0\xB4", "\x83\xDD", "\xBE\xFC",
  /* U+519C */	"\xC5\xA9", "\x83\xDE", "\x83\xDF", "\x83\xE0",
  /* U+51A0 */	"\xB9\xDA", "\x83\xE1", "\xDA\xA3", "\x83\xE2",
  /* U+51A4 */	"\xD4\xA9", "\xDA\xA4", "\x83\xE3", "\x83\xE4",
  /* U+51A8 */	"\x83\xE5", "\x83\xE6", "\x83\xE7", "\xD9\xFB",
  /* U+51AC */	"\xB6\xAC", "\x83\xE8", "\x83\xE9", "\xB7\xEB",
  /* U+51B0 */	"\xB1\xF9", "\xD9\xFC", "\xB3\xE5", "\xBE\xF6",
  /* U+51B4 */	"\x83\xEA", "\xBF\xF6", "\xD2\xB1", "\xC0\xE4",
  /* U+51B8 */	"\x83\xEB", "\x83\xEC", "\x83\xED", "\xB6\xB3",
  /* U+51BC */	"\xD9\xFE", "\xD9\xFD", "\x83\xEE", "\x83\xEF",
  /* U+51C0 */	"\xBE\xBB", "\x83\xF0", "\x83\xF1", "\x83\xF2",
  /* U+51C4 */	"\xC6\xE0", "\x83\xF3", "\xD7\xBC", "\xDA\xA1",
  /* U+51C8 */	"\x83\xF4", "\xC1\xB9", "\x83\xF5", "\xB5\xF2",
  /* U+51CC */	"\xC1\xE8", "\x83\xF6", "\x83\xF7", "\xBC\xF5",
  /* U+51D0 */	"\x83\xF8", "\xB4\xD5", "\x83\xF9", "\x83\xFA",
  /* U+51D4 */	"\x83\xFB", "\x83\xFC", "\x83\xFD", "\x83\xFE",
  /* U+51D8 */	"\x84\x40", "\x84\x41", "\x84\x42", "\xC1\xDD",
  /* U+51DC */	"\x84\x43", "\xC4\xFD", "\x84\x44", "\x84\x45",
  /* U+51E0 */	"\xBC\xB8", "\xB7\xB2", "\x84\x46", "\x84\x47",
  /* U+51E4 */	"\xB7\xEF", "\x84\x48", "\x84\x49", "\x84\x4A",
  /* U+51E8 */	"\x84\x4B", "\x84\x4C", "\x84\x4D", "\xD9\xEC",
  /* U+51EC */	"\x84\x4E", "\xC6\xBE", "\x84\x4F", "\xBF\xAD",
  /* U+51F0 */	"\xBB\xCB", "\x84\x50", "\x84\x51", "\xB5\xCA",
  /* U+51F4 */	"\x84\x52", "\xDB\xC9", "\xD0\xD7", "\x84\x53",
  /* U+51F8 */	"\xCD\xB9", "\xB0\xBC", "\xB3\xF6", "\xBB\xF7",
  /* U+51FC */	"\xDB\xCA", "\xBA\xAF", "\x84\x54", "\xD4\xE4",
  /* U+5200 */	"\xB5\xB6", "\xB5\xF3", "\xD8\xD6", "\xC8\xD0",
  /* U+5204 */	"\x84\x55", "\x84\x56", "\xB7\xD6", "\xC7\xD0",
  /* U+5208 */	"\xD8\xD7", "\x84\x57", "\xBF\xAF", "\x84\x58",
  /* U+520C */	"\x84\x59", "\xDB\xBB", "\xD8\xD8", "\x84\x5A",
  /* U+5210 */	"\x84\x5B", "\xD0\xCC", "\xBB\xAE", "\x84\x5C",
  /* U+5214 */	"\x84\x5D", "\x84\x5E", "\xEB\xBE", "\xC1\xD0",
  /* U+5218 */	"\xC1\xF5", "\xD4\xF2", "\xB8\xD5", "\xB4\xB4",
  /* U+521C */	"\x84\x5F", "\xB3\xF5", "\x84\x60", "\x84\x61",
  /* U+5220 */	"\xC9\xBE", "\x84\x62", "\x84\x63", "\x84\x64",
  /* U+5224 */	"\xC5\xD0", "\x84\x65", "\x84\x66", "\x84\x67",
  /* U+5228 */	"\xC5\xD9", "\xC0\xFB", "\x84\x68", "\xB1\xF0",
  /* U+522C */	"\x84\x69", "\xD8\xD9", "\xB9\xCE", "\x84\x6A",
  /* U+5230 */	"\xB5\xBD", "\x84\x6B", "\x84\x6C", "\xD8\xDA",
  /* U+5234 */	"\x84\x6D", "\x84\x6E", "\xD6\xC6", "\xCB\xA2",
  /* U+5238 */	"\xC8\xAF", "\xC9\xB2", "\xB4\xCC", "\xBF\xCC",
  /* U+523C */	"\x84\x6F", "\xB9\xF4", "\x84\x70", "\xD8\xDB",
  /* U+5240 */	"\xD8\xDC", "\xB6\xE7", "\xBC\xC1", "\xCC\xEA",
  /* U+5244 */	"\x84\x71", "\x84\x72", "\x84\x73", "\x84\x74",
  /* U+5248 */	"\x84\x75", "\x84\x76", "\xCF\xF7", "\x84\x77",
  /* U+524C */	"\xD8\xDD", "\xC7\xB0", "\x84\x78", "\x84\x79",
  /* U+5250 */	"\xB9\xD0", "\xBD\xA3", "\x84\x7A", "\x84\x7B",
  /* U+5254 */	"\xCC\xDE", "\x84\x7C", "\xC6\xCA", "\x84\x7D",
  /* U+5258 */	"\x84\x7E", "\x84\x80", "\x84\x81", "\x84\x82",
  /* U+525C */	"\xD8\xE0", "\x84\x83", "\xD8\xDE", "\x84\x84",
  /* U+5260 */	"\x84\x85", "\xD8\xDF", "\x84\x86", "\x84\x87",
  /* U+5264 */	"\x84\x88", "\xB0\xFE", "\x84\x89", "\xBE\xE7",
  /* U+5268 */	"\x84\x8A", "\xCA\xA3", "\xBC\xF4", "\x84\x8B",
  /* U+526C */	"\x84\x8C", "\x84\x8D", "\x84\x8E", "\xB8\xB1",
  /* U+5270 */	"\x84\x8F", "\x84\x90", "\xB8\xEE", "\x84\x91",
  /* U+5274 */	"\x84\x92", "\x84\x93", "\x84\x94", "\x84\x95",
  /* U+5278 */	"\x84\x96", "\x84\x97", "\x84\x98", "\x84\x99",
  /* U+527C */	"\x84\x9A", "\xD8\xE2", "\x84\x9B", "\xBD\xCB",
  /* U+5280 */	"\x84\x9C", "\xD8\xE4", "\xD8\xE3", "\x84\x9D",
  /* U+5284 */	"\x84\x9E", "\x84\x9F", "\x84\xA0", "\x84\xA1",
  /* U+5288 */	"\xC5\xFC", "\x84\xA2", "\x84\xA3", "\x84\xA4",
  /* U+528C */	"\x84\xA5", "\x84\xA6", "\x84\xA7", "\x84\xA8",
  /* U+5290 */	"\xD8\xE5", "\x84\xA9", "\x84\xAA", "\xD8\xE6",
  /* U+5294 */	"\x84\xAB", "\x84\xAC", "\x84\xAD", "\x84\xAE",
  /* U+5298 */	"\x84\xAF", "\x84\xB0", "\x84\xB1", "\xC1\xA6",
  /* U+529C */	"\x84\xB2", "\xC8\xB0", "\xB0\xEC", "\xB9\xA6",
  /* U+52A0 */	"\xBC\xD3", "\xCE\xF1", "\xDB\xBD", "\xC1\xD3",
  /* U+52A4 */	"\x84\xB3", "\x84\xB4", "\x84\xB5", "\x84\xB6",
  /* U+52A8 */	"\xB6\xAF", "\xD6\xFA", "\xC5\xAC", "\xBD\xD9",
  /* U+52AC */	"\xDB\xBE", "\xDB\xBF", "\x84\xB7", "\x84\xB8",
  /* U+52B0 */	"\x84\xB9", "\xC0\xF8", "\xBE\xA2", "\xC0\xCD",
  /* U+52B4 */	"\x84\xBA", "\x84\xBB", "\x84\xBC", "\x84\xBD",
  /* U+52B8 */	"\x84\xBE", "\x84\xBF", "\x84\xC0", "\x84\xC1",
  /* U+52BC */	"\x84\xC2", "\x84\xC3", "\xDB\xC0", "\xCA\xC6",
  /* U+52C0 */	"\x84\xC4", "\x84\xC5", "\x84\xC6", "\xB2\xAA",
  /* U+52C4 */	"\x84\xC7", "\x84\xC8", "\x84\xC9", "\xD3\xC2",
  /* U+52C8 */	"\x84\xCA", "\xC3\xE3", "\x84\xCB", "\xD1\xAB",
  /* U+52CC */	"\x84\xCC", "\x84\xCD", "\x84\xCE", "\x84\xCF",
  /* U+52D0 */	"\xDB\xC2", "\x84\xD0", "\xC0\xD5", "\x84\xD1",
  /* U+52D4 */	"\x84\xD2", "\x84\xD3", "\xDB\xC3", "\x84\xD4",
  /* U+52D8 */	"\xBF\xB1", "\x84\xD5", "\x84\xD6", "\x84\xD7",
  /* U+52DC */	"\x84\xD8", "\x84\xD9", "\x84\xDA", "\xC4\xBC",
  /* U+52E0 */	"\x84\xDB", "\x84\xDC", "\x84\xDD", "\x84\xDE",
  /* U+52E4 */	"\xC7\xDA", "\x84\xDF", "\x84\xE0", "\x84\xE1",
  /* U+52E8 */	"\x84\xE2", "\x84\xE3", "\x84\xE4", "\x84\xE5",
  /* U+52EC */	"\x84\xE6", "\x84\xE7", "\x84\xE8", "\x84\xE9",
  /* U+52F0 */	"\xDB\xC4", "\x84\xEA", "\x84\xEB", "\x84\xEC",
  /* U+52F4 */	"\x84\xED", "\x84\xEE", "\x84\xEF", "\x84\xF0",
  /* U+52F8 */	"\x84\xF1", "\xD9\xE8", "\xC9\xD7", "\x84\xF2",
  /* U+52FC */	"\x84\xF3", "\x84\xF4", "\xB9\xB4", "\xCE\xF0",
  /* U+5300 */	"\xD4\xC8", "\x84\xF5", "\x84\xF6", "\x84\xF7",
  /* U+5304 */	"\x84\xF8", "\xB0\xFC", "\xB4\xD2", "\x84\xF9",
  /* U+5308 */	"\xD0\xD9", "\x84\xFA", "\x84\xFB", "\x84\xFC",
  /* U+530C */	"\x84\xFD", "\xD9\xE9", "\x84\xFE", "\xDE\xCB",
  /* U+5310 */	"\xD9\xEB", "\x85\x40", "\x85\x41", "\x85\x42",
  /* U+5314 */	"\x85\x43", "\xD8\xB0", "\xBB\xAF", "\xB1\xB1",
  /* U+5318 */	"\x85\x44", "\xB3\xD7", "\xD8\xCE", "\x85\x45",
  /* U+531C */	"\x85\x46", "\xD4\xD1", "\x85\x47", "\x85\x48",
  /* U+5320 */	"\xBD\xB3", "\xBF\xEF", "\x85\x49", "\xCF\xBB",
  /* U+5324 */	"\x85\x4A", "\x85\x4B", "\xD8\xD0", "\x85\x4C",
  /* U+5328 */	"\x85\x4D", "\x85\x4E", "\xB7\xCB", "\x85\x4F",
  /* U+532C */	"\x85\x50", "\x85\x51", "\xD8\xD1", "\x85\x52",
  /* U+5330 */	"\x85\x53", "\x85\x54", "\x85\x55", "\x85\x56",
  /* U+5334 */	"\x85\x57", "\x85\x58", "\x85\x59", "\x85\x5A",
  /* U+5338 */	"\x85\x5B", "\xC6\xA5", "\xC7\xF8", "\xD2\xBD",
  /* U+533C */	"\x85\x5C", "\x85\x5D", "\xD8\xD2", "\xC4\xE4",
  /* U+5340 */	"\x85\x5E", "\xCA\xAE", "\x85\x5F", "\xC7\xA7",
  /* U+5344 */	"\x85\x60", "\xD8\xA6", "\x85\x61", "\xC9\xFD",
  /* U+5348 */	"\xCE\xE7", "\xBB\xDC", "\xB0\xEB", "\x85\x62",
  /* U+534C */	"\x85\x63", "\x85\x64", "\xBB\xAA", "\xD0\xAD",
  /* U+5350 */	"\x85\x65", "\xB1\xB0", "\xD7\xE4", "\xD7\xBF",
  /* U+5354 */	"\x85\x66", "\xB5\xA5", "\xC2\xF4", "\xC4\xCF",
  /* U+5358 */	"\x85\x67", "\x85\x68", "\xB2\xA9", "\x85\x69",
  /* U+535C */	"\xB2\xB7", "\x85\x6A", "\xB1\xE5", "\xDF\xB2",
  /* U+5360 */	"\xD5\xBC", "\xBF\xA8", "\xC2\xAC", "\xD8\xD5",
  /* U+5364 */	"\xC2\xB1", "\x85\x6B", "\xD8\xD4", "\xCE\xD4",
  /* U+5368 */	"\x85\x6C", "\xDA\xE0", "\x85\x6D", "\xCE\xC0",
  /* U+536C */	"\x85\x6E", "\x85\x6F", "\xD8\xB4", "\xC3\xAE",
  /* U+5370 */	"\xD3\xA1", "\xCE\xA3", "\x85\x70", "\xBC\xB4",
  /* U+5374 */	"\xC8\xB4", "\xC2\xD1", "\x85\x71", "\xBE\xED",
  /* U+5378 */	"\xD0\xB6", "\x85\x72", "\xDA\xE1", "\x85\x73",
  /* U+537C */	"\x85\x74", "\x85\x75", "\x85\x76", "\xC7\xE4",
  /* U+5380 */	"\x85\x77", "\x85\x78", "\xB3\xA7", "\x85\x79",
  /* U+5384 */	"\xB6\xF2", "\xCC\xFC", "\xC0\xFA", "\x85\x7A",
  /* U+5388 */	"\x85\x7B", "\xC0\xF7", "\x85\x7C", "\xD1\xB9",
  /* U+538C */	"\xD1\xE1", "\xD8\xC7", "\x85\x7D", "\x85\x7E",
  /* U+5390 */	"\x85\x80", "\x85\x81", "\x85\x82", "\x85\x83",
  /* U+5394 */	"\x85\x84", "\xB2\xDE", "\x85\x85", "\x85\x86",
  /* U+5398 */	"\xC0\xE5", "\x85\x87", "\xBA\xF1", "\x85\x88",
  /* U+539C */	"\x85\x89", "\xD8\xC8", "\x85\x8A", "\xD4\xAD",
  /* U+53A0 */	"\x85\x8B", "\x85\x8C", "\xCF\xE1", "\xD8\xC9",
  /* U+53A4 */	"\x85\x8D", "\xD8\xCA", "\xCF\xC3", "\x85\x8E",
  /* U+53A8 */	"\xB3\xF8", "\xBE\xC7", "\x85\x8F", "\x85\x90",
  /* U+53AC */	"\x85\x91", "\x85\x92", "\xD8\xCB", "\x85\x93",
  /* U+53B0 */	"\x85\x94", "\x85\x95", "\x85\x96", "\x85\x97",
  /* U+53B4 */	"\x85\x98", "\x85\x99", "\xDB\xCC", "\x85\x9A",
  /* U+53B8 */	"\x85\x9B", "\x85\x9C", "\x85\x9D", "\xC8\xA5",
  /* U+53BC */	"\x85\x9E", "\x85\x9F", "\x85\xA0", "\xCF\xD8",
  /* U+53C0 */	"\x85\xA1", "\xC8\xFE", "\xB2\xCE", "\x85\xA2",
  /* U+53C4 */	"\x85\xA3", "\x85\xA4", "\x85\xA5", "\x85\xA6",
  /* U+53C8 */	"\xD3\xD6", "\xB2\xE6", "\xBC\xB0", "\xD3\xD1",
  /* U+53CC */	"\xCB\xAB", "\xB7\xB4", "\x85\xA7", "\x85\xA8",
  /* U+53D0 */	"\x85\xA9", "\xB7\xA2", "\x85\xAA", "\x85\xAB",
  /* U+53D4 */	"\xCA\xE5", "\x85\xAC", "\xC8\xA1", "\xCA\xDC",
  /* U+53D8 */	"\xB1\xE4", "\xD0\xF0", "\x85\xAD", "\xC5\xD1",
  /* U+53DC */	"\x85\xAE", "\x85\xAF", "\x85\xB0", "\xDB\xC5",
  /* U+53E0 */	"\xB5\xFE", "\x85\xB1", "\x85\xB2", "\xBF\xDA",
  /* U+53E4 */	"\xB9\xC5", "\xBE\xE4", "\xC1\xED", "\x85\xB3",
  /* U+53E8 */	"\xDF\xB6", "\xDF\xB5", "\xD6\xBB", "\xBD\xD0",
  /* U+53EC */	"\xD5\xD9", "\xB0\xC8", "\xB6\xA3", "\xBF\xC9",
  /* U+53F0 */	"\xCC\xA8", "\xDF\xB3", "\xCA\xB7", "\xD3\xD2",
  /* U+53F4 */	"\x85\xB4", "\xD8\xCF", "\xD2\xB6", "\xBA\xC5",
  /* U+53F8 */	"\xCB\xBE", "\xCC\xBE", "\x85\xB5", "\xDF\xB7",
  /* U+53FC */	"\xB5\xF0", "\xDF\xB4", "\x85\xB6", "\x85\xB7",
  /* U+5400 */	"\x85\xB8", "\xD3\xF5", "\x85\xB9", "\xB3\xD4",
  /* U+5404 */	"\xB8\xF7", "\x85\xBA", "\xDF\xBA", "\x85\xBB",
  /* U+5408 */	"\xBA\xCF", "\xBC\xAA", "\xB5\xF5", "\x85\xBC",
  /* U+540C */	"\xCD\xAC", "\xC3\xFB", "\xBA\xF3", "\xC0\xF4",
  /* U+5410 */	"\xCD\xC2", "\xCF\xF2", "\xDF\xB8", "\xCF\xC5",
  /* U+5414 */	"\x85\xBD", "\xC2\xC0", "\xDF\xB9", "\xC2\xF0",
  /* U+5418 */	"\x85\xBE", "\x85\xBF", "\x85\xC0", "\xBE\xFD",
  /* U+541C */	"\x85\xC1", "\xC1\xDF", "\xCD\xCC", "\xD2\xF7",
  /* U+5420 */	"\xB7\xCD", "\xDF\xC1", "\x85\xC2", "\xDF\xC4",
  /* U+5424 */	"\x85\xC3", "\x85\xC4", "\xB7\xF1", "\xB0\xC9",
  /* U+5428 */	"\xB6\xD6", "\xB7\xD4", "\x85\xC5", "\xBA\xAC",
  /* U+542C */	"\xCC\xFD", "\xBF\xD4", "\xCB\xB1", "\xC6\xF4",
  /* U+5430 */	"\x85\xC6", "\xD6\xA8", "\xDF\xC5", "\x85\xC7",
  /* U+5434 */	"\xCE\xE2", "\xB3\xB3", "\x85\xC8", "\x85\xC9",
  /* U+5438 */	"\xCE\xFC", "\xB4\xB5", "\x85\xCA", "\xCE\xC7",
  /* U+543C */	"\xBA\xF0", "\x85\xCB", "\xCE\xE1", "\x85\xCC",
  /* U+5440 */	"\xD1\xBD", "\x85\xCD", "\x85\xCE", "\xDF\xC0",
  /* U+5444 */	"\x85\xCF", "\x85\xD0", "\xB4\xF4", "\x85\xD1",
  /* U+5448 */	"\xB3\xCA", "\x85\xD2", "\xB8\xE6", "\xDF\xBB",
  /* U+544C */	"\x85\xD3", "\x85\xD4", "\x85\xD5", "\x85\xD6",
  /* U+5450 */	"\xC4\xC5", "\x85\xD7", "\xDF\xBC", "\xDF\xBD",
  /* U+5454 */	"\xDF\xBE", "\xC5\xBB", "\xDF\xBF", "\xDF\xC2",
  /* U+5458 */	"\xD4\xB1", "\xDF\xC3", "\x85\xD8", "\xC7\xBA",
  /* U+545C */	"\xCE\xD8", "\x85\xD9", "\x85\xDA", "\x85\xDB",
  /* U+5460 */	"\x85\xDC", "\x85\xDD", "\xC4\xD8", "\x85\xDE",
  /* U+5464 */	"\xDF\xCA", "\x85\xDF", "\xDF\xCF", "\x85\xE0",
  /* U+5468 */	"\xD6\xDC", "\x85\xE1", "\x85\xE2", "\x85\xE3",
  /* U+546C */	"\x85\xE4", "\x85\xE5", "\x85\xE6", "\x85\xE7",
  /* U+5470 */	"\x85\xE8", "\xDF\xC9", "\xDF\xDA", "\xCE\xB6",
  /* U+5474 */	"\x85\xE9", "\xBA\xC7", "\xDF\xCE", "\xDF\xC8",
  /* U+5478 */	"\xC5\xDE", "\x85\xEA", "\x85\xEB", "\xC9\xEB",
  /* U+547C */	"\xBA\xF4", "\xC3\xFC", "\x85\xEC", "\x85\xED",
  /* U+5480 */	"\xBE\xD7", "\x85\xEE", "\xDF\xC6", "\x85\xEF",
  /* U+5484 */	"\xDF\xCD", "\x85\xF0", "\xC5\xD8", "\x85\xF1",
  /* U+5488 */	"\x85\xF2", "\x85\xF3", "\x85\xF4", "\xD5\xA6",
  /* U+548C */	"\xBA\xCD", "\x85\xF5", "\xBE\xCC", "\xD3\xBD",
  /* U+5490 */	"\xB8\xC0", "\x85\xF6", "\xD6\xE4", "\x85\xF7",
  /* U+5494 */	"\xDF\xC7", "\xB9\xBE", "\xBF\xA7", "\x85\xF8",
  /* U+5498 */	"\x85\xF9", "\xC1\xFC", "\xDF\xCB", "\xDF\xCC",
  /* U+549C */	"\x85\xFA", "\xDF\xD0", "\x85\xFB", "\x85\xFC",
  /* U+54A0 */	"\x85\xFD", "\x85\xFE", "\x86\x40", "\xDF\xDB",
  /* U+54A4 */	"\xDF\xE5", "\x86\x41", "\xDF\xD7", "\xDF\xD6",
  /* U+54A8 */	"\xD7\xC9", "\xDF\xE3", "\xDF\xE4", "\xE5\xEB",
  /* U+54AC */	"\xD2\xA7", "\xDF\xD2", "\x86\x42", "\xBF\xA9",
  /* U+54B0 */	"\x86\x43", "\xD4\xDB", "\x86\x44", "\xBF\xC8",
  /* U+54B4 */	"\xDF\xD4", "\x86\x45", "\x86\x46", "\x86\x47",
  /* U+54B8 */	"\xCF\xCC", "\x86\x48", "\x86\x49", "\xDF\xDD",
  /* U+54BC */	"\x86\x4A", "\xD1\xCA", "\x86\x4B", "\xDF\xDE",
  /* U+54C0 */	"\xB0\xA7", "\xC6\xB7", "\xDF\xD3", "\x86\x4C",
  /* U+54C4 */	"\xBA\xE5", "\x86\x4D", "\xB6\xDF", "\xCD\xDB",
  /* U+54C8 */	"\xB9\xFE", "\xD4\xD5", "\x86\x4E", "\x86\x4F",
  /* U+54CC */	"\xDF\xDF", "\xCF\xEC", "\xB0\xA5", "\xDF\xE7",
  /* U+54D0 */	"\xDF\xD1", "\xD1\xC6", "\xDF\xD5", "\xDF\xD8",
  /* U+54D4 */	"\xDF\xD9", "\xDF\xDC", "\x86\x50", "\xBB\xA9",
  /* U+54D8 */	"\x86\x51", "\xDF\xE0", "\xDF\xE1", "\x86\x52",
  /* U+54DC */	"\xDF\xE2", "\xDF\xE6", "\xDF\xE8", "\xD3\xB4",
  /* U+54E0 */	"\x86\x53", "\x86\x54", "\x86\x55", "\x86\x56",
  /* U+54E4 */	"\x86\x57", "\xB8\xE7", "\xC5\xB6", "\xDF\xEA",
  /* U+54E8 */	"\xC9\xDA", "\xC1\xA8", "\xC4\xC4", "\x86\x58",
  /* U+54EC */	"\x86\x59", "\xBF\xDE", "\xCF\xF8", "\x86\x5A",
  /* U+54F0 */	"\x86\x5B", "\x86\x5C", "\xD5\xDC", "\xDF\xEE",
  /* U+54F4 */	"\x86\x5D", "\x86\x5E", "\x86\x5F", "\x86\x60",
  /* U+54F8 */	"\x86\x61", "\x86\x62", "\xB2\xB8", "\x86\x63",
  /* U+54FC */	"\xBA\xDF", "\xDF\xEC", "\x86\x64", "\xDB\xC1",
  /* U+5500 */	"\x86\x65", "\xD1\xE4", "\x86\x66", "\x86\x67",
  /* U+5504 */	"\x86\x68", "\x86\x69", "\xCB\xF4", "\xB4\xBD",
  /* U+5508 */	"\x86\x6A", "\xB0\xA6", "\x86\x6B", "\x86\x6C",
  /* U+550C */	"\x86\x6D", "\x86\x6E", "\x86\x6F", "\xDF\xF1",
  /* U+5510 */	"\xCC\xC6", "\xDF\xF2", "\x86\x70", "\x86\x71",
  /* U+5514 */	"\xDF\xED", "\x86\x72", "\x86\x73", "\x86\x74",
  /* U+5518 */	"\x86\x75", "\x86\x76", "\x86\x77", "\xDF\xE9",
  /* U+551C */	"\x86\x78", "\x86\x79", "\x86\x7A", "\x86\x7B",
  /* U+5520 */	"\xDF\xEB", "\x86\x7C", "\xDF\xEF", "\xDF\xF0",
  /* U+5524 */	"\xBB\xBD", "\x86\x7D", "\x86\x7E", "\xDF\xF3",
  /* U+5528 */	"\x86\x80", "\x86\x81", "\xDF\xF4", "\x86\x82",
  /* U+552C */	"\xBB\xA3", "\x86\x83", "\xCA\xDB", "\xCE\xA8",
  /* U+5530 */	"\xE0\xA7", "\xB3\xAA", "\x86\x84", "\xE0\xA6",
  /* U+5534 */	"\x86\x85", "\x86\x86", "\x86\x87", "\xE0\xA1",
  /* U+5538 */	"\x86\x88", "\x86\x89", "\x86\x8A", "\x86\x8B",
  /* U+553C */	"\xDF\xFE", "\x86\x8C", "\xCD\xD9", "\xDF\xFC",
  /* U+5540 */	"\x86\x8D", "\xDF\xFA", "\x86\x8E", "\xBF\xD0",
  /* U+5544 */	"\xD7\xC4", "\x86\x8F", "\xC9\xCC", "\x86\x90",
  /* U+5548 */	"\x86\x91", "\xDF\xF8", "\xB0\xA1", "\x86\x92",
  /* U+554C */	"\x86\x93", "\x86\x94", "\x86\x95", "\x86\x96",
  /* U+5550 */	"\xDF\xFD", "\x86\x97", "\x86\x98", "\x86\x99",
  /* U+5554 */	"\x86\x9A", "\xDF\xFB", "\xE0\xA2", "\x86\x9B",
  /* U+5558 */	"\x86\x9C", "\x86\x9D", "\x86\x9E", "\x86\x9F",
  /* U+555C */	"\xE0\xA8", "\x86\xA0", "\x86\xA1", "\x86\xA2",
  /* U+5560 */	"\x86\xA3", "\xB7\xC8", "\x86\xA4", "\x86\xA5",
  /* U+5564 */	"\xC6\xA1", "\xC9\xB6", "\xC0\xB2", "\xDF\xF5",
  /* U+5568 */	"\x86\xA6", "\x86\xA7", "\xC5\xBE", "\x86\xA8",
  /* U+556C */	"\xD8\xC4", "\xDF\xF9", "\xC4\xF6", "\x86\xA9",
  /* U+5570 */	"\x86\xAA", "\x86\xAB", "\x86\xAC", "\x86\xAD",
  /* U+5574 */	"\x86\xAE", "\xE0\xA3", "\xE0\xA4", "\xE0\xA5",
  /* U+5578 */	"\xD0\xA5", "\x86\xAF", "\x86\xB0", "\xE0\xB4",
  /* U+557C */	"\xCC\xE4", "\x86\xB1", "\xE0\xB1", "\x86\xB2",
  /* U+5580 */	"\xBF\xA6", "\xE0\xAF", "\xCE\xB9", "\xE0\xAB",
  /* U+5584 */	"\xC9\xC6", "\x86\xB3", "\x86\xB4", "\xC0\xAE",
  /* U+5588 */	"\xE0\xAE", "\xBA\xED", "\xBA\xB0", "\xE0\xA9",
  /* U+558C */	"\x86\xB5", "\x86\xB6", "\x86\xB7", "\xDF\xF6",
  /* U+5590 */	"\x86\xB8", "\xE0\xB3", "\x86\xB9", "\x86\xBA",
  /* U+5594 */	"\xE0\xB8", "\x86\xBB", "\x86\xBC", "\x86\xBD",
  /* U+5598 */	"\xB4\xAD", "\xE0\xB9", "\x86\xBE", "\x86\xBF",
  /* U+559C */	"\xCF\xB2", "\xBA\xC8", "\x86\xC0", "\xE0\xB0",
  /* U+55A0 */	"\x86\xC1", "\x86\xC2", "\x86\xC3", "\x86\xC4",
  /* U+55A4 */	"\x86\xC5", "\x86\xC6", "\x86\xC7", "\xD0\xFA",
  /* U+55A8 */	"\x86\xC8", "\x86\xC9", "\x86\xCA", "\x86\xCB",
  /* U+55AC */	"\x86\xCC", "\x86\xCD", "\x86\xCE", "\x86\xCF",
  /* U+55B0 */	"\x86\xD0", "\xE0\xAC", "\x86\xD1", "\xD4\xFB",
  /* U+55B4 */	"\x86\xD2", "\xDF\xF7", "\x86\xD3", "\xC5\xE7",
  /* U+55B8 */	"\x86\xD4", "\xE0\xAD", "\x86\xD5", "\xD3\xF7",
  /* U+55BC */	"\x86\xD6", "\xE0\xB6", "\xE0\xB7", "\x86\xD7",
  /* U+55C0 */	"\x86\xD8", "\x86\xD9", "\x86\xDA", "\x86\xDB",
  /* U+55C4 */	"\xE0\xC4", "\xD0\xE1", "\x86\xDC", "\x86\xDD",
  /* U+55C8 */	"\x86\xDE", "\xE0\xBC", "\x86\xDF", "\x86\xE0",
  /* U+55CC */	"\xE0\xC9", "\xE0\xCA", "\x86\xE1", "\x86\xE2",
  /* U+55D0 */	"\x86\xE3", "\xE0\xBE", "\xE0\xAA", "\xC9\xA4",
  /* U+55D4 */	"\xE0\xC1", "\x86\xE4", "\xE0\xB2", "\x86\xE5",
  /* U+55D8 */	"\x86\xE6", "\x86\xE7", "\x86\xE8", "\x86\xE9",
  /* U+55DC */	"\xCA\xC8", "\xE0\xC3", "\x86\xEA", "\xE0\xB5",
  /* U+55E0 */	"\x86\xEB", "\xCE\xCB", "\x86\xEC", "\xCB\xC3",
  /* U+55E4 */	"\xE0\xCD", "\xE0\xC6", "\xE0\xC2", "\x86\xED",
  /* U+55E8 */	"\xE0\xCB", "\x86\xEE", "\xE0\xBA", "\xE0\xBF",
  /* U+55EC */	"\xE0\xC0", "\x86\xEF", "\x86\xF0", "\xE0\xC5",
  /* U+55F0 */	"\x86\xF1", "\x86\xF2", "\xE0\xC7", "\xE0\xC8",
  /* U+55F4 */	"\x86\xF3", "\xE0\xCC", "\x86\xF4", "\xE0\xBB",
  /* U+55F8 */	"\x86\xF5", "\x86\xF6", "\x86\xF7", "\x86\xF8",
  /* U+55FC */	"\x86\xF9", "\xCB\xD4", "\xE0\xD5", "\x86\xFA",
  /* U+5600 */	"\xE0\xD6", "\xE0\xD2", "\x86\xFB", "\x86\xFC",
  /* U+5604 */	"\x86\xFD", "\x86\xFE", "\x87\x40", "\x87\x41",
  /* U+5608 */	"\xE0\xD0", "\xBC\xCE", "\x87\x42", "\x87\x43",
  /* U+560C */	"\xE0\xD1", "\x87\x44", "\xB8\xC2", "\xD8\xC5",
  /* U+5610 */	"\x87\x45", "\x87\x46", "\x87\x47", "\x87\x48",
  /* U+5614 */	"\x87\x49", "\x87\x4A", "\x87\x4B", "\x87\x4C",
  /* U+5618 */	"\xD0\xEA", "\x87\x4D", "\x87\x4E", "\xC2\xEF",
  /* U+561C */	"\x87\x4F", "\x87\x50", "\xE0\xCF", "\xE0\xBD",
  /* U+5620 */	"\x87\x51", "\x87\x52", "\x87\x53", "\xE0\xD4",
  /* U+5624 */	"\xE0\xD3", "\x87\x54", "\x87\x55", "\xE0\xD7",
  /* U+5628 */	"\x87\x56", "\x87\x57", "\x87\x58", "\x87\x59",
  /* U+562C */	"\xE0\xDC", "\xE0\xD8", "\x87\x5A", "\x87\x5B",
  /* U+5630 */	"\x87\x5C", "\xD6\xF6", "\xB3\xB0", "\x87\x5D",
  /* U+5634 */	"\xD7\xEC", "\x87\x5E", "\xCB\xBB", "\x87\x5F",
  /* U+5638 */	"\x87\x60", "\xE0\xDA", "\x87\x61", "\xCE\xFB",
  /* U+563C */	"\x87\x62", "\x87\x63", "\x87\x64", "\xBA\xD9",
  /* U+5640 */	"\x87\x65", "\x87\x66", "\x87\x67", "\x87\x68",
  /* U+5644 */	"\x87\x69", "\x87\x6A", "\x87\x6B", "\x87\x6C",
  /* U+5648 */	"\x87\x6D", "\x87\x6E", "\x87\x6F", "\x87\x70",
  /* U+564C */	"\xE0\xE1", "\xE0\xDD", "\xD2\xAD", "\x87\x71",
  /* U+5650 */	"\x87\x72", "\x87\x73", "\x87\x74", "\x87\x75",
  /* U+5654 */	"\xE0\xE2", "\x87\x76", "\x87\x77", "\xE0\xDB",
  /* U+5658 */	"\xE0\xD9", "\xE0\xDF", "\x87\x78", "\x87\x79",
  /* U+565C */	"\xE0\xE0", "\x87\x7A", "\x87\x7B", "\x87\x7C",
  /* U+5660 */	"\x87\x7D", "\x87\x7E", "\xE0\xDE", "\x87\x80",
  /* U+5664 */	"\xE0\xE4", "\x87\x81", "\x87\x82", "\x87\x83",
  /* U+5668 */	"\xC6\xF7", "\xD8\xAC", "\xD4\xEB", "\xE0\xE6",
  /* U+566C */	"\xCA\xC9", "\x87\x84", "\x87\x85", "\x87\x86",
  /* U+5670 */	"\x87\x87", "\xE0\xE5", "\x87\x88", "\x87\x89",
  /* U+5674 */	"\x87\x8A", "\x87\x8B", "\xB8\xC1", "\x87\x8C",
  /* U+5678 */	"\x87\x8D", "\x87\x8E", "\x87\x8F", "\xE0\xE7",
  /* U+567C */	"\xE0\xE8", "\x87\x90", "\x87\x91", "\x87\x92",
  /* U+5680 */	"\x87\x93", "\x87\x94", "\x87\x95", "\x87\x96",
  /* U+5684 */	"\x87\x97", "\xE0\xE9", "\xE0\xE3", "\x87\x98",
  /* U+5688 */	"\x87\x99", "\x87\x9A", "\x87\x9B", "\x87\x9C",
  /* U+568C */	"\x87\x9D", "\x87\x9E", "\xBA\xBF", "\xCC\xE7",
  /* U+5690 */	"\x87\x9F", "\x87\xA0", "\x87\xA1", "\xE0\xEA",
  /* U+5694 */	"\x87\xA2", "\x87\xA3", "\x87\xA4", "\x87\xA5",
  /* U+5698 */	"\x87\xA6", "\x87\xA7", "\x87\xA8", "\x87\xA9",
  /* U+569C */	"\x87\xAA", "\x87\xAB", "\x87\xAC", "\x87\xAD",
  /* U+56A0 */	"\x87\xAE", "\x87\xAF", "\x87\xB0", "\xCF\xF9",
  /* U+56A4 */	"\x87\xB1", "\x87\xB2", "\x87\xB3", "\x87\xB4",
  /* U+56A8 */	"\x87\xB5", "\x87\xB6", "\x87\xB7", "\x87\xB8",
  /* U+56AC */	"\x87\xB9", "\x87\xBA", "\x87\xBB", "\xE0\xEB",
  /* U+56B0 */	"\x87\xBC", "\x87\xBD", "\x87\xBE", "\x87\xBF",
  /* U+56B4 */	"\x87\xC0", "\x87\xC1", "\x87\xC2", "\xC8\xC2",
  /* U+56B8 */	"\x87\xC3", "\x87\xC4", "\x87\xC5", "\x87\xC6",
  /* U+56BC */	"\xBD\xC0", "\x87\xC7", "\x87\xC8", "\x87\xC9",
  /* U+56C0 */	"\x87\xCA", "\x87\xCB", "\x87\xCC", "\x87\xCD",
  /* U+56C4 */	"\x87\xCE", "\x87\xCF", "\x87\xD0", "\x87\xD1",
  /* U+56C8 */	"\x87\xD2", "\x87\xD3", "\xC4\xD2", "\x87\xD4",
  /* U+56CC */	"\x87\xD5", "\x87\xD6", "\x87\xD7", "\x87\xD8",
  /* U+56D0 */	"\x87\xD9", "\x87\xDA", "\x87\xDB", "\x87\xDC",
  /* U+56D4 */	"\xE0\xEC", "\x87\xDD", "\x87\xDE", "\xE0\xED",
  /* U+56D8 */	"\x87\xDF", "\x87\xE0", "\xC7\xF4", "\xCB\xC4",
  /* U+56DC */	"\x87\xE1", "\xE0\xEE", "\xBB\xD8", "\xD8\xB6",
  /* U+56E0 */	"\xD2\xF2", "\xE0\xEF", "\xCD\xC5", "\x87\xE2",
  /* U+56E4 */	"\xB6\xDA", "\x87\xE3", "\x87\xE4", "\x87\xE5",
  /* U+56E8 */	"\x87\xE6", "\x87\xE7", "\x87\xE8", "\xE0\xF1",
  /* U+56EC */	"\x87\xE9", "\xD4\xB0", "\x87\xEA", "\x87\xEB",
  /* U+56F0 */	"\xC0\xA7", "\xB4\xD1", "\x87\xEC", "\x87\xED",
  /* U+56F4 */	"\xCE\xA7", "\xE0\xF0", "\x87\xEE", "\x87\xEF",
  /* U+56F8 */	"\x87\xF0", "\xE0\xF2", "\xB9\xCC", "\x87\xF1",
  /* U+56FC */	"\x87\xF2", "\xB9\xFA", "\xCD\xBC", "\xE0\xF3",
  /* U+5700 */	"\x87\xF3", "\x87\xF4", "\x87\xF5", "\xC6\xD4",
  /* U+5704 */	"\xE0\xF4", "\x87\xF6", "\xD4\xB2", "\x87\xF7",
  /* U+5708 */	"\xC8\xA6", "\xE0\xF6", "\xE0\xF5", "\x87\xF8",
  /* U+570C */	"\x87\xF9", "\x87\xFA", "\x87\xFB", "\x87\xFC",
  /* U+5710 */	"\x87\xFD", "\x87\xFE", "\x88\x40", "\x88\x41",
  /* U+5714 */	"\x88\x42", "\x88\x43", "\x88\x44", "\x88\x45",
  /* U+5718 */	"\x88\x46", "\x88\x47", "\x88\x48", "\x88\x49",
  /* U+571C */	"\xE0\xF7", "\x88\x4A", "\x88\x4B", "\xCD\xC1",
  /* U+5720 */	"\x88\x4C", "\x88\x4D", "\x88\x4E", "\xCA\xA5",
  /* U+5724 */	"\x88\x4F", "\x88\x50", "\x88\x51", "\x88\x52",
  /* U+5728 */	"\xD4\xDA", "\xDB\xD7", "\xDB\xD9", "\x88\x53",
  /* U+572C */	"\xDB\xD8", "\xB9\xE7", "\xDB\xDC", "\xDB\xDD",
  /* U+5730 */	"\xB5\xD8", "\x88\x54", "\x88\x55", "\xDB\xDA",
  /* U+5734 */	"\x88\x56", "\x88\x57", "\x88\x58", "\x88\x59",
  /* U+5738 */	"\x88\x5A", "\xDB\xDB", "\xB3\xA1", "\xDB\xDF",
  /* U+573C */	"\x88\x5B", "\x88\x5C", "\xBB\xF8", "\x88\x5D",
  /* U+5740 */	"\xD6\xB7", "\x88\x5E", "\xDB\xE0", "\x88\x5F",
  /* U+5744 */	"\x88\x60", "\x88\x61", "\x88\x62", "\xBE\xF9",
  /* U+5748 */	"\x88\x63", "\x88\x64", "\xB7\xBB", "\x88\x65",
  /* U+574C */	"\xDB\xD0", "\xCC\xAE", "\xBF\xB2", "\xBB\xB5",
  /* U+5750 */	"\xD7\xF8", "\xBF\xD3", "\x88\x66", "\x88\x67",
  /* U+5754 */	"\x88\x68", "\x88\x69", "\x88\x6A", "\xBF\xE9",
  /* U+5758 */	"\x88\x6B", "\x88\x6C", "\xBC\xE1", "\xCC\xB3",
  /* U+575C */	"\xDB\xDE", "\xB0\xD3", "\xCE\xEB", "\xB7\xD8",
  /* U+5760 */	"\xD7\xB9", "\xC6\xC2", "\x88\x6D", "\x88\x6E",
  /* U+5764 */	"\xC0\xA4", "\x88\x6F", "\xCC\xB9", "\x88\x70",
  /* U+5768 */	"\xDB\xE7", "\xDB\xE1", "\xC6\xBA", "\xDB\xE3",
  /* U+576C */	"\x88\x71", "\xDB\xE8", "\x88\x72", "\xC5\xF7",
  /* U+5770 */	"\x88\x73", "\x88\x74", "\x88\x75", "\xDB\xEA",
  /* U+5774 */	"\x88\x76", "\x88\x77", "\xDB\xE9", "\xBF\xC0",
  /* U+5778 */	"\x88\x78", "\x88\x79", "\x88\x7A", "\xDB\xE6",
  /* U+577C */	"\xDB\xE5", "\x88\x7B", "\x88\x7C", "\x88\x7D",
  /* U+5780 */	"\x88\x7E", "\x88\x80", "\xB4\xB9", "\xC0\xAC",
  /* U+5784 */	"\xC2\xA2", "\xDB\xE2", "\xDB\xE4", "\x88\x81",
  /* U+5788 */	"\x88\x82", "\x88\x83", "\x88\x84", "\xD0\xCD",
  /* U+578C */	"\xDB\xED", "\x88\x85", "\x88\x86", "\x88\x87",
  /* U+5790 */	"\x88\x88", "\x88\x89", "\xC0\xDD", "\xDB\xF2",
  /* U+5794 */	"\x88\x8A", "\x88\x8B", "\x88\x8C", "\x88\x8D",
  /* U+5798 */	"\x88\x8E", "\x88\x8F", "\x88\x90", "\xB6\xE2",
  /* U+579C */	"\x88\x91", "\x88\x92", "\x88\x93", "\x88\x94",
  /* U+57A0 */	"\xDB\xF3", "\xDB\xD2", "\xB9\xB8", "\xD4\xAB",
  /* U+57A4 */	"\xDB\xEC", "\x88\x95", "\xBF\xD1", "\xDB\xF0",
  /* U+57A8 */	"\x88\x96", "\xDB\xD1", "\x88\x97", "\xB5\xE6",
  /* U+57AC */	"\x88\x98", "\xDB\xEB", "\xBF\xE5", "\x88\x99",
  /* U+57B0 */	"\x88\x9A", "\x88\x9B", "\xDB\xEE", "\x88\x9C",
  /* U+57B4 */	"\xDB\xF1", "\x88\x9D", "\x88\x9E", "\x88\x9F",
  /* U+57B8 */	"\xDB\xF9", "\x88\xA0", "\x88\xA1", "\x88\xA2",
  /* U+57BC */	"\x88\xA3", "\x88\xA4", "\x88\xA5", "\x88\xA6",
  /* U+57C0 */	"\x88\xA7", "\x88\xA8", "\xB9\xA1", "\xB0\xA3",
  /* U+57C4 */	"\x88\xA9", "\x88\xAA", "\x88\xAB", "\x88\xAC",
  /* U+57C8 */	"\x88\xAD", "\x88\xAE", "\x88\xAF", "\xC2\xF1",
  /* U+57CC */	"\x88\xB0", "\x88\xB1", "\xB3\xC7", "\xDB\xEF",
  /* U+57D0 */	"\x88\xB2", "\x88\xB3", "\xDB\xF8", "\x88\xB4",
  /* U+57D4 */	"\xC6\xD2", "\xDB\xF4", "\x88\xB5", "\x88\xB6",
  /* U+57D8 */	"\xDB\xF5", "\xDB\xF7", "\xDB\xF6", "\x88\xB7",
  /* U+57DC */	"\x88\xB8", "\xDB\xFE", "\x88\xB9", "\xD3\xF2",
  /* U+57E0 */	"\xB2\xBA", "\x88\xBA", "\x88\xBB", "\x88\xBC",
  /* U+57E4 */	"\xDB\xFD", "\x88\xBD", "\x88\xBE", "\x88\xBF",
  /* U+57E8 */	"\x88\xC0", "\x88\xC1", "\x88\xC2", "\x88\xC3",
  /* U+57EC */	"\x88\xC4", "\xDC\xA4", "\x88\xC5", "\xDB\xFB",
  /* U+57F0 */	"\x88\xC6", "\x88\xC7", "\x88\xC8", "\x88\xC9",
  /* U+57F4 */	"\xDB\xFA", "\x88\xCA", "\x88\xCB", "\x88\xCC",
  /* U+57F8 */	"\xDB\xFC", "\xC5\xE0", "\xBB\xF9", "\x88\xCD",
  /* U+57FC */	"\x88\xCE", "\xDC\xA3", "\x88\xCF", "\x88\xD0",
  /* U+5800 */	"\xDC\xA5", "\x88\xD1", "\xCC\xC3", "\x88\xD2",
  /* U+5804 */	"\x88\xD3", "\x88\xD4", "\xB6\xD1", "\xDD\xC0",
  /* U+5808 */	"\x88\xD5", "\x88\xD6", "\x88\xD7", "\xDC\xA1",
  /* U+580C */	"\x88\xD8", "\xDC\xA2", "\x88\xD9", "\x88\xDA",
  /* U+5810 */	"\x88\xDB", "\xC7\xB5", "\x88\xDC", "\x88\xDD",
  /* U+5814 */	"\x88\xDE", "\xB6\xE9", "\x88\xDF", "\x88\xE0",
  /* U+5818 */	"\x88\xE1", "\xDC\xA7", "\x88\xE2", "\x88\xE3",
  /* U+581C */	"\x88\xE4", "\x88\xE5", "\xDC\xA6", "\x88\xE6",
  /* U+5820 */	"\xDC\xA9", "\xB1\xA4", "\x88\xE7", "\x88\xE8",
  /* U+5824 */	"\xB5\xCC", "\x88\xE9", "\x88\xEA", "\x88\xEB",
  /* U+5828 */	"\x88\xEC", "\x88\xED", "\xBF\xB0", "\x88\xEE",
  /* U+582C */	"\x88\xEF", "\x88\xF0", "\x88\xF1", "\x88\xF2",
  /* U+5830 */	"\xD1\xDF", "\x88\xF3", "\x88\xF4", "\x88\xF5",
  /* U+5834 */	"\x88\xF6", "\xB6\xC2", "\x88\xF7", "\x88\xF8",
  /* U+5838 */	"\x88\xF9", "\x88\xFA", "\x88\xFB", "\x88\xFC",
  /* U+583C */	"\x88\xFD", "\x88\xFE", "\x89\x40", "\x89\x41",
  /* U+5840 */	"\x89\x42", "\x89\x43", "\x89\x44", "\x89\x45",
  /* U+5844 */	"\xDC\xA8", "\x89\x46", "\x89\x47", "\x89\x48",
  /* U+5848 */	"\x89\x49", "\x89\x4A", "\x89\x4B", "\x89\x4C",
  /* U+584C */	"\xCB\xFA", "\xEB\xF3", "\x89\x4D", "\x89\x4E",
  /* U+5850 */	"\x89\x4F", "\xCB\xDC", "\x89\x50", "\x89\x51",
  /* U+5854 */	"\xCB\xFE", "\x89\x52", "\x89\x53", "\x89\x54",
  /* U+5858 */	"\xCC\xC1", "\x89\x55", "\x89\x56", "\x89\x57",
  /* U+585C */	"\x89\x58", "\x89\x59", "\xC8\xFB", "\x89\x5A",
  /* U+5860 */	"\x89\x5B", "\x89\x5C", "\x89\x5D", "\x89\x5E",
  /* U+5864 */	"\x89\x5F", "\xDC\xAA", "\x89\x60", "\x89\x61",
  /* U+5868 */	"\x89\x62", "\x89\x63", "\x89\x64", "\xCC\xEE",
  /* U+586C */	"\xDC\xAB", "\x89\x65", "\x89\x66", "\x89\x67",
  /* U+5870 */	"\x89\x68", "\x89\x69", "\x89\x6A", "\x89\x6B",
  /* U+5874 */	"\x89\x6C", "\x89\x6D", "\x89\x6E", "\x89\x6F",
  /* U+5878 */	"\x89\x70", "\x89\x71", "\x89\x72", "\x89\x73",
  /* U+587C */	"\x89\x74", "\x89\x75", "\xDB\xD3", "\x89\x76",
  /* U+5880 */	"\xDC\xAF", "\xDC\xAC", "\x89\x77", "\xBE\xB3",
  /* U+5884 */	"\x89\x78", "\xCA\xFB", "\x89\x79", "\x89\x7A",
  /* U+5888 */	"\x89\x7B", "\xDC\xAD", "\x89\x7C", "\x89\x7D",
  /* U+588C */	"\x89\x7E", "\x89\x80", "\x89\x81", "\x89\x82",
  /* U+5890 */	"\x89\x83", "\x89\x84", "\xC9\xCA", "\xC4\xB9",
  /* U+5894 */	"\x89\x85", "\x89\x86", "\x89\x87", "\x89\x88",
  /* U+5898 */	"\x89\x89", "\xC7\xBD", "\xDC\xAE", "\x89\x8A",
  /* U+589C */	"\x89\x8B", "\x89\x8C", "\xD4\xF6", "\xD0\xE6",
  /* U+58A0 */	"\x89\x8D", "\x89\x8E", "\x89\x8F", "\x89\x90",
  /* U+58A4 */	"\x89\x91", "\x89\x92", "\x89\x93", "\x89\x94",
  /* U+58A8 */	"\xC4\xAB", "\xB6\xD5", "\x89\x95", "\x89\x96",
  /* U+58AC */	"\x89\x97", "\x89\x98", "\x89\x99", "\x89\x9A",
  /* U+58B0 */	"\x89\x9B", "\x89\x9C", "\x89\x9D", "\x89\x9E",
  /* U+58B4 */	"\x89\x9F", "\x89\xA0", "\x89\xA1", "\x89\xA2",
  /* U+58B8 */	"\x89\xA3", "\x89\xA4", "\x89\xA5", "\x89\xA6",
  /* U+58BC */	"\xDB\xD4", "\x89\xA7", "\x89\xA8", "\x89\xA9",
  /* U+58C0 */	"\x89\xAA", "\xB1\xDA", "\x89\xAB", "\x89\xAC",
  /* U+58C4 */	"\x89\xAD", "\xDB\xD5", "\x89\xAE", "\x89\xAF",
  /* U+58C8 */	"\x89\xB0", "\x89\xB1", "\x89\xB2", "\x89\xB3",
  /* U+58CC */	"\x89\xB4", "\x89\xB5", "\x89\xB6", "\x89\xB7",
  /* U+58D0 */	"\x89\xB8", "\xDB\xD6", "\x89\xB9", "\x89\xBA",
  /* U+58D4 */	"\x89\xBB", "\xBA\xBE", "\x89\xBC", "\x89\xBD",
  /* U+58D8 */	"\x89\xBE", "\x89\xBF", "\x89\xC0", "\x89\xC1",
  /* U+58DC */	"\x89\xC2", "\x89\xC3", "\x89\xC4", "\x89\xC5",
  /* U+58E0 */	"\x89\xC6", "\x89\xC7", "\x89\xC8", "\x89\xC9",
  /* U+58E4 */	"\xC8\xC0", "\x89\xCA", "\x89\xCB", "\x89\xCC",
  /* U+58E8 */	"\x89\xCD", "\x89\xCE", "\x89\xCF", "\xCA\xBF",
  /* U+58EC */	"\xC8\xC9", "\x89\xD0", "\xD7\xB3", "\x89\xD1",
  /* U+58F0 */	"\xC9\xF9", "\x89\xD2", "\x89\xD3", "\xBF\xC7",
  /* U+58F4 */	"\x89\xD4", "\x89\xD5", "\xBA\xF8", "\x89\xD6",
  /* U+58F8 */	"\x89\xD7", "\xD2\xBC", "\x89\xD8", "\x89\xD9",
  /* U+58FC */	"\x89\xDA", "\x89\xDB", "\x89\xDC", "\x89\xDD",
  /* U+5900 */	"\x89\xDE", "\x89\xDF", "\xE2\xBA", "\x89\xE0",
  /* U+5904 */	"\xB4\xA6", "\x89\xE1", "\x89\xE2", "\xB1\xB8",
  /* U+5908 */	"\x89\xE3", "\x89\xE4", "\x89\xE5", "\x89\xE6",
  /* U+590C */	"\x89\xE7", "\xB8\xB4", "\x89\xE8", "\xCF\xC4",
  /* U+5910 */	"\x89\xE9", "\x89\xEA", "\x89\xEB", "\x89\xEC",
  /* U+5914 */	"\xD9\xE7", "\xCF\xA6", "\xCD\xE2", "\x89\xED",
  /* U+5918 */	"\x89\xEE", "\xD9\xED", "\xB6\xE0", "\x89\xEF",
  /* U+591C */	"\xD2\xB9", "\x89\xF0", "\x89\xF1", "\xB9\xBB",
  /* U+5920 */	"\x89\xF2", "\x89\xF3", "\x89\xF4", "\x89\xF5",
  /* U+5924 */	"\xE2\xB9", "\xE2\xB7", "\x89\xF6", "\xB4\xF3",
  /* U+5928 */	"\x89\xF7", "\xCC\xEC", "\xCC\xAB", "\xB7\xF2",
  /* U+592C */	"\x89\xF8", "\xD8\xB2", "\xD1\xEB", "\xBA\xBB",
  /* U+5930 */	"\x89\xF9", "\xCA\xA7", "\x89\xFA", "\x89\xFB",
  /* U+5934 */	"\xCD\xB7", "\x89\xFC", "\x89\xFD", "\xD2\xC4",
  /* U+5938 */	"\xBF\xE4", "\xBC\xD0", "\xB6\xE1", "\x89\xFE",
  /* U+593C */	"\xDE\xC5", "\x8A\x40", "\x8A\x41", "\x8A\x42",
  /* U+5940 */	"\x8A\x43", "\xDE\xC6", "\xDB\xBC", "\x8A\x44",
  /* U+5944 */	"\xD1\xD9", "\x8A\x45", "\x8A\x46", "\xC6\xE6",
  /* U+5948 */	"\xC4\xCE", "\xB7\xEE", "\x8A\x47", "\xB7\xDC",
  /* U+594C */	"\x8A\x48", "\x8A\x49", "\xBF\xFC", "\xD7\xE0",
  /* U+5950 */	"\x8A\x4A", "\xC6\xF5", "\x8A\x4B", "\x8A\x4C",
  /* U+5954 */	"\xB1\xBC", "\xDE\xC8", "\xBD\xB1", "\xCC\xD7",
  /* U+5958 */	"\xDE\xCA", "\x8A\x4D", "\xDE\xC9", "\x8A\x4E",
  /* U+595C */	"\x8A\x4F", "\x8A\x50", "\x8A\x51", "\x8A\x52",
  /* U+5960 */	"\xB5\xEC", "\x8A\x53", "\xC9\xDD", "\x8A\x54",
  /* U+5964 */	"\x8A\x55", "\xB0\xC2", "\x8A\x56", "\x8A\x57",
  /* U+5968 */	"\x8A\x58", "\x8A\x59", "\x8A\x5A", "\x8A\x5B",
  /* U+596C */	"\x8A\x5C", "\x8A\x5D", "\x8A\x5E", "\x8A\x5F",
  /* U+5970 */	"\x8A\x60", "\x8A\x61", "\x8A\x62", "\xC5\xAE",
  /* U+5974 */	"\xC5\xAB", "\x8A\x63", "\xC4\xCC", "\x8A\x64",
  /* U+5978 */	"\xBC\xE9", "\xCB\xFD", "\x8A\x65", "\x8A\x66",
  /* U+597C */	"\x8A\x67", "\xBA\xC3", "\x8A\x68", "\x8A\x69",
  /* U+5980 */	"\x8A\x6A", "\xE5\xF9", "\xC8\xE7", "\xE5\xFA",
  /* U+5984 */	"\xCD\xFD", "\x8A\x6B", "\xD7\xB1", "\xB8\xBE",
  /* U+5988 */	"\xC2\xE8", "\x8A\x6C", "\xC8\xD1", "\x8A\x6D",
  /* U+598C */	"\x8A\x6E", "\xE5\xFB", "\x8A\x6F", "\x8A\x70",
  /* U+5990 */	"\x8A\x71", "\x8A\x72", "\xB6\xCA", "\xBC\xCB",
  /* U+5994 */	"\x8A\x73", "\x8A\x74", "\xD1\xFD", "\xE6\xA1",
  /* U+5998 */	"\x8A\x75", "\xC3\xEE", "\x8A\x76", "\x8A\x77",
  /* U+599C */	"\x8A\x78", "\x8A\x79", "\xE6\xA4", "\x8A\x7A",
  /* U+59A0 */	"\x8A\x7B", "\x8A\x7C", "\x8A\x7D", "\xE5\xFE",
  /* U+59A4 */	"\xE6\xA5", "\xCD\xD7", "\x8A\x7E", "\x8A\x80",
  /* U+59A8 */	"\xB7\xC1", "\xE5\xFC", "\xE5\xFD", "\xE6\xA3",
  /* U+59AC */	"\x8A\x81", "\x8A\x82", "\xC4\xDD", "\xE6\xA8",
  /* U+59B0 */	"\x8A\x83", "\x8A\x84", "\xE6\xA7", "\x8A\x85",
  /* U+59B4 */	"\x8A\x86", "\x8A\x87", "\x8A\x88", "\x8A\x89",
  /* U+59B8 */	"\x8A\x8A", "\xC3\xC3", "\x8A\x8B", "\xC6\xDE",
  /* U+59BC */	"\x8A\x8C", "\x8A\x8D", "\xE6\xAA", "\x8A\x8E",
  /* U+59C0 */	"\x8A\x8F", "\x8A\x90", "\x8A\x91", "\x8A\x92",
  /* U+59C4 */	"\x8A\x93", "\x8A\x94", "\xC4\xB7", "\x8A\x95",
  /* U+59C8 */	"\x8A\x96", "\x8A\x97", "\xE6\xA2", "\xCA\xBC",
  /* U+59CC */	"\x8A\x98", "\x8A\x99", "\x8A\x9A", "\x8A\x9B",
  /* U+59D0 */	"\xBD\xE3", "\xB9\xC3", "\xE6\xA6", "\xD0\xD5",
  /* U+59D4 */	"\xCE\xAF", "\x8A\x9C", "\x8A\x9D", "\xE6\xA9",
  /* U+59D8 */	"\xE6\xB0", "\x8A\x9E", "\xD2\xA6", "\x8A\x9F",
  /* U+59DC */	"\xBD\xAA", "\xE6\xAD", "\x8A\xA0", "\x8A\xA1",
  /* U+59E0 */	"\x8A\xA2", "\x8A\xA3", "\x8A\xA4", "\xE6\xAF",
  /* U+59E4 */	"\x8A\xA5", "\xC0\xD1", "\x8A\xA6", "\x8A\xA7",
  /* U+59E8 */	"\xD2\xCC", "\x8A\xA8", "\x8A\xA9", "\x8A\xAA",
  /* U+59EC */	"\xBC\xA7", "\x8A\xAB", "\x8A\xAC", "\x8A\xAD",
  /* U+59F0 */	"\x8A\xAE", "\x8A\xAF", "\x8A\xB0", "\x8A\xB1",
  /* U+59F4 */	"\x8A\xB2", "\x8A\xB3", "\x8A\xB4", "\x8A\xB5",
  /* U+59F8 */	"\x8A\xB6", "\xE6\xB1", "\x8A\xB7", "\xD2\xF6",
  /* U+59FC */	"\x8A\xB8", "\x8A\xB9", "\x8A\xBA", "\xD7\xCB",
  /* U+5A00 */	"\x8A\xBB", "\xCD\xFE", "\x8A\xBC", "\xCD\xDE",
  /* U+5A04 */	"\xC2\xA6", "\xE6\xAB", "\xE6\xAC", "\xBD\xBF",
  /* U+5A08 */	"\xE6\xAE", "\xE6\xB3", "\x8A\xBD", "\x8A\xBE",
  /* U+5A0C */	"\xE6\xB2", "\x8A\xBF", "\x8A\xC0", "\x8A\xC1",
  /* U+5A10 */	"\x8A\xC2", "\xE6\xB6", "\x8A\xC3", "\xE6\xB8",
  /* U+5A14 */	"\x8A\xC4", "\x8A\xC5", "\x8A\xC6", "\x8A\xC7",
  /* U+5A18 */	"\xC4\xEF", "\x8A\xC8", "\x8A\xC9", "\x8A\xCA",
  /* U+5A1C */	"\xC4\xC8", "\x8A\xCB", "\x8A\xCC", "\xBE\xEA",
  /* U+5A20 */	"\xC9\xEF", "\x8A\xCD", "\x8A\xCE", "\xE6\xB7",
  /* U+5A24 */	"\x8A\xCF", "\xB6\xF0", "\x8A\xD0", "\x8A\xD1",
  /* U+5A28 */	"\x8A\xD2", "\xC3\xE4", "\x8A\xD3", "\x8A\xD4",
  /* U+5A2C */	"\x8A\xD5", "\x8A\xD6", "\x8A\xD7", "\x8A\xD8",
  /* U+5A30 */	"\x8A\xD9", "\xD3\xE9", "\xE6\xB4", "\x8A\xDA",
  /* U+5A34 */	"\xE6\xB5", "\x8A\xDB", "\xC8\xA2", "\x8A\xDC",
  /* U+5A38 */	"\x8A\xDD", "\x8A\xDE", "\x8A\xDF", "\x8A\xE0",
  /* U+5A3C */	"\xE6\xBD", "\x8A\xE1", "\x8A\xE2", "\x8A\xE3",
  /* U+5A40 */	"\xE6\xB9", "\x8A\xE4", "\x8A\xE5", "\x8A\xE6",
  /* U+5A44 */	"\x8A\xE7", "\x8A\xE8", "\xC6\xC5", "\x8A\xE9",
  /* U+5A48 */	"\x8A\xEA", "\xCD\xF1", "\xE6\xBB", "\x8A\xEB",
  /* U+5A4C */	"\x8A\xEC", "\x8A\xED", "\x8A\xEE", "\x8A\xEF",
  /* U+5A50 */	"\x8A\xF0", "\x8A\xF1", "\x8A\xF2", "\x8A\xF3",
  /* U+5A54 */	"\x8A\xF4", "\xE6\xBC", "\x8A\xF5", "\x8A\xF6",
  /* U+5A58 */	"\x8A\xF7", "\x8A\xF8", "\xBB\xE9", "\x8A\xF9",
  /* U+5A5C */	"\x8A\xFA", "\x8A\xFB", "\x8A\xFC", "\x8A\xFD",
  /* U+5A60 */	"\x8A\xFE", "\x8B\x40", "\xE6\xBE", "\x8B\x41",
  /* U+5A64 */	"\x8B\x42", "\x8B\x43", "\x8B\x44", "\xE6\xBA",
  /* U+5A68 */	"\x8B\x45", "\x8B\x46", "\xC0\xB7", "\x8B\x47",
  /* U+5A6C */	"\x8B\x48", "\x8B\x49", "\x8B\x4A", "\x8B\x4B",
  /* U+5A70 */	"\x8B\x4C", "\x8B\x4D", "\x8B\x4E", "\x8B\x4F",
  /* U+5A74 */	"\xD3\xA4", "\xE6\xBF", "\xC9\xF4", "\xE6\xC3",
  /* U+5A78 */	"\x8B\x50", "\x8B\x51", "\xE6\xC4", "\x8B\x52",
  /* U+5A7C */	"\x8B\x53", "\x8B\x54", "\x8B\x55", "\xD0\xF6",
  /* U+5A80 */	"\x8B\x56", "\x8B\x57", "\x8B\x58", "\x8B\x59",
  /* U+5A84 */	"\x8B\x5A", "\x8B\x5B", "\x8B\x5C", "\x8B\x5D",
  /* U+5A88 */	"\x8B\x5E", "\x8B\x5F", "\x8B\x60", "\x8B\x61",
  /* U+5A8C */	"\x8B\x62", "\x8B\x63", "\x8B\x64", "\x8B\x65",
  /* U+5A90 */	"\x8B\x66", "\x8B\x67", "\xC3\xBD", "\x8B\x68",
  /* U+5A94 */	"\x8B\x69", "\x8B\x6A", "\x8B\x6B", "\x8B\x6C",
  /* U+5A98 */	"\x8B\x6D", "\x8B\x6E", "\xC3\xC4", "\xE6\xC2",
  /* U+5A9C */	"\x8B\x6F", "\x8B\x70", "\x8B\x71", "\x8B\x72",
  /* U+5AA0 */	"\x8B\x73", "\x8B\x74", "\x8B\x75", "\x8B\x76",
  /* U+5AA4 */	"\x8B\x77", "\x8B\x78", "\x8B\x79", "\x8B\x7A",
  /* U+5AA8 */	"\x8B\x7B", "\x8B\x7C", "\xE6\xC1", "\x8B\x7D",
  /* U+5AAC */	"\x8B\x7E", "\x8B\x80", "\x8B\x81", "\x8B\x82",
  /* U+5AB0 */	"\x8B\x83", "\x8B\x84", "\xE6\xC7", "\xCF\xB1",
  /* U+5AB4 */	"\x8B\x85", "\xEB\xF4", "\x8B\x86", "\x8B\x87",
  /* U+5AB8 */	"\xE6\xCA", "\x8B\x88", "\x8B\x89", "\x8B\x8A",
  /* U+5ABC */	"\x8B\x8B", "\x8B\x8C", "\xE6\xC5", "\x8B\x8D",
  /* U+5AC0 */	"\x8B\x8E", "\xBC\xDE", "\xC9\xA9", "\x8B\x8F",
  /* U+5AC4 */	"\x8B\x90", "\x8B\x91", "\x8B\x92", "\x8B\x93",
  /* U+5AC8 */	"\x8B\x94", "\xBC\xB5", "\x8B\x95", "\x8B\x96",
  /* U+5ACC */	"\xCF\xD3", "\x8B\x97", "\x8B\x98", "\x8B\x99",
  /* U+5AD0 */	"\x8B\x9A", "\x8B\x9B", "\xE6\xC8", "\x8B\x9C",
  /* U+5AD4 */	"\xE6\xC9", "\x8B\x9D", "\xE6\xCE", "\x8B\x9E",
  /* U+5AD8 */	"\xE6\xD0", "\x8B\x9F", "\x8B\xA0", "\x8B\xA1",
  /* U+5ADC */	"\xE6\xD1", "\x8B\xA2", "\x8B\xA3", "\x8B\xA4",
  /* U+5AE0 */	"\xE6\xCB", "\xB5\xD5", "\x8B\xA5", "\xE6\xCC",
  /* U+5AE4 */	"\x8B\xA6", "\x8B\xA7", "\xE6\xCF", "\x8B\xA8",
  /* U+5AE8 */	"\x8B\xA9", "\xC4\xDB", "\x8B\xAA", "\xE6\xC6",
  /* U+5AEC */	"\x8B\xAB", "\x8B\xAC", "\x8B\xAD", "\x8B\xAE",
  /* U+5AF0 */	"\x8B\xAF", "\xE6\xCD", "\x8B\xB0", "\x8B\xB1",
  /* U+5AF4 */	"\x8B\xB2", "\x8B\xB3", "\x8B\xB4", "\x8B\xB5",
  /* U+5AF8 */	"\x8B\xB6", "\x8B\xB7", "\x8B\xB8", "\x8B\xB9",
  /* U+5AFC */	"\x8B\xBA", "\x8B\xBB", "\x8B\xBC", "\x8B\xBD",
  /* U+5B00 */	"\x8B\xBE", "\x8B\xBF", "\x8B\xC0", "\x8B\xC1",
  /* U+5B04 */	"\x8B\xC2", "\x8B\xC3", "\x8B\xC4", "\x8B\xC5",
  /* U+5B08 */	"\x8B\xC6", "\xE6\xD2", "\x8B\xC7", "\x8B\xC8",
  /* U+5B0C */	"\x8B\xC9", "\x8B\xCA", "\x8B\xCB", "\x8B\xCC",
  /* U+5B10 */	"\x8B\xCD", "\x8B\xCE", "\x8B\xCF", "\x8B\xD0",
  /* U+5B14 */	"\x8B\xD1", "\x8B\xD2", "\xE6\xD4", "\xE6\xD3",
  /* U+5B18 */	"\x8B\xD3", "\x8B\xD4", "\x8B\xD5", "\x8B\xD6",
  /* U+5B1C */	"\x8B\xD7", "\x8B\xD8", "\x8B\xD9", "\x8B\xDA",
  /* U+5B20 */	"\x8B\xDB", "\x8B\xDC", "\x8B\xDD", "\x8B\xDE",
  /* U+5B24 */	"\x8B\xDF", "\x8B\xE0", "\x8B\xE1", "\x8B\xE2",
  /* U+5B28 */	"\x8B\xE3", "\x8B\xE4", "\x8B\xE5", "\x8B\xE6",
  /* U+5B2C */	"\x8B\xE7", "\x8B\xE8", "\x8B\xE9", "\x8B\xEA",
  /* U+5B30 */	"\x8B\xEB", "\x8B\xEC", "\xE6\xD5", "\x8B\xED",
  /* U+5B34 */	"\xD9\xF8", "\x8B\xEE", "\x8B\xEF", "\xE6\xD6",
  /* U+5B38 */	"\x8B\xF0", "\x8B\xF1", "\x8B\xF2", "\x8B\xF3",
  /* U+5B3C */	"\x8B\xF4", "\x8B\xF5", "\x8B\xF6", "\x8B\xF7",
  /* U+5B40 */	"\xE6\xD7", "\x8B\xF8", "\x8B\xF9", "\x8B\xFA",
  /* U+5B44 */	"\x8B\xFB", "\x8B\xFC", "\x8B\xFD", "\x8B\xFE",
  /* U+5B48 */	"\x8C\x40", "\x8C\x41", "\x8C\x42", "\x8C\x43",
  /* U+5B4C */	"\x8C\x44", "\x8C\x45", "\x8C\x46", "\x8C\x47",
  /* U+5B50 */	"\xD7\xD3", "\xE6\xDD", "\x8C\x48", "\xE6\xDE",
  /* U+5B54 */	"\xBF\xD7", "\xD4\xD0", "\x8C\x49", "\xD7\xD6",
  /* U+5B58 */	"\xB4\xE6", "\xCB\xEF", "\xE6\xDA", "\xD8\xC3",
  /* U+5B5C */	"\xD7\xCE", "\xD0\xA2", "\x8C\x4A", "\xC3\xCF",
  /* U+5B60 */	"\x8C\x4B", "\x8C\x4C", "\xE6\xDF", "\xBC\xBE",
  /* U+5B64 */	"\xB9\xC2", "\xE6\xDB", "\xD1\xA7", "\x8C\x4D",
  /* U+5B68 */	"\x8C\x4E", "\xBA\xA2", "\xC2\xCF", "\x8C\x4F",
  /* U+5B6C */	"\xD8\xAB", "\x8C\x50", "\x8C\x51", "\x8C\x52",
  /* U+5B70 */	"\xCA\xEB", "\xE5\xEE", "\x8C\x53", "\xE6\xDC",
  /* U+5B74 */	"\x8C\x54", "\xB7\xF5", "\x8C\x55", "\x8C\x56",
  /* U+5B78 */	"\x8C\x57", "\x8C\x58", "\xC8\xE6", "\x8C\x59",
  /* U+5B7C */	"\x8C\x5A", "\xC4\xF5", "\x8C\x5B", "\x8C\x5C",
  /* U+5B80 */	"\xE5\xB2", "\xC4\xFE", "\x8C\x5D", "\xCB\xFC",
  /* U+5B84 */	"\xE5\xB3", "\xD5\xAC", "\x8C\x5E", "\xD3\xEE",
  /* U+5B88 */	"\xCA\xD8", "\xB0\xB2", "\x8C\x5F", "\xCB\xCE",
  /* U+5B8C */	"\xCD\xEA", "\x8C\x60", "\x8C\x61", "\xBA\xEA",
  /* U+5B90 */	"\x8C\x62", "\x8C\x63", "\x8C\x64", "\xE5\xB5",
  /* U+5B94 */	"\x8C\x65", "\xE5\xB4", "\x8C\x66", "\xD7\xDA",
  /* U+5B98 */	"\xB9\xD9", "\xD6\xE6", "\xB6\xA8", "\xCD\xF0",
  /* U+5B9C */	"\xD2\xCB", "\xB1\xA6", "\xCA\xB5", "\x8C\x67",
  /* U+5BA0 */	"\xB3\xE8", "\xC9\xF3", "\xBF\xCD", "\xD0\xFB",
  /* U+5BA4 */	"\xCA\xD2", "\xE5\xB6", "\xBB\xC2", "\x8C\x68",
  /* U+5BA8 */	"\x8C\x69", "\x8C\x6A", "\xCF\xDC", "\xB9\xAC",
  /* U+5BAC */	"\x8C\x6B", "\x8C\x6C", "\x8C\x6D", "\x8C\x6E",
  /* U+5BB0 */	"\xD4\xD7", "\x8C\x6F", "\x8C\x70", "\xBA\xA6",
  /* U+5BB4 */	"\xD1\xE7", "\xCF\xFC", "\xBC\xD2", "\x8C\x71",
  /* U+5BB8 */	"\xE5\xB7", "\xC8\xDD", "\x8C\x72", "\x8C\x73",
  /* U+5BBC */	"\x8C\x74", "\xBF\xED", "\xB1\xF6", "\xCB\xDE",
  /* U+5BC0 */	"\x8C\x75", "\x8C\x76", "\xBC\xC5", "\x8C\x77",
  /* U+5BC4 */	"\xBC\xC4", "\xD2\xFA", "\xC3\xDC", "\xBF\xDC",
  /* U+5BC8 */	"\x8C\x78", "\x8C\x79", "\x8C\x7A", "\x8C\x7B",
  /* U+5BCC */	"\xB8\xBB", "\x8C\x7C", "\x8C\x7D", "\x8C\x7E",
  /* U+5BD0 */	"\xC3\xC2", "\x8C\x80", "\xBA\xAE", "\xD4\xA2",
  /* U+5BD4 */	"\x8C\x81", "\x8C\x82", "\x8C\x83", "\x8C\x84",
  /* U+5BD8 */	"\x8C\x85", "\x8C\x86", "\x8C\x87", "\x8C\x88",
  /* U+5BDC */	"\x8C\x89", "\xC7\xDE", "\xC4\xAF", "\xB2\xEC",
  /* U+5BE0 */	"\x8C\x8A", "\xB9\xD1", "\x8C\x8B", "\x8C\x8C",
  /* U+5BE4 */	"\xE5\xBB", "\xC1\xC8", "\x8C\x8D", "\x8C\x8E",
  /* U+5BE8 */	"\xD5\xAF", "\x8C\x8F", "\x8C\x90", "\x8C\x91",
  /* U+5BEC */	"\x8C\x92", "\x8C\x93", "\xE5\xBC", "\x8C\x94",
  /* U+5BF0 */	"\xE5\xBE", "\x8C\x95", "\x8C\x96", "\x8C\x97",
  /* U+5BF4 */	"\x8C\x98", "\x8C\x99", "\x8C\x9A", "\x8C\x9B",
  /* U+5BF8 */	"\xB4\xE7", "\xB6\xD4", "\xCB\xC2", "\xD1\xB0",
  /* U+5BFC */	"\xB5\xBC", "\x8C\x9C", "\x8C\x9D", "\xCA\xD9",
  /* U+5C00 */	"\x8C\x9E", "\xB7\xE2", "\x8C\x9F", "\x8C\xA0",
  /* U+5C04 */	"\xC9\xE4", "\x8C\xA1", "\xBD\xAB", "\x8C\xA2",
  /* U+5C08 */	"\x8C\xA3", "\xCE\xBE", "\xD7\xF0", "\x8C\xA4",
  /* U+5C0C */	"\x8C\xA5", "\x8C\xA6", "\x8C\xA7", "\xD0\xA1",
  /* U+5C10 */	"\x8C\xA8", "\xC9\xD9", "\x8C\xA9", "\x8C\xAA",
  /* U+5C14 */	"\xB6\xFB", "\xE6\xD8", "\xBC\xE2", "\x8C\xAB",
  /* U+5C18 */	"\xB3\xBE", "\x8C\xAC", "\xC9\xD0", "\x8C\xAD",
  /* U+5C1C */	"\xE6\xD9", "\xB3\xA2", "\x8C\xAE", "\x8C\xAF",
  /* U+5C20 */	"\x8C\xB0", "\x8C\xB1", "\xDE\xCC", "\x8C\xB2",
  /* U+5C24 */	"\xD3\xC8", "\xDE\xCD", "\x8C\xB3", "\xD2\xA2",
  /* U+5C28 */	"\x8C\xB4", "\x8C\xB5", "\x8C\xB6", "\x8C\xB7",
  /* U+5C2C */	"\xDE\xCE", "\x8C\xB8", "\x8C\xB9", "\x8C\xBA",
  /* U+5C30 */	"\x8C\xBB", "\xBE\xCD", "\x8C\xBC", "\x8C\xBD",
  /* U+5C34 */	"\xDE\xCF", "\x8C\xBE", "\x8C\xBF", "\x8C\xC0",
  /* U+5C38 */	"\xCA\xAC", "\xD2\xFC", "\xB3\xDF", "\xE5\xEA",
  /* U+5C3C */	"\xC4\xE1", "\xBE\xA1", "\xCE\xB2", "\xC4\xF2",
  /* U+5C40 */	"\xBE\xD6", "\xC6\xA8", "\xB2\xE3", "\x8C\xC1",
  /* U+5C44 */	"\x8C\xC2", "\xBE\xD3", "\x8C\xC3", "\x8C\xC4",
  /* U+5C48 */	"\xC7\xFC", "\xCC\xEB", "\xBD\xEC", "\xCE\xDD",
  /* U+5C4C */	"\x8C\xC5", "\x8C\xC6", "\xCA\xBA", "\xC6\xC1",
  /* U+5C50 */	"\xE5\xEC", "\xD0\xBC", "\x8C\xC7", "\x8C\xC8",
  /* U+5C54 */	"\x8C\xC9", "\xD5\xB9", "\x8C\xCA", "\x8C\xCB",
  /* U+5C58 */	"\x8C\xCC", "\xE5\xED", "\x8C\xCD", "\x8C\xCE",
  /* U+5C5C */	"\x8C\xCF", "\x8C\xD0", "\xCA\xF4", "\x8C\xD1",
  /* U+5C60 */	"\xCD\xC0", "\xC2\xC5", "\x8C\xD2", "\xE5\xEF",
  /* U+5C64 */	"\x8C\xD3", "\xC2\xC4", "\xE5\xF0", "\x8C\xD4",
  /* U+5C68 */	"\x8C\xD5", "\x8C\xD6", "\x8C\xD7", "\x8C\xD8",
  /* U+5C6C */	"\x8C\xD9", "\x8C\xDA", "\xE5\xF8", "\xCD\xCD",
  /* U+5C70 */	"\x8C\xDB", "\xC9\xBD", "\x8C\xDC", "\x8C\xDD",
  /* U+5C74 */	"\x8C\xDE", "\x8C\xDF", "\x8C\xE0", "\x8C\xE1",
  /* U+5C78 */	"\x8C\xE2", "\xD2\xD9", "\xE1\xA8", "\x8C\xE3",
  /* U+5C7C */	"\x8C\xE4", "\x8C\xE5", "\x8C\xE6", "\xD3\xEC",
  /* U+5C80 */	"\x8C\xE7", "\xCB\xEA", "\xC6\xF1", "\x8C\xE8",
  /* U+5C84 */	"\x8C\xE9", "\x8C\xEA", "\x8C\xEB", "\x8C\xEC",
  /* U+5C88 */	"\xE1\xAC", "\x8C\xED", "\x8C\xEE", "\x8C\xEF",
  /* U+5C8C */	"\xE1\xA7", "\xE1\xA9", "\x8C\xF0", "\x8C\xF1",
  /* U+5C90 */	"\xE1\xAA", "\xE1\xAF", "\x8C\xF2", "\x8C\xF3",
  /* U+5C94 */	"\xB2\xED", "\x8C\xF4", "\xE1\xAB", "\xB8\xDA",
  /* U+5C98 */	"\xE1\xAD", "\xE1\xAE", "\xE1\xB0", "\xB5\xBA",
  /* U+5C9C */	"\xE1\xB1", "\x8C\xF5", "\x8C\xF6", "\x8C\xF7",
  /* U+5CA0 */	"\x8C\xF8", "\x8C\xF9", "\xE1\xB3", "\xE1\xB8",
  /* U+5CA4 */	"\x8C\xFA", "\x8C\xFB", "\x8C\xFC", "\x8C\xFD",
  /* U+5CA8 */	"\x8C\xFE", "\xD1\xD2", "\x8D\x40", "\xE1\xB6",
  /* U+5CAC */	"\xE1\xB5", "\xC1\xEB", "\x8D\x41", "\x8D\x42",
  /* U+5CB0 */	"\x8D\x43", "\xE1\xB7", "\x8D\x44", "\xD4\xC0",
  /* U+5CB4 */	"\x8D\x45", "\xE1\xB2", "\x8D\x46", "\xE1\xBA",
  /* U+5CB8 */	"\xB0\xB6", "\x8D\x47", "\x8D\x48", "\x8D\x49",
  /* U+5CBC */	"\x8D\x4A", "\xE1\xB4", "\x8D\x4B", "\xBF\xF9",
  /* U+5CC0 */	"\x8D\x4C", "\xE1\xB9", "\x8D\x4D", "\x8D\x4E",
  /* U+5CC4 */	"\xE1\xBB", "\x8D\x4F", "\x8D\x50", "\x8D\x51",
  /* U+5CC8 */	"\x8D\x52", "\x8D\x53", "\x8D\x54", "\xE1\xBE",
  /* U+5CCC */	"\x8D\x55", "\x8D\x56", "\x8D\x57", "\x8D\x58",
  /* U+5CD0 */	"\x8D\x59", "\x8D\x5A", "\xE1\xBC", "\x8D\x5B",
  /* U+5CD4 */	"\x8D\x5C", "\x8D\x5D", "\x8D\x5E", "\x8D\x5F",
  /* U+5CD8 */	"\x8D\x60", "\xD6\xC5", "\x8D\x61", "\x8D\x62",
  /* U+5CDC */	"\x8D\x63", "\x8D\x64", "\x8D\x65", "\x8D\x66",
  /* U+5CE0 */	"\x8D\x67", "\xCF\xBF", "\x8D\x68", "\x8D\x69",
  /* U+5CE4 */	"\xE1\xBD", "\xE1\xBF", "\xC2\xCD", "\x8D\x6A",
  /* U+5CE8 */	"\xB6\xEB", "\x8D\x6B", "\xD3\xF8", "\x8D\x6C",
  /* U+5CEC */	"\x8D\x6D", "\xC7\xCD", "\x8D\x6E", "\x8D\x6F",
  /* U+5CF0 */	"\xB7\xE5", "\x8D\x70", "\x8D\x71", "\x8D\x72",
  /* U+5CF4 */	"\x8D\x73", "\x8D\x74", "\x8D\x75", "\x8D\x76",
  /* U+5CF8 */	"\x8D\x77", "\x8D\x78", "\x8D\x79", "\xBE\xFE",
  /* U+5CFC */	"\x8D\x7A", "\x8D\x7B", "\x8D\x7C", "\x8D\x7D",
  /* U+5D00 */	"\x8D\x7E", "\x8D\x80", "\xE1\xC0", "\xE1\xC1",
  /* U+5D04 */	"\x8D\x81", "\x8D\x82", "\xE1\xC7", "\xB3\xE7",
  /* U+5D08 */	"\x8D\x83", "\x8D\x84", "\x8D\x85", "\x8D\x86",
  /* U+5D0C */	"\x8D\x87", "\x8D\x88", "\xC6\xE9", "\x8D\x89",
  /* U+5D10 */	"\x8D\x8A", "\x8D\x8B", "\x8D\x8C", "\x8D\x8D",
  /* U+5D14 */	"\xB4\xDE", "\x8D\x8E", "\xD1\xC2", "\x8D\x8F",
  /* U+5D18 */	"\x8D\x90", "\x8D\x91", "\x8D\x92", "\xE1\xC8",
  /* U+5D1C */	"\x8D\x93", "\x8D\x94", "\xE1\xC6", "\x8D\x95",
  /* U+5D20 */	"\x8D\x96", "\x8D\x97", "\x8D\x98", "\x8D\x99",
  /* U+5D24 */	"\xE1\xC5", "\x8D\x9A", "\xE1\xC3", "\xE1\xC2",
  /* U+5D28 */	"\x8D\x9B", "\xB1\xC0", "\x8D\x9C", "\x8D\x9D",
  /* U+5D2C */	"\x8D\x9E", "\xD5\xB8", "\xE1\xC4", "\x8D\x9F",
  /* U+5D30 */	"\x8D\xA0", "\x8D\xA1", "\x8D\xA2", "\x8D\xA3",
  /* U+5D34 */	"\xE1\xCB", "\x8D\xA4", "\x8D\xA5", "\x8D\xA6",
  /* U+5D38 */	"\x8D\xA7", "\x8D\xA8", "\x8D\xA9", "\x8D\xAA",
  /* U+5D3C */	"\x8D\xAB", "\xE1\xCC", "\xE1\xCA", "\x8D\xAC",
  /* U+5D40 */	"\x8D\xAD", "\x8D\xAE", "\x8D\xAF", "\x8D\xB0",
  /* U+5D44 */	"\x8D\xB1", "\x8D\xB2", "\x8D\xB3", "\xEF\xFA",
  /* U+5D48 */	"\x8D\xB4", "\x8D\xB5", "\xE1\xD3", "\xE1\xD2",
  /* U+5D4C */	"\xC7\xB6", "\x8D\xB6", "\x8D\xB7", "\x8D\xB8",
  /* U+5D50 */	"\x8D\xB9", "\x8D\xBA", "\x8D\xBB", "\x8D\xBC",
  /* U+5D54 */	"\x8D\xBD", "\x8D\xBE", "\x8D\xBF", "\x8D\xC0",
  /* U+5D58 */	"\xE1\xC9", "\x8D\xC1", "\x8D\xC2", "\xE1\xCE",
  /* U+5D5C */	"\x8D\xC3", "\xE1\xD0", "\x8D\xC4", "\x8D\xC5",
  /* U+5D60 */	"\x8D\xC6", "\x8D\xC7", "\x8D\xC8", "\x8D\xC9",
  /* U+5D64 */	"\x8D\xCA", "\x8D\xCB", "\x8D\xCC", "\x8D\xCD",
  /* U+5D68 */	"\x8D\xCE", "\xE1\xD4", "\x8D\xCF", "\xE1\xD1",
  /* U+5D6C */	"\xE1\xCD", "\x8D\xD0", "\x8D\xD1", "\xE1\xCF",
  /* U+5D70 */	"\x8D\xD2", "\x8D\xD3", "\x8D\xD4", "\x8D\xD5",
  /* U+5D74 */	"\xE1\xD5", "\x8D\xD6", "\x8D\xD7", "\x8D\xD8",
  /* U+5D78 */	"\x8D\xD9", "\x8D\xDA", "\x8D\xDB", "\x8D\xDC",
  /* U+5D7C */	"\x8D\xDD", "\x8D\xDE", "\x8D\xDF", "\x8D\xE0",
  /* U+5D80 */	"\x8D\xE1", "\x8D\xE2", "\xE1\xD6", "\x8D\xE3",
  /* U+5D84 */	"\x8D\xE4", "\x8D\xE5", "\x8D\xE6", "\x8D\xE7",
  /* U+5D88 */	"\x8D\xE8", "\x8D\xE9", "\x8D\xEA", "\x8D\xEB",
  /* U+5D8C */	"\x8D\xEC", "\x8D\xED", "\x8D\xEE", "\x8D\xEF",
  /* U+5D90 */	"\x8D\xF0", "\x8D\xF1", "\x8D\xF2", "\x8D\xF3",
  /* U+5D94 */	"\x8D\xF4", "\x8D\xF5", "\x8D\xF6", "\x8D\xF7",
  /* U+5D98 */	"\x8D\xF8", "\xE1\xD7", "\x8D\xF9", "\x8D\xFA",
  /* U+5D9C */	"\x8D\xFB", "\xE1\xD8", "\x8D\xFC", "\x8D\xFD",
  /* U+5DA0 */	"\x8D\xFE", "\x8E\x40", "\x8E\x41", "\x8E\x42",
  /* U+5DA4 */	"\x8E\x43", "\x8E\x44", "\x8E\x45", "\x8E\x46",
  /* U+5DA8 */	"\x8E\x47", "\x8E\x48", "\x8E\x49", "\x8E\x4A",
  /* U+5DAC */	"\x8E\x4B", "\x8E\x4C", "\x8E\x4D", "\x8E\x4E",
  /* U+5DB0 */	"\x8E\x4F", "\x8E\x50", "\x8E\x51", "\x8E\x52",
  /* U+5DB4 */	"\x8E\x53", "\x8E\x54", "\x8E\x55", "\xE1\xDA",
  /* U+5DB8 */	"\x8E\x56", "\x8E\x57", "\x8E\x58", "\x8E\x59",
  /* U+5DBC */	"\x8E\x5A", "\x8E\x5B", "\x8E\x5C", "\x8E\x5D",
  /* U+5DC0 */	"\x8E\x5E", "\x8E\x5F", "\x8E\x60", "\x8E\x61",
  /* U+5DC4 */	"\x8E\x62", "\xE1\xDB", "\x8E\x63", "\x8E\x64",
  /* U+5DC8 */	"\x8E\x65", "\x8E\x66", "\x8E\x67", "\x8E\x68",
  /* U+5DCC */	"\x8E\x69", "\xCE\xA1", "\x8E\x6A", "\x8E\x6B",
  /* U+5DD0 */	"\x8E\x6C", "\x8E\x6D", "\x8E\x6E", "\x8E\x6F",
  /* U+5DD4 */	"\x8E\x70", "\x8E\x71", "\x8E\x72", "\x8E\x73",
  /* U+5DD8 */	"\x8E\x74", "\x8E\x75", "\x8E\x76", "\xE7\xDD",
  /* U+5DDC */	"\x8E\x77", "\xB4\xA8", "\xD6\xDD", "\x8E\x78",
  /* U+5DE0 */	"\x8E\x79", "\xD1\xB2", "\xB3\xB2", "\x8E\x7A",
  /* U+5DE4 */	"\x8E\x7B", "\xB9\xA4", "\xD7\xF3", "\xC7\xC9",
  /* U+5DE8 */	"\xBE\xDE", "\xB9\xAE", "\x8E\x7C", "\xCE\xD7",
  /* U+5DEC */	"\x8E\x7D", "\x8E\x7E", "\xB2\xEE", "\xDB\xCF",
  /* U+5DF0 */	"\x8E\x80", "\xBC\xBA", "\xD2\xD1", "\xCB\xC8",
  /* U+5DF4 */	"\xB0\xCD", "\x8E\x81", "\x8E\x82", "\xCF\xEF",
  /* U+5DF8 */	"\x8E\x83", "\x8E\x84", "\x8E\x85", "\x8E\x86",
  /* U+5DFC */	"\x8E\x87", "\xD9\xE3", "\xBD\xED", "\x8E\x88",
  /* U+5E00 */	"\x8E\x89", "\xB1\xD2", "\xCA\xD0", "\xB2\xBC",
  /* U+5E04 */	"\x8E\x8A", "\xCB\xA7", "\xB7\xAB", "\x8E\x8B",
  /* U+5E08 */	"\xCA\xA6", "\x8E\x8C", "\x8E\x8D", "\x8E\x8E",
  /* U+5E0C */	"\xCF\xA3", "\x8E\x8F", "\x8E\x90", "\xE0\xF8",
  /* U+5E10 */	"\xD5\xCA", "\xE0\xFB", "\x8E\x91", "\x8E\x92",
  /* U+5E14 */	"\xE0\xFA", "\xC5\xC1", "\xCC\xFB", "\x8E\x93",
  /* U+5E18 */	"\xC1\xB1", "\xE0\xF9", "\xD6\xE3", "\xB2\xAF",
  /* U+5E1C */	"\xD6\xC4", "\xB5\xDB", "\x8E\x94", "\x8E\x95",
  /* U+5E20 */	"\x8E\x96", "\x8E\x97", "\x8E\x98", "\x8E\x99",
  /* U+5E24 */	"\x8E\x9A", "\x8E\x9B", "\xB4\xF8", "\xD6\xA1",
  /* U+5E28 */	"\x8E\x9C", "\x8E\x9D", "\x8E\x9E", "\x8E\x9F",
  /* U+5E2C */	"\x8E\xA0", "\xCF\xAF", "\xB0\xEF", "\x8E\xA1",
  /* U+5E30 */	"\x8E\xA2", "\xE0\xFC", "\x8E\xA3", "\x8E\xA4",
  /* U+5E34 */	"\x8E\xA5", "\x8E\xA6", "\x8E\xA7", "\xE1\xA1",
  /* U+5E38 */	"\xB3\xA3", "\x8E\xA8", "\x8E\xA9", "\xE0\xFD",
  /* U+5E3C */	"\xE0\xFE", "\xC3\xB1", "\x8E\xAA", "\x8E\xAB",
  /* U+5E40 */	"\x8E\xAC", "\x8E\xAD", "\xC3\xDD", "\x8E\xAE",
  /* U+5E44 */	"\xE1\xA2", "\xB7\xF9", "\x8E\xAF", "\x8E\xB0",
  /* U+5E48 */	"\x8E\xB1", "\x8E\xB2", "\x8E\xB3", "\x8E\xB4",
  /* U+5E4C */	"\xBB\xCF", "\x8E\xB5", "\x8E\xB6", "\x8E\xB7",
  /* U+5E50 */	"\x8E\xB8", "\x8E\xB9", "\x8E\xBA", "\x8E\xBB",
  /* U+5E54 */	"\xE1\xA3", "\xC4\xBB", "\x8E\xBC", "\x8E\xBD",
  /* U+5E58 */	"\x8E\xBE", "\x8E\xBF", "\x8E\xC0", "\xE1\xA4",
  /* U+5E5C */	"\x8E\xC1", "\x8E\xC2", "\xE1\xA5", "\x8E\xC3",
  /* U+5E60 */	"\x8E\xC4", "\xE1\xA6", "\xB4\xB1", "\x8E\xC5",
  /* U+5E64 */	"\x8E\xC6", "\x8E\xC7", "\x8E\xC8", "\x8E\xC9",
  /* U+5E68 */	"\x8E\xCA", "\x8E\xCB", "\x8E\xCC", "\x8E\xCD",
  /* U+5E6C */	"\x8E\xCE", "\x8E\xCF", "\x8E\xD0", "\x8E\xD1",
  /* U+5E70 */	"\x8E\xD2", "\x8E\xD3", "\xB8\xC9", "\xC6\xBD",
  /* U+5E74 */	"\xC4\xEA", "\x8E\xD4", "\xB2\xA2", "\x8E\xD5",
  /* U+5E78 */	"\xD0\xD2", "\x8E\xD6", "\xE7\xDB", "\xBB\xC3",
  /* U+5E7C */	"\xD3\xD7", "\xD3\xC4", "\x8E\xD7", "\xB9\xE3",
  /* U+5E80 */	"\xE2\xCF", "\x8E\xD8", "\x8E\xD9", "\x8E\xDA",
  /* U+5E84 */	"\xD7\xAF", "\x8E\xDB", "\xC7\xEC", "\xB1\xD3",
  /* U+5E88 */	"\x8E\xDC", "\x8E\xDD", "\xB4\xB2", "\xE2\xD1",
  /* U+5E8C */	"\x8E\xDE", "\x8E\xDF", "\x8E\xE0", "\xD0\xF2",
  /* U+5E90 */	"\xC2\xAE", "\xE2\xD0", "\x8E\xE1", "\xBF\xE2",
  /* U+5E94 */	"\xD3\xA6", "\xB5\xD7", "\xE2\xD2", "\xB5\xEA",
  /* U+5E98 */	"\x8E\xE2", "\xC3\xED", "\xB8\xFD", "\x8E\xE3",
  /* U+5E9C */	"\xB8\xAE", "\x8E\xE4", "\xC5\xD3", "\xB7\xCF",
  /* U+5EA0 */	"\xE2\xD4", "\x8E\xE5", "\x8E\xE6", "\x8E\xE7",
  /* U+5EA4 */	"\x8E\xE8", "\xE2\xD3", "\xB6\xC8", "\xD7\xF9",
  /* U+5EA8 */	"\x8E\xE9", "\x8E\xEA", "\x8E\xEB", "\x8E\xEC",
  /* U+5EAC */	"\x8E\xED", "\xCD\xA5", "\x8E\xEE", "\x8E\xEF",
  /* U+5EB0 */	"\x8E\xF0", "\x8E\xF1", "\x8E\xF2", "\xE2\xD8",
  /* U+5EB4 */	"\x8E\xF3", "\xE2\xD6", "\xCA\xFC", "\xBF\xB5",
  /* U+5EB8 */	"\xD3\xB9", "\xE2\xD5", "\x8E\xF4", "\x8E\xF5",
  /* U+5EBC */	"\x8E\xF6", "\x8E\xF7", "\xE2\xD7", "\x8E\xF8",
  /* U+5EC0 */	"\x8E\xF9", "\x8E\xFA", "\x8E\xFB", "\x8E\xFC",
  /* U+5EC4 */	"\x8E\xFD", "\x8E\xFE", "\x8F\x40", "\x8F\x41",
  /* U+5EC8 */	"\x8F\x42", "\xC1\xAE", "\xC0\xC8", "\x8F\x43",
  /* U+5ECC */	"\x8F\x44", "\x8F\x45", "\x8F\x46", "\x8F\x47",
  /* U+5ED0 */	"\x8F\x48", "\xE2\xDB", "\xE2\xDA", "\xC0\xAA",
  /* U+5ED4 */	"\x8F\x49", "\x8F\x4A", "\xC1\xCE", "\x8F\x4B",
  /* U+5ED8 */	"\x8F\x4C", "\x8F\x4D", "\x8F\x4E", "\xE2\xDC",
  /* U+5EDC */	"\x8F\x4F", "\x8F\x50", "\x8F\x51", "\x8F\x52",
  /* U+5EE0 */	"\x8F\x53", "\x8F\x54", "\x8F\x55", "\x8F\x56",
  /* U+5EE4 */	"\x8F\x57", "\x8F\x58", "\x8F\x59", "\x8F\x5A",
  /* U+5EE8 */	"\xE2\xDD", "\x8F\x5B", "\xE2\xDE", "\x8F\x5C",
  /* U+5EEC */	"\x8F\x5D", "\x8F\x5E", "\x8F\x5F", "\x8F\x60",
  /* U+5EF0 */	"\x8F\x61", "\x8F\x62", "\x8F\x63", "\x8F\x64",
  /* U+5EF4 */	"\xDB\xC8", "\x8F\x65", "\xD1\xD3", "\xCD\xA2",
  /* U+5EF8 */	"\x8F\x66", "\x8F\x67", "\xBD\xA8", "\x8F\x68",
  /* U+5EFC */	"\x8F\x69", "\x8F\x6A", "\xDE\xC3", "\xD8\xA5",
  /* U+5F00 */	"\xBF\xAA", "\xDB\xCD", "\xD2\xEC", "\xC6\xFA",
  /* U+5F04 */	"\xC5\xAA", "\x8F\x6B", "\x8F\x6C", "\x8F\x6D",
  /* U+5F08 */	"\xDE\xC4", "\x8F\x6E", "\xB1\xD7", "\xDF\xAE",
  /* U+5F0C */	"\x8F\x6F", "\x8F\x70", "\x8F\x71", "\xCA\xBD",
  /* U+5F10 */	"\x8F\x72", "\xDF\xB1", "\x8F\x73", "\xB9\xAD",
  /* U+5F14 */	"\x8F\x74", "\xD2\xFD", "\x8F\x75", "\xB8\xA5",
  /* U+5F18 */	"\xBA\xEB", "\x8F\x76", "\x8F\x77", "\xB3\xDA",
  /* U+5F1C */	"\x8F\x78", "\x8F\x79", "\x8F\x7A", "\xB5\xDC",
  /* U+5F20 */	"\xD5\xC5", "\x8F\x7B", "\x8F\x7C", "\x8F\x7D",
  /* U+5F24 */	"\x8F\x7E", "\xC3\xD6", "\xCF\xD2", "\xBB\xA1",
  /* U+5F28 */	"\x8F\x80", "\xE5\xF3", "\xE5\xF2", "\x8F\x81",
  /* U+5F2C */	"\x8F\x82", "\xE5\xF4", "\x8F\x83", "\xCD\xE4",
  /* U+5F30 */	"\x8F\x84", "\xC8\xF5", "\x8F\x85", "\x8F\x86",
  /* U+5F34 */	"\x8F\x87", "\x8F\x88", "\x8F\x89", "\x8F\x8A",
  /* U+5F38 */	"\x8F\x8B", "\xB5\xAF", "\xC7\xBF", "\x8F\x8C",
  /* U+5F3C */	"\xE5\xF6", "\x8F\x8D", "\x8F\x8E", "\x8F\x8F",
  /* U+5F40 */	"\xEC\xB0", "\x8F\x90", "\x8F\x91", "\x8F\x92",
  /* U+5F44 */	"\x8F\x93", "\x8F\x94", "\x8F\x95", "\x8F\x96",
  /* U+5F48 */	"\x8F\x97", "\x8F\x98", "\x8F\x99", "\x8F\x9A",
  /* U+5F4C */	"\x8F\x9B", "\x8F\x9C", "\x8F\x9D", "\x8F\x9E",
  /* U+5F50 */	"\xE5\xE6", "\x8F\x9F", "\xB9\xE9", "\xB5\xB1",
  /* U+5F54 */	"\x8F\xA0", "\xC2\xBC", "\xE5\xE8", "\xE5\xE7",
  /* U+5F58 */	"\xE5\xE9", "\x8F\xA1", "\x8F\xA2", "\x8F\xA3",
  /* U+5F5C */	"\x8F\xA4", "\xD2\xCD", "\x8F\xA5", "\x8F\xA6",
  /* U+5F60 */	"\x8F\xA7", "\xE1\xEA", "\xD0\xCE", "\x8F\xA8",
  /* U+5F64 */	"\xCD\xAE", "\x8F\xA9", "\xD1\xE5", "\x8F\xAA",
  /* U+5F68 */	"\x8F\xAB", "\xB2\xCA", "\xB1\xEB", "\x8F\xAC",
  /* U+5F6C */	"\xB1\xF2", "\xC5\xED", "\x8F\xAD", "\x8F\xAE",
  /* U+5F70 */	"\xD5\xC3", "\xD3\xB0", "\x8F\xAF", "\xE1\xDC",
  /* U+5F74 */	"\x8F\xB0", "\x8F\xB1", "\x8F\xB2", "\xE1\xDD",
  /* U+5F78 */	"\x8F\xB3", "\xD2\xDB", "\x8F\xB4", "\xB3\xB9",
  /* U+5F7C */	"\xB1\xCB", "\x8F\xB5", "\x8F\xB6", "\x8F\xB7",
  /* U+5F80 */	"\xCD\xF9", "\xD5\xF7", "\xE1\xDE", "\x8F\xB8",
  /* U+5F84 */	"\xBE\xB6", "\xB4\xFD", "\x8F\xB9", "\xE1\xDF",
  /* U+5F88 */	"\xBA\xDC", "\xE1\xE0", "\xBB\xB2", "\xC2\xC9",
  /* U+5F8C */	"\xE1\xE1", "\x8F\xBA", "\x8F\xBB", "\x8F\xBC",
  /* U+5F90 */	"\xD0\xEC", "\x8F\xBD", "\xCD\xBD", "\x8F\xBE",
  /* U+5F94 */	"\x8F\xBF", "\xE1\xE2", "\x8F\xC0", "\xB5\xC3",
  /* U+5F98 */	"\xC5\xC7", "\xE1\xE3", "\x8F\xC1", "\x8F\xC2",
  /* U+5F9C */	"\xE1\xE4", "\x8F\xC3", "\x8F\xC4", "\x8F\xC5",
  /* U+5FA0 */	"\x8F\xC6", "\xD3\xF9", "\x8F\xC7", "\x8F\xC8",
  /* U+5FA4 */	"\x8F\xC9", "\x8F\xCA", "\x8F\xCB", "\x8F\xCC",
  /* U+5FA8 */	"\xE1\xE5", "\x8F\xCD", "\xD1\xAD", "\x8F\xCE",
  /* U+5FAC */	"\x8F\xCF", "\xE1\xE6", "\xCE\xA2", "\x8F\xD0",
  /* U+5FB0 */	"\x8F\xD1", "\x8F\xD2", "\x8F\xD3", "\x8F\xD4",
  /* U+5FB4 */	"\x8F\xD5", "\xE1\xE7", "\x8F\xD6", "\xB5\xC2",
  /* U+5FB8 */	"\x8F\xD7", "\x8F\xD8", "\x8F\xD9", "\x8F\xDA",
  /* U+5FBC */	"\xE1\xE8", "\xBB\xD5", "\x8F\xDB", "\x8F\xDC",
  /* U+5FC0 */	"\x8F\xDD", "\x8F\xDE", "\x8F\xDF", "\xD0\xC4",
  /* U+5FC4 */	"\xE2\xE0", "\xB1\xD8", "\xD2\xE4", "\x8F\xE0",
  /* U+5FC8 */	"\x8F\xE1", "\xE2\xE1", "\x8F\xE2", "\x8F\xE3",
  /* U+5FCC */	"\xBC\xC9", "\xC8\xCC", "\x8F\xE4", "\xE2\xE3",
  /* U+5FD0 */	"\xEC\xFE", "\xEC\xFD", "\xDF\xAF", "\x8F\xE5",
  /* U+5FD4 */	"\x8F\xE6", "\x8F\xE7", "\xE2\xE2", "\xD6\xBE",
  /* U+5FD8 */	"\xCD\xFC", "\xC3\xA6", "\x8F\xE8", "\x8F\xE9",
  /* U+5FDC */	"\x8F\xEA", "\xE3\xC3", "\x8F\xEB", "\x8F\xEC",
  /* U+5FE0 */	"\xD6\xD2", "\xE2\xE7", "\x8F\xED", "\x8F\xEE",
  /* U+5FE4 */	"\xE2\xE8", "\x8F\xEF", "\x8F\xF0", "\xD3\xC7",
  /* U+5FE8 */	"\x8F\xF1", "\x8F\xF2", "\xE2\xEC", "\xBF\xEC",
  /* U+5FEC */	"\x8F\xF3", "\xE2\xED", "\xE2\xE5", "\x8F\xF4",
  /* U+5FF0 */	"\x8F\xF5", "\xB3\xC0", "\x8F\xF6", "\x8F\xF7",
  /* U+5FF4 */	"\x8F\xF8", "\xC4\xEE", "\x8F\xF9", "\x8F\xFA",
  /* U+5FF8 */	"\xE2\xEE", "\x8F\xFB", "\x8F\xFC", "\xD0\xC3",
  /* U+5FFC */	"\x8F\xFD", "\xBA\xF6", "\xE2\xE9", "\xB7\xDE",
  /* U+6000 */	"\xBB\xB3", "\xCC\xAC", "\xCB\xCB", "\xE2\xE4",
  /* U+6004 */	"\xE2\xE6", "\xE2\xEA", "\xE2\xEB", "\x8F\xFE",
  /* U+6008 */	"\x90\x40", "\x90\x41", "\xE2\xF7", "\x90\x42",
  /* U+600C */	"\x90\x43", "\xE2\xF4", "\xD4\xF5", "\xE2\xF3",
  /* U+6010 */	"\x90\x44", "\x90\x45", "\xC5\xAD", "\x90\x46",
  /* U+6014 */	"\xD5\xFA", "\xC5\xC2", "\xB2\xC0", "\x90\x47",
  /* U+6018 */	"\x90\x48", "\xE2\xEF", "\x90\x49", "\xE2\xF2",
  /* U+601C */	"\xC1\xAF", "\xCB\xBC", "\x90\x4A", "\x90\x4B",
  /* U+6020 */	"\xB5\xA1", "\xE2\xF9", "\x90\x4C", "\x90\x4D",
  /* U+6024 */	"\x90\x4E", "\xBC\xB1", "\xE2\xF1", "\xD0\xD4",
  /* U+6028 */	"\xD4\xB9", "\xE2\xF5", "\xB9\xD6", "\xE2\xF6",
  /* U+602C */	"\x90\x4F", "\x90\x50", "\x90\x51", "\xC7\xD3",
  /* U+6030 */	"\x90\x52", "\x90\x53", "\x90\x54", "\x90\x55",
  /* U+6034 */	"\x90\x56", "\xE2\xF0", "\x90\x57", "\x90\x58",
  /* U+6038 */	"\x90\x59", "\x90\x5A", "\x90\x5B", "\xD7\xDC",
  /* U+603C */	"\xED\xA1", "\x90\x5C", "\x90\x5D", "\xE2\xF8",
  /* U+6040 */	"\x90\x5E", "\xED\xA5", "\xE2\xFE", "\xCA\xD1",
  /* U+6044 */	"\x90\x5F", "\x90\x60", "\x90\x61", "\x90\x62",
  /* U+6048 */	"\x90\x63", "\x90\x64", "\x90\x65", "\xC1\xB5",
  /* U+604C */	"\x90\x66", "\xBB\xD0", "\x90\x67", "\x90\x68",
  /* U+6050 */	"\xBF\xD6", "\x90\x69", "\xBA\xE3", "\x90\x6A",
  /* U+6054 */	"\x90\x6B", "\xCB\xA1", "\x90\x6C", "\x90\x6D",
  /* U+6058 */	"\x90\x6E", "\xED\xA6", "\xED\xA3", "\x90\x6F",
  /* U+605C */	"\x90\x70", "\xED\xA2", "\x90\x71", "\x90\x72",
  /* U+6060 */	"\x90\x73", "\x90\x74", "\xBB\xD6", "\xED\xA7",
  /* U+6064 */	"\xD0\xF4", "\x90\x75", "\x90\x76", "\xED\xA4",
  /* U+6068 */	"\xBA\xDE", "\xB6\xF7", "\xE3\xA1", "\xB6\xB2",
  /* U+606C */	"\xCC\xF1", "\xB9\xA7", "\x90\x77", "\xCF\xA2",
  /* U+6070 */	"\xC7\xA1", "\x90\x78", "\x90\x79", "\xBF\xD2",
  /* U+6074 */	"\x90\x7A", "\x90\x7B", "\xB6\xF1", "\x90\x7C",
  /* U+6078 */	"\xE2\xFA", "\xE2\xFB", "\xE2\xFD", "\xE2\xFC",
  /* U+607C */	"\xC4\xD5", "\xE3\xA2", "\x90\x7D", "\xD3\xC1",
  /* U+6080 */	"\x90\x7E", "\x90\x80", "\x90\x81", "\xE3\xA7",
  /* U+6084 */	"\xC7\xC4", "\x90\x82", "\x90\x83", "\x90\x84",
  /* U+6088 */	"\x90\x85", "\xCF\xA4", "\x90\x86", "\x90\x87",
  /* U+608C */	"\xE3\xA9", "\xBA\xB7", "\x90\x88", "\x90\x89",
  /* U+6090 */	"\x90\x8A", "\x90\x8B", "\xE3\xA8", "\x90\x8C",
  /* U+6094 */	"\xBB\xDA", "\x90\x8D", "\xE3\xA3", "\x90\x8E",
  /* U+6098 */	"\x90\x8F", "\x90\x90", "\xE3\xA4", "\xE3\xAA",
  /* U+609C */	"\x90\x91", "\xE3\xA6", "\x90\x92", "\xCE\xF2",
  /* U+60A0 */	"\xD3\xC6", "\x90\x93", "\x90\x94", "\xBB\xBC",
  /* U+60A4 */	"\x90\x95", "\x90\x96", "\xD4\xC3", "\x90\x97",
  /* U+60A8 */	"\xC4\xFA", "\x90\x98", "\x90\x99", "\xED\xA8",
  /* U+60AC */	"\xD0\xFC", "\xE3\xA5", "\x90\x9A", "\xC3\xF5",
  /* U+60B0 */	"\x90\x9B", "\xE3\xAD", "\xB1\xAF", "\x90\x9C",
  /* U+60B4 */	"\xE3\xB2", "\x90\x9D", "\x90\x9E", "\x90\x9F",
  /* U+60B8 */	"\xBC\xC2", "\x90\xA0", "\x90\xA1", "\xE3\xAC",
  /* U+60BC */	"\xB5\xBF", "\x90\xA2", "\x90\xA3", "\x90\xA4",
  /* U+60C0 */	"\x90\xA5", "\x90\xA6", "\x90\xA7", "\x90\xA8",
  /* U+60C4 */	"\x90\xA9", "\xC7\xE9", "\xE3\xB0", "\x90\xAA",
  /* U+60C8 */	"\x90\xAB", "\x90\xAC", "\xBE\xAA", "\xCD\xEF",
  /* U+60CC */	"\x90\xAD", "\x90\xAE", "\x90\xAF", "\x90\xB0",
  /* U+60D0 */	"\x90\xB1", "\xBB\xF3", "\x90\xB2", "\x90\xB3",
  /* U+60D4 */	"\x90\xB4", "\xCC\xE8", "\x90\xB5", "\x90\xB6",
  /* U+60D8 */	"\xE3\xAF", "\x90\xB7", "\xE3\xB1", "\x90\xB8",
  /* U+60DC */	"\xCF\xA7", "\xE3\xAE", "\x90\xB9", "\xCE\xA9",
  /* U+60E0 */	"\xBB\xDD", "\x90\xBA", "\x90\xBB", "\x90\xBC",
  /* U+60E4 */	"\x90\xBD", "\x90\xBE", "\xB5\xEB", "\xBE\xE5",
  /* U+60E8 */	"\xB2\xD2", "\xB3\xCD", "\x90\xBF", "\xB1\xB9",
  /* U+60EC */	"\xE3\xAB", "\xB2\xD1", "\xB5\xAC", "\xB9\xDF",
  /* U+60F0 */	"\xB6\xE8", "\x90\xC0", "\x90\xC1", "\xCF\xEB",
  /* U+60F4 */	"\xE3\xB7", "\x90\xC2", "\xBB\xCC", "\x90\xC3",
  /* U+60F8 */	"\x90\xC4", "\xC8\xC7", "\xD0\xCA", "\x90\xC5",
  /* U+60FC */	"\x90\xC6", "\x90\xC7", "\x90\xC8", "\x90\xC9",
  /* U+6100 */	"\xE3\xB8", "\xB3\xEE", "\x90\xCA", "\x90\xCB",
  /* U+6104 */	"\x90\xCC", "\x90\xCD", "\xED\xA9", "\x90\xCE",
  /* U+6108 */	"\xD3\xFA", "\xD3\xE4", "\x90\xCF", "\x90\xD0",
  /* U+610C */	"\x90\xD1", "\xED\xAA", "\xE3\xB9", "\xD2\xE2",
  /* U+6110 */	"\x90\xD2", "\x90\xD3", "\x90\xD4", "\x90\xD5",
  /* U+6114 */	"\x90\xD6", "\xE3\xB5", "\x90\xD7", "\x90\xD8",
  /* U+6118 */	"\x90\xD9", "\x90\xDA", "\xD3\xDE", "\x90\xDB",
  /* U+611C */	"\x90\xDC", "\x90\xDD", "\x90\xDE", "\xB8\xD0",
  /* U+6120 */	"\xE3\xB3", "\x90\xDF", "\x90\xE0", "\xE3\xB6",
  /* U+6124 */	"\xB7\xDF", "\x90\xE1", "\xE3\xB4", "\xC0\xA2",
  /* U+6128 */	"\x90\xE2", "\x90\xE3", "\x90\xE4", "\xE3\xBA",
  /* U+612C */	"\x90\xE5", "\x90\xE6", "\x90\xE7", "\x90\xE8",
  /* U+6130 */	"\x90\xE9", "\x90\xEA", "\x90\xEB", "\x90\xEC",
  /* U+6134 */	"\x90\xED", "\x90\xEE", "\x90\xEF", "\x90\xF0",
  /* U+6138 */	"\x90\xF1", "\x90\xF2", "\x90\xF3", "\x90\xF4",
  /* U+613C */	"\x90\xF5", "\x90\xF6", "\x90\xF7", "\xD4\xB8",
  /* U+6140 */	"\x90\xF8", "\x90\xF9", "\x90\xFA", "\x90\xFB",
  /* U+6144 */	"\x90\xFC", "\x90\xFD", "\x90\xFE", "\x91\x40",
  /* U+6148 */	"\xB4\xC8", "\x91\x41", "\xE3\xBB", "\x91\x42",
  /* U+614C */	"\xBB\xC5", "\x91\x43", "\xC9\xF7", "\x91\x44",
  /* U+6150 */	"\x91\x45", "\xC9\xE5", "\x91\x46", "\x91\x47",
  /* U+6154 */	"\x91\x48", "\xC4\xBD", "\x91\x49", "\x91\x4A",
  /* U+6158 */	"\x91\x4B", "\x91\x4C", "\x91\x4D", "\x91\x4E",
  /* U+615C */	"\x91\x4F", "\xED\xAB", "\x91\x50", "\x91\x51",
  /* U+6160 */	"\x91\x52", "\x91\x53", "\xC2\xFD", "\x91\x54",
  /* U+6164 */	"\x91\x55", "\x91\x56", "\x91\x57", "\xBB\xDB",
  /* U+6168 */	"\xBF\xAE", "\x91\x58", "\x91\x59", "\x91\x5A",
  /* U+616C */	"\x91\x5B", "\x91\x5C", "\x91\x5D", "\x91\x5E",
  /* U+6170 */	"\xCE\xBF", "\x91\x5F", "\x91\x60", "\x91\x61",
  /* U+6174 */	"\x91\x62", "\xE3\xBC", "\x91\x63", "\xBF\xB6",
  /* U+6178 */	"\x91\x64", "\x91\x65", "\x91\x66", "\x91\x67",
  /* U+617C */	"\x91\x68", "\x91\x69", "\x91\x6A", "\x91\x6B",
  /* U+6180 */	"\x91\x6C", "\x91\x6D", "\x91\x6E", "\x91\x6F",
  /* U+6184 */	"\x91\x70", "\x91\x71", "\x91\x72", "\x91\x73",
  /* U+6188 */	"\x91\x74", "\x91\x75", "\x91\x76", "\xB1\xEF",
  /* U+618C */	"\x91\x77", "\x91\x78", "\xD4\xF7", "\x91\x79",
  /* U+6190 */	"\x91\x7A", "\x91\x7B", "\x91\x7C", "\x91\x7D",
  /* U+6194 */	"\xE3\xBE", "\x91\x7E", "\x91\x80", "\x91\x81",
  /* U+6198 */	"\x91\x82", "\x91\x83", "\x91\x84", "\x91\x85",
  /* U+619C */	"\x91\x86", "\xED\xAD", "\x91\x87", "\x91\x88",
  /* U+61A0 */	"\x91\x89", "\x91\x8A", "\x91\x8B", "\x91\x8C",
  /* U+61A4 */	"\x91\x8D", "\x91\x8E", "\x91\x8F", "\xE3\xBF",
  /* U+61A8 */	"\xBA\xA9", "\xED\xAC", "\x91\x90", "\x91\x91",
  /* U+61AC */	"\xE3\xBD", "\x91\x92", "\x91\x93", "\x91\x94",
  /* U+61B0 */	"\x91\x95", "\x91\x96", "\x91\x97", "\x91\x98",
  /* U+61B4 */	"\x91\x99", "\x91\x9A", "\x91\x9B", "\xE3\xC0",
  /* U+61B8 */	"\x91\x9C", "\x91\x9D", "\x91\x9E", "\x91\x9F",
  /* U+61BC */	"\x91\xA0", "\x91\xA1", "\xBA\xB6", "\x91\xA2",
  /* U+61C0 */	"\x91\xA3", "\x91\xA4", "\xB6\xAE", "\x91\xA5",
  /* U+61C4 */	"\x91\xA6", "\x91\xA7", "\x91\xA8", "\x91\xA9",
  /* U+61C8 */	"\xD0\xB8", "\x91\xAA", "\xB0\xC3", "\xED\xAE",
  /* U+61CC */	"\x91\xAB", "\x91\xAC", "\x91\xAD", "\x91\xAE",
  /* U+61D0 */	"\x91\xAF", "\xED\xAF", "\xC0\xC1", "\x91\xB0",
  /* U+61D4 */	"\xE3\xC1", "\x91\xB1", "\x91\xB2", "\x91\xB3",
  /* U+61D8 */	"\x91\xB4", "\x91\xB5", "\x91\xB6", "\x91\xB7",
  /* U+61DC */	"\x91\xB8", "\x91\xB9", "\x91\xBA", "\x91\xBB",
  /* U+61E0 */	"\x91\xBC", "\x91\xBD", "\x91\xBE", "\x91\xBF",
  /* U+61E4 */	"\x91\xC0", "\x91\xC1", "\xC5\xB3", "\x91\xC2",
  /* U+61E8 */	"\x91\xC3", "\x91\xC4", "\x91\xC5", "\x91\xC6",
  /* U+61EC */	"\x91\xC7", "\x91\xC8", "\x91\xC9", "\x91\xCA",
  /* U+61F0 */	"\x91\xCB", "\x91\xCC", "\x91\xCD", "\x91\xCE",
  /* U+61F4 */	"\x91\xCF", "\xE3\xC2", "\x91\xD0", "\x91\xD1",
  /* U+61F8 */	"\x91\xD2", "\x91\xD3", "\x91\xD4", "\x91\xD5",
  /* U+61FC */	"\x91\xD6", "\x91\xD7", "\x91\xD8", "\xDC\xB2",
  /* U+6200 */	"\x91\xD9", "\x91\xDA", "\x91\xDB", "\x91\xDC",
  /* U+6204 */	"\x91\xDD", "\x91\xDE", "\xED\xB0", "\x91\xDF",
  /* U+6208 */	"\xB8\xEA", "\x91\xE0", "\xCE\xEC", "\xEA\xA7",
  /* U+620C */	"\xD0\xE7", "\xCA\xF9", "\xC8\xD6", "\xCF\xB7",
  /* U+6210 */	"\xB3\xC9", "\xCE\xD2", "\xBD\xE4", "\x91\xE1",
  /* U+6214 */	"\x91\xE2", "\xE3\xDE", "\xBB\xF2", "\xEA\xA8",
  /* U+6218 */	"\xD5\xBD", "\x91\xE3", "\xC6\xDD", "\xEA\xA9",
  /* U+621C */	"\x91\xE4", "\x91\xE5", "\x91\xE6", "\xEA\xAA",
  /* U+6220 */	"\x91\xE7", "\xEA\xAC", "\xEA\xAB", "\x91\xE8",
  /* U+6224 */	"\xEA\xAE", "\xEA\xAD", "\x91\xE9", "\x91\xEA",
  /* U+6228 */	"\x91\xEB", "\x91\xEC", "\xBD\xD8", "\x91\xED",
  /* U+622C */	"\xEA\xAF", "\x91\xEE", "\xC2\xBE", "\x91\xEF",
  /* U+6230 */	"\x91\xF0", "\x91\xF1", "\x91\xF2", "\xB4\xC1",
  /* U+6234 */	"\xB4\xF7", "\x91\xF3", "\x91\xF4", "\xBB\xA7",
  /* U+6238 */	"\x91\xF5", "\x91\xF6", "\x91\xF7", "\x91\xF8",
  /* U+623C */	"\x91\xF9", "\xEC\xE6", "\xEC\xE5", "\xB7\xBF",
  /* U+6240 */	"\xCB\xF9", "\xB1\xE2", "\x91\xFA", "\xEC\xE7",
  /* U+6244 */	"\x91\xFB", "\x91\xFC", "\x91\xFD", "\xC9\xC8",
  /* U+6248 */	"\xEC\xE8", "\xEC\xE9", "\x91\xFE", "\xCA\xD6",
  /* U+624C */	"\xDE\xD0", "\xB2\xC5", "\xD4\xFA", "\x92\x40",
  /* U+6250 */	"\x92\x41", "\xC6\xCB", "\xB0\xC7", "\xB4\xF2",
  /* U+6254 */	"\xC8\xD3", "\x92\x42", "\x92\x43", "\x92\x44",
  /* U+6258 */	"\xCD\xD0", "\x92\x45", "\x92\x46", "\xBF\xB8",
  /* U+625C */	"\x92\x47", "\x92\x48", "\x92\x49", "\x92\x4A",
  /* U+6260 */	"\x92\x4B", "\x92\x4C", "\x92\x4D", "\xBF\xDB",
  /* U+6264 */	"\x92\x4E", "\x92\x4F", "\xC7\xA4", "\xD6\xB4",
  /* U+6268 */	"\x92\x50", "\xC0\xA9", "\xDE\xD1", "\xC9\xA8",
  /* U+626C */	"\xD1\xEF", "\xC5\xA4", "\xB0\xE7", "\xB3\xB6",
  /* U+6270 */	"\xC8\xC5", "\x92\x51", "\x92\x52", "\xB0\xE2",
  /* U+6274 */	"\x92\x53", "\x92\x54", "\xB7\xF6", "\x92\x55",
  /* U+6278 */	"\x92\x56", "\xC5\xFA", "\x92\x57", "\x92\x58",
  /* U+627C */	"\xB6\xF3", "\x92\x59", "\xD5\xD2", "\xB3\xD0",
  /* U+6280 */	"\xBC\xBC", "\x92\x5A", "\x92\x5B", "\x92\x5C",
  /* U+6284 */	"\xB3\xAD", "\x92\x5D", "\x92\x5E", "\x92\x5F",
  /* U+6288 */	"\x92\x60", "\xBE\xF1", "\xB0\xD1", "\x92\x61",
  /* U+628C */	"\x92\x62", "\x92\x63", "\x92\x64", "\x92\x65",
  /* U+6290 */	"\x92\x66", "\xD2\xD6", "\xCA\xE3", "\xD7\xA5",
  /* U+6294 */	"\x92\x67", "\xCD\xB6", "\xB6\xB6", "\xBF\xB9",
  /* U+6298 */	"\xD5\xDB", "\x92\x68", "\xB8\xA7", "\xC5\xD7",
  /* U+629C */	"\x92\x69", "\x92\x6A", "\x92\x6B", "\xDE\xD2",
  /* U+62A0 */	"\xBF\xD9", "\xC2\xD5", "\xC7\xC0", "\x92\x6C",
  /* U+62A4 */	"\xBB\xA4", "\xB1\xA8", "\x92\x6D", "\x92\x6E",
  /* U+62A8 */	"\xC5\xEA", "\x92\x6F", "\x92\x70", "\xC5\xFB",
  /* U+62AC */	"\xCC\xA7", "\x92\x71", "\x92\x72", "\x92\x73",
  /* U+62B0 */	"\x92\x74", "\xB1\xA7", "\x92\x75", "\x92\x76",
  /* U+62B4 */	"\x92\x77", "\xB5\xD6", "\x92\x78", "\x92\x79",
  /* U+62B8 */	"\x92\x7A", "\xC4\xA8", "\x92\x7B", "\xDE\xD3",
  /* U+62BC */	"\xD1\xBA", "\xB3\xE9", "\x92\x7C", "\xC3\xF2",
  /* U+62C0 */	"\x92\x7D", "\x92\x7E", "\xB7\xF7", "\x92\x80",
  /* U+62C4 */	"\xD6\xF4", "\xB5\xA3", "\xB2\xF0", "\xC4\xB4",
  /* U+62C8 */	"\xC4\xE9", "\xC0\xAD", "\xDE\xD4", "\x92\x81",
  /* U+62CC */	"\xB0\xE8", "\xC5\xC4", "\xC1\xE0", "\x92\x82",
  /* U+62D0 */	"\xB9\xD5", "\x92\x83", "\xBE\xDC", "\xCD\xD8",
  /* U+62D4 */	"\xB0\xCE", "\x92\x84", "\xCD\xCF", "\xDE\xD6",
  /* U+62D8 */	"\xBE\xD0", "\xD7\xBE", "\xDE\xD5", "\xD5\xD0",
  /* U+62DC */	"\xB0\xDD", "\x92\x85", "\x92\x86", "\xC4\xE2",
  /* U+62E0 */	"\x92\x87", "\x92\x88", "\xC2\xA3", "\xBC\xF0",
  /* U+62E4 */	"\x92\x89", "\xD3\xB5", "\xC0\xB9", "\xC5\xA1",
  /* U+62E8 */	"\xB2\xA6", "\xD4\xF1", "\x92\x8A", "\x92\x8B",
  /* U+62EC */	"\xC0\xA8", "\xCA\xC3", "\xDE\xD7", "\xD5\xFC",
  /* U+62F0 */	"\x92\x8C", "\xB9\xB0", "\x92\x8D", "\xC8\xAD",
  /* U+62F4 */	"\xCB\xA9", "\x92\x8E", "\xDE\xD9", "\xBF\xBD",
  /* U+62F8 */	"\x92\x8F", "\x92\x90", "\x92\x91", "\x92\x92",
  /* U+62FC */	"\xC6\xB4", "\xD7\xA7", "\xCA\xB0", "\xC4\xC3",
  /* U+6300 */	"\x92\x93", "\xB3\xD6", "\xB9\xD2", "\x92\x94",
  /* U+6304 */	"\x92\x95", "\x92\x96", "\x92\x97", "\xD6\xB8",
  /* U+6308 */	"\xEA\xFC", "\xB0\xB4", "\x92\x98", "\x92\x99",
  /* U+630C */	"\x92\x9A", "\x92\x9B", "\xBF\xE6", "\x92\x9C",
  /* U+6310 */	"\x92\x9D", "\xCC\xF4", "\x92\x9E", "\x92\x9F",
  /* U+6314 */	"\x92\xA0", "\x92\xA1", "\xCD\xDA", "\x92\xA2",
  /* U+6318 */	"\x92\xA3", "\x92\xA4", "\xD6\xBF", "\xC2\xCE",
  /* U+631C */	"\x92\xA5", "\xCE\xCE", "\xCC\xA2", "\xD0\xAE",
  /* U+6320 */	"\xC4\xD3", "\xB5\xB2", "\xDE\xD8", "\xD5\xF5",
  /* U+6324 */	"\xBC\xB7", "\xBB\xD3", "\x92\xA6", "\x92\xA7",
  /* U+6328 */	"\xB0\xA4", "\x92\xA8", "\xC5\xB2", "\xB4\xEC",
  /* U+632C */	"\x92\xA9", "\x92\xAA", "\x92\xAB", "\xD5\xF1",
  /* U+6330 */	"\x92\xAC", "\x92\xAD", "\xEA\xFD", "\x92\xAE",
  /* U+6334 */	"\x92\xAF", "\x92\xB0", "\x92\xB1", "\x92\xB2",
  /* U+6338 */	"\x92\xB3", "\xDE\xDA", "\xCD\xA6", "\x92\xB4",
  /* U+633C */	"\x92\xB5", "\xCD\xEC", "\x92\xB6", "\x92\xB7",
  /* U+6340 */	"\x92\xB8", "\x92\xB9", "\xCE\xE6", "\xDE\xDC",
  /* U+6344 */	"\x92\xBA", "\xCD\xB1", "\xC0\xA6", "\x92\xBB",
  /* U+6348 */	"\x92\xBC", "\xD7\xBD", "\x92\xBD", "\xDE\xDB",
  /* U+634C */	"\xB0\xC6", "\xBA\xB4", "\xC9\xD3", "\xC4\xF3",
  /* U+6350 */	"\xBE\xE8", "\x92\xBE", "\x92\xBF", "\x92\xC0",
  /* U+6354 */	"\x92\xC1", "\xB2\xB6", "\x92\xC2", "\x92\xC3",
  /* U+6358 */	"\x92\xC4", "\x92\xC5", "\x92\xC6", "\x92\xC7",
  /* U+635C */	"\x92\xC8", "\x92\xC9", "\xC0\xCC", "\xCB\xF0",
  /* U+6360 */	"\x92\xCA", "\xBC\xF1", "\xBB\xBB", "\xB5\xB7",
  /* U+6364 */	"\x92\xCB", "\x92\xCC", "\x92\xCD", "\xC5\xF5",
  /* U+6368 */	"\x92\xCE", "\xDE\xE6", "\x92\xCF", "\x92\xD0",
  /* U+636C */	"\x92\xD1", "\xDE\xE3", "\xBE\xDD", "\x92\xD2",
  /* U+6370 */	"\x92\xD3", "\xDE\xDF", "\x92\xD4", "\x92\xD5",
  /* U+6374 */	"\x92\xD6", "\x92\xD7", "\xB4\xB7", "\xBD\xDD",
  /* U+6378 */	"\x92\xD8", "\x92\xD9", "\xDE\xE0", "\xC4\xED",
  /* U+637C */	"\x92\xDA", "\x92\xDB", "\x92\xDC", "\x92\xDD",
  /* U+6380 */	"\xCF\xC6", "\x92\xDE", "\xB5\xE0", "\x92\xDF",
  /* U+6384 */	"\x92\xE0", "\x92\xE1", "\x92\xE2", "\xB6\xDE",
  /* U+6388 */	"\xCA\xDA", "\xB5\xF4", "\xDE\xE5", "\x92\xE3",
  /* U+638C */	"\xD5\xC6", "\x92\xE4", "\xDE\xE1", "\xCC\xCD",
  /* U+6390 */	"\xC6\xFE", "\x92\xE5", "\xC5\xC5", "\x92\xE6",
  /* U+6394 */	"\x92\xE7", "\x92\xE8", "\xD2\xB4", "\x92\xE9",
  /* U+6398 */	"\xBE\xF2", "\x92\xEA", "\x92\xEB", "\x92\xEC",
  /* U+639C */	"\x92\xED", "\x92\xEE", "\x92\xEF", "\x92\xF0",
  /* U+63A0 */	"\xC2\xD3", "\x92\xF1", "\xCC\xBD", "\xB3\xB8",
  /* U+63A4 */	"\x92\xF2", "\xBD\xD3", "\x92\xF3", "\xBF\xD8",
  /* U+63A8 */	"\xCD\xC6", "\xD1\xDA", "\xB4\xEB", "\x92\xF4",
  /* U+63AC */	"\xDE\xE4", "\xDE\xDD", "\xDE\xE7", "\x92\xF5",
  /* U+63B0 */	"\xEA\xFE", "\x92\xF6", "\x92\xF7", "\xC2\xB0",
  /* U+63B4 */	"\xDE\xE2", "\x92\xF8", "\x92\xF9", "\xD6\xC0",
  /* U+63B8 */	"\xB5\xA7", "\x92\xFA", "\xB2\xF4", "\x92\xFB",
  /* U+63BC */	"\xDE\xE8", "\x92\xFC", "\xDE\xF2", "\x92\xFD",
  /* U+63C0 */	"\x92\xFE", "\x93\x40", "\x93\x41", "\x93\x42",
  /* U+63C4 */	"\xDE\xED", "\x93\x43", "\xDE\xF1", "\x93\x44",
  /* U+63C8 */	"\x93\x45", "\xC8\xE0", "\x93\x46", "\x93\x47",
  /* U+63CC */	"\x93\x48", "\xD7\xE1", "\xDE\xEF", "\xC3\xE8",
  /* U+63D0 */	"\xCC\xE1", "\x93\x49", "\xB2\xE5", "\x93\x4A",
  /* U+63D4 */	"\x93\x4B", "\x93\x4C", "\xD2\xBE", "\x93\x4D",
  /* U+63D8 */	"\x93\x4E", "\x93\x4F", "\x93\x50", "\x93\x51",
  /* U+63DC */	"\x93\x52", "\x93\x53", "\xDE\xEE", "\x93\x54",
  /* U+63E0 */	"\xDE\xEB", "\xCE\xD5", "\x93\x55", "\xB4\xA7",
  /* U+63E4 */	"\x93\x56", "\x93\x57", "\x93\x58", "\x93\x59",
  /* U+63E8 */	"\x93\x5A", "\xBF\xAB", "\xBE\xBE", "\x93\x5B",
  /* U+63EC */	"\x93\x5C", "\xBD\xD2", "\x93\x5D", "\x93\x5E",
  /* U+63F0 */	"\x93\x5F", "\x93\x60", "\xDE\xE9", "\x93\x61",
  /* U+63F4 */	"\xD4\xAE", "\x93\x62", "\xDE\xDE", "\x93\x63",
  /* U+63F8 */	"\xDE\xEA", "\x93\x64", "\x93\x65", "\x93\x66",
  /* U+63FC */	"\x93\x67", "\xC0\xBF", "\x93\x68", "\xDE\xEC",
  /* U+6400 */	"\xB2\xF3", "\xB8\xE9", "\xC2\xA7", "\x93\x69",
  /* U+6404 */	"\x93\x6A", "\xBD\xC1", "\x93\x6B", "\x93\x6C",
  /* U+6408 */	"\x93\x6D", "\x93\x6E", "\x93\x6F", "\xDE\xF5",
  /* U+640C */	"\xDE\xF8", "\x93\x70", "\x93\x71", "\xB2\xAB",
  /* U+6410 */	"\xB4\xA4", "\x93\x72", "\x93\x73", "\xB4\xEA",
  /* U+6414 */	"\xC9\xA6", "\x93\x74", "\x93\x75", "\x93\x76",
  /* U+6418 */	"\x93\x77", "\x93\x78", "\x93\x79", "\xDE\xF6",
  /* U+641C */	"\xCB\xD1", "\x93\x7A", "\xB8\xE3", "\x93\x7B",
  /* U+6420 */	"\xDE\xF7", "\xDE\xFA", "\x93\x7C", "\x93\x7D",
  /* U+6424 */	"\x93\x7E", "\x93\x80", "\xDE\xF9", "\x93\x81",
  /* U+6428 */	"\x93\x82", "\x93\x83", "\xCC\xC2", "\x93\x84",
  /* U+642C */	"\xB0\xE1", "\xB4\xEE", "\x93\x85", "\x93\x86",
  /* U+6430 */	"\x93\x87", "\x93\x88", "\x93\x89", "\x93\x8A",
  /* U+6434 */	"\xE5\xBA", "\x93\x8B", "\x93\x8C", "\x93\x8D",
  /* U+6438 */	"\x93\x8E", "\x93\x8F", "\xD0\xAF", "\x93\x90",
  /* U+643C */	"\x93\x91", "\xB2\xEB", "\x93\x92", "\xEB\xA1",
  /* U+6440 */	"\x93\x93", "\xDE\xF4", "\x93\x94", "\x93\x95",
  /* U+6444 */	"\xC9\xE3", "\xDE\xF3", "\xB0\xDA", "\xD2\xA1",
  /* U+6448 */	"\xB1\xF7", "\x93\x96", "\xCC\xAF", "\x93\x97",
  /* U+644C */	"\x93\x98", "\x93\x99", "\x93\x9A", "\x93\x9B",
  /* U+6450 */	"\x93\x9C", "\x93\x9D", "\xDE\xF0", "\x93\x9E",
  /* U+6454 */	"\xCB\xA4", "\x93\x9F", "\x93\xA0", "\x93\xA1",
  /* U+6458 */	"\xD5\xAA", "\x93\xA2", "\x93\xA3", "\x93\xA4",
  /* U+645C */	"\x93\xA5", "\x93\xA6", "\xDE\xFB", "\x93\xA7",
  /* U+6460 */	"\x93\xA8", "\x93\xA9", "\x93\xAA", "\x93\xAB",
  /* U+6464 */	"\x93\xAC", "\x93\xAD", "\x93\xAE", "\xB4\xDD",
  /* U+6468 */	"\x93\xAF", "\xC4\xA6", "\x93\xB0", "\x93\xB1",
  /* U+646C */	"\x93\xB2", "\xDE\xFD", "\x93\xB3", "\x93\xB4",
  /* U+6470 */	"\x93\xB5", "\x93\xB6", "\x93\xB7", "\x93\xB8",
  /* U+6474 */	"\x93\xB9", "\x93\xBA", "\x93\xBB", "\x93\xBC",
  /* U+6478 */	"\xC3\xFE", "\xC4\xA1", "\xDF\xA1", "\x93\xBD",
  /* U+647C */	"\x93\xBE", "\x93\xBF", "\x93\xC0", "\x93\xC1",
  /* U+6480 */	"\x93\xC2", "\x93\xC3", "\xC1\xCC", "\x93\xC4",
  /* U+6484 */	"\xDE\xFC", "\xBE\xEF", "\x93\xC5", "\xC6\xB2",
  /* U+6488 */	"\x93\xC6", "\x93\xC7", "\x93\xC8", "\x93\xC9",
  /* U+648C */	"\x93\xCA", "\x93\xCB", "\x93\xCC", "\x93\xCD",
  /* U+6490 */	"\x93\xCE", "\xB3\xC5", "\xC8\xF6", "\x93\xCF",
  /* U+6494 */	"\x93\xD0", "\xCB\xBA", "\xDE\xFE", "\x93\xD1",
  /* U+6498 */	"\x93\xD2", "\xDF\xA4", "\x93\xD3", "\x93\xD4",
  /* U+649C */	"\x93\xD5", "\x93\xD6", "\xD7\xB2", "\x93\xD7",
  /* U+64A0 */	"\x93\xD8", "\x93\xD9", "\x93\xDA", "\x93\xDB",
  /* U+64A4 */	"\xB3\xB7", "\x93\xDC", "\x93\xDD", "\x93\xDE",
  /* U+64A8 */	"\x93\xDF", "\xC1\xC3", "\x93\xE0", "\x93\xE1",
  /* U+64AC */	"\xC7\xCB", "\xB2\xA5", "\xB4\xE9", "\x93\xE2",
  /* U+64B0 */	"\xD7\xAB", "\x93\xE3", "\x93\xE4", "\x93\xE5",
  /* U+64B4 */	"\x93\xE6", "\xC4\xEC", "\x93\xE7", "\xDF\xA2",
  /* U+64B8 */	"\xDF\xA3", "\x93\xE8", "\xDF\xA5", "\x93\xE9",
  /* U+64BC */	"\xBA\xB3", "\x93\xEA", "\x93\xEB", "\x93\xEC",
  /* U+64C0 */	"\xDF\xA6", "\x93\xED", "\xC0\xDE", "\x93\xEE",
  /* U+64C4 */	"\x93\xEF", "\xC9\xC3", "\x93\xF0", "\x93\xF1",
  /* U+64C8 */	"\x93\xF2", "\x93\xF3", "\x93\xF4", "\x93\xF5",
  /* U+64CC */	"\x93\xF6", "\xB2\xD9", "\xC7\xE6", "\x93\xF7",
  /* U+64D0 */	"\xDF\xA7", "\x93\xF8", "\xC7\xDC", "\x93\xF9",
  /* U+64D4 */	"\x93\xFA", "\x93\xFB", "\x93\xFC", "\xDF\xA8",
  /* U+64D8 */	"\xEB\xA2", "\x93\xFD", "\x93\xFE", "\x94\x40",
  /* U+64DC */	"\x94\x41", "\x94\x42", "\xCB\xD3", "\x94\x43",
  /* U+64E0 */	"\x94\x44", "\x94\x45", "\xDF\xAA", "\x94\x46",
  /* U+64E4 */	"\xDF\xA9", "\x94\x47", "\xB2\xC1", "\x94\x48",
  /* U+64E8 */	"\x94\x49", "\x94\x4A", "\x94\x4B", "\x94\x4C",
  /* U+64EC */	"\x94\x4D", "\x94\x4E", "\x94\x4F", "\x94\x50",
  /* U+64F0 */	"\x94\x51", "\x94\x52", "\x94\x53", "\x94\x54",
  /* U+64F4 */	"\x94\x55", "\x94\x56", "\x94\x57", "\x94\x58",
  /* U+64F8 */	"\x94\x59", "\x94\x5A", "\x94\x5B", "\x94\x5C",
  /* U+64FC */	"\x94\x5D", "\x94\x5E", "\x94\x5F", "\x94\x60",
  /* U+6500 */	"\xC5\xCA", "\x94\x61", "\x94\x62", "\x94\x63",
  /* U+6504 */	"\x94\x64", "\x94\x65", "\x94\x66", "\x94\x67",
  /* U+6508 */	"\x94\x68", "\xDF\xAB", "\x94\x69", "\x94\x6A",
  /* U+650C */	"\x94\x6B", "\x94\x6C", "\x94\x6D", "\x94\x6E",
  /* U+6510 */	"\x94\x6F", "\x94\x70", "\xD4\xDC", "\x94\x71",
  /* U+6514 */	"\x94\x72", "\x94\x73", "\x94\x74", "\x94\x75",
  /* U+6518 */	"\xC8\xC1", "\x94\x76", "\x94\x77", "\x94\x78",
  /* U+651C */	"\x94\x79", "\x94\x7A", "\x94\x7B", "\x94\x7C",
  /* U+6520 */	"\x94\x7D", "\x94\x7E", "\x94\x80", "\x94\x81",
  /* U+6524 */	"\x94\x82", "\xDF\xAC", "\x94\x83", "\x94\x84",
  /* U+6528 */	"\x94\x85", "\x94\x86", "\x94\x87", "\xBE\xF0",
  /* U+652C */	"\x94\x88", "\x94\x89", "\xDF\xAD", "\xD6\xA7",
  /* U+6530 */	"\x94\x8A", "\x94\x8B", "\x94\x8C", "\x94\x8D",
  /* U+6534 */	"\xEA\xB7", "\xEB\xB6", "\xCA\xD5", "\x94\x8E",
  /* U+6538 */	"\xD8\xFC", "\xB8\xC4", "\x94\x8F", "\xB9\xA5",
  /* U+653C */	"\x94\x90", "\x94\x91", "\xB7\xC5", "\xD5\xFE",
  /* U+6540 */	"\x94\x92", "\x94\x93", "\x94\x94", "\x94\x95",
  /* U+6544 */	"\x94\x96", "\xB9\xCA", "\x94\x97", "\x94\x98",
  /* U+6548 */	"\xD0\xA7", "\xF4\xCD", "\x94\x99", "\x94\x9A",
  /* U+654C */	"\xB5\xD0", "\x94\x9B", "\x94\x9C", "\xC3\xF4",
  /* U+6550 */	"\x94\x9D", "\xBE\xC8", "\x94\x9E", "\x94\x9F",
  /* U+6554 */	"\x94\xA0", "\xEB\xB7", "\xB0\xBD", "\x94\xA1",
  /* U+6558 */	"\x94\xA2", "\xBD\xCC", "\x94\xA3", "\xC1\xB2",
  /* U+655C */	"\x94\xA4", "\xB1\xD6", "\xB3\xA8", "\x94\xA5",
  /* U+6560 */	"\x94\xA6", "\x94\xA7", "\xB8\xD2", "\xC9\xA2",
  /* U+6564 */	"\x94\xA8", "\x94\xA9", "\xB6\xD8", "\x94\xAA",
  /* U+6568 */	"\x94\xAB", "\x94\xAC", "\x94\xAD", "\xEB\xB8",
  /* U+656C */	"\xBE\xB4", "\x94\xAE", "\x94\xAF", "\x94\xB0",
  /* U+6570 */	"\xCA\xFD", "\x94\xB1", "\xC7\xC3", "\x94\xB2",
  /* U+6574 */	"\xD5\xFB", "\x94\xB3", "\x94\xB4", "\xB7\xF3",
  /* U+6578 */	"\x94\xB5", "\x94\xB6", "\x94\xB7", "\x94\xB8",
  /* U+657C */	"\x94\xB9", "\x94\xBA", "\x94\xBB", "\x94\xBC",
  /* U+6580 */	"\x94\xBD", "\x94\xBE", "\x94\xBF", "\x94\xC0",
  /* U+6584 */	"\x94\xC1", "\x94\xC2", "\x94\xC3", "\xCE\xC4",
  /* U+6588 */	"\x94\xC4", "\x94\xC5", "\x94\xC6", "\xD5\xAB",
  /* U+658C */	"\xB1\xF3", "\x94\xC7", "\x94\xC8", "\x94\xC9",
  /* U+6590 */	"\xEC\xB3", "\xB0\xDF", "\x94\xCA", "\xEC\xB5",
  /* U+6594 */	"\x94\xCB", "\x94\xCC", "\x94\xCD", "\xB6\xB7",
  /* U+6598 */	"\x94\xCE", "\xC1\xCF", "\x94\xCF", "\xF5\xFA",
  /* U+659C */	"\xD0\xB1", "\x94\xD0", "\x94\xD1", "\xD5\xE5",
  /* U+65A0 */	"\x94\xD2", "\xCE\xD3", "\x94\xD3", "\x94\xD4",
  /* U+65A4 */	"\xBD\xEF", "\xB3\xE2", "\x94\xD5", "\xB8\xAB",
  /* U+65A8 */	"\x94\xD6", "\xD5\xB6", "\x94\xD7", "\xED\xBD",
  /* U+65AC */	"\x94\xD8", "\xB6\xCF", "\x94\xD9", "\xCB\xB9",
  /* U+65B0 */	"\xD0\xC2", "\x94\xDA", "\x94\xDB", "\x94\xDC",
  /* U+65B4 */	"\x94\xDD", "\x94\xDE", "\x94\xDF", "\x94\xE0",
  /* U+65B8 */	"\x94\xE1", "\xB7\xBD", "\x94\xE2", "\x94\xE3",
  /* U+65BC */	"\xEC\xB6", "\xCA\xA9", "\x94\xE4", "\x94\xE5",
  /* U+65C0 */	"\x94\xE6", "\xC5\xD4", "\x94\xE7", "\xEC\xB9",
  /* U+65C4 */	"\xEC\xB8", "\xC2\xC3", "\xEC\xB7", "\x94\xE8",
  /* U+65C8 */	"\x94\xE9", "\x94\xEA", "\x94\xEB", "\xD0\xFD",
  /* U+65CC */	"\xEC\xBA", "\x94\xEC", "\xEC\xBB", "\xD7\xE5",
  /* U+65D0 */	"\x94\xED", "\x94\xEE", "\xEC\xBC", "\x94\xEF",
  /* U+65D4 */	"\x94\xF0", "\x94\xF1", "\xEC\xBD", "\xC6\xEC",
  /* U+65D8 */	"\x94\xF2", "\x94\xF3", "\x94\xF4", "\x94\xF5",
  /* U+65DC */	"\x94\xF6", "\x94\xF7", "\x94\xF8", "\x94\xF9",
  /* U+65E0 */	"\xCE\xDE", "\x94\xFA", "\xBC\xC8", "\x94\xFB",
  /* U+65E4 */	"\x94\xFC", "\xC8\xD5", "\xB5\xA9", "\xBE\xC9",
  /* U+65E8 */	"\xD6\xBC", "\xD4\xE7", "\x94\xFD", "\x94\xFE",
  /* U+65EC */	"\xD1\xAE", "\xD0\xF1", "\xEA\xB8", "\xEA\xB9",
  /* U+65F0 */	"\xEA\xBA", "\xBA\xB5", "\x95\x40", "\x95\x41",
  /* U+65F4 */	"\x95\x42", "\x95\x43", "\xCA\xB1", "\xBF\xF5",
  /* U+65F8 */	"\x95\x44", "\x95\x45", "\xCD\xFA", "\x95\x46",
  /* U+65FC */	"\x95\x47", "\x95\x48", "\x95\x49", "\x95\x4A",
  /* U+6600 */	"\xEA\xC0", "\x95\x4B", "\xB0\xBA", "\xEA\xBE",
  /* U+6604 */	"\x95\x4C", "\x95\x4D", "\xC0\xA5", "\x95\x4E",
  /* U+6608 */	"\x95\x4F", "\x95\x50", "\xEA\xBB", "\x95\x51",
  /* U+660C */	"\xB2\xFD", "\x95\x52", "\xC3\xF7", "\xBB\xE8",
  /* U+6610 */	"\x95\x53", "\x95\x54", "\x95\x55", "\xD2\xD7",
  /* U+6614 */	"\xCE\xF4", "\xEA\xBF", "\x95\x56", "\x95\x57",
  /* U+6618 */	"\x95\x58", "\xEA\xBC", "\x95\x59", "\x95\x5A",
  /* U+661C */	"\x95\x5B", "\xEA\xC3", "\x95\x5C", "\xD0\xC7",
  /* U+6620 */	"\xD3\xB3", "\x95\x5D", "\x95\x5E", "\x95\x5F",
  /* U+6624 */	"\x95\x60", "\xB4\xBA", "\x95\x61", "\xC3\xC1",
  /* U+6628 */	"\xD7\xF2", "\x95\x62", "\x95\x63", "\x95\x64",
  /* U+662C */	"\x95\x65", "\xD5\xD1", "\x95\x66", "\xCA\xC7",
  /* U+6630 */	"\x95\x67", "\xEA\xC5", "\x95\x68", "\x95\x69",
  /* U+6634 */	"\xEA\xC4", "\xEA\xC7", "\xEA\xC6", "\x95\x6A",
  /* U+6638 */	"\x95\x6B", "\x95\x6C", "\x95\x6D", "\x95\x6E",
  /* U+663C */	"\xD6\xE7", "\x95\x6F", "\xCF\xD4", "\x95\x70",
  /* U+6640 */	"\x95\x71", "\xEA\xCB", "\x95\x72", "\xBB\xCE",
  /* U+6644 */	"\x95\x73", "\x95\x74", "\x95\x75", "\x95\x76",
  /* U+6648 */	"\x95\x77", "\x95\x78", "\x95\x79", "\xBD\xFA",
  /* U+664C */	"\xC9\xCE", "\x95\x7A", "\x95\x7B", "\xEA\xCC",
  /* U+6650 */	"\x95\x7C", "\x95\x7D", "\xC9\xB9", "\xCF\xFE",
  /* U+6654 */	"\xEA\xCA", "\xD4\xCE", "\xEA\xCD", "\xEA\xCF",
  /* U+6658 */	"\x95\x7E", "\x95\x80", "\xCD\xED", "\x95\x81",
  /* U+665C */	"\x95\x82", "\x95\x83", "\x95\x84", "\xEA\xC9",
  /* U+6660 */	"\x95\x85", "\xEA\xCE", "\x95\x86", "\x95\x87",
  /* U+6664 */	"\xCE\xEE", "\x95\x88", "\xBB\xDE", "\x95\x89",
  /* U+6668 */	"\xB3\xBF", "\x95\x8A", "\x95\x8B", "\x95\x8C",
  /* U+666C */	"\x95\x8D", "\x95\x8E", "\xC6\xD5", "\xBE\xB0",
  /* U+6670 */	"\xCE\xFA", "\x95\x8F", "\x95\x90", "\x95\x91",
  /* U+6674 */	"\xC7\xE7", "\x95\x92", "\xBE\xA7", "\xEA\xD0",
  /* U+6678 */	"\x95\x93", "\x95\x94", "\xD6\xC7", "\x95\x95",
  /* U+667C */	"\x95\x96", "\x95\x97", "\xC1\xC0", "\x95\x98",
  /* U+6680 */	"\x95\x99", "\x95\x9A", "\xD4\xDD", "\x95\x9B",
  /* U+6684 */	"\xEA\xD1", "\x95\x9C", "\x95\x9D", "\xCF\xBE",
  /* U+6688 */	"\x95\x9E", "\x95\x9F", "\x95\xA0", "\x95\xA1",
  /* U+668C */	"\xEA\xD2", "\x95\xA2", "\x95\xA3", "\x95\xA4",
  /* U+6690 */	"\x95\xA5", "\xCA\xEE", "\x95\xA6", "\x95\xA7",
  /* U+6694 */	"\x95\xA8", "\x95\xA9", "\xC5\xAF", "\xB0\xB5",
  /* U+6698 */	"\x95\xAA", "\x95\xAB", "\x95\xAC", "\x95\xAD",
  /* U+669C */	"\x95\xAE", "\xEA\xD4", "\x95\xAF", "\x95\xB0",
  /* U+66A0 */	"\x95\xB1", "\x95\xB2", "\x95\xB3", "\x95\xB4",
  /* U+66A4 */	"\x95\xB5", "\x95\xB6", "\x95\xB7", "\xEA\xD3",
  /* U+66A8 */	"\xF4\xDF", "\x95\xB8", "\x95\xB9", "\x95\xBA",
  /* U+66AC */	"\x95\xBB", "\x95\xBC", "\xC4\xBA", "\x95\xBD",
  /* U+66B0 */	"\x95\xBE", "\x95\xBF", "\x95\xC0", "\x95\xC1",
  /* U+66B4 */	"\xB1\xA9", "\x95\xC2", "\x95\xC3", "\x95\xC4",
  /* U+66B8 */	"\x95\xC5", "\xE5\xDF", "\x95\xC6", "\x95\xC7",
  /* U+66BC */	"\x95\xC8", "\x95\xC9", "\xEA\xD5", "\x95\xCA",
  /* U+66C0 */	"\x95\xCB", "\x95\xCC", "\x95\xCD", "\x95\xCE",
  /* U+66C4 */	"\x95\xCF", "\x95\xD0", "\x95\xD1", "\x95\xD2",
  /* U+66C8 */	"\x95\xD3", "\x95\xD4", "\x95\xD5", "\x95\xD6",
  /* U+66CC */	"\x95\xD7", "\x95\xD8", "\x95\xD9", "\x95\xDA",
  /* U+66D0 */	"\x95\xDB", "\x95\xDC", "\x95\xDD", "\x95\xDE",
  /* U+66D4 */	"\x95\xDF", "\x95\xE0", "\x95\xE1", "\x95\xE2",
  /* U+66D8 */	"\x95\xE3", "\xCA\xEF", "\x95\xE4", "\xEA\xD6",
  /* U+66DC */	"\xEA\xD7", "\xC6\xD8", "\x95\xE5", "\x95\xE6",
  /* U+66E0 */	"\x95\xE7", "\x95\xE8", "\x95\xE9", "\x95\xEA",
  /* U+66E4 */	"\x95\xEB", "\x95\xEC", "\xEA\xD8", "\x95\xED",
  /* U+66E8 */	"\x95\xEE", "\xEA\xD9", "\x95\xEF", "\x95\xF0",
  /* U+66EC */	"\x95\xF1", "\x95\xF2", "\x95\xF3", "\x95\xF4",
  /* U+66F0 */	"\xD4\xBB", "\x95\xF5", "\xC7\xFA", "\xD2\xB7",
  /* U+66F4 */	"\xB8\xFC", "\x95\xF6", "\x95\xF7", "\xEA\xC2",
  /* U+66F8 */	"\x95\xF8", "\xB2\xDC", "\x95\xF9", "\x95\xFA",
  /* U+66FC */	"\xC2\xFC", "\x95\xFB", "\xD4\xF8", "\xCC\xE6",
  /* U+6700 */	"\xD7\xEE", "\x95\xFC", "\x95\xFD", "\x95\xFE",
  /* U+6704 */	"\x96\x40", "\x96\x41", "\x96\x42", "\x96\x43",
  /* U+6708 */	"\xD4\xC2", "\xD3\xD0", "\xEB\xC3", "\xC5\xF3",
  /* U+670C */	"\x96\x44", "\xB7\xFE", "\x96\x45", "\x96\x46",
  /* U+6710 */	"\xEB\xD4", "\x96\x47", "\x96\x48", "\x96\x49",
  /* U+6714 */	"\xCB\xB7", "\xEB\xDE", "\x96\x4A", "\xC0\xCA",
  /* U+6718 */	"\x96\x4B", "\x96\x4C", "\x96\x4D", "\xCD\xFB",
  /* U+671C */	"\x96\x4E", "\xB3\xAF", "\x96\x4F", "\xC6\xDA",
  /* U+6720 */	"\x96\x50", "\x96\x51", "\x96\x52", "\x96\x53",
  /* U+6724 */	"\x96\x54", "\x96\x55", "\xEB\xFC", "\x96\x56",
  /* U+6728 */	"\xC4\xBE", "\x96\x57", "\xCE\xB4", "\xC4\xA9",
  /* U+672C */	"\xB1\xBE", "\xD4\xFD", "\x96\x58", "\xCA\xF5",
  /* U+6730 */	"\x96\x59", "\xD6\xEC", "\x96\x5A", "\x96\x5B",
  /* U+6734 */	"\xC6\xD3", "\xB6\xE4", "\x96\x5C", "\x96\x5D",
  /* U+6738 */	"\x96\x5E", "\x96\x5F", "\xBB\xFA", "\x96\x60",
  /* U+673C */	"\x96\x61", "\xD0\xE0", "\x96\x62", "\x96\x63",
  /* U+6740 */	"\xC9\xB1", "\x96\x64", "\xD4\xD3", "\xC8\xA8",
  /* U+6744 */	"\x96\x65", "\x96\x66", "\xB8\xCB", "\x96\x67",
  /* U+6748 */	"\xE8\xBE", "\xC9\xBC", "\x96\x68", "\x96\x69",
  /* U+674C */	"\xE8\xBB", "\x96\x6A", "\xC0\xEE", "\xD0\xD3",
  /* U+6750 */	"\xB2\xC4", "\xB4\xE5", "\x96\x6B", "\xE8\xBC",
  /* U+6754 */	"\x96\x6C", "\x96\x6D", "\xD5\xC8", "\x96\x6E",
  /* U+6758 */	"\x96\x6F", "\x96\x70", "\x96\x71", "\x96\x72",
  /* U+675C */	"\xB6\xC5", "\x96\x73", "\xE8\xBD", "\xCA\xF8",
  /* U+6760 */	"\xB8\xDC", "\xCC\xF5", "\x96\x74", "\x96\x75",
  /* U+6764 */	"\x96\x76", "\xC0\xB4", "\x96\x77", "\x96\x78",
  /* U+6768 */	"\xD1\xEE", "\xE8\xBF", "\xE8\xC2", "\x96\x79",
  /* U+676C */	"\x96\x7A", "\xBA\xBC", "\x96\x7B", "\xB1\xAD",
  /* U+6770 */	"\xBD\xDC", "\x96\x7C", "\xEA\xBD", "\xE8\xC3",
  /* U+6774 */	"\x96\x7D", "\xE8\xC6", "\x96\x7E", "\xE8\xCB",
  /* U+6778 */	"\x96\x80", "\x96\x81", "\x96\x82", "\x96\x83",
  /* U+677C */	"\xE8\xCC", "\x96\x84", "\xCB\xC9", "\xB0\xE5",
  /* U+6780 */	"\x96\x85", "\xBC\xAB", "\x96\x86", "\x96\x87",
  /* U+6784 */	"\xB9\xB9", "\x96\x88", "\x96\x89", "\xE8\xC1",
  /* U+6788 */	"\x96\x8A", "\xCD\xF7", "\x96\x8B", "\xE8\xCA",
  /* U+678C */	"\x96\x8C", "\x96\x8D", "\x96\x8E", "\x96\x8F",
  /* U+6790 */	"\xCE\xF6", "\x96\x90", "\x96\x91", "\x96\x92",
  /* U+6794 */	"\x96\x93", "\xD5\xED", "\x96\x94", "\xC1\xD6",
  /* U+6798 */	"\xE8\xC4", "\x96\x95", "\xC3\xB6", "\x96\x96",
  /* U+679C */	"\xB9\xFB", "\xD6\xA6", "\xE8\xC8", "\x96\x97",
  /* U+67A0 */	"\x96\x98", "\x96\x99", "\xCA\xE0", "\xD4\xE6",
  /* U+67A4 */	"\x96\x9A", "\xE8\xC0", "\x96\x9B", "\xE8\xC5",
  /* U+67A8 */	"\xE8\xC7", "\x96\x9C", "\xC7\xB9", "\xB7\xE3",
  /* U+67AC */	"\x96\x9D", "\xE8\xC9", "\x96\x9E", "\xBF\xDD",
  /* U+67B0 */	"\xE8\xD2", "\x96\x9F", "\x96\xA0", "\xE8\xD7",
  /* U+67B4 */	"\x96\xA1", "\xE8\xD5", "\xBC\xDC", "\xBC\xCF",
  /* U+67B8 */	"\xE8\xDB", "\x96\xA2", "\x96\xA3", "\x96\xA4",
  /* U+67BC */	"\x96\xA5", "\x96\xA6", "\x96\xA7", "\x96\xA8",
  /* U+67C0 */	"\x96\xA9", "\xE8\xDE", "\x96\xAA", "\xE8\xDA",
  /* U+67C4 */	"\xB1\xFA", "\x96\xAB", "\x96\xAC", "\x96\xAD",
  /* U+67C8 */	"\x96\xAE", "\x96\xAF", "\x96\xB0", "\x96\xB1",
  /* U+67CC */	"\x96\xB2", "\x96\xB3", "\x96\xB4", "\xB0\xD8",
  /* U+67D0 */	"\xC4\xB3", "\xB8\xCC", "\xC6\xE2", "\xC8\xBE",
  /* U+67D4 */	"\xC8\xE1", "\x96\xB5", "\x96\xB6", "\x96\xB7",
  /* U+67D8 */	"\xE8\xCF", "\xE8\xD4", "\xE8\xD6", "\x96\xB8",
  /* U+67DC */	"\xB9\xF1", "\xE8\xD8", "\xD7\xF5", "\x96\xB9",
  /* U+67E0 */	"\xC4\xFB", "\x96\xBA", "\xE8\xDC", "\x96\xBB",
  /* U+67E4 */	"\x96\xBC", "\xB2\xE9", "\x96\xBD", "\x96\xBE",
  /* U+67E8 */	"\x96\xBF", "\xE8\xD1", "\x96\xC0", "\x96\xC1",
  /* U+67EC */	"\xBC\xED", "\x96\xC2", "\x96\xC3", "\xBF\xC2",
  /* U+67F0 */	"\xE8\xCD", "\xD6\xF9", "\x96\xC4", "\xC1\xF8",
  /* U+67F4 */	"\xB2\xF1", "\x96\xC5", "\x96\xC6", "\x96\xC7",
  /* U+67F8 */	"\x96\xC8", "\x96\xC9", "\x96\xCA", "\x96\xCB",
  /* U+67FC */	"\x96\xCC", "\xE8\xDF", "\x96\xCD", "\xCA\xC1",
  /* U+6800 */	"\xE8\xD9", "\x96\xCE", "\x96\xCF", "\x96\xD0",
  /* U+6804 */	"\x96\xD1", "\xD5\xA4", "\x96\xD2", "\xB1\xEA",
  /* U+6808 */	"\xD5\xBB", "\xE8\xCE", "\xE8\xD0", "\xB6\xB0",
  /* U+680C */	"\xE8\xD3", "\x96\xD3", "\xE8\xDD", "\xC0\xB8",
  /* U+6810 */	"\x96\xD4", "\xCA\xF7", "\x96\xD5", "\xCB\xA8",
  /* U+6814 */	"\x96\xD6", "\x96\xD7", "\xC6\xDC", "\xC0\xF5",
  /* U+6818 */	"\x96\xD8", "\x96\xD9", "\x96\xDA", "\x96\xDB",
  /* U+681C */	"\x96\xDC", "\xE8\xE9", "\x96\xDD", "\x96\xDE",
  /* U+6820 */	"\x96\xDF", "\xD0\xA3", "\x96\xE0", "\x96\xE1",
  /* U+6824 */	"\x96\xE2", "\x96\xE3", "\x96\xE4", "\x96\xE5",
  /* U+6828 */	"\x96\xE6", "\xE8\xF2", "\xD6\xEA", "\x96\xE7",
  /* U+682C */	"\x96\xE8", "\x96\xE9", "\x96\xEA", "\x96\xEB",
  /* U+6830 */	"\x96\xEC", "\x96\xED", "\xE8\xE0", "\xE8\xE1",
  /* U+6834 */	"\x96\xEE", "\x96\xEF", "\x96\xF0", "\xD1\xF9",
  /* U+6838 */	"\xBA\xCB", "\xB8\xF9", "\x96\xF1", "\x96\xF2",
  /* U+683C */	"\xB8\xF1", "\xD4\xD4", "\xE8\xEF", "\x96\xF3",
  /* U+6840 */	"\xE8\xEE", "\xE8\xEC", "\xB9\xF0", "\xCC\xD2",
  /* U+6844 */	"\xE8\xE6", "\xCE\xA6", "\xBF\xF2", "\x96\xF4",
  /* U+6848 */	"\xB0\xB8", "\xE8\xF1", "\xE8\xF0", "\x96\xF5",
  /* U+684C */	"\xD7\xC0", "\x96\xF6", "\xE8\xE4", "\x96\xF7",
  /* U+6850 */	"\xCD\xA9", "\xC9\xA3", "\x96\xF8", "\xBB\xB8",
  /* U+6854 */	"\xBD\xDB", "\xE8\xEA", "\x96\xF9", "\x96\xFA",
  /* U+6858 */	"\x96\xFB", "\x96\xFC", "\x96\xFD", "\x96\xFE",
  /* U+685C */	"\x97\x40", "\x97\x41", "\x97\x42", "\x97\x43",
  /* U+6860 */	"\xE8\xE2", "\xE8\xE3", "\xE8\xE5", "\xB5\xB5",
  /* U+6864 */	"\xE8\xE7", "\xC7\xC5", "\xE8\xEB", "\xE8\xED",
  /* U+6868 */	"\xBD\xB0", "\xD7\xAE", "\x97\x44", "\xE8\xF8",
  /* U+686C */	"\x97\x45", "\x97\x46", "\x97\x47", "\x97\x48",
  /* U+6870 */	"\x97\x49", "\x97\x4A", "\x97\x4B", "\x97\x4C",
  /* U+6874 */	"\xE8\xF5", "\x97\x4D", "\xCD\xB0", "\xE8\xF6",
  /* U+6878 */	"\x97\x4E", "\x97\x4F", "\x97\x50", "\x97\x51",
  /* U+687C */	"\x97\x52", "\x97\x53", "\x97\x54", "\x97\x55",
  /* U+6880 */	"\x97\x56", "\xC1\xBA", "\x97\x57", "\xE8\xE8",
  /* U+6884 */	"\x97\x58", "\xC3\xB7", "\xB0\xF0", "\x97\x59",
  /* U+6888 */	"\x97\x5A", "\x97\x5B", "\x97\x5C", "\x97\x5D",
  /* U+688C */	"\x97\x5E", "\x97\x5F", "\x97\x60", "\xE8\xF4",
  /* U+6890 */	"\x97\x61", "\x97\x62", "\x97\x63", "\xE8\xF7",
  /* U+6894 */	"\x97\x64", "\x97\x65", "\x97\x66", "\xB9\xA3",
  /* U+6898 */	"\x97\x67", "\x97\x68", "\x97\x69", "\x97\x6A",
  /* U+689C */	"\x97\x6B", "\x97\x6C", "\x97\x6D", "\x97\x6E",
  /* U+68A0 */	"\x97\x6F", "\x97\x70", "\xC9\xD2", "\x97\x71",
  /* U+68A4 */	"\x97\x72", "\x97\x73", "\xC3\xCE", "\xCE\xE0",
  /* U+68A8 */	"\xC0\xE6", "\x97\x74", "\x97\x75", "\x97\x76",
  /* U+68AC */	"\x97\x77", "\xCB\xF3", "\x97\x78", "\xCC\xDD",
  /* U+68B0 */	"\xD0\xB5", "\x97\x79", "\x97\x7A", "\xCA\xE1",
  /* U+68B4 */	"\x97\x7B", "\xE8\xF3", "\x97\x7C", "\x97\x7D",
  /* U+68B8 */	"\x97\x7E", "\x97\x80", "\x97\x81", "\x97\x82",
  /* U+68BC */	"\x97\x83", "\x97\x84", "\x97\x85", "\x97\x86",
  /* U+68C0 */	"\xBC\xEC", "\x97\x87", "\xE8\xF9", "\x97\x88",
  /* U+68C4 */	"\x97\x89", "\x97\x8A", "\x97\x8B", "\x97\x8C",
  /* U+68C8 */	"\x97\x8D", "\xC3\xDE", "\x97\x8E", "\xC6\xE5",
  /* U+68CC */	"\x97\x8F", "\xB9\xF7", "\x97\x90", "\x97\x91",
  /* U+68D0 */	"\x97\x92", "\x97\x93", "\xB0\xF4", "\x97\x94",
  /* U+68D4 */	"\x97\x95", "\xD7\xD8", "\x97\x96", "\x97\x97",
  /* U+68D8 */	"\xBC\xAC", "\x97\x98", "\xC5\xEF", "\x97\x99",
  /* U+68DC */	"\x97\x9A", "\x97\x9B", "\x97\x9C", "\x97\x9D",
  /* U+68E0 */	"\xCC\xC4", "\x97\x9E", "\x97\x9F", "\xE9\xA6",
  /* U+68E4 */	"\x97\xA0", "\x97\xA1", "\x97\xA2", "\x97\xA3",
  /* U+68E8 */	"\x97\xA4", "\x97\xA5", "\x97\xA6", "\x97\xA7",
  /* U+68EC */	"\x97\xA8", "\x97\xA9", "\xC9\xAD", "\x97\xAA",
  /* U+68F0 */	"\xE9\xA2", "\xC0\xE2", "\x97\xAB", "\x97\xAC",
  /* U+68F4 */	"\x97\xAD", "\xBF\xC3", "\x97\xAE", "\x97\xAF",
  /* U+68F8 */	"\x97\xB0", "\xE8\xFE", "\xB9\xD7", "\x97\xB1",
  /* U+68FC */	"\xE8\xFB", "\x97\xB2", "\x97\xB3", "\x97\xB4",
  /* U+6900 */	"\x97\xB5", "\xE9\xA4", "\x97\xB6", "\x97\xB7",
  /* U+6904 */	"\x97\xB8", "\xD2\xCE", "\x97\xB9", "\x97\xBA",
  /* U+6908 */	"\x97\xBB", "\x97\xBC", "\x97\xBD", "\xE9\xA3",
  /* U+690C */	"\x97\xBE", "\xD6\xB2", "\xD7\xB5", "\x97\xBF",
  /* U+6910 */	"\xE9\xA7", "\x97\xC0", "\xBD\xB7", "\x97\xC1",
  /* U+6914 */	"\x97\xC2", "\x97\xC3", "\x97\xC4", "\x97\xC5",
  /* U+6918 */	"\x97\xC6", "\x97\xC7", "\x97\xC8", "\x97\xC9",
  /* U+691C */	"\x97\xCA", "\x97\xCB", "\x97\xCC", "\xE8\xFC",
  /* U+6920 */	"\xE8\xFD", "\x97\xCD", "\x97\xCE", "\x97\xCF",
  /* U+6924 */	"\xE9\xA1", "\x97\xD0", "\x97\xD1", "\x97\xD2",
  /* U+6928 */	"\x97\xD3", "\x97\xD4", "\x97\xD5", "\x97\xD6",
  /* U+692C */	"\x97\xD7", "\xCD\xD6", "\x97\xD8", "\x97\xD9",
  /* U+6930 */	"\xD2\xAC", "\x97\xDA", "\x97\xDB", "\x97\xDC",
  /* U+6934 */	"\xE9\xB2", "\x97\xDD", "\x97\xDE", "\x97\xDF",
  /* U+6938 */	"\x97\xE0", "\xE9\xA9", "\x97\xE1", "\x97\xE2",
  /* U+693C */	"\x97\xE3", "\xB4\xAA", "\x97\xE4", "\xB4\xBB",
  /* U+6940 */	"\x97\xE5", "\x97\xE6", "\xE9\xAB", "\x97\xE7",
  /* U+6944 */	"\x97\xE8", "\x97\xE9", "\x97\xEA", "\x97\xEB",
  /* U+6948 */	"\x97\xEC", "\x97\xED", "\x97\xEE", "\x97\xEF",
  /* U+694C */	"\x97\xF0", "\x97\xF1", "\x97\xF2", "\x97\xF3",
  /* U+6950 */	"\x97\xF4", "\x97\xF5", "\x97\xF6", "\x97\xF7",
  /* U+6954 */	"\xD0\xA8", "\x97\xF8", "\x97\xF9", "\xE9\xA5",
  /* U+6958 */	"\x97\xFA", "\x97\xFB", "\xB3\xFE", "\x97\xFC",
  /* U+695C */	"\x97\xFD", "\xE9\xAC", "\xC0\xE3", "\x97\xFE",
  /* U+6960 */	"\xE9\xAA", "\x98\x40", "\x98\x41", "\xE9\xB9",
  /* U+6964 */	"\x98\x42", "\x98\x43", "\xE9\xB8", "\x98\x44",
  /* U+6968 */	"\x98\x45", "\x98\x46", "\x98\x47", "\xE9\xAE",
  /* U+696C */	"\x98\x48", "\x98\x49", "\xE8\xFA", "\x98\x4A",
  /* U+6970 */	"\x98\x4B", "\xE9\xA8", "\x98\x4C", "\x98\x4D",
  /* U+6974 */	"\x98\x4E", "\x98\x4F", "\x98\x50", "\xBF\xAC",
  /* U+6978 */	"\xE9\xB1", "\xE9\xBA", "\x98\x51", "\x98\x52",
  /* U+697C */	"\xC2\xA5", "\x98\x53", "\x98\x54", "\x98\x55",
  /* U+6980 */	"\xE9\xAF", "\x98\x56", "\xB8\xC5", "\x98\x57",
  /* U+6984 */	"\xE9\xAD", "\x98\x58", "\xD3\xDC", "\xE9\xB4",
  /* U+6988 */	"\xE9\xB5", "\xE9\xB7", "\x98\x59", "\x98\x5A",
  /* U+698C */	"\x98\x5B", "\xE9\xC7", "\x98\x5C", "\x98\x5D",
  /* U+6990 */	"\x98\x5E", "\x98\x5F", "\x98\x60", "\x98\x61",
  /* U+6994 */	"\xC0\xC6", "\xE9\xC5", "\x98\x62", "\x98\x63",
  /* U+6998 */	"\xE9\xB0", "\x98\x64", "\x98\x65", "\xE9\xBB",
  /* U+699C */	"\xB0\xF1", "\x98\x66", "\x98\x67", "\x98\x68",
  /* U+69A0 */	"\x98\x69", "\x98\x6A", "\x98\x6B", "\x98\x6C",
  /* U+69A4 */	"\x98\x6D", "\x98\x6E", "\x98\x6F", "\xE9\xBC",
  /* U+69A8 */	"\xD5\xA5", "\x98\x70", "\x98\x71", "\xE9\xBE",
  /* U+69AC */	"\x98\x72", "\xE9\xBF", "\x98\x73", "\x98\x74",
  /* U+69B0 */	"\x98\x75", "\xE9\xC1", "\x98\x76", "\x98\x77",
  /* U+69B4 */	"\xC1\xF1", "\x98\x78", "\x98\x79", "\xC8\xB6",
  /* U+69B8 */	"\x98\x7A", "\x98\x7B", "\x98\x7C", "\xE9\xBD",
  /* U+69BC */	"\x98\x7D", "\x98\x7E", "\x98\x80", "\x98\x81",
  /* U+69C0 */	"\x98\x82", "\xE9\xC2", "\x98\x83", "\x98\x84",
  /* U+69C4 */	"\x98\x85", "\x98\x86", "\x98\x87", "\x98\x88",
  /* U+69C8 */	"\x98\x89", "\x98\x8A", "\xE9\xC3", "\x98\x8B",
  /* U+69CC */	"\xE9\xB3", "\x98\x8C", "\xE9\xB6", "\x98\x8D",
  /* U+69D0 */	"\xBB\xB1", "\x98\x8E", "\x98\x8F", "\x98\x90",
  /* U+69D4 */	"\xE9\xC0", "\x98\x91", "\x98\x92", "\x98\x93",
  /* U+69D8 */	"\x98\x94", "\x98\x95", "\x98\x96", "\xBC\xF7",
  /* U+69DC */	"\x98\x97", "\x98\x98", "\x98\x99", "\xE9\xC4",
  /* U+69E0 */	"\xE9\xC6", "\x98\x9A", "\x98\x9B", "\x98\x9C",
  /* U+69E4 */	"\x98\x9D", "\x98\x9E", "\x98\x9F", "\x98\xA0",
  /* U+69E8 */	"\x98\xA1", "\x98\xA2", "\x98\xA3", "\x98\xA4",
  /* U+69EC */	"\x98\xA5", "\xE9\xCA", "\x98\xA6", "\x98\xA7",
  /* U+69F0 */	"\x98\xA8", "\x98\xA9", "\xE9\xCE", "\x98\xAA",
  /* U+69F4 */	"\x98\xAB", "\x98\xAC", "\x98\xAD", "\x98\xAE",
  /* U+69F8 */	"\x98\xAF", "\x98\xB0", "\x98\xB1", "\x98\xB2",
  /* U+69FC */	"\x98\xB3", "\xB2\xDB", "\x98\xB4", "\xE9\xC8",
  /* U+6A00 */	"\x98\xB5", "\x98\xB6", "\x98\xB7", "\x98\xB8",
  /* U+6A04 */	"\x98\xB9", "\x98\xBA", "\x98\xBB", "\x98\xBC",
  /* U+6A08 */	"\x98\xBD", "\x98\xBE", "\xB7\xAE", "\x98\xBF",
  /* U+6A0C */	"\x98\xC0", "\x98\xC1", "\x98\xC2", "\x98\xC3",
  /* U+6A10 */	"\x98\xC4", "\x98\xC5", "\x98\xC6", "\x98\xC7",
  /* U+6A14 */	"\x98\xC8", "\x98\xC9", "\x98\xCA", "\xE9\xCB",
  /* U+6A18 */	"\xE9\xCC", "\x98\xCB", "\x98\xCC", "\x98\xCD",
  /* U+6A1C */	"\x98\xCE", "\x98\xCF", "\x98\xD0", "\xD5\xC1",
  /* U+6A20 */	"\x98\xD1", "\xC4\xA3", "\x98\xD2", "\x98\xD3",
  /* U+6A24 */	"\x98\xD4", "\x98\xD5", "\x98\xD6", "\x98\xD7",
  /* U+6A28 */	"\xE9\xD8", "\x98\xD8", "\xBA\xE1", "\x98\xD9",
  /* U+6A2C */	"\x98\xDA", "\x98\xDB", "\x98\xDC", "\xE9\xC9",
  /* U+6A30 */	"\x98\xDD", "\xD3\xA3", "\x98\xDE", "\x98\xDF",
  /* U+6A34 */	"\x98\xE0", "\xE9\xD4", "\x98\xE1", "\x98\xE2",
  /* U+6A38 */	"\x98\xE3", "\x98\xE4", "\x98\xE5", "\x98\xE6",
  /* U+6A3C */	"\x98\xE7", "\xE9\xD7", "\xE9\xD0", "\x98\xE8",
  /* U+6A40 */	"\x98\xE9", "\x98\xEA", "\x98\xEB", "\x98\xEC",
  /* U+6A44 */	"\xE9\xCF", "\x98\xED", "\x98\xEE", "\xC7\xC1",
  /* U+6A48 */	"\x98\xEF", "\x98\xF0", "\x98\xF1", "\x98\xF2",
  /* U+6A4C */	"\x98\xF3", "\x98\xF4", "\x98\xF5", "\x98\xF6",
  /* U+6A50 */	"\xE9\xD2", "\x98\xF7", "\x98\xF8", "\x98\xF9",
  /* U+6A54 */	"\x98\xFA", "\x98\xFB", "\x98\xFC", "\x98\xFD",
  /* U+6A58 */	"\xE9\xD9", "\xB3\xC8", "\x98\xFE", "\xE9\xD3",
  /* U+6A5C */	"\x99\x40", "\x99\x41", "\x99\x42", "\x99\x43",
  /* U+6A60 */	"\x99\x44", "\xCF\xF0", "\x99\x45", "\x99\x46",
  /* U+6A64 */	"\x99\x47", "\xE9\xCD", "\x99\x48", "\x99\x49",
  /* U+6A68 */	"\x99\x4A", "\x99\x4B", "\x99\x4C", "\x99\x4D",
  /* U+6A6C */	"\x99\x4E", "\x99\x4F", "\x99\x50", "\x99\x51",
  /* U+6A70 */	"\x99\x52", "\xB3\xF7", "\x99\x53", "\x99\x54",
  /* U+6A74 */	"\x99\x55", "\x99\x56", "\x99\x57", "\x99\x58",
  /* U+6A78 */	"\x99\x59", "\xE9\xD6", "\x99\x5A", "\x99\x5B",
  /* U+6A7C */	"\xE9\xDA", "\x99\x5C", "\x99\x5D", "\x99\x5E",
  /* U+6A80 */	"\xCC\xB4", "\x99\x5F", "\x99\x60", "\x99\x61",
  /* U+6A84 */	"\xCF\xAD", "\x99\x62", "\x99\x63", "\x99\x64",
  /* U+6A88 */	"\x99\x65", "\x99\x66", "\x99\x67", "\x99\x68",
  /* U+6A8C */	"\x99\x69", "\x99\x6A", "\xE9\xD5", "\x99\x6B",
  /* U+6A90 */	"\xE9\xDC", "\xE9\xDB", "\x99\x6C", "\x99\x6D",
  /* U+6A94 */	"\x99\x6E", "\x99\x6F", "\x99\x70", "\xE9\xDE",
  /* U+6A98 */	"\x99\x71", "\x99\x72", "\x99\x73", "\x99\x74",
  /* U+6A9C */	"\x99\x75", "\x99\x76", "\x99\x77", "\x99\x78",
  /* U+6AA0 */	"\xE9\xD1", "\x99\x79", "\x99\x7A", "\x99\x7B",
  /* U+6AA4 */	"\x99\x7C", "\x99\x7D", "\x99\x7E", "\x99\x80",
  /* U+6AA8 */	"\x99\x81", "\xE9\xDD", "\x99\x82", "\xE9\xDF",
  /* U+6AAC */	"\xC3\xCA", "\x99\x83", "\x99\x84", "\x99\x85",
  /* U+6AB0 */	"\x99\x86", "\x99\x87", "\x99\x88", "\x99\x89",
  /* U+6AB4 */	"\x99\x8A", "\x99\x8B", "\x99\x8C", "\x99\x8D",
  /* U+6AB8 */	"\x99\x8E", "\x99\x8F", "\x99\x90", "\x99\x91",
  /* U+6ABC */	"\x99\x92", "\x99\x93", "\x99\x94", "\x99\x95",
  /* U+6AC0 */	"\x99\x96", "\x99\x97", "\x99\x98", "\x99\x99",
  /* U+6AC4 */	"\x99\x9A", "\x99\x9B", "\x99\x9C", "\x99\x9D",
  /* U+6AC8 */	"\x99\x9E", "\x99\x9F", "\x99\xA0", "\x99\xA1",
  /* U+6ACC */	"\x99\xA2", "\x99\xA3", "\x99\xA4", "\x99\xA5",
  /* U+6AD0 */	"\x99\xA6", "\x99\xA7", "\x99\xA8", "\x99\xA9",
  /* U+6AD4 */	"\x99\xAA", "\x99\xAB", "\x99\xAC", "\x99\xAD",
  /* U+6AD8 */	"\x99\xAE", "\x99\xAF", "\x99\xB0", "\x99\xB1",
  /* U+6ADC */	"\x99\xB2", "\x99\xB3", "\x99\xB4", "\x99\xB5",
  /* U+6AE0 */	"\x99\xB6", "\x99\xB7", "\x99\xB8", "\x99\xB9",
  /* U+6AE4 */	"\x99\xBA", "\x99\xBB", "\x99\xBC", "\x99\xBD",
  /* U+6AE8 */	"\x99\xBE", "\x99\xBF", "\x99\xC0", "\x99\xC1",
  /* U+6AEC */	"\x99\xC2", "\x99\xC3", "\x99\xC4", "\x99\xC5",
  /* U+6AF0 */	"\x99\xC6", "\x99\xC7", "\x99\xC8", "\x99\xC9",
  /* U+6AF4 */	"\x99\xCA", "\x99\xCB", "\x99\xCC", "\x99\xCD",
  /* U+6AF8 */	"\x99\xCE", "\x99\xCF", "\x99\xD0", "\x99\xD1",
  /* U+6AFC */	"\x99\xD2", "\x99\xD3", "\x99\xD4", "\x99\xD5",
  /* U+6B00 */	"\x99\xD6", "\x99\xD7", "\x99\xD8", "\x99\xD9",
  /* U+6B04 */	"\x99\xDA", "\x99\xDB", "\x99\xDC", "\x99\xDD",
  /* U+6B08 */	"\x99\xDE", "\x99\xDF", "\x99\xE0", "\x99\xE1",
  /* U+6B0C */	"\x99\xE2", "\x99\xE3", "\x99\xE4", "\x99\xE5",
  /* U+6B10 */	"\x99\xE6", "\x99\xE7", "\x99\xE8", "\x99\xE9",
  /* U+6B14 */	"\x99\xEA", "\x99\xEB", "\x99\xEC", "\x99\xED",
  /* U+6B18 */	"\x99\xEE", "\x99\xEF", "\x99\xF0", "\x99\xF1",
  /* U+6B1C */	"\x99\xF2", "\x99\xF3", "\x99\xF4", "\x99\xF5",
  /* U+6B20 */	"\xC7\xB7", "\xB4\xCE", "\xBB\xB6", "\xD0\xC0",
  /* U+6B24 */	"\xEC\xA3", "\x99\xF6", "\x99\xF7", "\xC5\xB7",
  /* U+6B28 */	"\x99\xF8", "\x99\xF9", "\x99\xFA", "\x99\xFB",
  /* U+6B2C */	"\x99\xFC", "\x99\xFD", "\x99\xFE", "\x9A\x40",
  /* U+6B30 */	"\x9A\x41", "\x9A\x42", "\xD3\xFB", "\x9A\x43",
  /* U+6B34 */	"\x9A\x44", "\x9A\x45", "\x9A\x46", "\xEC\xA4",
  /* U+6B38 */	"\x9A\x47", "\xEC\xA5", "\xC6\xDB", "\x9A\x48",
  /* U+6B3C */	"\x9A\x49", "\x9A\x4A", "\xBF\xEE", "\x9A\x4B",
  /* U+6B40 */	"\x9A\x4C", "\x9A\x4D", "\x9A\x4E", "\xEC\xA6",
  /* U+6B44 */	"\x9A\x4F", "\x9A\x50", "\xEC\xA7", "\xD0\xAA",
  /* U+6B48 */	"\x9A\x51", "\xC7\xB8", "\x9A\x52", "\x9A\x53",
  /* U+6B4C */	"\xB8\xE8", "\x9A\x54", "\x9A\x55", "\x9A\x56",
  /* U+6B50 */	"\x9A\x57", "\x9A\x58", "\x9A\x59", "\x9A\x5A",
  /* U+6B54 */	"\x9A\x5B", "\x9A\x5C", "\x9A\x5D", "\x9A\x5E",
  /* U+6B58 */	"\x9A\x5F", "\xEC\xA8", "\x9A\x60", "\x9A\x61",
  /* U+6B5C */	"\x9A\x62", "\x9A\x63", "\x9A\x64", "\x9A\x65",
  /* U+6B60 */	"\x9A\x66", "\x9A\x67", "\xD6\xB9", "\xD5\xFD",
  /* U+6B64 */	"\xB4\xCB", "\xB2\xBD", "\xCE\xE4", "\xC6\xE7",
  /* U+6B68 */	"\x9A\x68", "\x9A\x69", "\xCD\xE1", "\x9A\x6A",
  /* U+6B6C */	"\x9A\x6B", "\x9A\x6C", "\x9A\x6D", "\x9A\x6E",
  /* U+6B70 */	"\x9A\x6F", "\x9A\x70", "\x9A\x71", "\x9A\x72",
  /* U+6B74 */	"\x9A\x73", "\x9A\x74", "\x9A\x75", "\x9A\x76",
  /* U+6B78 */	"\x9A\x77", "\xB4\xF5", "\x9A\x78", "\xCB\xC0",
  /* U+6B7C */	"\xBC\xDF", "\x9A\x79", "\x9A\x7A", "\x9A\x7B",
  /* U+6B80 */	"\x9A\x7C", "\xE9\xE2", "\xE9\xE3", "\xD1\xEA",
  /* U+6B84 */	"\xE9\xE5", "\x9A\x7D", "\xB4\xF9", "\xE9\xE4",
  /* U+6B88 */	"\x9A\x7E", "\xD1\xB3", "\xCA\xE2", "\xB2\xD0",
  /* U+6B8C */	"\x9A\x80", "\xE9\xE8", "\x9A\x81", "\x9A\x82",
  /* U+6B90 */	"\x9A\x83", "\x9A\x84", "\xE9\xE6", "\xE9\xE7",
  /* U+6B94 */	"\x9A\x85", "\x9A\x86", "\xD6\xB3", "\x9A\x87",
  /* U+6B98 */	"\x9A\x88", "\x9A\x89", "\xE9\xE9", "\xE9\xEA",
  /* U+6B9C */	"\x9A\x8A", "\x9A\x8B", "\x9A\x8C", "\x9A\x8D",
  /* U+6BA0 */	"\x9A\x8E", "\xE9\xEB", "\x9A\x8F", "\x9A\x90",
  /* U+6BA4 */	"\x9A\x91", "\x9A\x92", "\x9A\x93", "\x9A\x94",
  /* U+6BA8 */	"\x9A\x95", "\x9A\x96", "\xE9\xEC", "\x9A\x97",
  /* U+6BAC */	"\x9A\x98", "\x9A\x99", "\x9A\x9A", "\x9A\x9B",
  /* U+6BB0 */	"\x9A\x9C", "\x9A\x9D", "\x9A\x9E", "\xEC\xAF",
  /* U+6BB4 */	"\xC5\xB9", "\xB6\xCE", "\x9A\x9F", "\xD2\xF3",
  /* U+6BB8 */	"\x9A\xA0", "\x9A\xA1", "\x9A\xA2", "\x9A\xA3",
  /* U+6BBC */	"\x9A\xA4", "\x9A\xA5", "\x9A\xA6", "\xB5\xEE",
  /* U+6BC0 */	"\x9A\xA7", "\xBB\xD9", "\xEC\xB1", "\x9A\xA8",
  /* U+6BC4 */	"\x9A\xA9", "\xD2\xE3", "\x9A\xAA", "\x9A\xAB",
  /* U+6BC8 */	"\x9A\xAC", "\x9A\xAD", "\x9A\xAE", "\xCE\xE3",
  /* U+6BCC */	"\x9A\xAF", "\xC4\xB8", "\x9A\xB0", "\xC3\xBF",
  /* U+6BD0 */	"\x9A\xB1", "\x9A\xB2", "\xB6\xBE", "\xD8\xB9",
  /* U+6BD4 */	"\xB1\xC8", "\xB1\xCF", "\xB1\xD1", "\xC5\xFE",
  /* U+6BD8 */	"\x9A\xB3", "\xB1\xD0", "\x9A\xB4", "\xC3\xAB",
  /* U+6BDC */	"\x9A\xB5", "\x9A\xB6", "\x9A\xB7", "\x9A\xB8",
  /* U+6BE0 */	"\x9A\xB9", "\xD5\xB1", "\x9A\xBA", "\x9A\xBB",
  /* U+6BE4 */	"\x9A\xBC", "\x9A\xBD", "\x9A\xBE", "\x9A\xBF",
  /* U+6BE8 */	"\x9A\xC0", "\x9A\xC1", "\xEB\xA4", "\xBA\xC1",
  /* U+6BEC */	"\x9A\xC2", "\x9A\xC3", "\x9A\xC4", "\xCC\xBA",
  /* U+6BF0 */	"\x9A\xC5", "\x9A\xC6", "\x9A\xC7", "\xEB\xA5",
  /* U+6BF4 */	"\x9A\xC8", "\xEB\xA7", "\x9A\xC9", "\x9A\xCA",
  /* U+6BF8 */	"\x9A\xCB", "\xEB\xA8", "\x9A\xCC", "\x9A\xCD",
  /* U+6BFC */	"\x9A\xCE", "\xEB\xA6", "\x9A\xCF", "\x9A\xD0",
  /* U+6C00 */	"\x9A\xD1", "\x9A\xD2", "\x9A\xD3", "\x9A\xD4",
  /* U+6C04 */	"\x9A\xD5", "\xEB\xA9", "\xEB\xAB", "\xEB\xAA",
  /* U+6C08 */	"\x9A\xD6", "\x9A\xD7", "\x9A\xD8", "\x9A\xD9",
  /* U+6C0C */	"\x9A\xDA", "\xEB\xAC", "\x9A\xDB", "\xCA\xCF",
  /* U+6C10 */	"\xD8\xB5", "\xC3\xF1", "\x9A\xDC", "\xC3\xA5",
  /* U+6C14 */	"\xC6\xF8", "\xEB\xAD", "\xC4\xCA", "\x9A\xDD",
  /* U+6C18 */	"\xEB\xAE", "\xEB\xAF", "\xEB\xB0", "\xB7\xD5",
  /* U+6C1C */	"\x9A\xDE", "\x9A\xDF", "\x9A\xE0", "\xB7\xFA",
  /* U+6C20 */	"\x9A\xE1", "\xEB\xB1", "\xC7\xE2", "\x9A\xE2",
  /* U+6C24 */	"\xEB\xB3", "\x9A\xE3", "\xBA\xA4", "\xD1\xF5",
  /* U+6C28 */	"\xB0\xB1", "\xEB\xB2", "\xEB\xB4", "\x9A\xE4",
  /* U+6C2C */	"\x9A\xE5", "\x9A\xE6", "\xB5\xAA", "\xC2\xC8",
  /* U+6C30 */	"\xC7\xE8", "\x9A\xE7", "\xEB\xB5", "\x9A\xE8",
  /* U+6C34 */	"\xCB\xAE", "\xE3\xDF", "\x9A\xE9", "\x9A\xEA",
  /* U+6C38 */	"\xD3\xC0", "\x9A\xEB", "\x9A\xEC", "\x9A\xED",
  /* U+6C3C */	"\x9A\xEE", "\xD9\xDB", "\x9A\xEF", "\x9A\xF0",
  /* U+6C40 */	"\xCD\xA1", "\xD6\xAD", "\xC7\xF3", "\x9A\xF1",
  /* U+6C44 */	"\x9A\xF2", "\x9A\xF3", "\xD9\xE0", "\xBB\xE3",
  /* U+6C48 */	"\x9A\xF4", "\xBA\xBA", "\xE3\xE2", "\x9A\xF5",
  /* U+6C4C */	"\x9A\xF6", "\x9A\xF7", "\x9A\xF8", "\x9A\xF9",
  /* U+6C50 */	"\xCF\xAB", "\x9A\xFA", "\x9A\xFB", "\x9A\xFC",
  /* U+6C54 */	"\xE3\xE0", "\xC9\xC7", "\x9A\xFD", "\xBA\xB9",
  /* U+6C58 */	"\x9A\xFE", "\x9B\x40", "\x9B\x41", "\xD1\xB4",
  /* U+6C5C */	"\xE3\xE1", "\xC8\xEA", "\xB9\xAF", "\xBD\xAD",
  /* U+6C60 */	"\xB3\xD8", "\xCE\xDB", "\x9B\x42", "\x9B\x43",
  /* U+6C64 */	"\xCC\xC0", "\x9B\x44", "\x9B\x45", "\x9B\x46",
  /* U+6C68 */	"\xE3\xE8", "\xE3\xE9", "\xCD\xF4", "\x9B\x47",
  /* U+6C6C */	"\x9B\x48", "\x9B\x49", "\x9B\x4A", "\x9B\x4B",
  /* U+6C70 */	"\xCC\xAD", "\x9B\x4C", "\xBC\xB3", "\x9B\x4D",
  /* U+6C74 */	"\xE3\xEA", "\x9B\x4E", "\xE3\xEB", "\x9B\x4F",
  /* U+6C78 */	"\x9B\x50", "\xD0\xDA", "\x9B\x51", "\x9B\x52",
  /* U+6C7C */	"\x9B\x53", "\xC6\xFB", "\xB7\xDA", "\x9B\x54",
  /* U+6C80 */	"\x9B\x55", "\xC7\xDF", "\xD2\xCA", "\xCE\xD6",
  /* U+6C84 */	"\x9B\x56", "\xE3\xE4", "\xE3\xEC", "\x9B\x57",
  /* U+6C88 */	"\xC9\xF2", "\xB3\xC1", "\x9B\x58", "\x9B\x59",
  /* U+6C8C */	"\xE3\xE7", "\x9B\x5A", "\x9B\x5B", "\xC6\xE3",
  /* U+6C90 */	"\xE3\xE5", "\x9B\x5C", "\x9B\x5D", "\xED\xB3",
  /* U+6C94 */	"\xE3\xE6", "\x9B\x5E", "\x9B\x5F", "\x9B\x60",
  /* U+6C98 */	"\x9B\x61", "\xC9\xB3", "\x9B\x62", "\xC5\xE6",
  /* U+6C9C */	"\x9B\x63", "\x9B\x64", "\x9B\x65", "\xB9\xB5",
  /* U+6CA0 */	"\x9B\x66", "\xC3\xBB", "\x9B\x67", "\xE3\xE3",
  /* U+6CA4 */	"\xC5\xBD", "\xC1\xA4", "\xC2\xD9", "\xB2\xD7",
  /* U+6CA8 */	"\x9B\x68", "\xE3\xED", "\xBB\xA6", "\xC4\xAD",
  /* U+6CAC */	"\x9B\x69", "\xE3\xF0", "\xBE\xDA", "\x9B\x6A",
  /* U+6CB0 */	"\x9B\x6B", "\xE3\xFB", "\xE3\xF5", "\xBA\xD3",
  /* U+6CB4 */	"\x9B\x6C", "\x9B\x6D", "\x9B\x6E", "\x9B\x6F",
  /* U+6CB8 */	"\xB7\xD0", "\xD3\xCD", "\x9B\x70", "\xD6\xCE",
  /* U+6CBC */	"\xD5\xD3", "\xB9\xC1", "\xD5\xB4", "\xD1\xD8",
  /* U+6CC0 */	"\x9B\x71", "\x9B\x72", "\x9B\x73", "\x9B\x74",
  /* U+6CC4 */	"\xD0\xB9", "\xC7\xF6", "\x9B\x75", "\x9B\x76",
  /* U+6CC8 */	"\x9B\x77", "\xC8\xAA", "\xB2\xB4", "\x9B\x78",
  /* U+6CCC */	"\xC3\xDA", "\x9B\x79", "\x9B\x7A", "\x9B\x7B",
  /* U+6CD0 */	"\xE3\xEE", "\x9B\x7C", "\x9B\x7D", "\xE3\xFC",
  /* U+6CD4 */	"\xE3\xEF", "\xB7\xA8", "\xE3\xF7", "\xE3\xF4",
  /* U+6CD8 */	"\x9B\x7E", "\x9B\x80", "\x9B\x81", "\xB7\xBA",
  /* U+6CDC */	"\x9B\x82", "\x9B\x83", "\xC5\xA2", "\x9B\x84",
  /* U+6CE0 */	"\xE3\xF6", "\xC5\xDD", "\xB2\xA8", "\xC6\xFC",
  /* U+6CE4 */	"\x9B\x85", "\xC4\xE0", "\x9B\x86", "\x9B\x87",
  /* U+6CE8 */	"\xD7\xA2", "\x9B\x88", "\xC0\xE1", "\xE3\xF9",
  /* U+6CEC */	"\x9B\x89", "\x9B\x8A", "\xE3\xFA", "\xE3\xFD",
  /* U+6CF0 */	"\xCC\xA9", "\xE3\xF3", "\x9B\x8B", "\xD3\xBE",
  /* U+6CF4 */	"\x9B\x8C", "\xB1\xC3", "\xED\xB4", "\xE3\xF1",
  /* U+6CF8 */	"\xE3\xF2", "\x9B\x8D", "\xE3\xF8", "\xD0\xBA",
  /* U+6CFC */	"\xC6\xC3", "\xD4\xF3", "\xE3\xFE", "\x9B\x8E",
  /* U+6D00 */	"\x9B\x8F", "\xBD\xE0", "\x9B\x90", "\x9B\x91",
  /* U+6D04 */	"\xE4\xA7", "\x9B\x92", "\x9B\x93", "\xE4\xA6",
  /* U+6D08 */	"\x9B\x94", "\x9B\x95", "\x9B\x96", "\xD1\xF3",
  /* U+6D0C */	"\xE4\xA3", "\x9B\x97", "\xE4\xA9", "\x9B\x98",
  /* U+6D10 */	"\x9B\x99", "\x9B\x9A", "\xC8\xF7", "\x9B\x9B",
  /* U+6D14 */	"\x9B\x9C", "\x9B\x9D", "\x9B\x9E", "\xCF\xB4",
  /* U+6D18 */	"\x9B\x9F", "\xE4\xA8", "\xE4\xAE", "\xC2\xE5",
  /* U+6D1C */	"\x9B\xA0", "\x9B\xA1", "\xB6\xB4", "\x9B\xA2",
  /* U+6D20 */	"\x9B\xA3", "\x9B\xA4", "\x9B\xA5", "\x9B\xA6",
  /* U+6D24 */	"\x9B\xA7", "\xBD\xF2", "\x9B\xA8", "\xE4\xA2",
  /* U+6D28 */	"\x9B\xA9", "\x9B\xAA", "\xBA\xE9", "\xE4\xAA",
  /* U+6D2C */	"\x9B\xAB", "\x9B\xAC", "\xE4\xAC", "\x9B\xAD",
  /* U+6D30 */	"\x9B\xAE", "\xB6\xFD", "\xD6\xDE", "\xE4\xB2",
  /* U+6D34 */	"\x9B\xAF", "\xE4\xAD", "\x9B\xB0", "\x9B\xB1",
  /* U+6D38 */	"\x9B\xB2", "\xE4\xA1", "\x9B\xB3", "\xBB\xEE",
  /* U+6D3C */	"\xCD\xDD", "\xC7\xA2", "\xC5\xC9", "\x9B\xB4",
  /* U+6D40 */	"\x9B\xB5", "\xC1\xF7", "\x9B\xB6", "\xE4\xA4",
  /* U+6D44 */	"\x9B\xB7", "\xC7\xB3", "\xBD\xAC", "\xBD\xBD",
  /* U+6D48 */	"\xE4\xA5", "\x9B\xB8", "\xD7\xC7", "\xB2\xE2",
  /* U+6D4C */	"\x9B\xB9", "\xE4\xAB", "\xBC\xC3", "\xE4\xAF",
  /* U+6D50 */	"\x9B\xBA", "\xBB\xEB", "\xE4\xB0", "\xC5\xA8",
  /* U+6D54 */	"\xE4\xB1", "\x9B\xBB", "\x9B\xBC", "\x9B\xBD",
  /* U+6D58 */	"\x9B\xBE", "\xD5\xE3", "\xBF\xA3", "\x9B\xBF",
  /* U+6D5C */	"\xE4\xBA", "\x9B\xC0", "\xE4\xB7", "\x9B\xC1",
  /* U+6D60 */	"\xE4\xBB", "\x9B\xC2", "\x9B\xC3", "\xE4\xBD",
  /* U+6D64 */	"\x9B\xC4", "\x9B\xC5", "\xC6\xD6", "\x9B\xC6",
  /* U+6D68 */	"\x9B\xC7", "\xBA\xC6", "\xC0\xCB", "\x9B\xC8",
  /* U+6D6C */	"\x9B\xC9", "\x9B\xCA", "\xB8\xA1", "\xE4\xB4",
  /* U+6D70 */	"\x9B\xCB", "\x9B\xCC", "\x9B\xCD", "\x9B\xCE",
  /* U+6D74 */	"\xD4\xA1", "\x9B\xCF", "\x9B\xD0", "\xBA\xA3",
  /* U+6D78 */	"\xBD\xFE", "\x9B\xD1", "\x9B\xD2", "\x9B\xD3",
  /* U+6D7C */	"\xE4\xBC", "\x9B\xD4", "\x9B\xD5", "\x9B\xD6",
  /* U+6D80 */	"\x9B\xD7", "\x9B\xD8", "\xCD\xBF", "\x9B\xD9",
  /* U+6D84 */	"\x9B\xDA", "\xC4\xF9", "\x9B\xDB", "\x9B\xDC",
  /* U+6D88 */	"\xCF\xFB", "\xC9\xE6", "\x9B\xDD", "\x9B\xDE",
  /* U+6D8C */	"\xD3\xBF", "\x9B\xDF", "\xCF\xD1", "\x9B\xE0",
  /* U+6D90 */	"\x9B\xE1", "\xE4\xB3", "\x9B\xE2", "\xE4\xB8",
  /* U+6D94 */	"\xE4\xB9", "\xCC\xE9", "\x9B\xE3", "\x9B\xE4",
  /* U+6D98 */	"\x9B\xE5", "\x9B\xE6", "\x9B\xE7", "\xCC\xCE",
  /* U+6D9C */	"\x9B\xE8", "\xC0\xD4", "\xE4\xB5", "\xC1\xB0",
  /* U+6DA0 */	"\xE4\xB6", "\xCE\xD0", "\x9B\xE9", "\xBB\xC1",
  /* U+6DA4 */	"\xB5\xD3", "\x9B\xEA", "\xC8\xF3", "\xBD\xA7",
  /* U+6DA8 */	"\xD5\xC7", "\xC9\xAC", "\xB8\xA2", "\xE4\xCA",
  /* U+6DAC */	"\x9B\xEB", "\x9B\xEC", "\xE4\xCC", "\xD1\xC4",
  /* U+6DB0 */	"\x9B\xED", "\x9B\xEE", "\xD2\xBA", "\x9B\xEF",
  /* U+6DB4 */	"\x9B\xF0", "\xBA\xAD", "\x9B\xF1", "\x9B\xF2",
  /* U+6DB8 */	"\xBA\xD4", "\x9B\xF3", "\x9B\xF4", "\x9B\xF5",
  /* U+6DBC */	"\x9B\xF6", "\x9B\xF7", "\x9B\xF8", "\xE4\xC3",
  /* U+6DC0 */	"\xB5\xED", "\x9B\xF9", "\x9B\xFA", "\x9B\xFB",
  /* U+6DC4 */	"\xD7\xCD", "\xE4\xC0", "\xCF\xFD", "\xE4\xBF",
  /* U+6DC8 */	"\x9B\xFC", "\x9B\xFD", "\x9B\xFE", "\xC1\xDC",
  /* U+6DCC */	"\xCC\xCA", "\x9C\x40", "\x9C\x41", "\x9C\x42",
  /* U+6DD0 */	"\x9C\x43", "\xCA\xE7", "\x9C\x44", "\x9C\x45",
  /* U+6DD4 */	"\x9C\x46", "\x9C\x47", "\xC4\xD7", "\x9C\x48",
  /* U+6DD8 */	"\xCC\xD4", "\xE4\xC8", "\x9C\x49", "\x9C\x4A",
  /* U+6DDC */	"\x9C\x4B", "\xE4\xC7", "\xE4\xC1", "\x9C\x4C",
  /* U+6DE0 */	"\xE4\xC4", "\xB5\xAD", "\x9C\x4D", "\x9C\x4E",
  /* U+6DE4 */	"\xD3\xD9", "\x9C\x4F", "\xE4\xC6", "\x9C\x50",
  /* U+6DE8 */	"\x9C\x51", "\x9C\x52", "\x9C\x53", "\xD2\xF9",
  /* U+6DEC */	"\xB4\xE3", "\x9C\x54", "\xBB\xB4", "\x9C\x55",
  /* U+6DF0 */	"\x9C\x56", "\xC9\xEE", "\x9C\x57", "\xB4\xBE",
  /* U+6DF4 */	"\x9C\x58", "\x9C\x59", "\x9C\x5A", "\xBB\xEC",
  /* U+6DF8 */	"\x9C\x5B", "\xD1\xCD", "\x9C\x5C", "\xCC\xED",
  /* U+6DFC */	"\xED\xB5", "\x9C\x5D", "\x9C\x5E", "\x9C\x5F",
  /* U+6E00 */	"\x9C\x60", "\x9C\x61", "\x9C\x62", "\x9C\x63",
  /* U+6E04 */	"\x9C\x64", "\xC7\xE5", "\x9C\x65", "\x9C\x66",
  /* U+6E08 */	"\x9C\x67", "\x9C\x68", "\xD4\xA8", "\x9C\x69",
  /* U+6E0C */	"\xE4\xCB", "\xD7\xD5", "\xE4\xC2", "\x9C\x6A",
  /* U+6E10 */	"\xBD\xA5", "\xE4\xC5", "\x9C\x6B", "\x9C\x6C",
  /* U+6E14 */	"\xD3\xE6", "\x9C\x6D", "\xE4\xC9", "\xC9\xF8",
  /* U+6E18 */	"\x9C\x6E", "\x9C\x6F", "\xE4\xBE", "\x9C\x70",
  /* U+6E1C */	"\x9C\x71", "\xD3\xE5", "\x9C\x72", "\x9C\x73",
  /* U+6E20 */	"\xC7\xFE", "\xB6\xC9", "\x9C\x74", "\xD4\xFC",
  /* U+6E24 */	"\xB2\xB3", "\xE4\xD7", "\x9C\x75", "\x9C\x76",
  /* U+6E28 */	"\x9C\x77", "\xCE\xC2", "\x9C\x78", "\xE4\xCD",
  /* U+6E2C */	"\x9C\x79", "\xCE\xBC", "\x9C\x7A", "\xB8\xDB",
  /* U+6E30 */	"\x9C\x7B", "\x9C\x7C", "\xE4\xD6", "\x9C\x7D",
  /* U+6E34 */	"\xBF\xCA", "\x9C\x7E", "\x9C\x80", "\x9C\x81",
  /* U+6E38 */	"\xD3\xCE", "\x9C\x82", "\xC3\xEC", "\x9C\x83",
  /* U+6E3C */	"\x9C\x84", "\x9C\x85", "\x9C\x86", "\x9C\x87",
  /* U+6E40 */	"\x9C\x88", "\x9C\x89", "\x9C\x8A", "\xC5\xC8",
  /* U+6E44 */	"\xE4\xD8", "\x9C\x8B", "\x9C\x8C", "\x9C\x8D",
  /* U+6E48 */	"\x9C\x8E", "\x9C\x8F", "\x9C\x90", "\x9C\x91",
  /* U+6E4C */	"\x9C\x92", "\xCD\xC4", "\xE4\xCF", "\x9C\x93",
  /* U+6E50 */	"\x9C\x94", "\x9C\x95", "\x9C\x96", "\xE4\xD4",
  /* U+6E54 */	"\xE4\xD5", "\x9C\x97", "\xBA\xFE", "\x9C\x98",
  /* U+6E58 */	"\xCF\xE6", "\x9C\x99", "\x9C\x9A", "\xD5\xBF",
  /* U+6E5C */	"\x9C\x9B", "\x9C\x9C", "\x9C\x9D", "\xE4\xD2",
  /* U+6E60 */	"\x9C\x9E", "\x9C\x9F", "\x9C\xA0", "\x9C\xA1",
  /* U+6E64 */	"\x9C\xA2", "\x9C\xA3", "\x9C\xA4", "\x9C\xA5",
  /* U+6E68 */	"\x9C\xA6", "\x9C\xA7", "\x9C\xA8", "\xE4\xD0",
  /* U+6E6C */	"\x9C\xA9", "\x9C\xAA", "\xE4\xCE", "\x9C\xAB",
  /* U+6E70 */	"\x9C\xAC", "\x9C\xAD", "\x9C\xAE", "\x9C\xAF",
  /* U+6E74 */	"\x9C\xB0", "\x9C\xB1", "\x9C\xB2", "\x9C\xB3",
  /* U+6E78 */	"\x9C\xB4", "\x9C\xB5", "\x9C\xB6", "\x9C\xB7",
  /* U+6E7C */	"\x9C\xB8", "\x9C\xB9", "\xCD\xE5", "\xCA\xAA",
  /* U+6E80 */	"\x9C\xBA", "\x9C\xBB", "\x9C\xBC", "\xC0\xA3",
  /* U+6E84 */	"\x9C\xBD", "\xBD\xA6", "\xE4\xD3", "\x9C\xBE",
  /* U+6E88 */	"\x9C\xBF", "\xB8\xC8", "\x9C\xC0", "\x9C\xC1",
  /* U+6E8C */	"\x9C\xC2", "\x9C\xC3", "\x9C\xC4", "\xE4\xE7",
  /* U+6E90 */	"\xD4\xB4", "\x9C\xC5", "\x9C\xC6", "\x9C\xC7",
  /* U+6E94 */	"\x9C\xC8", "\x9C\xC9", "\x9C\xCA", "\x9C\xCB",
  /* U+6E98 */	"\xE4\xDB", "\x9C\xCC", "\x9C\xCD", "\x9C\xCE",
  /* U+6E9C */	"\xC1\xEF", "\x9C\xCF", "\x9C\xD0", "\xE4\xE9",
  /* U+6EA0 */	"\x9C\xD1", "\x9C\xD2", "\xD2\xE7", "\x9C\xD3",
  /* U+6EA4 */	"\x9C\xD4", "\xE4\xDF", "\x9C\xD5", "\xE4\xE0",
  /* U+6EA8 */	"\x9C\xD6", "\x9C\xD7", "\xCF\xAA", "\x9C\xD8",
  /* U+6EAC */	"\x9C\xD9", "\x9C\xDA", "\x9C\xDB", "\xCB\xDD",
  /* U+6EB0 */	"\x9C\xDC", "\xE4\xDA", "\xE4\xD1", "\x9C\xDD",
  /* U+6EB4 */	"\xE4\xE5", "\x9C\xDE", "\xC8\xDC", "\xE4\xE3",
  /* U+6EB8 */	"\x9C\xDF", "\x9C\xE0", "\xC4\xE7", "\xE4\xE2",
  /* U+6EBC */	"\x9C\xE1", "\xE4\xE1", "\x9C\xE2", "\x9C\xE3",
  /* U+6EC0 */	"\x9C\xE4", "\xB3\xFC", "\xE4\xE8", "\x9C\xE5",
  /* U+6EC4 */	"\x9C\xE6", "\x9C\xE7", "\x9C\xE8", "\xB5\xE1",
  /* U+6EC8 */	"\x9C\xE9", "\x9C\xEA", "\x9C\xEB", "\xD7\xCC",
  /* U+6ECC */	"\x9C\xEC", "\x9C\xED", "\x9C\xEE", "\xE4\xE6",
  /* U+6ED0 */	"\x9C\xEF", "\xBB\xAC", "\x9C\xF0", "\xD7\xD2",
  /* U+6ED4 */	"\xCC\xCF", "\xEB\xF8", "\x9C\xF1", "\xE4\xE4",
  /* U+6ED8 */	"\x9C\xF2", "\x9C\xF3", "\xB9\xF6", "\x9C\xF4",
  /* U+6EDC */	"\x9C\xF5", "\x9C\xF6", "\xD6\xCD", "\xE4\xD9",
  /* U+6EE0 */	"\xE4\xDC", "\xC2\xFA", "\xE4\xDE", "\x9C\xF7",
  /* U+6EE4 */	"\xC2\xCB", "\xC0\xC4", "\xC2\xD0", "\x9C\xF8",
  /* U+6EE8 */	"\xB1\xF5", "\xCC\xB2", "\x9C\xF9", "\x9C\xFA",
  /* U+6EEC */	"\x9C\xFB", "\x9C\xFC", "\x9C\xFD", "\x9C\xFE",
  /* U+6EF0 */	"\x9D\x40", "\x9D\x41", "\x9D\x42", "\x9D\x43",
  /* U+6EF4 */	"\xB5\xCE", "\x9D\x44", "\x9D\x45", "\x9D\x46",
  /* U+6EF8 */	"\x9D\x47", "\xE4\xEF", "\x9D\x48", "\x9D\x49",
  /* U+6EFC */	"\x9D\x4A", "\x9D\x4B", "\x9D\x4C", "\x9D\x4D",
  /* U+6F00 */	"\x9D\x4E", "\x9D\x4F", "\xC6\xAF", "\x9D\x50",
  /* U+6F04 */	"\x9D\x51", "\x9D\x52", "\xC6\xE1", "\x9D\x53",
  /* U+6F08 */	"\x9D\x54", "\xE4\xF5", "\x9D\x55", "\x9D\x56",
  /* U+6F0C */	"\x9D\x57", "\x9D\x58", "\x9D\x59", "\xC2\xA9",
  /* U+6F10 */	"\x9D\x5A", "\x9D\x5B", "\x9D\x5C", "\xC0\xEC",
  /* U+6F14 */	"\xD1\xDD", "\xE4\xEE", "\x9D\x5D", "\x9D\x5E",
  /* U+6F18 */	"\x9D\x5F", "\x9D\x60", "\x9D\x61", "\x9D\x62",
  /* U+6F1C */	"\x9D\x63", "\x9D\x64", "\x9D\x65", "\x9D\x66",
  /* U+6F20 */	"\xC4\xAE", "\x9D\x67", "\x9D\x68", "\x9D\x69",
  /* U+6F24 */	"\xE4\xED", "\x9D\x6A", "\x9D\x6B", "\x9D\x6C",
  /* U+6F28 */	"\x9D\x6D", "\xE4\xF6", "\xE4\xF4", "\xC2\xFE",
  /* U+6F2C */	"\x9D\x6E", "\xE4\xDD", "\x9D\x6F", "\xE4\xF0",
  /* U+6F30 */	"\x9D\x70", "\xCA\xFE", "\x9D\x71", "\xD5\xC4",
  /* U+6F34 */	"\x9D\x72", "\x9D\x73", "\xE4\xF1", "\x9D\x74",
  /* U+6F38 */	"\x9D\x75", "\x9D\x76", "\x9D\x77", "\x9D\x78",
  /* U+6F3C */	"\x9D\x79", "\x9D\x7A", "\xD1\xFA", "\x9D\x7B",
  /* U+6F40 */	"\x9D\x7C", "\x9D\x7D", "\x9D\x7E", "\x9D\x80",
  /* U+6F44 */	"\x9D\x81", "\x9D\x82", "\xE4\xEB", "\xE4\xEC",
  /* U+6F48 */	"\x9D\x83", "\x9D\x84", "\x9D\x85", "\xE4\xF2",
  /* U+6F4C */	"\x9D\x86", "\xCE\xAB", "\x9D\x87", "\x9D\x88",
  /* U+6F50 */	"\x9D\x89", "\x9D\x8A", "\x9D\x8B", "\x9D\x8C",
  /* U+6F54 */	"\x9D\x8D", "\x9D\x8E", "\x9D\x8F", "\x9D\x90",
  /* U+6F58 */	"\xC5\xCB", "\x9D\x91", "\x9D\x92", "\x9D\x93",
  /* U+6F5C */	"\xC7\xB1", "\x9D\x94", "\xC2\xBA", "\x9D\x95",
  /* U+6F60 */	"\x9D\x96", "\x9D\x97", "\xE4\xEA", "\x9D\x98",
  /* U+6F64 */	"\x9D\x99", "\x9D\x9A", "\xC1\xCA", "\x9D\x9B",
  /* U+6F68 */	"\x9D\x9C", "\x9D\x9D", "\x9D\x9E", "\x9D\x9F",
  /* U+6F6C */	"\x9D\xA0", "\xCC\xB6", "\xB3\xB1", "\x9D\xA1",
  /* U+6F70 */	"\x9D\xA2", "\x9D\xA3", "\xE4\xFB", "\x9D\xA4",
  /* U+6F74 */	"\xE4\xF3", "\x9D\xA5", "\x9D\xA6", "\x9D\xA7",
  /* U+6F78 */	"\xE4\xFA", "\x9D\xA8", "\xE4\xFD", "\x9D\xA9",
  /* U+6F7C */	"\xE4\xFC", "\x9D\xAA", "\x9D\xAB", "\x9D\xAC",
  /* U+6F80 */	"\x9D\xAD", "\x9D\xAE", "\x9D\xAF", "\x9D\xB0",
  /* U+6F84 */	"\xB3\xCE", "\x9D\xB1", "\x9D\xB2", "\x9D\xB3",
  /* U+6F88 */	"\xB3\xBA", "\xE4\xF7", "\x9D\xB4", "\x9D\xB5",
  /* U+6F8C */	"\xE4\xF9", "\xE4\xF8", "\xC5\xEC", "\x9D\xB6",
  /* U+6F90 */	"\x9D\xB7", "\x9D\xB8", "\x9D\xB9", "\x9D\xBA",
  /* U+6F94 */	"\x9D\xBB", "\x9D\xBC", "\x9D\xBD", "\x9D\xBE",
  /* U+6F98 */	"\x9D\xBF", "\x9D\xC0", "\x9D\xC1", "\x9D\xC2",
  /* U+6F9C */	"\xC0\xBD", "\x9D\xC3", "\x9D\xC4", "\x9D\xC5",
  /* U+6FA0 */	"\x9D\xC6", "\xD4\xE8", "\x9D\xC7", "\x9D\xC8",
  /* U+6FA4 */	"\x9D\xC9", "\x9D\xCA", "\x9D\xCB", "\xE5\xA2",
  /* U+6FA8 */	"\x9D\xCC", "\x9D\xCD", "\x9D\xCE", "\x9D\xCF",
  /* U+6FAC */	"\x9D\xD0", "\x9D\xD1", "\x9D\xD2", "\x9D\xD3",
  /* U+6FB0 */	"\x9D\xD4", "\x9D\xD5", "\x9D\xD6", "\xB0\xC4",
  /* U+6FB4 */	"\x9D\xD7", "\x9D\xD8", "\xE5\xA4", "\x9D\xD9",
  /* U+6FB8 */	"\x9D\xDA", "\xE5\xA3", "\x9D\xDB", "\x9D\xDC",
  /* U+6FBC */	"\x9D\xDD", "\x9D\xDE", "\x9D\xDF", "\x9D\xE0",
  /* U+6FC0 */	"\xBC\xA4", "\x9D\xE1", "\xE5\xA5", "\x9D\xE2",
  /* U+6FC4 */	"\x9D\xE3", "\x9D\xE4", "\x9D\xE5", "\x9D\xE6",
  /* U+6FC8 */	"\x9D\xE7", "\xE5\xA1", "\x9D\xE8", "\x9D\xE9",
  /* U+6FCC */	"\x9D\xEA", "\x9D\xEB", "\x9D\xEC", "\x9D\xED",
  /* U+6FD0 */	"\x9D\xEE", "\xE4\xFE", "\xB1\xF4", "\x9D\xEF",
  /* U+6FD4 */	"\x9D\xF0", "\x9D\xF1", "\x9D\xF2", "\x9D\xF3",
  /* U+6FD8 */	"\x9D\xF4", "\x9D\xF5", "\x9D\xF6", "\x9D\xF7",
  /* U+6FDC */	"\x9D\xF8", "\x9D\xF9", "\xE5\xA8", "\x9D\xFA",
  /* U+6FE0 */	"\xE5\xA9", "\xE5\xA6", "\x9D\xFB", "\x9D\xFC",
  /* U+6FE4 */	"\x9D\xFD", "\x9D\xFE", "\x9E\x40", "\x9E\x41",
  /* U+6FE8 */	"\x9E\x42", "\x9E\x43", "\x9E\x44", "\x9E\x45",
  /* U+6FEC */	"\x9E\x46", "\x9E\x47", "\xE5\xA7", "\xE5\xAA",
  /* U+6FF0 */	"\x9E\x48", "\x9E\x49", "\x9E\x4A", "\x9E\x4B",
  /* U+6FF4 */	"\x9E\x4C", "\x9E\x4D", "\x9E\x4E", "\x9E\x4F",
  /* U+6FF8 */	"\x9E\x50", "\x9E\x51", "\x9E\x52", "\x9E\x53",
  /* U+6FFC */	"\x9E\x54", "\x9E\x55", "\x9E\x56", "\x9E\x57",
  /* U+7000 */	"\x9E\x58", "\x9E\x59", "\x9E\x5A", "\x9E\x5B",
  /* U+7004 */	"\x9E\x5C", "\x9E\x5D", "\x9E\x5E", "\x9E\x5F",
  /* U+7008 */	"\x9E\x60", "\x9E\x61", "\x9E\x62", "\x9E\x63",
  /* U+700C */	"\x9E\x64", "\x9E\x65", "\x9E\x66", "\x9E\x67",
  /* U+7010 */	"\x9E\x68", "\xC6\xD9", "\x9E\x69", "\x9E\x6A",
  /* U+7014 */	"\x9E\x6B", "\x9E\x6C", "\x9E\x6D", "\x9E\x6E",
  /* U+7018 */	"\x9E\x6F", "\x9E\x70", "\xE5\xAB", "\xE5\xAD",
  /* U+701C */	"\x9E\x71", "\x9E\x72", "\x9E\x73", "\x9E\x74",
  /* U+7020 */	"\x9E\x75", "\x9E\x76", "\x9E\x77", "\xE5\xAC",
  /* U+7024 */	"\x9E\x78", "\x9E\x79", "\x9E\x7A", "\x9E\x7B",
  /* U+7028 */	"\x9E\x7C", "\x9E\x7D", "\x9E\x7E", "\x9E\x80",
  /* U+702C */	"\x9E\x81", "\x9E\x82", "\x9E\x83", "\x9E\x84",
  /* U+7030 */	"\x9E\x85", "\x9E\x86", "\x9E\x87", "\x9E\x88",
  /* U+7034 */	"\x9E\x89", "\xE5\xAF", "\x9E\x8A", "\x9E\x8B",
  /* U+7038 */	"\x9E\x8C", "\xE5\xAE", "\x9E\x8D", "\x9E\x8E",
  /* U+703C */	"\x9E\x8F", "\x9E\x90", "\x9E\x91", "\x9E\x92",
  /* U+7040 */	"\x9E\x93", "\x9E\x94", "\x9E\x95", "\x9E\x96",
  /* U+7044 */	"\x9E\x97", "\x9E\x98", "\x9E\x99", "\x9E\x9A",
  /* U+7048 */	"\x9E\x9B", "\x9E\x9C", "\x9E\x9D", "\x9E\x9E",
  /* U+704C */	"\xB9\xE0", "\x9E\x9F", "\x9E\xA0", "\xE5\xB0",
  /* U+7050 */	"\x9E\xA1", "\x9E\xA2", "\x9E\xA3", "\x9E\xA4",
  /* U+7054 */	"\x9E\xA5", "\x9E\xA6", "\x9E\xA7", "\x9E\xA8",
  /* U+7058 */	"\x9E\xA9", "\x9E\xAA", "\x9E\xAB", "\x9E\xAC",
  /* U+705C */	"\x9E\xAD", "\x9E\xAE", "\xE5\xB1", "\x9E\xAF",
  /* U+7060 */	"\x9E\xB0", "\x9E\xB1", "\x9E\xB2", "\x9E\xB3",
  /* U+7064 */	"\x9E\xB4", "\x9E\xB5", "\x9E\xB6", "\x9E\xB7",
  /* U+7068 */	"\x9E\xB8", "\x9E\xB9", "\x9E\xBA", "\xBB\xF0",
  /* U+706C */	"\xEC\xE1", "\xC3\xF0", "\x9E\xBB", "\xB5\xC6",
  /* U+7070 */	"\xBB\xD2", "\x9E\xBC", "\x9E\xBD", "\x9E\xBE",
  /* U+7074 */	"\x9E\xBF", "\xC1\xE9", "\xD4\xEE", "\x9E\xC0",
  /* U+7078 */	"\xBE\xC4", "\x9E\xC1", "\x9E\xC2", "\x9E\xC3",
  /* U+707C */	"\xD7\xC6", "\x9E\xC4", "\xD4\xD6", "\xB2\xD3",
  /* U+7080 */	"\xEC\xBE", "\x9E\xC5", "\x9E\xC6", "\x9E\xC7",
  /* U+7084 */	"\x9E\xC8", "\xEA\xC1", "\x9E\xC9", "\x9E\xCA",
  /* U+7088 */	"\x9E\xCB", "\xC2\xAF", "\xB4\xB6", "\x9E\xCC",
  /* U+708C */	"\x9E\xCD", "\x9E\xCE", "\xD1\xD7", "\x9E\xCF",
  /* U+7090 */	"\x9E\xD0", "\x9E\xD1", "\xB3\xB4", "\x9E\xD2",
  /* U+7094 */	"\xC8\xB2", "\xBF\xBB", "\xEC\xC0", "\x9E\xD3",
  /* U+7098 */	"\x9E\xD4", "\xD6\xCB", "\x9E\xD5", "\x9E\xD6",
  /* U+709C */	"\xEC\xBF", "\xEC\xC1", "\x9E\xD7", "\x9E\xD8",
  /* U+70A0 */	"\x9E\xD9", "\x9E\xDA", "\x9E\xDB", "\x9E\xDC",
  /* U+70A4 */	"\x9E\xDD", "\x9E\xDE", "\x9E\xDF", "\x9E\xE0",
  /* U+70A8 */	"\x9E\xE1", "\x9E\xE2", "\x9E\xE3", "\xEC\xC5",
  /* U+70AC */	"\xBE\xE6", "\xCC\xBF", "\xC5\xDA", "\xBE\xBC",
  /* U+70B0 */	"\x9E\xE4", "\xEC\xC6", "\x9E\xE5", "\xB1\xFE",
  /* U+70B4 */	"\x9E\xE6", "\x9E\xE7", "\x9E\xE8", "\xEC\xC4",
  /* U+70B8 */	"\xD5\xA8", "\xB5\xE3", "\x9E\xE9", "\xEC\xC2",
  /* U+70BC */	"\xC1\xB6", "\xB3\xE3", "\x9E\xEA", "\x9E\xEB",
  /* U+70C0 */	"\xEC\xC3", "\xCB\xB8", "\xC0\xC3", "\xCC\xFE",
  /* U+70C4 */	"\x9E\xEC", "\x9E\xED", "\x9E\xEE", "\x9E\xEF",
  /* U+70C8 */	"\xC1\xD2", "\x9E\xF0", "\xEC\xC8", "\x9E\xF1",
  /* U+70CC */	"\x9E\xF2", "\x9E\xF3", "\x9E\xF4", "\x9E\xF5",
  /* U+70D0 */	"\x9E\xF6", "\x9E\xF7", "\x9E\xF8", "\x9E\xF9",
  /* U+70D4 */	"\x9E\xFA", "\x9E\xFB", "\x9E\xFC", "\x9E\xFD",
  /* U+70D8 */	"\xBA\xE6", "\xC0\xD3", "\x9E\xFE", "\xD6\xF2",
  /* U+70DC */	"\x9F\x40", "\x9F\x41", "\x9F\x42", "\xD1\xCC",
  /* U+70E0 */	"\x9F\x43", "\x9F\x44", "\x9F\x45", "\x9F\x46",
  /* U+70E4 */	"\xBF\xBE", "\x9F\x47", "\xB7\xB3", "\xC9\xD5",
  /* U+70E8 */	"\xEC\xC7", "\xBB\xE2", "\x9F\x48", "\xCC\xCC",
  /* U+70EC */	"\xBD\xFD", "\xC8\xC8", "\x9F\x49", "\xCF\xA9",
  /* U+70F0 */	"\x9F\x4A", "\x9F\x4B", "\x9F\x4C", "\x9F\x4D",
  /* U+70F4 */	"\x9F\x4E", "\x9F\x4F", "\x9F\x50", "\xCD\xE9",
  /* U+70F8 */	"\x9F\x51", "\xC5\xEB", "\x9F\x52", "\x9F\x53",
  /* U+70FC */	"\x9F\x54", "\xB7\xE9", "\x9F\x55", "\x9F\x56",
  /* U+7100 */	"\x9F\x57", "\x9F\x58", "\x9F\x59", "\x9F\x5A",
  /* U+7104 */	"\x9F\x5B", "\x9F\x5C", "\x9F\x5D", "\x9F\x5E",
  /* U+7108 */	"\x9F\x5F", "\xD1\xC9", "\xBA\xB8", "\x9F\x60",
  /* U+710C */	"\x9F\x61", "\x9F\x62", "\x9F\x63", "\x9F\x64",
  /* U+7110 */	"\xEC\xC9", "\x9F\x65", "\x9F\x66", "\xEC\xCA",
  /* U+7114 */	"\x9F\x67", "\xBB\xC0", "\xEC\xCB", "\x9F\x68",
  /* U+7118 */	"\xEC\xE2", "\xB1\xBA", "\xB7\xD9", "\x9F\x69",
  /* U+711C */	"\x9F\x6A", "\x9F\x6B", "\x9F\x6C", "\x9F\x6D",
  /* U+7120 */	"\x9F\x6E", "\x9F\x6F", "\x9F\x70", "\x9F\x71",
  /* U+7124 */	"\x9F\x72", "\x9F\x73", "\xBD\xB9", "\x9F\x74",
  /* U+7128 */	"\x9F\x75", "\x9F\x76", "\x9F\x77", "\x9F\x78",
  /* U+712C */	"\x9F\x79", "\x9F\x7A", "\x9F\x7B", "\xEC\xCC",
  /* U+7130 */	"\xD1\xE6", "\xEC\xCD", "\x9F\x7C", "\x9F\x7D",
  /* U+7134 */	"\x9F\x7E", "\x9F\x80", "\xC8\xBB", "\x9F\x81",
  /* U+7138 */	"\x9F\x82", "\x9F\x83", "\x9F\x84", "\x9F\x85",
  /* U+713C */	"\x9F\x86", "\x9F\x87", "\x9F\x88", "\x9F\x89",
  /* U+7140 */	"\x9F\x8A", "\x9F\x8B", "\x9F\x8C", "\x9F\x8D",
  /* U+7144 */	"\x9F\x8E", "\xEC\xD1", "\x9F\x8F", "\x9F\x90",
  /* U+7148 */	"\x9F\x91", "\x9F\x92", "\xEC\xD3", "\x9F\x93",
  /* U+714C */	"\xBB\xCD", "\x9F\x94", "\xBC\xE5", "\x9F\x95",
  /* U+7150 */	"\x9F\x96", "\x9F\x97", "\x9F\x98", "\x9F\x99",
  /* U+7154 */	"\x9F\x9A", "\x9F\x9B", "\x9F\x9C", "\x9F\x9D",
  /* U+7158 */	"\x9F\x9E", "\x9F\x9F", "\x9F\xA0", "\x9F\xA1",
  /* U+715C */	"\xEC\xCF", "\x9F\xA2", "\xC9\xB7", "\x9F\xA3",
  /* U+7160 */	"\x9F\xA4", "\x9F\xA5", "\x9F\xA6", "\x9F\xA7",
  /* U+7164 */	"\xC3\xBA", "\x9F\xA8", "\xEC\xE3", "\xD5\xD5",
  /* U+7168 */	"\xEC\xD0", "\x9F\xA9", "\x9F\xAA", "\x9F\xAB",
  /* U+716C */	"\x9F\xAC", "\x9F\xAD", "\xD6\xF3", "\x9F\xAE",
  /* U+7170 */	"\x9F\xAF", "\x9F\xB0", "\xEC\xD2", "\xEC\xCE",
  /* U+7174 */	"\x9F\xB1", "\x9F\xB2", "\x9F\xB3", "\x9F\xB4",
  /* U+7178 */	"\xEC\xD4", "\x9F\xB5", "\xEC\xD5", "\x9F\xB6",
  /* U+717C */	"\x9F\xB7", "\xC9\xBF", "\x9F\xB8", "\x9F\xB9",
  /* U+7180 */	"\x9F\xBA", "\x9F\xBB", "\x9F\xBC", "\x9F\xBD",
  /* U+7184 */	"\xCF\xA8", "\x9F\xBE", "\x9F\xBF", "\x9F\xC0",
  /* U+7188 */	"\x9F\xC1", "\x9F\xC2", "\xD0\xDC", "\x9F\xC3",
  /* U+718C */	"\x9F\xC4", "\x9F\xC5", "\x9F\xC6", "\xD1\xAC",
  /* U+7190 */	"\x9F\xC7", "\x9F\xC8", "\x9F\xC9", "\x9F\xCA",
  /* U+7194 */	"\xC8\xDB", "\x9F\xCB", "\x9F\xCC", "\x9F\xCD",
  /* U+7198 */	"\xEC\xD6", "\xCE\xF5", "\x9F\xCE", "\x9F\xCF",
  /* U+719C */	"\x9F\xD0", "\x9F\xD1", "\x9F\xD2", "\xCA\xEC",
  /* U+71A0 */	"\xEC\xDA", "\x9F\xD3", "\x9F\xD4", "\x9F\xD5",
  /* U+71A4 */	"\x9F\xD6", "\x9F\xD7", "\x9F\xD8", "\x9F\xD9",
  /* U+71A8 */	"\xEC\xD9", "\x9F\xDA", "\x9F\xDB", "\x9F\xDC",
  /* U+71AC */	"\xB0\xBE", "\x9F\xDD", "\x9F\xDE", "\x9F\xDF",
  /* U+71B0 */	"\x9F\xE0", "\x9F\xE1", "\x9F\xE2", "\xEC\xD7",
  /* U+71B4 */	"\x9F\xE3", "\xEC\xD8", "\x9F\xE4", "\x9F\xE5",
  /* U+71B8 */	"\x9F\xE6", "\xEC\xE4", "\x9F\xE7", "\x9F\xE8",
  /* U+71BC */	"\x9F\xE9", "\x9F\xEA", "\x9F\xEB", "\x9F\xEC",
  /* U+71C0 */	"\x9F\xED", "\x9F\xEE", "\x9F\xEF", "\xC8\xBC",
  /* U+71C4 */	"\x9F\xF0", "\x9F\xF1", "\x9F\xF2", "\x9F\xF3",
  /* U+71C8 */	"\x9F\xF4", "\x9F\xF5", "\x9F\xF6", "\x9F\xF7",
  /* U+71CC */	"\x9F\xF8", "\x9F\xF9", "\xC1\xC7", "\x9F\xFA",
  /* U+71D0 */	"\x9F\xFB", "\x9F\xFC", "\x9F\xFD", "\x9F\xFE",
  /* U+71D4 */	"\xEC\xDC", "\xD1\xE0", "\xA0\x40", "\xA0\x41",
  /* U+71D8 */	"\xA0\x42", "\xA0\x43", "\xA0\x44", "\xA0\x45",
  /* U+71DC */	"\xA0\x46", "\xA0\x47", "\xA0\x48", "\xA0\x49",
  /* U+71E0 */	"\xEC\xDB", "\xA0\x4A", "\xA0\x4B", "\xA0\x4C",
  /* U+71E4 */	"\xA0\x4D", "\xD4\xEF", "\xA0\x4E", "\xEC\xDD",
  /* U+71E8 */	"\xA0\x4F", "\xA0\x50", "\xA0\x51", "\xA0\x52",
  /* U+71EC */	"\xA0\x53", "\xA0\x54", "\xDB\xC6", "\xA0\x55",
  /* U+71F0 */	"\xA0\x56", "\xA0\x57", "\xA0\x58", "\xA0\x59",
  /* U+71F4 */	"\xA0\x5A", "\xA0\x5B", "\xA0\x5C", "\xA0\x5D",
  /* U+71F8 */	"\xA0\x5E", "\xEC\xDE", "\xA0\x5F", "\xA0\x60",
  /* U+71FC */	"\xA0\x61", "\xA0\x62", "\xA0\x63", "\xA0\x64",
  /* U+7200 */	"\xA0\x65", "\xA0\x66", "\xA0\x67", "\xA0\x68",
  /* U+7204 */	"\xA0\x69", "\xA0\x6A", "\xB1\xAC", "\xA0\x6B",
  /* U+7208 */	"\xA0\x6C", "\xA0\x6D", "\xA0\x6E", "\xA0\x6F",
  /* U+720C */	"\xA0\x70", "\xA0\x71", "\xA0\x72", "\xA0\x73",
  /* U+7210 */	"\xA0\x74", "\xA0\x75", "\xA0\x76", "\xA0\x77",
  /* U+7214 */	"\xA0\x78", "\xA0\x79", "\xA0\x7A", "\xA0\x7B",
  /* U+7218 */	"\xA0\x7C", "\xA0\x7D", "\xA0\x7E", "\xA0\x80",
  /* U+721C */	"\xA0\x81", "\xEC\xDF", "\xA0\x82", "\xA0\x83",
  /* U+7220 */	"\xA0\x84", "\xA0\x85", "\xA0\x86", "\xA0\x87",
  /* U+7224 */	"\xA0\x88", "\xA0\x89", "\xA0\x8A", "\xA0\x8B",
  /* U+7228 */	"\xEC\xE0", "\xA0\x8C", "\xD7\xA6", "\xA0\x8D",
  /* U+722C */	"\xC5\xC0", "\xA0\x8E", "\xA0\x8F", "\xA0\x90",
  /* U+7230 */	"\xEB\xBC", "\xB0\xAE", "\xA0\x91", "\xA0\x92",
  /* U+7234 */	"\xA0\x93", "\xBE\xF4", "\xB8\xB8", "\xD2\xAF",
  /* U+7238 */	"\xB0\xD6", "\xB5\xF9", "\xA0\x94", "\xD8\xB3",
  /* U+723C */	"\xA0\x95", "\xCB\xAC", "\xA0\x96", "\xE3\xDD",
  /* U+7240 */	"\xA0\x97", "\xA0\x98", "\xA0\x99", "\xA0\x9A",
  /* U+7244 */	"\xA0\x9B", "\xA0\x9C", "\xA0\x9D", "\xC6\xAC",
  /* U+7248 */	"\xB0\xE6", "\xA0\x9E", "\xA0\x9F", "\xA0\xA0",
  /* U+724C */	"\xC5\xC6", "\xEB\xB9", "\xA0\xA1", "\xA0\xA2",
  /* U+7250 */	"\xA0\xA3", "\xA0\xA4", "\xEB\xBA", "\xA0\xA5",
  /* U+7254 */	"\xA0\xA6", "\xA0\xA7", "\xEB\xBB", "\xA0\xA8",
  /* U+7258 */	"\xA0\xA9", "\xD1\xC0", "\xA0\xAA", "\xC5\xA3",
  /* U+725C */	"\xA0\xAB", "\xEA\xF2", "\xA0\xAC", "\xC4\xB2",
  /* U+7260 */	"\xA0\xAD", "\xC4\xB5", "\xC0\xCE", "\xA0\xAE",
  /* U+7264 */	"\xA0\xAF", "\xA0\xB0", "\xEA\xF3", "\xC4\xC1",
  /* U+7268 */	"\xA0\xB1", "\xCE\xEF", "\xA0\xB2", "\xA0\xB3",
  /* U+726C */	"\xA0\xB4", "\xA0\xB5", "\xEA\xF0", "\xEA\xF4",
  /* U+7270 */	"\xA0\xB6", "\xA0\xB7", "\xC9\xFC", "\xA0\xB8",
  /* U+7274 */	"\xA0\xB9", "\xC7\xA3", "\xA0\xBA", "\xA0\xBB",
  /* U+7278 */	"\xA0\xBC", "\xCC\xD8", "\xCE\xFE", "\xA0\xBD",
  /* U+727C */	"\xA0\xBE", "\xA0\xBF", "\xEA\xF5", "\xEA\xF6",
  /* U+7280 */	"\xCF\xAC", "\xC0\xE7", "\xA0\xC0", "\xA0\xC1",
  /* U+7284 */	"\xEA\xF7", "\xA0\xC2", "\xA0\xC3", "\xA0\xC4",
  /* U+7288 */	"\xA0\xC5", "\xA0\xC6", "\xB6\xBF", "\xEA\xF8",
  /* U+728C */	"\xA0\xC7", "\xEA\xF9", "\xA0\xC8", "\xEA\xFA",
  /* U+7290 */	"\xA0\xC9", "\xA0\xCA", "\xEA\xFB", "\xA0\xCB",
  /* U+7294 */	"\xA0\xCC", "\xA0\xCD", "\xA0\xCE", "\xA0\xCF",
  /* U+7298 */	"\xA0\xD0", "\xA0\xD1", "\xA0\xD2", "\xA0\xD3",
  /* U+729C */	"\xA0\xD4", "\xA0\xD5", "\xA0\xD6", "\xEA\xF1",
  /* U+72A0 */	"\xA0\xD7", "\xA0\xD8", "\xA0\xD9", "\xA0\xDA",
  /* U+72A4 */	"\xA0\xDB", "\xA0\xDC", "\xA0\xDD", "\xA0\xDE",
  /* U+72A8 */	"\xA0\xDF", "\xA0\xE0", "\xA0\xE1", "\xA0\xE2",
  /* U+72AC */	"\xC8\xAE", "\xE1\xEB", "\xA0\xE3", "\xB7\xB8",
  /* U+72B0 */	"\xE1\xEC", "\xA0\xE4", "\xA0\xE5", "\xA0\xE6",
  /* U+72B4 */	"\xE1\xED", "\xA0\xE7", "\xD7\xB4", "\xE1\xEE",
  /* U+72B8 */	"\xE1\xEF", "\xD3\xCC", "\xA0\xE8", "\xA0\xE9",
  /* U+72BC */	"\xA0\xEA", "\xA0\xEB", "\xA0\xEC", "\xA0\xED",
  /* U+72C0 */	"\xA0\xEE", "\xE1\xF1", "\xBF\xF1", "\xE1\xF0",
  /* U+72C4 */	"\xB5\xD2", "\xA0\xEF", "\xA0\xF0", "\xA0\xF1",
  /* U+72C8 */	"\xB1\xB7", "\xA0\xF2", "\xA0\xF3", "\xA0\xF4",
  /* U+72CC */	"\xA0\xF5", "\xE1\xF3", "\xE1\xF2", "\xA0\xF6",
  /* U+72D0 */	"\xBA\xFC", "\xA0\xF7", "\xE1\xF4", "\xA0\xF8",
  /* U+72D4 */	"\xA0\xF9", "\xA0\xFA", "\xA0\xFB", "\xB9\xB7",
  /* U+72D8 */	"\xA0\xFC", "\xBE\xD1", "\xA0\xFD", "\xA0\xFE",
  /* U+72DC */	"\xAA\x40", "\xAA\x41", "\xC4\xFC", "\xAA\x42",
  /* U+72E0 */	"\xBA\xDD", "\xBD\xC6", "\xAA\x43", "\xAA\x44",
  /* U+72E4 */	"\xAA\x45", "\xAA\x46", "\xAA\x47", "\xAA\x48",
  /* U+72E8 */	"\xE1\xF5", "\xE1\xF7", "\xAA\x49", "\xAA\x4A",
  /* U+72EC */	"\xB6\xC0", "\xCF\xC1", "\xCA\xA8", "\xE1\xF6",
  /* U+72F0 */	"\xD5\xF8", "\xD3\xFC", "\xE1\xF8", "\xE1\xFC",
  /* U+72F4 */	"\xE1\xF9", "\xAA\x4B", "\xAA\x4C", "\xE1\xFA",
  /* U+72F8 */	"\xC0\xEA", "\xAA\x4D", "\xE1\xFE", "\xE2\xA1",
  /* U+72FC */	"\xC0\xC7", "\xAA\x4E", "\xAA\x4F", "\xAA\x50",
  /* U+7300 */	"\xAA\x51", "\xE1\xFB", "\xAA\x52", "\xE1\xFD",
  /* U+7304 */	"\xAA\x53", "\xAA\x54", "\xAA\x55", "\xAA\x56",
  /* U+7308 */	"\xAA\x57", "\xAA\x58", "\xE2\xA5", "\xAA\x59",
  /* U+730C */	"\xAA\x5A", "\xAA\x5B", "\xC1\xD4", "\xAA\x5C",
  /* U+7310 */	"\xAA\x5D", "\xAA\x5E", "\xAA\x5F", "\xE2\xA3",
  /* U+7314 */	"\xAA\x60", "\xE2\xA8", "\xB2\xFE", "\xE2\xA2",
  /* U+7318 */	"\xAA\x61", "\xAA\x62", "\xAA\x63", "\xC3\xCD",
  /* U+731C */	"\xB2\xC2", "\xE2\xA7", "\xE2\xA6", "\xAA\x64",
  /* U+7320 */	"\xAA\x65", "\xE2\xA4", "\xE2\xA9", "\xAA\x66",
  /* U+7324 */	"\xAA\x67", "\xE2\xAB", "\xAA\x68", "\xAA\x69",
  /* U+7328 */	"\xAA\x6A", "\xD0\xC9", "\xD6\xED", "\xC3\xA8",
  /* U+732C */	"\xE2\xAC", "\xAA\x6B", "\xCF\xD7", "\xAA\x6C",
  /* U+7330 */	"\xAA\x6D", "\xE2\xAE", "\xAA\x6E", "\xAA\x6F",
  /* U+7334 */	"\xBA\xEF", "\xAA\x70", "\xAA\x71", "\xE9\xE0",
  /* U+7338 */	"\xE2\xAD", "\xE2\xAA", "\xAA\x72", "\xAA\x73",
  /* U+733C */	"\xAA\x74", "\xAA\x75", "\xBB\xAB", "\xD4\xB3",
  /* U+7340 */	"\xAA\x76", "\xAA\x77", "\xAA\x78", "\xAA\x79",
  /* U+7344 */	"\xAA\x7A", "\xAA\x7B", "\xAA\x7C", "\xAA\x7D",
  /* U+7348 */	"\xAA\x7E", "\xAA\x80", "\xAA\x81", "\xAA\x82",
  /* U+734C */	"\xAA\x83", "\xE2\xB0", "\xAA\x84", "\xAA\x85",
  /* U+7350 */	"\xE2\xAF", "\xAA\x86", "\xE9\xE1", "\xAA\x87",
  /* U+7354 */	"\xAA\x88", "\xAA\x89", "\xAA\x8A", "\xE2\xB1",
  /* U+7358 */	"\xAA\x8B", "\xAA\x8C", "\xAA\x8D", "\xAA\x8E",
  /* U+735C */	"\xAA\x8F", "\xAA\x90", "\xAA\x91", "\xAA\x92",
  /* U+7360 */	"\xE2\xB2", "\xAA\x93", "\xAA\x94", "\xAA\x95",
  /* U+7364 */	"\xAA\x96", "\xAA\x97", "\xAA\x98", "\xAA\x99",
  /* U+7368 */	"\xAA\x9A", "\xAA\x9B", "\xAA\x9C", "\xAA\x9D",
  /* U+736C */	"\xE2\xB3", "\xCC\xA1", "\xAA\x9E", "\xE2\xB4",
  /* U+7370 */	"\xAA\x9F", "\xAA\xA0", "\xAB\x40", "\xAB\x41",
  /* U+7374 */	"\xAB\x42", "\xAB\x43", "\xAB\x44", "\xAB\x45",
  /* U+7378 */	"\xAB\x46", "\xAB\x47", "\xAB\x48", "\xAB\x49",
  /* U+737C */	"\xAB\x4A", "\xAB\x4B", "\xE2\xB5", "\xAB\x4C",
  /* U+7380 */	"\xAB\x4D", "\xAB\x4E", "\xAB\x4F", "\xAB\x50",
  /* U+7384 */	"\xD0\xFE", "\xAB\x51", "\xAB\x52", "\xC2\xCA",
  /* U+7388 */	"\xAB\x53", "\xD3\xF1", "\xAB\x54", "\xCD\xF5",
  /* U+738C */	"\xAB\x55", "\xAB\x56", "\xE7\xE0", "\xAB\x57",
  /* U+7390 */	"\xAB\x58", "\xE7\xE1", "\xAB\x59", "\xAB\x5A",
  /* U+7394 */	"\xAB\x5B", "\xAB\x5C", "\xBE\xC1", "\xAB\x5D",
  /* U+7398 */	"\xAB\x5E", "\xAB\x5F", "\xAB\x60", "\xC2\xEA",
  /* U+739C */	"\xAB\x61", "\xAB\x62", "\xAB\x63", "\xE7\xE4",
  /* U+73A0 */	"\xAB\x64", "\xAB\x65", "\xE7\xE3", "\xAB\x66",
  /* U+73A4 */	"\xAB\x67", "\xAB\x68", "\xAB\x69", "\xAB\x6A",
  /* U+73A8 */	"\xAB\x6B", "\xCD\xE6", "\xAB\x6C", "\xC3\xB5",
  /* U+73AC */	"\xAB\x6D", "\xAB\x6E", "\xE7\xE2", "\xBB\xB7",
  /* U+73B0 */	"\xCF\xD6", "\xAB\x6F", "\xC1\xE1", "\xE7\xE9",
  /* U+73B4 */	"\xAB\x70", "\xAB\x71", "\xAB\x72", "\xE7\xE8",
  /* U+73B8 */	"\xAB\x73", "\xAB\x74", "\xE7\xF4", "\xB2\xA3",
  /* U+73BC */	"\xAB\x75", "\xAB\x76", "\xAB\x77", "\xAB\x78",
  /* U+73C0 */	"\xE7\xEA", "\xAB\x79", "\xE7\xE6", "\xAB\x7A",
  /* U+73C4 */	"\xAB\x7B", "\xAB\x7C", "\xAB\x7D", "\xAB\x7E",
  /* U+73C8 */	"\xE7\xEC", "\xE7\xEB", "\xC9\xBA", "\xAB\x80",
  /* U+73CC */	"\xAB\x81", "\xD5\xE4", "\xAB\x82", "\xE7\xE5",
  /* U+73D0 */	"\xB7\xA9", "\xE7\xE7", "\xAB\x83", "\xAB\x84",
  /* U+73D4 */	"\xAB\x85", "\xAB\x86", "\xAB\x87", "\xAB\x88",
  /* U+73D8 */	"\xAB\x89", "\xE7\xEE", "\xAB\x8A", "\xAB\x8B",
  /* U+73DC */	"\xAB\x8C", "\xAB\x8D", "\xE7\xF3", "\xAB\x8E",
  /* U+73E0 */	"\xD6\xE9", "\xAB\x8F", "\xAB\x90", "\xAB\x91",
  /* U+73E4 */	"\xAB\x92", "\xE7\xED", "\xAB\x93", "\xE7\xF2",
  /* U+73E8 */	"\xAB\x94", "\xE7\xF1", "\xAB\x95", "\xAB\x96",
  /* U+73EC */	"\xAB\x97", "\xB0\xE0", "\xAB\x98", "\xAB\x99",
  /* U+73F0 */	"\xAB\x9A", "\xAB\x9B", "\xE7\xF5", "\xAB\x9C",
  /* U+73F4 */	"\xAB\x9D", "\xAB\x9E", "\xAB\x9F", "\xAB\xA0",
  /* U+73F8 */	"\xAC\x40", "\xAC\x41", "\xAC\x42", "\xAC\x43",
  /* U+73FC */	"\xAC\x44", "\xAC\x45", "\xAC\x46", "\xAC\x47",
  /* U+7400 */	"\xAC\x48", "\xAC\x49", "\xAC\x4A", "\xC7\xF2",
  /* U+7404 */	"\xAC\x4B", "\xC0\xC5", "\xC0\xED", "\xAC\x4C",
  /* U+7408 */	"\xAC\x4D", "\xC1\xF0", "\xE7\xF0", "\xAC\x4E",
  /* U+740C */	"\xAC\x4F", "\xAC\x50", "\xAC\x51", "\xE7\xF6",
  /* U+7410 */	"\xCB\xF6", "\xAC\x52", "\xAC\x53", "\xAC\x54",
  /* U+7414 */	"\xAC\x55", "\xAC\x56", "\xAC\x57", "\xAC\x58",
  /* U+7418 */	"\xAC\x59", "\xAC\x5A", "\xE8\xA2", "\xE8\xA1",
  /* U+741C */	"\xAC\x5B", "\xAC\x5C", "\xAC\x5D", "\xAC\x5E",
  /* U+7420 */	"\xAC\x5F", "\xAC\x60", "\xD7\xC1", "\xAC\x61",
  /* U+7424 */	"\xAC\x62", "\xE7\xFA", "\xE7\xF9", "\xAC\x63",
  /* U+7428 */	"\xE7\xFB", "\xAC\x64", "\xE7\xF7", "\xAC\x65",
  /* U+742C */	"\xE7\xFE", "\xAC\x66", "\xE7\xFD", "\xAC\x67",
  /* U+7430 */	"\xE7\xFC", "\xAC\x68", "\xAC\x69", "\xC1\xD5",
  /* U+7434 */	"\xC7\xD9", "\xC5\xFD", "\xC5\xC3", "\xAC\x6A",
  /* U+7438 */	"\xAC\x6B", "\xAC\x6C", "\xAC\x6D", "\xAC\x6E",
  /* U+743C */	"\xC7\xED", "\xAC\x6F", "\xAC\x70", "\xAC\x71",
  /* U+7440 */	"\xAC\x72", "\xE8\xA3", "\xAC\x73", "\xAC\x74",
  /* U+7444 */	"\xAC\x75", "\xAC\x76", "\xAC\x77", "\xAC\x78",
  /* U+7448 */	"\xAC\x79", "\xAC\x7A", "\xAC\x7B", "\xAC\x7C",
  /* U+744C */	"\xAC\x7D", "\xAC\x7E", "\xAC\x80", "\xAC\x81",
  /* U+7450 */	"\xAC\x82", "\xAC\x83", "\xAC\x84", "\xAC\x85",
  /* U+7454 */	"\xAC\x86", "\xE8\xA6", "\xAC\x87", "\xE8\xA5",
  /* U+7458 */	"\xAC\x88", "\xE8\xA7", "\xBA\xF7", "\xE7\xF8",
  /* U+745C */	"\xE8\xA4", "\xAC\x89", "\xC8\xF0", "\xC9\xAA",
  /* U+7460 */	"\xAC\x8A", "\xAC\x8B", "\xAC\x8C", "\xAC\x8D",
  /* U+7464 */	"\xAC\x8E", "\xAC\x8F", "\xAC\x90", "\xAC\x91",
  /* U+7468 */	"\xAC\x92", "\xAC\x93", "\xAC\x94", "\xAC\x95",
  /* U+746C */	"\xAC\x96", "\xE8\xA9", "\xAC\x97", "\xAC\x98",
  /* U+7470 */	"\xB9\xE5", "\xAC\x99", "\xAC\x9A", "\xAC\x9B",
  /* U+7474 */	"\xAC\x9C", "\xAC\x9D", "\xD1\xFE", "\xE8\xA8",
  /* U+7478 */	"\xAC\x9E", "\xAC\x9F", "\xAC\xA0", "\xAD\x40",
  /* U+747C */	"\xAD\x41", "\xAD\x42", "\xE8\xAA", "\xAD\x43",
  /* U+7480 */	"\xE8\xAD", "\xE8\xAE", "\xAD\x44", "\xC1\xA7",
  /* U+7484 */	"\xAD\x45", "\xAD\x46", "\xAD\x47", "\xE8\xAF",
  /* U+7488 */	"\xAD\x48", "\xAD\x49", "\xAD\x4A", "\xE8\xB0",
  /* U+748C */	"\xAD\x4B", "\xAD\x4C", "\xE8\xAC", "\xAD\x4D",
  /* U+7490 */	"\xE8\xB4", "\xAD\x4E", "\xAD\x4F", "\xAD\x50",
  /* U+7494 */	"\xAD\x51", "\xAD\x52", "\xAD\x53", "\xAD\x54",
  /* U+7498 */	"\xAD\x55", "\xAD\x56", "\xAD\x57", "\xAD\x58",
  /* U+749C */	"\xE8\xAB", "\xAD\x59", "\xE8\xB1", "\xAD\x5A",
  /* U+74A0 */	"\xAD\x5B", "\xAD\x5C", "\xAD\x5D", "\xAD\x5E",
  /* U+74A4 */	"\xAD\x5F", "\xAD\x60", "\xAD\x61", "\xE8\xB5",
  /* U+74A8 */	"\xE8\xB2", "\xE8\xB3", "\xAD\x62", "\xAD\x63",
  /* U+74AC */	"\xAD\x64", "\xAD\x65", "\xAD\x66", "\xAD\x67",
  /* U+74B0 */	"\xAD\x68", "\xAD\x69", "\xAD\x6A", "\xAD\x6B",
  /* U+74B4 */	"\xAD\x6C", "\xAD\x6D", "\xAD\x6E", "\xAD\x6F",
  /* U+74B8 */	"\xAD\x70", "\xAD\x71", "\xE8\xB7", "\xAD\x72",
  /* U+74BC */	"\xAD\x73", "\xAD\x74", "\xAD\x75", "\xAD\x76",
  /* U+74C0 */	"\xAD\x77", "\xAD\x78", "\xAD\x79", "\xAD\x7A",
  /* U+74C4 */	"\xAD\x7B", "\xAD\x7C", "\xAD\x7D", "\xAD\x7E",
  /* U+74C8 */	"\xAD\x80", "\xAD\x81", "\xAD\x82", "\xAD\x83",
  /* U+74CC */	"\xAD\x84", "\xAD\x85", "\xAD\x86", "\xAD\x87",
  /* U+74D0 */	"\xAD\x88", "\xAD\x89", "\xE8\xB6", "\xAD\x8A",
  /* U+74D4 */	"\xAD\x8B", "\xAD\x8C", "\xAD\x8D", "\xAD\x8E",
  /* U+74D8 */	"\xAD\x8F", "\xAD\x90", "\xAD\x91", "\xAD\x92",
  /* U+74DC */	"\xB9\xCF", "\xAD\x93", "\xF0\xAC", "\xAD\x94",
  /* U+74E0 */	"\xF0\xAD", "\xAD\x95", "\xC6\xB0", "\xB0\xEA",
  /* U+74E4 */	"\xC8\xBF", "\xAD\x96", "\xCD\xDF", "\xAD\x97",
  /* U+74E8 */	"\xAD\x98", "\xAD\x99", "\xAD\x9A", "\xAD\x9B",
  /* U+74EC */	"\xAD\x9C", "\xAD\x9D", "\xCE\xCD", "\xEA\xB1",
  /* U+74F0 */	"\xAD\x9E", "\xAD\x9F", "\xAD\xA0", "\xAE\x40",
  /* U+74F4 */	"\xEA\xB2", "\xAE\x41", "\xC6\xBF", "\xB4\xC9",
  /* U+74F8 */	"\xAE\x42", "\xAE\x43", "\xAE\x44", "\xAE\x45",
  /* U+74FC */	"\xAE\x46", "\xAE\x47", "\xAE\x48", "\xEA\xB3",
  /* U+7500 */	"\xAE\x49", "\xAE\x4A", "\xAE\x4B", "\xAE\x4C",
  /* U+7504 */	"\xD5\xE7", "\xAE\x4D", "\xAE\x4E", "\xAE\x4F",
  /* U+7508 */	"\xAE\x50", "\xAE\x51", "\xAE\x52", "\xAE\x53",
  /* U+750C */	"\xAE\x54", "\xDD\xF9", "\xAE\x55", "\xEA\xB4",
  /* U+7510 */	"\xAE\x56", "\xEA\xB5", "\xAE\x57", "\xEA\xB6",
  /* U+7514 */	"\xAE\x58", "\xAE\x59", "\xAE\x5A", "\xAE\x5B",
  /* U+7518 */	"\xB8\xCA", "\xDF\xB0", "\xC9\xF5", "\xAE\x5C",
  /* U+751C */	"\xCC\xF0", "\xAE\x5D", "\xAE\x5E", "\xC9\xFA",
  /* U+7520 */	"\xAE\x5F", "\xAE\x60", "\xAE\x61", "\xAE\x62",
  /* U+7524 */	"\xAE\x63", "\xC9\xFB", "\xAE\x64", "\xAE\x65",
  /* U+7528 */	"\xD3\xC3", "\xCB\xA6", "\xAE\x66", "\xB8\xA6",
  /* U+752C */	"\xF0\xAE", "\xB1\xC2", "\xAE\x67", "\xE5\xB8",
  /* U+7530 */	"\xCC\xEF", "\xD3\xC9", "\xBC\xD7", "\xC9\xEA",
  /* U+7534 */	"\xAE\x68", "\xB5\xE7", "\xAE\x69", "\xC4\xD0",
  /* U+7538 */	"\xB5\xE9", "\xAE\x6A", "\xEE\xAE", "\xBB\xAD",
  /* U+753C */	"\xAE\x6B", "\xAE\x6C", "\xE7\xDE", "\xAE\x6D",
  /* U+7540 */	"\xEE\xAF", "\xAE\x6E", "\xAE\x6F", "\xAE\x70",
  /* U+7544 */	"\xAE\x71", "\xB3\xA9", "\xAE\x72", "\xAE\x73",
  /* U+7548 */	"\xEE\xB2", "\xAE\x74", "\xAE\x75", "\xEE\xB1",
  /* U+754C */	"\xBD\xE7", "\xAE\x76", "\xEE\xB0", "\xCE\xB7",
  /* U+7550 */	"\xAE\x77", "\xAE\x78", "\xAE\x79", "\xAE\x7A",
  /* U+7554 */	"\xC5\xCF", "\xAE\x7B", "\xAE\x7C", "\xAE\x7D",
  /* U+7558 */	"\xAE\x7E", "\xC1\xF4", "\xDB\xCE", "\xEE\xB3",
  /* U+755C */	"\xD0\xF3", "\xAE\x80", "\xAE\x81", "\xAE\x82",
  /* U+7560 */	"\xAE\x83", "\xAE\x84", "\xAE\x85", "\xAE\x86",
  /* U+7564 */	"\xAE\x87", "\xC2\xD4", "\xC6\xE8", "\xAE\x88",
  /* U+7568 */	"\xAE\x89", "\xAE\x8A", "\xB7\xAC", "\xAE\x8B",
  /* U+756C */	"\xAE\x8C", "\xAE\x8D", "\xAE\x8E", "\xAE\x8F",
  /* U+7570 */	"\xAE\x90", "\xAE\x91", "\xEE\xB4", "\xAE\x92",
  /* U+7574 */	"\xB3\xEB", "\xAE\x93", "\xAE\x94", "\xAE\x95",
  /* U+7578 */	"\xBB\xFB", "\xEE\xB5", "\xAE\x96", "\xAE\x97",
  /* U+757C */	"\xAE\x98", "\xAE\x99", "\xAE\x9A", "\xE7\xDC",
  /* U+7580 */	"\xAE\x9B", "\xAE\x9C", "\xAE\x9D", "\xEE\xB6",
  /* U+7584 */	"\xAE\x9E", "\xAE\x9F", "\xBD\xAE", "\xAE\xA0",
  /* U+7588 */	"\xAF\x40", "\xAF\x41", "\xAF\x42", "\xF1\xE2",
  /* U+758C */	"\xAF\x43", "\xAF\x44", "\xAF\x45", "\xCA\xE8",
  /* U+7590 */	"\xAF\x46", "\xD2\xC9", "\xF0\xDA", "\xAF\x47",
  /* U+7594 */	"\xF0\xDB", "\xAF\x48", "\xF0\xDC", "\xC1\xC6",
  /* U+7598 */	"\xAF\x49", "\xB8\xED", "\xBE\xCE", "\xAF\x4A",
  /* U+759C */	"\xAF\x4B", "\xF0\xDE", "\xAF\x4C", "\xC5\xB1",
  /* U+75A0 */	"\xF0\xDD", "\xD1\xF1", "\xAF\x4D", "\xF0\xE0",
  /* U+75A4 */	"\xB0\xCC", "\xBD\xEA", "\xAF\x4E", "\xAF\x4F",
  /* U+75A8 */	"\xAF\x50", "\xAF\x51", "\xAF\x52", "\xD2\xDF",
  /* U+75AC */	"\xF0\xDF", "\xAF\x53", "\xB4\xAF", "\xB7\xE8",
  /* U+75B0 */	"\xF0\xE6", "\xF0\xE5", "\xC6\xA3", "\xF0\xE1",
  /* U+75B4 */	"\xF0\xE2", "\xB4\xC3", "\xAF\x54", "\xAF\x55",
  /* U+75B8 */	"\xF0\xE3", "\xD5\xEE", "\xAF\x56", "\xAF\x57",
  /* U+75BC */	"\xCC\xDB", "\xBE\xD2", "\xBC\xB2", "\xAF\x58",
  /* U+75C0 */	"\xAF\x59", "\xAF\x5A", "\xF0\xE8", "\xF0\xE7",
  /* U+75C4 */	"\xF0\xE4", "\xB2\xA1", "\xAF\x5B", "\xD6\xA2",
  /* U+75C8 */	"\xD3\xB8", "\xBE\xB7", "\xC8\xAC", "\xAF\x5C",
  /* U+75CC */	"\xAF\x5D", "\xF0\xEA", "\xAF\x5E", "\xAF\x5F",
  /* U+75D0 */	"\xAF\x60", "\xAF\x61", "\xD1\xF7", "\xAF\x62",
  /* U+75D4 */	"\xD6\xCC", "\xBA\xDB", "\xF0\xE9", "\xAF\x63",
  /* U+75D8 */	"\xB6\xBB", "\xAF\x64", "\xAF\x65", "\xCD\xB4",
  /* U+75DC */	"\xAF\x66", "\xAF\x67", "\xC6\xA6", "\xAF\x68",
  /* U+75E0 */	"\xAF\x69", "\xAF\x6A", "\xC1\xA1", "\xF0\xEB",
  /* U+75E4 */	"\xF0\xEE", "\xAF\x6B", "\xF0\xED", "\xF0\xF0",
  /* U+75E8 */	"\xF0\xEC", "\xAF\x6C", "\xBB\xBE", "\xF0\xEF",
  /* U+75EC */	"\xAF\x6D", "\xAF\x6E", "\xAF\x6F", "\xAF\x70",
  /* U+75F0 */	"\xCC\xB5", "\xF0\xF2", "\xAF\x71", "\xAF\x72",
  /* U+75F4 */	"\xB3\xD5", "\xAF\x73", "\xAF\x74", "\xAF\x75",
  /* U+75F8 */	"\xAF\x76", "\xB1\xD4", "\xAF\x77", "\xAF\x78",
  /* U+75FC */	"\xF0\xF3", "\xAF\x79", "\xAF\x7A", "\xF0\xF4",
  /* U+7600 */	"\xF0\xF6", "\xB4\xE1", "\xAF\x7B", "\xF0\xF1",
  /* U+7604 */	"\xAF\x7C", "\xF0\xF7", "\xAF\x7D", "\xAF\x7E",
  /* U+7608 */	"\xAF\x80", "\xAF\x81", "\xF0\xFA", "\xAF\x82",
  /* U+760C */	"\xF0\xF8", "\xAF\x83", "\xAF\x84", "\xAF\x85",
  /* U+7610 */	"\xF0\xF5", "\xAF\x86", "\xAF\x87", "\xAF\x88",
  /* U+7614 */	"\xAF\x89", "\xF0\xFD", "\xAF\x8A", "\xF0\xF9",
  /* U+7618 */	"\xF0\xFC", "\xF0\xFE", "\xAF\x8B", "\xF1\xA1",
  /* U+761C */	"\xAF\x8C", "\xAF\x8D", "\xAF\x8E", "\xCE\xC1",
  /* U+7620 */	"\xF1\xA4", "\xAF\x8F", "\xF1\xA3", "\xAF\x90",
  /* U+7624 */	"\xC1\xF6", "\xF0\xFB", "\xCA\xDD", "\xAF\x91",
  /* U+7628 */	"\xAF\x92", "\xB4\xF1", "\xB1\xF1", "\xCC\xB1",
  /* U+762C */	"\xAF\x93", "\xF1\xA6", "\xAF\x94", "\xAF\x95",
  /* U+7630 */	"\xF1\xA7", "\xAF\x96", "\xAF\x97", "\xF1\xAC",
  /* U+7634 */	"\xD5\xCE", "\xF1\xA9", "\xAF\x98", "\xAF\x99",
  /* U+7638 */	"\xC8\xB3", "\xAF\x9A", "\xAF\x9B", "\xAF\x9C",
  /* U+763C */	"\xF1\xA2", "\xAF\x9D", "\xF1\xAB", "\xF1\xA8",
  /* U+7640 */	"\xF1\xA5", "\xAF\x9E", "\xAF\x9F", "\xF1\xAA",
  /* U+7644 */	"\xAF\xA0", "\xB0\x40", "\xB0\x41", "\xB0\x42",
  /* U+7648 */	"\xB0\x43", "\xB0\x44", "\xB0\x45", "\xB0\x46",
  /* U+764C */	"\xB0\xA9", "\xF1\xAD", "\xB0\x47", "\xB0\x48",
  /* U+7650 */	"\xB0\x49", "\xB0\x4A", "\xB0\x4B", "\xB0\x4C",
  /* U+7654 */	"\xF1\xAF", "\xB0\x4D", "\xF1\xB1", "\xB0\x4E",
  /* U+7658 */	"\xB0\x4F", "\xB0\x50", "\xB0\x51", "\xB0\x52",
  /* U+765C */	"\xF1\xB0", "\xB0\x53", "\xF1\xAE", "\xB0\x54",
  /* U+7660 */	"\xB0\x55", "\xB0\x56", "\xB0\x57", "\xD1\xA2",
  /* U+7664 */	"\xB0\x58", "\xB0\x59", "\xB0\x5A", "\xB0\x5B",
  /* U+7668 */	"\xB0\x5C", "\xB0\x5D", "\xB0\x5E", "\xF1\xB2",
  /* U+766C */	"\xB0\x5F", "\xB0\x60", "\xB0\x61", "\xF1\xB3",
  /* U+7670 */	"\xB0\x62", "\xB0\x63", "\xB0\x64", "\xB0\x65",
  /* U+7674 */	"\xB0\x66", "\xB0\x67", "\xB0\x68", "\xB0\x69",
  /* U+7678 */	"\xB9\xEF", "\xB0\x6A", "\xB0\x6B", "\xB5\xC7",
  /* U+767C */	"\xB0\x6C", "\xB0\xD7", "\xB0\xD9", "\xB0\x6D",
  /* U+7680 */	"\xB0\x6E", "\xB0\x6F", "\xD4\xED", "\xB0\x70",
  /* U+7684 */	"\xB5\xC4", "\xB0\x71", "\xBD\xD4", "\xBB\xCA",
  /* U+7688 */	"\xF0\xA7", "\xB0\x72", "\xB0\x73", "\xB8\xDE",
  /* U+768C */	"\xB0\x74", "\xB0\x75", "\xF0\xA8", "\xB0\x76",
  /* U+7690 */	"\xB0\x77", "\xB0\xA8", "\xB0\x78", "\xF0\xA9",
  /* U+7694 */	"\xB0\x79", "\xB0\x7A", "\xCD\xEE", "\xB0\x7B",
  /* U+7698 */	"\xB0\x7C", "\xF0\xAA", "\xB0\x7D", "\xB0\x7E",
  /* U+769C */	"\xB0\x80", "\xB0\x81", "\xB0\x82", "\xB0\x83",
  /* U+76A0 */	"\xB0\x84", "\xB0\x85", "\xB0\x86", "\xB0\x87",
  /* U+76A4 */	"\xF0\xAB", "\xB0\x88", "\xB0\x89", "\xB0\x8A",
  /* U+76A8 */	"\xB0\x8B", "\xB0\x8C", "\xB0\x8D", "\xB0\x8E",
  /* U+76AC */	"\xB0\x8F", "\xB0\x90", "\xC6\xA4", "\xB0\x91",
  /* U+76B0 */	"\xB0\x92", "\xD6\xE5", "\xF1\xE4", "\xB0\x93",
  /* U+76B4 */	"\xF1\xE5", "\xB0\x94", "\xB0\x95", "\xB0\x96",
  /* U+76B8 */	"\xB0\x97", "\xB0\x98", "\xB0\x99", "\xB0\x9A",
  /* U+76BC */	"\xB0\x9B", "\xB0\x9C", "\xB0\x9D", "\xC3\xF3",
  /* U+76C0 */	"\xB0\x9E", "\xB0\x9F", "\xD3\xDB", "\xB0\xA0",
  /* U+76C4 */	"\xB1\x40", "\xD6\xD1", "\xC5\xE8", "\xB1\x41",
  /* U+76C8 */	"\xD3\xAF", "\xB1\x42", "\xD2\xE6", "\xB1\x43",
  /* U+76CC */	"\xB1\x44", "\xEE\xC1", "\xB0\xBB", "\xD5\xB5",
  /* U+76D0 */	"\xD1\xCE", "\xBC\xE0", "\xBA\xD0", "\xB1\x45",
  /* U+76D4 */	"\xBF\xF8", "\xB1\x46", "\xB8\xC7", "\xB5\xC1",
  /* U+76D8 */	"\xC5\xCC", "\xB1\x47", "\xB1\x48", "\xCA\xA2",
  /* U+76DC */	"\xB1\x49", "\xB1\x4A", "\xB1\x4B", "\xC3\xCB",
  /* U+76E0 */	"\xB1\x4C", "\xB1\x4D", "\xB1\x4E", "\xB1\x4F",
  /* U+76E4 */	"\xB1\x50", "\xEE\xC2", "\xB1\x51", "\xB1\x52",
  /* U+76E8 */	"\xB1\x53", "\xB1\x54", "\xB1\x55", "\xB1\x56",
  /* U+76EC */	"\xB1\x57", "\xB1\x58", "\xC4\xBF", "\xB6\xA2",
  /* U+76F0 */	"\xB1\x59", "\xED\xEC", "\xC3\xA4", "\xB1\x5A",
  /* U+76F4 */	"\xD6\xB1", "\xB1\x5B", "\xB1\x5C", "\xB1\x5D",
  /* U+76F8 */	"\xCF\xE0", "\xED\xEF", "\xB1\x5E", "\xB1\x5F",
  /* U+76FC */	"\xC5\xCE", "\xB1\x60", "\xB6\xDC", "\xB1\x61",
  /* U+7700 */	"\xB1\x62", "\xCA\xA1", "\xB1\x63", "\xB1\x64",
  /* U+7704 */	"\xED\xED", "\xB1\x65", "\xB1\x66", "\xED\xF0",
  /* U+7708 */	"\xED\xF1", "\xC3\xBC", "\xB1\x67", "\xBF\xB4",
  /* U+770C */	"\xB1\x68", "\xED\xEE", "\xB1\x69", "\xB1\x6A",
  /* U+7710 */	"\xB1\x6B", "\xB1\x6C", "\xB1\x6D", "\xB1\x6E",
  /* U+7714 */	"\xB1\x6F", "\xB1\x70", "\xB1\x71", "\xB1\x72",
  /* U+7718 */	"\xB1\x73", "\xED\xF4", "\xED\xF2", "\xB1\x74",
  /* U+771C */	"\xB1\x75", "\xB1\x76", "\xB1\x77", "\xD5\xE6",
  /* U+7720 */	"\xC3\xDF", "\xB1\x78", "\xED\xF3", "\xB1\x79",
  /* U+7724 */	"\xB1\x7A", "\xB1\x7B", "\xED\xF6", "\xB1\x7C",
  /* U+7728 */	"\xD5\xA3", "\xD1\xA3", "\xB1\x7D", "\xB1\x7E",
  /* U+772C */	"\xB1\x80", "\xED\xF5", "\xB1\x81", "\xC3\xD0",
  /* U+7730 */	"\xB1\x82", "\xB1\x83", "\xB1\x84", "\xB1\x85",
  /* U+7734 */	"\xB1\x86", "\xED\xF7", "\xBF\xF4", "\xBE\xEC",
  /* U+7738 */	"\xED\xF8", "\xB1\x87", "\xCC\xF7", "\xB1\x88",
  /* U+773C */	"\xD1\xDB", "\xB1\x89", "\xB1\x8A", "\xB1\x8B",
  /* U+7740 */	"\xD7\xC5", "\xD5\xF6", "\xB1\x8C", "\xED\xFC",
  /* U+7744 */	"\xB1\x8D", "\xB1\x8E", "\xB1\x8F", "\xED\xFB",
  /* U+7748 */	"\xB1\x90", "\xB1\x91", "\xB1\x92", "\xB1\x93",
  /* U+774C */	"\xB1\x94", "\xB1\x95", "\xB1\x96", "\xB1\x97",
  /* U+7750 */	"\xED\xF9", "\xED\xFA", "\xB1\x98", "\xB1\x99",
  /* U+7754 */	"\xB1\x9A", "\xB1\x9B", "\xB1\x9C", "\xB1\x9D",
  /* U+7758 */	"\xB1\x9E", "\xB1\x9F", "\xED\xFD", "\xBE\xA6",
  /* U+775C */	"\xB1\xA0", "\xB2\x40", "\xB2\x41", "\xB2\x42",
  /* U+7760 */	"\xB2\x43", "\xCB\xAF", "\xEE\xA1", "\xB6\xBD",
  /* U+7764 */	"\xB2\x44", "\xEE\xA2", "\xC4\xC0", "\xB2\x45",
  /* U+7768 */	"\xED\xFE", "\xB2\x46", "\xB2\x47", "\xBD\xDE",
  /* U+776C */	"\xB2\xC7", "\xB2\x48", "\xB2\x49", "\xB2\x4A",
  /* U+7770 */	"\xB2\x4B", "\xB2\x4C", "\xB2\x4D", "\xB2\x4E",
  /* U+7774 */	"\xB2\x4F", "\xB2\x50", "\xB2\x51", "\xB2\x52",
  /* U+7778 */	"\xB2\x53", "\xB6\xC3", "\xB2\x54", "\xB2\x55",
  /* U+777C */	"\xB2\x56", "\xEE\xA5", "\xD8\xBA", "\xEE\xA3",
  /* U+7780 */	"\xEE\xA6", "\xB2\x57", "\xB2\x58", "\xB2\x59",
  /* U+7784 */	"\xC3\xE9", "\xB3\xF2", "\xB2\x5A", "\xB2\x5B",
  /* U+7788 */	"\xB2\x5C", "\xB2\x5D", "\xB2\x5E", "\xB2\x5F",
  /* U+778C */	"\xEE\xA7", "\xEE\xA4", "\xCF\xB9", "\xB2\x60",
  /* U+7790 */	"\xB2\x61", "\xEE\xA8", "\xC2\xF7", "\xB2\x62",
  /* U+7794 */	"\xB2\x63", "\xB2\x64", "\xB2\x65", "\xB2\x66",
  /* U+7798 */	"\xB2\x67", "\xB2\x68", "\xB2\x69", "\xB2\x6A",
  /* U+779C */	"\xB2\x6B", "\xB2\x6C", "\xB2\x6D", "\xEE\xA9",
  /* U+77A0 */	"\xEE\xAA", "\xB2\x6E", "\xDE\xAB", "\xB2\x6F",
  /* U+77A4 */	"\xB2\x70", "\xC6\xB3", "\xB2\x71", "\xC7\xC6",
  /* U+77A8 */	"\xB2\x72", "\xD6\xF5", "\xB5\xC9", "\xB2\x73",
  /* U+77AC */	"\xCB\xB2", "\xB2\x74", "\xB2\x75", "\xB2\x76",
  /* U+77B0 */	"\xEE\xAB", "\xB2\x77", "\xB2\x78", "\xCD\xAB",
  /* U+77B4 */	"\xB2\x79", "\xEE\xAC", "\xB2\x7A", "\xB2\x7B",
  /* U+77B8 */	"\xB2\x7C", "\xB2\x7D", "\xB2\x7E", "\xD5\xB0",
  /* U+77BC */	"\xB2\x80", "\xEE\xAD", "\xB2\x81", "\xF6\xC4",
  /* U+77C0 */	"\xB2\x82", "\xB2\x83", "\xB2\x84", "\xB2\x85",
  /* U+77C4 */	"\xB2\x86", "\xB2\x87", "\xB2\x88", "\xB2\x89",
  /* U+77C8 */	"\xB2\x8A", "\xB2\x8B", "\xB2\x8C", "\xB2\x8D",
  /* U+77CC */	"\xB2\x8E", "\xDB\xC7", "\xB2\x8F", "\xB2\x90",
  /* U+77D0 */	"\xB2\x91", "\xB2\x92", "\xB2\x93", "\xB2\x94",
  /* U+77D4 */	"\xB2\x95", "\xB2\x96", "\xB2\x97", "\xB4\xA3",
  /* U+77D8 */	"\xB2\x98", "\xB2\x99", "\xB2\x9A", "\xC3\xAC",
  /* U+77DC */	"\xF1\xE6", "\xB2\x9B", "\xB2\x9C", "\xB2\x9D",
  /* U+77E0 */	"\xB2\x9E", "\xB2\x9F", "\xCA\xB8", "\xD2\xD3",
  /* U+77E4 */	"\xB2\xA0", "\xD6\xAA", "\xB3\x40", "\xEF\xF2",
  /* U+77E8 */	"\xB3\x41", "\xBE\xD8", "\xB3\x42", "\xBD\xC3",
  /* U+77EC */	"\xEF\xF3", "\xB6\xCC", "\xB0\xAB", "\xB3\x43",
  /* U+77F0 */	"\xB3\x44", "\xB3\x45", "\xB3\x46", "\xCA\xAF",
  /* U+77F4 */	"\xB3\x47", "\xB3\x48", "\xED\xB6", "\xB3\x49",
  /* U+77F8 */	"\xED\xB7", "\xB3\x4A", "\xB3\x4B", "\xB3\x4C",
  /* U+77FC */	"\xB3\x4D", "\xCE\xF9", "\xB7\xAF", "\xBF\xF3",
  /* U+7800 */	"\xED\xB8", "\xC2\xEB", "\xC9\xB0", "\xB3\x4E",
  /* U+7804 */	"\xB3\x4F", "\xB3\x50", "\xB3\x51", "\xB3\x52",
  /* U+7808 */	"\xB3\x53", "\xED\xB9", "\xB3\x54", "\xB3\x55",
  /* U+780C */	"\xC6\xF6", "\xBF\xB3", "\xB3\x56", "\xB3\x57",
  /* U+7810 */	"\xB3\x58", "\xED\xBC", "\xC5\xF8", "\xB3\x59",
  /* U+7814 */	"\xD1\xD0", "\xB3\x5A", "\xD7\xA9", "\xED\xBA",
  /* U+7818 */	"\xED\xBB", "\xB3\x5B", "\xD1\xE2", "\xB3\x5C",
  /* U+781C */	"\xED\xBF", "\xED\xC0", "\xB3\x5D", "\xED\xC4",
  /* U+7820 */	"\xB3\x5E", "\xB3\x5F", "\xB3\x60", "\xED\xC8",
  /* U+7824 */	"\xB3\x61", "\xED\xC6", "\xED\xCE", "\xD5\xE8",
  /* U+7828 */	"\xB3\x62", "\xED\xC9", "\xB3\x63", "\xB3\x64",
  /* U+782C */	"\xED\xC7", "\xED\xBE", "\xB3\x65", "\xB3\x66",
  /* U+7830 */	"\xC5\xE9", "\xB3\x67", "\xB3\x68", "\xB3\x69",
  /* U+7834 */	"\xC6\xC6", "\xB3\x6A", "\xB3\x6B", "\xC9\xE9",
  /* U+7838 */	"\xD4\xD2", "\xED\xC1", "\xED\xC2", "\xED\xC3",
  /* U+783C */	"\xED\xC5", "\xB3\x6C", "\xC0\xF9", "\xB3\x6D",
  /* U+7840 */	"\xB4\xA1", "\xB3\x6E", "\xB3\x6F", "\xB3\x70",
  /* U+7844 */	"\xB3\x71", "\xB9\xE8", "\xB3\x72", "\xED\xD0",
  /* U+7848 */	"\xB3\x73", "\xB3\x74", "\xB3\x75", "\xB3\x76",
  /* U+784C */	"\xED\xD1", "\xB3\x77", "\xED\xCA", "\xB3\x78",
  /* U+7850 */	"\xED\xCF", "\xB3\x79", "\xCE\xF8", "\xB3\x7A",
  /* U+7854 */	"\xB3\x7B", "\xCB\xB6", "\xED\xCC", "\xED\xCD",
  /* U+7858 */	"\xB3\x7C", "\xB3\x7D", "\xB3\x7E", "\xB3\x80",
  /* U+785C */	"\xB3\x81", "\xCF\xF5", "\xB3\x82", "\xB3\x83",
  /* U+7860 */	"\xB3\x84", "\xB3\x85", "\xB3\x86", "\xB3\x87",
  /* U+7864 */	"\xB3\x88", "\xB3\x89", "\xB3\x8A", "\xB3\x8B",
  /* U+7868 */	"\xB3\x8C", "\xB3\x8D", "\xED\xD2", "\xC1\xF2",
  /* U+786C */	"\xD3\xB2", "\xED\xCB", "\xC8\xB7", "\xB3\x8E",
  /* U+7870 */	"\xB3\x8F", "\xB3\x90", "\xB3\x91", "\xB3\x92",
  /* U+7874 */	"\xB3\x93", "\xB3\x94", "\xB3\x95", "\xBC\xEF",
  /* U+7878 */	"\xB3\x96", "\xB3\x97", "\xB3\x98", "\xB3\x99",
  /* U+787C */	"\xC5\xF0", "\xB3\x9A", "\xB3\x9B", "\xB3\x9C",
  /* U+7880 */	"\xB3\x9D", "\xB3\x9E", "\xB3\x9F", "\xB3\xA0",
  /* U+7884 */	"\xB4\x40", "\xB4\x41", "\xB4\x42", "\xED\xD6",
  /* U+7888 */	"\xB4\x43", "\xB5\xEF", "\xB4\x44", "\xB4\x45",
  /* U+788C */	"\xC2\xB5", "\xB0\xAD", "\xCB\xE9", "\xB4\x46",
  /* U+7890 */	"\xB4\x47", "\xB1\xAE", "\xB4\x48", "\xED\xD4",
  /* U+7894 */	"\xB4\x49", "\xB4\x4A", "\xB4\x4B", "\xCD\xEB",
  /* U+7898 */	"\xB5\xE2", "\xB4\x4C", "\xED\xD5", "\xED\xD3",
  /* U+789C */	"\xED\xD7", "\xB4\x4D", "\xB4\x4E", "\xB5\xFA",
  /* U+78A0 */	"\xB4\x4F", "\xED\xD8", "\xB4\x50", "\xED\xD9",
  /* U+78A4 */	"\xB4\x51", "\xED\xDC", "\xB4\x52", "\xB1\xCC",
  /* U+78A8 */	"\xB4\x53", "\xB4\x54", "\xB4\x55", "\xB4\x56",
  /* U+78AC */	"\xB4\x57", "\xB4\x58", "\xB4\x59", "\xB4\x5A",
  /* U+78B0 */	"\xC5\xF6", "\xBC\xEE", "\xED\xDA", "\xCC\xBC",
  /* U+78B4 */	"\xB2\xEA", "\xB4\x5B", "\xB4\x5C", "\xB4\x5D",
  /* U+78B8 */	"\xB4\x5E", "\xED\xDB", "\xB4\x5F", "\xB4\x60",
  /* U+78BC */	"\xB4\x61", "\xB4\x62", "\xC4\xEB", "\xB4\x63",
  /* U+78C0 */	"\xB4\x64", "\xB4\xC5", "\xB4\x65", "\xB4\x66",
  /* U+78C4 */	"\xB4\x67", "\xB0\xF5", "\xB4\x68", "\xB4\x69",
  /* U+78C8 */	"\xB4\x6A", "\xED\xDF", "\xC0\xDA", "\xB4\xE8",
  /* U+78CC */	"\xB4\x6B", "\xB4\x6C", "\xB4\x6D", "\xB4\x6E",
  /* U+78D0 */	"\xC5\xCD", "\xB4\x6F", "\xB4\x70", "\xB4\x71",
  /* U+78D4 */	"\xED\xDD", "\xBF\xC4", "\xB4\x72", "\xB4\x73",
  /* U+78D8 */	"\xB4\x74", "\xED\xDE", "\xB4\x75", "\xB4\x76",
  /* U+78DC */	"\xB4\x77", "\xB4\x78", "\xB4\x79", "\xB4\x7A",
  /* U+78E0 */	"\xB4\x7B", "\xB4\x7C", "\xB4\x7D", "\xB4\x7E",
  /* U+78E4 */	"\xB4\x80", "\xB4\x81", "\xB4\x82", "\xB4\x83",
  /* U+78E8 */	"\xC4\xA5", "\xB4\x84", "\xB4\x85", "\xB4\x86",
  /* U+78EC */	"\xED\xE0", "\xB4\x87", "\xB4\x88", "\xB4\x89",
  /* U+78F0 */	"\xB4\x8A", "\xB4\x8B", "\xED\xE1", "\xB4\x8C",
  /* U+78F4 */	"\xED\xE3", "\xB4\x8D", "\xB4\x8E", "\xC1\xD7",
  /* U+78F8 */	"\xB4\x8F", "\xB4\x90", "\xBB\xC7", "\xB4\x91",
  /* U+78FC */	"\xB4\x92", "\xB4\x93", "\xB4\x94", "\xB4\x95",
  /* U+7900 */	"\xB4\x96", "\xBD\xB8", "\xB4\x97", "\xB4\x98",
  /* U+7904 */	"\xB4\x99", "\xED\xE2", "\xB4\x9A", "\xB4\x9B",
  /* U+7908 */	"\xB4\x9C", "\xB4\x9D", "\xB4\x9E", "\xB4\x9F",
  /* U+790C */	"\xB4\xA0", "\xB5\x40", "\xB5\x41", "\xB5\x42",
  /* U+7910 */	"\xB5\x43", "\xB5\x44", "\xB5\x45", "\xED\xE4",
  /* U+7914 */	"\xB5\x46", "\xB5\x47", "\xB5\x48", "\xB5\x49",
  /* U+7918 */	"\xB5\x4A", "\xB5\x4B", "\xB5\x4C", "\xB5\x4D",
  /* U+791C */	"\xB5\x4E", "\xB5\x4F", "\xED\xE6", "\xB5\x50",
  /* U+7920 */	"\xB5\x51", "\xB5\x52", "\xB5\x53", "\xB5\x54",
  /* U+7924 */	"\xED\xE5", "\xB5\x55", "\xB5\x56", "\xB5\x57",
  /* U+7928 */	"\xB5\x58", "\xB5\x59", "\xB5\x5A", "\xB5\x5B",
  /* U+792C */	"\xB5\x5C", "\xB5\x5D", "\xB5\x5E", "\xB5\x5F",
  /* U+7930 */	"\xB5\x60", "\xB5\x61", "\xB5\x62", "\xB5\x63",
  /* U+7934 */	"\xED\xE7", "\xB5\x64", "\xB5\x65", "\xB5\x66",
  /* U+7938 */	"\xB5\x67", "\xB5\x68", "\xCA\xBE", "\xEC\xEA",
  /* U+793C */	"\xC0\xF1", "\xB5\x69", "\xC9\xE7", "\xB5\x6A",
  /* U+7940 */	"\xEC\xEB", "\xC6\xEE", "\xB5\x6B", "\xB5\x6C",
  /* U+7944 */	"\xB5\x6D", "\xB5\x6E", "\xEC\xEC", "\xB5\x6F",
  /* U+7948 */	"\xC6\xED", "\xEC\xED", "\xB5\x70", "\xB5\x71",
  /* U+794C */	"\xB5\x72", "\xB5\x73", "\xB5\x74", "\xB5\x75",
  /* U+7950 */	"\xB5\x76", "\xB5\x77", "\xB5\x78", "\xEC\xF0",
  /* U+7954 */	"\xB5\x79", "\xB5\x7A", "\xD7\xE6", "\xEC\xF3",
  /* U+7958 */	"\xB5\x7B", "\xB5\x7C", "\xEC\xF1", "\xEC\xEE",
  /* U+795C */	"\xEC\xEF", "\xD7\xA3", "\xC9\xF1", "\xCB\xEE",
  /* U+7960 */	"\xEC\xF4", "\xB5\x7D", "\xEC\xF2", "\xB5\x7E",
  /* U+7964 */	"\xB5\x80", "\xCF\xE9", "\xB5\x81", "\xEC\xF6",
  /* U+7968 */	"\xC6\xB1", "\xB5\x82", "\xB5\x83", "\xB5\x84",
  /* U+796C */	"\xB5\x85", "\xBC\xC0", "\xB5\x86", "\xEC\xF5",
  /* U+7970 */	"\xB5\x87", "\xB5\x88", "\xB5\x89", "\xB5\x8A",
  /* U+7974 */	"\xB5\x8B", "\xB5\x8C", "\xB5\x8D", "\xB5\xBB",
  /* U+7978 */	"\xBB\xF6", "\xB5\x8E", "\xEC\xF7", "\xB5\x8F",
  /* U+797C */	"\xB5\x90", "\xB5\x91", "\xB5\x92", "\xB5\x93",
  /* U+7980 */	"\xD9\xF7", "\xBD\xFB", "\xB5\x94", "\xB5\x95",
  /* U+7984 */	"\xC2\xBB", "\xEC\xF8", "\xB5\x96", "\xB5\x97",
  /* U+7988 */	"\xB5\x98", "\xB5\x99", "\xEC\xF9", "\xB5\x9A",
  /* U+798C */	"\xB5\x9B", "\xB5\x9C", "\xB5\x9D", "\xB8\xA3",
  /* U+7990 */	"\xB5\x9E", "\xB5\x9F", "\xB5\xA0", "\xB6\x40",
  /* U+7994 */	"\xB6\x41", "\xB6\x42", "\xB6\x43", "\xB6\x44",
  /* U+7998 */	"\xB6\x45", "\xB6\x46", "\xEC\xFA", "\xB6\x47",
  /* U+799C */	"\xB6\x48", "\xB6\x49", "\xB6\x4A", "\xB6\x4B",
  /* U+79A0 */	"\xB6\x4C", "\xB6\x4D", "\xB6\x4E", "\xB6\x4F",
  /* U+79A4 */	"\xB6\x50", "\xB6\x51", "\xB6\x52", "\xEC\xFB",
  /* U+79A8 */	"\xB6\x53", "\xB6\x54", "\xB6\x55", "\xB6\x56",
  /* U+79AC */	"\xB6\x57", "\xB6\x58", "\xB6\x59", "\xB6\x5A",
  /* U+79B0 */	"\xB6\x5B", "\xB6\x5C", "\xB6\x5D", "\xEC\xFC",
  /* U+79B4 */	"\xB6\x5E", "\xB6\x5F", "\xB6\x60", "\xB6\x61",
  /* U+79B8 */	"\xB6\x62", "\xD3\xED", "\xD8\xAE", "\xC0\xEB",
  /* U+79BC */	"\xB6\x63", "\xC7\xDD", "\xBA\xCC", "\xB6\x64",
  /* U+79C0 */	"\xD0\xE3", "\xCB\xBD", "\xB6\x65", "\xCD\xBA",
  /* U+79C4 */	"\xB6\x66", "\xB6\x67", "\xB8\xD1", "\xB6\x68",
  /* U+79C8 */	"\xB6\x69", "\xB1\xFC", "\xB6\x6A", "\xC7\xEF",
  /* U+79CC */	"\xB6\x6B", "\xD6\xD6", "\xB6\x6C", "\xB6\x6D",
  /* U+79D0 */	"\xB6\x6E", "\xBF\xC6", "\xC3\xEB", "\xB6\x6F",
  /* U+79D4 */	"\xB6\x70", "\xEF\xF5", "\xB6\x71", "\xB6\x72",
  /* U+79D8 */	"\xC3\xD8", "\xB6\x73", "\xB6\x74", "\xB6\x75",
  /* U+79DC */	"\xB6\x76", "\xB6\x77", "\xB6\x78", "\xD7\xE2",
  /* U+79E0 */	"\xB6\x79", "\xB6\x7A", "\xB6\x7B", "\xEF\xF7",
  /* U+79E4 */	"\xB3\xD3", "\xB6\x7C", "\xC7\xD8", "\xD1\xED",
  /* U+79E8 */	"\xB6\x7D", "\xD6\xC8", "\xB6\x7E", "\xEF\xF8",
  /* U+79EC */	"\xB6\x80", "\xEF\xF6", "\xB6\x81", "\xBB\xFD",
  /* U+79F0 */	"\xB3\xC6", "\xB6\x82", "\xB6\x83", "\xB6\x84",
  /* U+79F4 */	"\xB6\x85", "\xB6\x86", "\xB6\x87", "\xB6\x88",
  /* U+79F8 */	"\xBD\xD5", "\xB6\x89", "\xB6\x8A", "\xD2\xC6",
  /* U+79FC */	"\xB6\x8B", "\xBB\xE0", "\xB6\x8C", "\xB6\x8D",
  /* U+7A00 */	"\xCF\xA1", "\xB6\x8E", "\xEF\xFC", "\xEF\xFB",
  /* U+7A04 */	"\xB6\x8F", "\xB6\x90", "\xEF\xF9", "\xB6\x91",
  /* U+7A08 */	"\xB6\x92", "\xB6\x93", "\xB6\x94", "\xB3\xCC",
  /* U+7A0C */	"\xB6\x95", "\xC9\xD4", "\xCB\xB0", "\xB6\x96",
  /* U+7A10 */	"\xB6\x97", "\xB6\x98", "\xB6\x99", "\xB6\x9A",
  /* U+7A14 */	"\xEF\xFE", "\xB6\x9B", "\xB6\x9C", "\xB0\xDE",
  /* U+7A18 */	"\xB6\x9D", "\xB6\x9E", "\xD6\xC9", "\xB6\x9F",
  /* U+7A1C */	"\xB6\xA0", "\xB7\x40", "\xEF\xFD", "\xB7\x41",
  /* U+7A20 */	"\xB3\xED", "\xB7\x42", "\xB7\x43", "\xF6\xD5",
  /* U+7A24 */	"\xB7\x44", "\xB7\x45", "\xB7\x46", "\xB7\x47",
  /* U+7A28 */	"\xB7\x48", "\xB7\x49", "\xB7\x4A", "\xB7\x4B",
  /* U+7A2C */	"\xB7\x4C", "\xB7\x4D", "\xB7\x4E", "\xB7\x4F",
  /* U+7A30 */	"\xB7\x50", "\xB7\x51", "\xB7\x52", "\xCE\xC8",
  /* U+7A34 */	"\xB7\x53", "\xB7\x54", "\xB7\x55", "\xF0\xA2",
  /* U+7A38 */	"\xB7\x56", "\xF0\xA1", "\xB7\x57", "\xB5\xBE",
  /* U+7A3C */	"\xBC\xDA", "\xBB\xFC", "\xB7\x58", "\xB8\xE5",
  /* U+7A40 */	"\xB7\x59", "\xB7\x5A", "\xB7\x5B", "\xB7\x5C",
  /* U+7A44 */	"\xB7\x5D", "\xB7\x5E", "\xC4\xC2", "\xB7\x5F",
  /* U+7A48 */	"\xB7\x60", "\xB7\x61", "\xB7\x62", "\xB7\x63",
  /* U+7A4C */	"\xB7\x64", "\xB7\x65", "\xB7\x66", "\xB7\x67",
  /* U+7A50 */	"\xB7\x68", "\xF0\xA3", "\xB7\x69", "\xB7\x6A",
  /* U+7A54 */	"\xB7\x6B", "\xB7\x6C", "\xB7\x6D", "\xCB\xEB",
  /* U+7A58 */	"\xB7\x6E", "\xB7\x6F", "\xB7\x70", "\xB7\x71",
  /* U+7A5C */	"\xB7\x72", "\xB7\x73", "\xB7\x74", "\xB7\x75",
  /* U+7A60 */	"\xB7\x76", "\xB7\x77", "\xB7\x78", "\xB7\x79",
  /* U+7A64 */	"\xB7\x7A", "\xB7\x7B", "\xB7\x7C", "\xB7\x7D",
  /* U+7A68 */	"\xB7\x7E", "\xB7\x80", "\xB7\x81", "\xB7\x82",
  /* U+7A6C */	"\xB7\x83", "\xB7\x84", "\xB7\x85", "\xB7\x86",
  /* U+7A70 */	"\xF0\xA6", "\xB7\x87", "\xB7\x88", "\xB7\x89",
  /* U+7A74 */	"\xD1\xA8", "\xB7\x8A", "\xBE\xBF", "\xC7\xEE",
  /* U+7A78 */	"\xF1\xB6", "\xF1\xB7", "\xBF\xD5", "\xB7\x8B",
  /* U+7A7C */	"\xB7\x8C", "\xB7\x8D", "\xB7\x8E", "\xB4\xA9",
  /* U+7A80 */	"\xF1\xB8", "\xCD\xBB", "\xB7\x8F", "\xC7\xD4",
  /* U+7A84 */	"\xD5\xAD", "\xB7\x90", "\xF1\xB9", "\xB7\x91",
  /* U+7A88 */	"\xF1\xBA", "\xB7\x92", "\xB7\x93", "\xB7\x94",
  /* U+7A8C */	"\xB7\x95", "\xC7\xCF", "\xB7\x96", "\xB7\x97",
  /* U+7A90 */	"\xB7\x98", "\xD2\xA4", "\xD6\xCF", "\xB7\x99",
  /* U+7A94 */	"\xB7\x9A", "\xF1\xBB", "\xBD\xD1", "\xB4\xB0",
  /* U+7A98 */	"\xBE\xBD", "\xB7\x9B", "\xB7\x9C", "\xB7\x9D",
  /* U+7A9C */	"\xB4\xDC", "\xCE\xD1", "\xB7\x9E", "\xBF\xDF",
  /* U+7AA0 */	"\xF1\xBD", "\xB7\x9F", "\xB7\xA0", "\xB8\x40",
  /* U+7AA4 */	"\xB8\x41", "\xBF\xFA", "\xF1\xBC", "\xB8\x42",
  /* U+7AA8 */	"\xF1\xBF", "\xB8\x43", "\xB8\x44", "\xB8\x45",
  /* U+7AAC */	"\xF1\xBE", "\xF1\xC0", "\xB8\x46", "\xB8\x47",
  /* U+7AB0 */	"\xB8\x48", "\xB8\x49", "\xB8\x4A", "\xF1\xC1",
  /* U+7AB4 */	"\xB8\x4B", "\xB8\x4C", "\xB8\x4D", "\xB8\x4E",
  /* U+7AB8 */	"\xB8\x4F", "\xB8\x50", "\xB8\x51", "\xB8\x52",
  /* U+7ABC */	"\xB8\x53", "\xB8\x54", "\xB8\x55", "\xC1\xFE",
  /* U+7AC0 */	"\xB8\x56", "\xB8\x57", "\xB8\x58", "\xB8\x59",
  /* U+7AC4 */	"\xB8\x5A", "\xB8\x5B", "\xB8\x5C", "\xB8\x5D",
  /* U+7AC8 */	"\xB8\x5E", "\xB8\x5F", "\xB8\x60", "\xC1\xA2",
  /* U+7ACC */	"\xB8\x61", "\xB8\x62", "\xB8\x63", "\xB8\x64",
  /* U+7AD0 */	"\xB8\x65", "\xB8\x66", "\xB8\x67", "\xB8\x68",
  /* U+7AD4 */	"\xB8\x69", "\xB8\x6A", "\xCA\xFA", "\xB8\x6B",
  /* U+7AD8 */	"\xB8\x6C", "\xD5\xBE", "\xB8\x6D", "\xB8\x6E",
  /* U+7ADC */	"\xB8\x6F", "\xB8\x70", "\xBE\xBA", "\xBE\xB9",
  /* U+7AE0 */	"\xD5\xC2", "\xB8\x71", "\xB8\x72", "\xBF\xA2",
  /* U+7AE4 */	"\xB8\x73", "\xCD\xAF", "\xF1\xB5", "\xB8\x74",
  /* U+7AE8 */	"\xB8\x75", "\xB8\x76", "\xB8\x77", "\xB8\x78",
  /* U+7AEC */	"\xB8\x79", "\xBD\xDF", "\xB8\x7A", "\xB6\xCB",
  /* U+7AF0 */	"\xB8\x7B", "\xB8\x7C", "\xB8\x7D", "\xB8\x7E",
  /* U+7AF4 */	"\xB8\x80", "\xB8\x81", "\xB8\x82", "\xB8\x83",
  /* U+7AF8 */	"\xB8\x84", "\xD6\xF1", "\xF3\xC3", "\xB8\x85",
  /* U+7AFC */	"\xB8\x86", "\xF3\xC4", "\xB8\x87", "\xB8\xCD",
  /* U+7B00 */	"\xB8\x88", "\xB8\x89", "\xB8\x8A", "\xF3\xC6",
  /* U+7B04 */	"\xF3\xC7", "\xB8\x8B", "\xB0\xCA", "\xB8\x8C",
  /* U+7B08 */	"\xF3\xC5", "\xB8\x8D", "\xF3\xC9", "\xCB\xF1",
  /* U+7B0C */	"\xB8\x8E", "\xB8\x8F", "\xB8\x90", "\xF3\xCB",
  /* U+7B10 */	"\xB8\x91", "\xD0\xA6", "\xB8\x92", "\xB8\x93",
  /* U+7B14 */	"\xB1\xCA", "\xF3\xC8", "\xB8\x94", "\xB8\x95",
  /* U+7B18 */	"\xB8\x96", "\xF3\xCF", "\xB8\x97", "\xB5\xD1",
  /* U+7B1C */	"\xB8\x98", "\xB8\x99", "\xF3\xD7", "\xB8\x9A",
  /* U+7B20 */	"\xF3\xD2", "\xB8\x9B", "\xB8\x9C", "\xB8\x9D",
  /* U+7B24 */	"\xF3\xD4", "\xF3\xD3", "\xB7\xFB", "\xB8\x9E",
  /* U+7B28 */	"\xB1\xBF", "\xB8\x9F", "\xF3\xCE", "\xF3\xCA",
  /* U+7B2C */	"\xB5\xDA", "\xB8\xA0", "\xF3\xD0", "\xB9\x40",
  /* U+7B30 */	"\xB9\x41", "\xF3\xD1", "\xB9\x42", "\xF3\xD5",
  /* U+7B34 */	"\xB9\x43", "\xB9\x44", "\xB9\x45", "\xB9\x46",
  /* U+7B38 */	"\xF3\xCD", "\xB9\x47", "\xBC\xE3", "\xB9\x48",
  /* U+7B3C */	"\xC1\xFD", "\xB9\x49", "\xF3\xD6", "\xB9\x4A",
  /* U+7B40 */	"\xB9\x4B", "\xB9\x4C", "\xB9\x4D", "\xB9\x4E",
  /* U+7B44 */	"\xB9\x4F", "\xF3\xDA", "\xB9\x50", "\xF3\xCC",
  /* U+7B48 */	"\xB9\x51", "\xB5\xC8", "\xB9\x52", "\xBD\xEE",
  /* U+7B4C */	"\xF3\xDC", "\xB9\x53", "\xB9\x54", "\xB7\xA4",
  /* U+7B50 */	"\xBF\xF0", "\xD6\xFE", "\xCD\xB2", "\xB9\x55",
  /* U+7B54 */	"\xB4\xF0", "\xB9\x56", "\xB2\xDF", "\xB9\x57",
  /* U+7B58 */	"\xF3\xD8", "\xB9\x58", "\xF3\xD9", "\xC9\xB8",
  /* U+7B5C */	"\xB9\x59", "\xF3\xDD", "\xB9\x5A", "\xB9\x5B",
  /* U+7B60 */	"\xF3\xDE", "\xB9\x5C", "\xF3\xE1", "\xB9\x5D",
  /* U+7B64 */	"\xB9\x5E", "\xB9\x5F", "\xB9\x60", "\xB9\x61",
  /* U+7B68 */	"\xB9\x62", "\xB9\x63", "\xB9\x64", "\xB9\x65",
  /* U+7B6C */	"\xB9\x66", "\xB9\x67", "\xF3\xDF", "\xB9\x68",
  /* U+7B70 */	"\xB9\x69", "\xF3\xE3", "\xF3\xE2", "\xB9\x6A",
  /* U+7B74 */	"\xB9\x6B", "\xF3\xDB", "\xB9\x6C", "\xBF\xEA",
  /* U+7B78 */	"\xB9\x6D", "\xB3\xEF", "\xB9\x6E", "\xF3\xE0",
  /* U+7B7C */	"\xB9\x6F", "\xB9\x70", "\xC7\xA9", "\xB9\x71",
  /* U+7B80 */	"\xBC\xF2", "\xB9\x72", "\xB9\x73", "\xB9\x74",
  /* U+7B84 */	"\xB9\x75", "\xF3\xEB", "\xB9\x76", "\xB9\x77",
  /* U+7B88 */	"\xB9\x78", "\xB9\x79", "\xB9\x7A", "\xB9\x7B",
  /* U+7B8C */	"\xB9\x7C", "\xB9\xBF", "\xB9\x7D", "\xB9\x7E",
  /* U+7B90 */	"\xF3\xE4", "\xB9\x80", "\xB9\x81", "\xB9\x82",
  /* U+7B94 */	"\xB2\xAD", "\xBB\xFE", "\xB9\x83", "\xCB\xE3",
  /* U+7B98 */	"\xB9\x84", "\xB9\x85", "\xB9\x86", "\xB9\x87",
  /* U+7B9C */	"\xF3\xED", "\xF3\xE9", "\xB9\x88", "\xB9\x89",
  /* U+7BA0 */	"\xB9\x8A", "\xB9\xDC", "\xF3\xEE", "\xB9\x8B",
  /* U+7BA4 */	"\xB9\x8C", "\xB9\x8D", "\xF3\xE5", "\xF3\xE6",
  /* U+7BA8 */	"\xF3\xEA", "\xC2\xE1", "\xF3\xEC", "\xF3\xEF",
  /* U+7BAC */	"\xF3\xE8", "\xBC\xFD", "\xB9\x8E", "\xB9\x8F",
  /* U+7BB0 */	"\xB9\x90", "\xCF\xE4", "\xB9\x91", "\xB9\x92",
  /* U+7BB4 */	"\xF3\xF0", "\xB9\x93", "\xB9\x94", "\xB9\x95",
  /* U+7BB8 */	"\xF3\xE7", "\xB9\x96", "\xB9\x97", "\xB9\x98",
  /* U+7BBC */	"\xB9\x99", "\xB9\x9A", "\xB9\x9B", "\xB9\x9C",
  /* U+7BC0 */	"\xB9\x9D", "\xF3\xF2", "\xB9\x9E", "\xB9\x9F",
  /* U+7BC4 */	"\xB9\xA0", "\xBA\x40", "\xD7\xAD", "\xC6\xAA",
  /* U+7BC8 */	"\xBA\x41", "\xBA\x42", "\xBA\x43", "\xBA\x44",
  /* U+7BCC */	"\xF3\xF3", "\xBA\x45", "\xBA\x46", "\xBA\x47",
  /* U+7BD0 */	"\xBA\x48", "\xF3\xF1", "\xBA\x49", "\xC2\xA8",
  /* U+7BD4 */	"\xBA\x4A", "\xBA\x4B", "\xBA\x4C", "\xBA\x4D",
  /* U+7BD8 */	"\xBA\x4E", "\xB8\xDD", "\xF3\xF5", "\xBA\x4F",
  /* U+7BDC */	"\xBA\x50", "\xF3\xF4", "\xBA\x51", "\xBA\x52",
  /* U+7BE0 */	"\xBA\x53", "\xB4\xDB", "\xBA\x54", "\xBA\x55",
  /* U+7BE4 */	"\xBA\x56", "\xF3\xF6", "\xF3\xF7", "\xBA\x57",
  /* U+7BE8 */	"\xBA\x58", "\xBA\x59", "\xF3\xF8", "\xBA\x5A",
  /* U+7BEC */	"\xBA\x5B", "\xBA\x5C", "\xC0\xBA", "\xBA\x5D",
  /* U+7BF0 */	"\xBA\x5E", "\xC0\xE9", "\xBA\x5F", "\xBA\x60",
  /* U+7BF4 */	"\xBA\x61", "\xBA\x62", "\xBA\x63", "\xC5\xF1",
  /* U+7BF8 */	"\xBA\x64", "\xBA\x65", "\xBA\x66", "\xBA\x67",
  /* U+7BFC */	"\xF3\xFB", "\xBA\x68", "\xF3\xFA", "\xBA\x69",
  /* U+7C00 */	"\xBA\x6A", "\xBA\x6B", "\xBA\x6C", "\xBA\x6D",
  /* U+7C04 */	"\xBA\x6E", "\xBA\x6F", "\xBA\x70", "\xB4\xD8",
  /* U+7C08 */	"\xBA\x71", "\xBA\x72", "\xBA\x73", "\xF3\xFE",
  /* U+7C0C */	"\xF3\xF9", "\xBA\x74", "\xBA\x75", "\xF3\xFC",
  /* U+7C10 */	"\xBA\x76", "\xBA\x77", "\xBA\x78", "\xBA\x79",
  /* U+7C14 */	"\xBA\x7A", "\xBA\x7B", "\xF3\xFD", "\xBA\x7C",
  /* U+7C18 */	"\xBA\x7D", "\xBA\x7E", "\xBA\x80", "\xBA\x81",
  /* U+7C1C */	"\xBA\x82", "\xBA\x83", "\xBA\x84", "\xF4\xA1",
  /* U+7C20 */	"\xBA\x85", "\xBA\x86", "\xBA\x87", "\xBA\x88",
  /* U+7C24 */	"\xBA\x89", "\xBA\x8A", "\xF4\xA3", "\xBB\xC9",
  /* U+7C28 */	"\xBA\x8B", "\xBA\x8C", "\xF4\xA2", "\xBA\x8D",
  /* U+7C2C */	"\xBA\x8E", "\xBA\x8F", "\xBA\x90", "\xBA\x91",
  /* U+7C30 */	"\xBA\x92", "\xBA\x93", "\xBA\x94", "\xBA\x95",
  /* U+7C34 */	"\xBA\x96", "\xBA\x97", "\xBA\x98", "\xBA\x99",
  /* U+7C38 */	"\xF4\xA4", "\xBA\x9A", "\xBA\x9B", "\xBA\x9C",
  /* U+7C3C */	"\xBA\x9D", "\xBA\x9E", "\xBA\x9F", "\xB2\xBE",
  /* U+7C40 */	"\xF4\xA6", "\xF4\xA5", "\xBA\xA0", "\xBB\x40",
  /* U+7C44 */	"\xBB\x41", "\xBB\x42", "\xBB\x43", "\xBB\x44",
  /* U+7C48 */	"\xBB\x45", "\xBB\x46", "\xBB\x47", "\xBB\x48",
  /* U+7C4C */	"\xBB\x49", "\xBC\xAE", "\xBB\x4A", "\xBB\x4B",
  /* U+7C50 */	"\xBB\x4C", "\xBB\x4D", "\xBB\x4E", "\xBB\x4F",
  /* U+7C54 */	"\xBB\x50", "\xBB\x51", "\xBB\x52", "\xBB\x53",
  /* U+7C58 */	"\xBB\x54", "\xBB\x55", "\xBB\x56", "\xBB\x57",
  /* U+7C5C */	"\xBB\x58", "\xBB\x59", "\xBB\x5A", "\xBB\x5B",
  /* U+7C60 */	"\xBB\x5C", "\xBB\x5D", "\xBB\x5E", "\xBB\x5F",
  /* U+7C64 */	"\xBB\x60", "\xBB\x61", "\xBB\x62", "\xBB\x63",
  /* U+7C68 */	"\xBB\x64", "\xBB\x65", "\xBB\x66", "\xBB\x67",
  /* U+7C6C */	"\xBB\x68", "\xBB\x69", "\xBB\x6A", "\xBB\x6B",
  /* U+7C70 */	"\xBB\x6C", "\xBB\x6D", "\xBB\x6E", "\xC3\xD7",
  /* U+7C74 */	"\xD9\xE1", "\xBB\x6F", "\xBB\x70", "\xBB\x71",
  /* U+7C78 */	"\xBB\x72", "\xBB\x73", "\xBB\x74", "\xC0\xE0",
  /* U+7C7C */	"\xF4\xCC", "\xD7\xD1", "\xBB\x75", "\xBB\x76",
  /* U+7C80 */	"\xBB\x77", "\xBB\x78", "\xBB\x79", "\xBB\x7A",
  /* U+7C84 */	"\xBB\x7B", "\xBB\x7C", "\xBB\x7D", "\xBB\x7E",
  /* U+7C88 */	"\xBB\x80", "\xB7\xDB", "\xBB\x81", "\xBB\x82",
  /* U+7C8C */	"\xBB\x83", "\xBB\x84", "\xBB\x85", "\xBB\x86",
  /* U+7C90 */	"\xBB\x87", "\xF4\xCE", "\xC1\xA3", "\xBB\x88",
  /* U+7C94 */	"\xBB\x89", "\xC6\xC9", "\xBB\x8A", "\xB4\xD6",
  /* U+7C98 */	"\xD5\xB3", "\xBB\x8B", "\xBB\x8C", "\xBB\x8D",
  /* U+7C9C */	"\xF4\xD0", "\xF4\xCF", "\xF4\xD1", "\xCB\xDA",
  /* U+7CA0 */	"\xBB\x8E", "\xBB\x8F", "\xF4\xD2", "\xBB\x90",
  /* U+7CA4 */	"\xD4\xC1", "\xD6\xE0", "\xBB\x91", "\xBB\x92",
  /* U+7CA8 */	"\xBB\x93", "\xBB\x94", "\xB7\xE0", "\xBB\x95",
  /* U+7CAC */	"\xBB\x96", "\xBB\x97", "\xC1\xB8", "\xBB\x98",
  /* U+7CB0 */	"\xBB\x99", "\xC1\xBB", "\xF4\xD3", "\xBE\xAC",
  /* U+7CB4 */	"\xBB\x9A", "\xBB\x9B", "\xBB\x9C", "\xBB\x9D",
  /* U+7CB8 */	"\xBB\x9E", "\xB4\xE2", "\xBB\x9F", "\xBB\xA0",
  /* U+7CBC */	"\xF4\xD4", "\xF4\xD5", "\xBE\xAB", "\xBC\x40",
  /* U+7CC0 */	"\xBC\x41", "\xF4\xD6", "\xBC\x42", "\xBC\x43",
  /* U+7CC4 */	"\xBC\x44", "\xF4\xDB", "\xBC\x45", "\xF4\xD7",
  /* U+7CC8 */	"\xF4\xDA", "\xBC\x46", "\xBA\xFD", "\xBC\x47",
  /* U+7CCC */	"\xF4\xD8", "\xF4\xD9", "\xBC\x48", "\xBC\x49",
  /* U+7CD0 */	"\xBC\x4A", "\xBC\x4B", "\xBC\x4C", "\xBC\x4D",
  /* U+7CD4 */	"\xBC\x4E", "\xB8\xE2", "\xCC\xC7", "\xF4\xDC",
  /* U+7CD8 */	"\xBC\x4F", "\xB2\xDA", "\xBC\x50", "\xBC\x51",
  /* U+7CDC */	"\xC3\xD3", "\xBC\x52", "\xBC\x53", "\xD4\xE3",
  /* U+7CE0 */	"\xBF\xB7", "\xBC\x54", "\xBC\x55", "\xBC\x56",
  /* U+7CE4 */	"\xBC\x57", "\xBC\x58", "\xBC\x59", "\xBC\x5A",
  /* U+7CE8 */	"\xF4\xDD", "\xBC\x5B", "\xBC\x5C", "\xBC\x5D",
  /* U+7CEC */	"\xBC\x5E", "\xBC\x5F", "\xBC\x60", "\xC5\xB4",
  /* U+7CF0 */	"\xBC\x61", "\xBC\x62", "\xBC\x63", "\xBC\x64",
  /* U+7CF4 */	"\xBC\x65", "\xBC\x66", "\xBC\x67", "\xBC\x68",
  /* U+7CF8 */	"\xF4\xE9", "\xBC\x69", "\xBC\x6A", "\xCF\xB5",
  /* U+7CFC */	"\xBC\x6B", "\xBC\x6C", "\xBC\x6D", "\xBC\x6E",
  /* U+7D00 */	"\xBC\x6F", "\xBC\x70", "\xBC\x71", "\xBC\x72",
  /* U+7D04 */	"\xBC\x73", "\xBC\x74", "\xBC\x75", "\xBC\x76",
  /* U+7D08 */	"\xBC\x77", "\xBC\x78", "\xCE\xC9", "\xBC\x79",
  /* U+7D0C */	"\xBC\x7A", "\xBC\x7B", "\xBC\x7C", "\xBC\x7D",
  /* U+7D10 */	"\xBC\x7E", "\xBC\x80", "\xBC\x81", "\xBC\x82",
  /* U+7D14 */	"\xBC\x83", "\xBC\x84", "\xBC\x85", "\xBC\x86",
  /* U+7D18 */	"\xBC\x87", "\xBC\x88", "\xBC\x89", "\xBC\x8A",
  /* U+7D1C */	"\xBC\x8B", "\xBC\x8C", "\xBC\x8D", "\xBC\x8E",
  /* U+7D20 */	"\xCB\xD8", "\xBC\x8F", "\xCB\xF7", "\xBC\x90",
  /* U+7D24 */	"\xBC\x91", "\xBC\x92", "\xBC\x93", "\xBD\xF4",
  /* U+7D28 */	"\xBC\x94", "\xBC\x95", "\xBC\x96", "\xD7\xCF",
  /* U+7D2C */	"\xBC\x97", "\xBC\x98", "\xBC\x99", "\xC0\xDB",
  /* U+7D30 */	"\xBC\x9A", "\xBC\x9B", "\xBC\x9C", "\xBC\x9D",
  /* U+7D34 */	"\xBC\x9E", "\xBC\x9F", "\xBC\xA0", "\xBD\x40",
  /* U+7D38 */	"\xBD\x41", "\xBD\x42", "\xBD\x43", "\xBD\x44",
  /* U+7D3C */	"\xBD\x45", "\xBD\x46", "\xBD\x47", "\xBD\x48",
  /* U+7D40 */	"\xBD\x49", "\xBD\x4A", "\xBD\x4B", "\xBD\x4C",
  /* U+7D44 */	"\xBD\x4D", "\xBD\x4E", "\xBD\x4F", "\xBD\x50",
  /* U+7D48 */	"\xBD\x51", "\xBD\x52", "\xBD\x53", "\xBD\x54",
  /* U+7D4C */	"\xBD\x55", "\xBD\x56", "\xBD\x57", "\xBD\x58",
  /* U+7D50 */	"\xBD\x59", "\xBD\x5A", "\xBD\x5B", "\xBD\x5C",
  /* U+7D54 */	"\xBD\x5D", "\xBD\x5E", "\xBD\x5F", "\xBD\x60",
  /* U+7D58 */	"\xBD\x61", "\xBD\x62", "\xBD\x63", "\xBD\x64",
  /* U+7D5C */	"\xBD\x65", "\xBD\x66", "\xBD\x67", "\xBD\x68",
  /* U+7D60 */	"\xBD\x69", "\xBD\x6A", "\xBD\x6B", "\xBD\x6C",
  /* U+7D64 */	"\xBD\x6D", "\xBD\x6E", "\xBD\x6F", "\xBD\x70",
  /* U+7D68 */	"\xBD\x71", "\xBD\x72", "\xBD\x73", "\xBD\x74",
  /* U+7D6C */	"\xBD\x75", "\xBD\x76", "\xD0\xF5", "\xBD\x77",
  /* U+7D70 */	"\xBD\x78", "\xBD\x79", "\xBD\x7A", "\xBD\x7B",
  /* U+7D74 */	"\xBD\x7C", "\xBD\x7D", "\xBD\x7E", "\xF4\xEA",
  /* U+7D78 */	"\xBD\x80", "\xBD\x81", "\xBD\x82", "\xBD\x83",
  /* U+7D7C */	"\xBD\x84", "\xBD\x85", "\xBD\x86", "\xBD\x87",
  /* U+7D80 */	"\xBD\x88", "\xBD\x89", "\xBD\x8A", "\xBD\x8B",
  /* U+7D84 */	"\xBD\x8C", "\xBD\x8D", "\xBD\x8E", "\xBD\x8F",
  /* U+7D88 */	"\xBD\x90", "\xBD\x91", "\xBD\x92", "\xBD\x93",
  /* U+7D8C */	"\xBD\x94", "\xBD\x95", "\xBD\x96", "\xBD\x97",
  /* U+7D90 */	"\xBD\x98", "\xBD\x99", "\xBD\x9A", "\xBD\x9B",
  /* U+7D94 */	"\xBD\x9C", "\xBD\x9D", "\xBD\x9E", "\xBD\x9F",
  /* U+7D98 */	"\xBD\xA0", "\xBE\x40", "\xBE\x41", "\xBE\x42",
  /* U+7D9C */	"\xBE\x43", "\xBE\x44", "\xBE\x45", "\xBE\x46",
  /* U+7DA0 */	"\xBE\x47", "\xBE\x48", "\xBE\x49", "\xBE\x4A",
  /* U+7DA4 */	"\xBE\x4B", "\xBE\x4C", "\xF4\xEB", "\xBE\x4D",
  /* U+7DA8 */	"\xBE\x4E", "\xBE\x4F", "\xBE\x50", "\xBE\x51",
  /* U+7DAC */	"\xBE\x52", "\xBE\x53", "\xF4\xEC", "\xBE\x54",
  /* U+7DB0 */	"\xBE\x55", "\xBE\x56", "\xBE\x57", "\xBE\x58",
  /* U+7DB4 */	"\xBE\x59", "\xBE\x5A", "\xBE\x5B", "\xBE\x5C",
  /* U+7DB8 */	"\xBE\x5D", "\xBE\x5E", "\xBE\x5F", "\xBE\x60",
  /* U+7DBC */	"\xBE\x61", "\xBE\x62", "\xBE\x63", "\xBE\x64",
  /* U+7DC0 */	"\xBE\x65", "\xBE\x66", "\xBE\x67", "\xBE\x68",
  /* U+7DC4 */	"\xBE\x69", "\xBE\x6A", "\xBE\x6B", "\xBE\x6C",
  /* U+7DC8 */	"\xBE\x6D", "\xBE\x6E", "\xBE\x6F", "\xBE\x70",
  /* U+7DCC */	"\xBE\x71", "\xBE\x72", "\xBE\x73", "\xBE\x74",
  /* U+7DD0 */	"\xBE\x75", "\xBE\x76", "\xBE\x77", "\xBE\x78",
  /* U+7DD4 */	"\xBE\x79", "\xBE\x7A", "\xBE\x7B", "\xBE\x7C",
  /* U+7DD8 */	"\xBE\x7D", "\xBE\x7E", "\xBE\x80", "\xBE\x81",
  /* U+7DDC */	"\xBE\x82", "\xBE\x83", "\xBE\x84", "\xBE\x85",
  /* U+7DE0 */	"\xBE\x86", "\xBE\x87", "\xBE\x88", "\xBE\x89",
  /* U+7DE4 */	"\xBE\x8A", "\xBE\x8B", "\xBE\x8C", "\xBE\x8D",
  /* U+7DE8 */	"\xBE\x8E", "\xBE\x8F", "\xBE\x90", "\xBE\x91",
  /* U+7DEC */	"\xBE\x92", "\xBE\x93", "\xBE\x94", "\xBE\x95",
  /* U+7DF0 */	"\xBE\x96", "\xBE\x97", "\xBE\x98", "\xBE\x99",
  /* U+7DF4 */	"\xBE\x9A", "\xBE\x9B", "\xBE\x9C", "\xBE\x9D",
  /* U+7DF8 */	"\xBE\x9E", "\xBE\x9F", "\xBE\xA0", "\xBF\x40",
  /* U+7DFC */	"\xBF\x41", "\xBF\x42", "\xBF\x43", "\xBF\x44",
  /* U+7E00 */	"\xBF\x45", "\xBF\x46", "\xBF\x47", "\xBF\x48",
  /* U+7E04 */	"\xBF\x49", "\xBF\x4A", "\xBF\x4B", "\xBF\x4C",
  /* U+7E08 */	"\xBF\x4D", "\xBF\x4E", "\xBF\x4F", "\xBF\x50",
  /* U+7E0C */	"\xBF\x51", "\xBF\x52", "\xBF\x53", "\xBF\x54",
  /* U+7E10 */	"\xBF\x55", "\xBF\x56", "\xBF\x57", "\xBF\x58",
  /* U+7E14 */	"\xBF\x59", "\xBF\x5A", "\xBF\x5B", "\xBF\x5C",
  /* U+7E18 */	"\xBF\x5D", "\xBF\x5E", "\xBF\x5F", "\xBF\x60",
  /* U+7E1C */	"\xBF\x61", "\xBF\x62", "\xBF\x63", "\xBF\x64",
  /* U+7E20 */	"\xBF\x65", "\xBF\x66", "\xBF\x67", "\xBF\x68",
  /* U+7E24 */	"\xBF\x69", "\xBF\x6A", "\xBF\x6B", "\xBF\x6C",
  /* U+7E28 */	"\xBF\x6D", "\xBF\x6E", "\xBF\x6F", "\xBF\x70",
  /* U+7E2C */	"\xBF\x71", "\xBF\x72", "\xBF\x73", "\xBF\x74",
  /* U+7E30 */	"\xBF\x75", "\xBF\x76", "\xBF\x77", "\xBF\x78",
  /* U+7E34 */	"\xBF\x79", "\xBF\x7A", "\xBF\x7B", "\xBF\x7C",
  /* U+7E38 */	"\xBF\x7D", "\xBF\x7E", "\xBF\x80", "\xF7\xE3",
  /* U+7E3C */	"\xBF\x81", "\xBF\x82", "\xBF\x83", "\xBF\x84",
  /* U+7E40 */	"\xBF\x85", "\xB7\xB1", "\xBF\x86", "\xBF\x87",
  /* U+7E44 */	"\xBF\x88", "\xBF\x89", "\xBF\x8A", "\xF4\xED",
  /* U+7E48 */	"\xBF\x8B", "\xBF\x8C", "\xBF\x8D", "\xBF\x8E",
  /* U+7E4C */	"\xBF\x8F", "\xBF\x90", "\xBF\x91", "\xBF\x92",
  /* U+7E50 */	"\xBF\x93", "\xBF\x94", "\xBF\x95", "\xBF\x96",
  /* U+7E54 */	"\xBF\x97", "\xBF\x98", "\xBF\x99", "\xBF\x9A",
  /* U+7E58 */	"\xBF\x9B", "\xBF\x9C", "\xBF\x9D", "\xBF\x9E",
  /* U+7E5C */	"\xBF\x9F", "\xBF\xA0", "\xC0\x40", "\xC0\x41",
  /* U+7E60 */	"\xC0\x42", "\xC0\x43", "\xC0\x44", "\xC0\x45",
  /* U+7E64 */	"\xC0\x46", "\xC0\x47", "\xC0\x48", "\xC0\x49",
  /* U+7E68 */	"\xC0\x4A", "\xC0\x4B", "\xC0\x4C", "\xC0\x4D",
  /* U+7E6C */	"\xC0\x4E", "\xC0\x4F", "\xC0\x50", "\xC0\x51",
  /* U+7E70 */	"\xC0\x52", "\xC0\x53", "\xC0\x54", "\xC0\x55",
  /* U+7E74 */	"\xC0\x56", "\xC0\x57", "\xC0\x58", "\xC0\x59",
  /* U+7E78 */	"\xC0\x5A", "\xC0\x5B", "\xC0\x5C", "\xC0\x5D",
  /* U+7E7C */	"\xC0\x5E", "\xC0\x5F", "\xC0\x60", "\xC0\x61",
  /* U+7E80 */	"\xC0\x62", "\xC0\x63", "\xD7\xEB", "\xC0\x64",
  /* U+7E84 */	"\xC0\x65", "\xC0\x66", "\xC0\x67", "\xC0\x68",
  /* U+7E88 */	"\xC0\x69", "\xC0\x6A", "\xC0\x6B", "\xC0\x6C",
  /* U+7E8C */	"\xC0\x6D", "\xC0\x6E", "\xC0\x6F", "\xC0\x70",
  /* U+7E90 */	"\xC0\x71", "\xC0\x72", "\xC0\x73", "\xC0\x74",
  /* U+7E94 */	"\xC0\x75", "\xC0\x76", "\xC0\x77", "\xC0\x78",
  /* U+7E98 */	"\xC0\x79", "\xC0\x7A", "\xC0\x7B", "\xF4\xEE",
  /* U+7E9C */	"\xC0\x7C", "\xC0\x7D", "\xC0\x7E", "\xE6\xF9",
  /* U+7EA0 */	"\xBE\xC0", "\xE6\xFA", "\xBA\xEC", "\xE6\xFB",
  /* U+7EA4 */	"\xCF\xCB", "\xE6\xFC", "\xD4\xBC", "\xBC\xB6",
  /* U+7EA8 */	"\xE6\xFD", "\xE6\xFE", "\xBC\xCD", "\xC8\xD2",
  /* U+7EAC */	"\xCE\xB3", "\xE7\xA1", "\xC0\x80", "\xB4\xBF",
  /* U+7EB0 */	"\xE7\xA2", "\xC9\xB4", "\xB8\xD9", "\xC4\xC9",
  /* U+7EB4 */	"\xC0\x81", "\xD7\xDD", "\xC2\xDA", "\xB7\xD7",
  /* U+7EB8 */	"\xD6\xBD", "\xCE\xC6", "\xB7\xC4", "\xC0\x82",
  /* U+7EBC */	"\xC0\x83", "\xC5\xA6", "\xE7\xA3", "\xCF\xDF",
  /* U+7EC0 */	"\xE7\xA4", "\xE7\xA5", "\xE7\xA6", "\xC1\xB7",
  /* U+7EC4 */	"\xD7\xE9", "\xC9\xF0", "\xCF\xB8", "\xD6\xAF",
  /* U+7EC8 */	"\xD6\xD5", "\xE7\xA7", "\xB0\xED", "\xE7\xA8",
  /* U+7ECC */	"\xE7\xA9", "\xC9\xDC", "\xD2\xEF", "\xBE\xAD",
  /* U+7ED0 */	"\xE7\xAA", "\xB0\xF3", "\xC8\xDE", "\xBD\xE1",
  /* U+7ED4 */	"\xE7\xAB", "\xC8\xC6", "\xC0\x84", "\xE7\xAC",
  /* U+7ED8 */	"\xBB\xE6", "\xB8\xF8", "\xD1\xA4", "\xE7\xAD",
  /* U+7EDC */	"\xC2\xE7", "\xBE\xF8", "\xBD\xCA", "\xCD\xB3",
  /* U+7EE0 */	"\xE7\xAE", "\xE7\xAF", "\xBE\xEE", "\xD0\xE5",
  /* U+7EE4 */	"\xC0\x85", "\xCB\xE7", "\xCC\xD0", "\xBC\xCC",
  /* U+7EE8 */	"\xE7\xB0", "\xBC\xA8", "\xD0\xF7", "\xE7\xB1",
  /* U+7EEC */	"\xC0\x86", "\xD0\xF8", "\xE7\xB2", "\xE7\xB3",
  /* U+7EF0 */	"\xB4\xC2", "\xE7\xB4", "\xE7\xB5", "\xC9\xFE",
  /* U+7EF4 */	"\xCE\xAC", "\xC3\xE0", "\xE7\xB7", "\xB1\xC1",
  /* U+7EF8 */	"\xB3\xF1", "\xC0\x87", "\xE7\xB8", "\xE7\xB9",
  /* U+7EFC */	"\xD7\xDB", "\xD5\xC0", "\xE7\xBA", "\xC2\xCC",
  /* U+7F00 */	"\xD7\xBA", "\xE7\xBB", "\xE7\xBC", "\xE7\xBD",
  /* U+7F04 */	"\xBC\xEA", "\xC3\xE5", "\xC0\xC2", "\xE7\xBE",
  /* U+7F08 */	"\xE7\xBF", "\xBC\xA9", "\xC0\x88", "\xE7\xC0",
  /* U+7F0C */	"\xE7\xC1", "\xE7\xB6", "\xB6\xD0", "\xE7\xC2",
  /* U+7F10 */	"\xC0\x89", "\xE7\xC3", "\xE7\xC4", "\xBB\xBA",
  /* U+7F14 */	"\xB5\xDE", "\xC2\xC6", "\xB1\xE0", "\xE7\xC5",
  /* U+7F18 */	"\xD4\xB5", "\xE7\xC6", "\xB8\xBF", "\xE7\xC8",
  /* U+7F1C */	"\xE7\xC7", "\xB7\xEC", "\xC0\x8A", "\xE7\xC9",
  /* U+7F20 */	"\xB2\xF8", "\xE7\xCA", "\xE7\xCB", "\xE7\xCC",
  /* U+7F24 */	"\xE7\xCD", "\xE7\xCE", "\xE7\xCF", "\xE7\xD0",
  /* U+7F28 */	"\xD3\xA7", "\xCB\xF5", "\xE7\xD1", "\xE7\xD2",
  /* U+7F2C */	"\xE7\xD3", "\xE7\xD4", "\xC9\xC9", "\xE7\xD5",
  /* U+7F30 */	"\xE7\xD6", "\xE7\xD7", "\xE7\xD8", "\xE7\xD9",
  /* U+7F34 */	"\xBD\xC9", "\xE7\xDA", "\xF3\xBE", "\xC0\x8B",
  /* U+7F38 */	"\xB8\xD7", "\xC0\x8C", "\xC8\xB1", "\xC0\x8D",
  /* U+7F3C */	"\xC0\x8E", "\xC0\x8F", "\xC0\x90", "\xC0\x91",
  /* U+7F40 */	"\xC0\x92", "\xC0\x93", "\xF3\xBF", "\xC0\x94",
  /* U+7F44 */	"\xF3\xC0", "\xF3\xC1", "\xC0\x95", "\xC0\x96",
  /* U+7F48 */	"\xC0\x97", "\xC0\x98", "\xC0\x99", "\xC0\x9A",
  /* U+7F4C */	"\xC0\x9B", "\xC0\x9C", "\xC0\x9D", "\xC0\x9E",
  /* U+7F50 */	"\xB9\xDE", "\xCD\xF8", "\xC0\x9F", "\xC0\xA0",
  /* U+7F54 */	"\xD8\xE8", "\xBA\xB1", "\xC1\x40", "\xC2\xDE",
  /* U+7F58 */	"\xEE\xB7", "\xC1\x41", "\xB7\xA3", "\xC1\x42",
  /* U+7F5C */	"\xC1\x43", "\xC1\x44", "\xC1\x45", "\xEE\xB9",
  /* U+7F60 */	"\xC1\x46", "\xEE\xB8", "\xB0\xD5", "\xC1\x47",
  /* U+7F64 */	"\xC1\x48", "\xC1\x49", "\xC1\x4A", "\xC1\x4B",
  /* U+7F68 */	"\xEE\xBB", "\xD5\xD6", "\xD7\xEF", "\xC1\x4C",
  /* U+7F6C */	"\xC1\x4D", "\xC1\x4E", "\xD6\xC3", "\xC1\x4F",
  /* U+7F70 */	"\xC1\x50", "\xEE\xBD", "\xCA\xF0", "\xC1\x51",
  /* U+7F74 */	"\xEE\xBC", "\xC1\x52", "\xC1\x53", "\xC1\x54",
  /* U+7F78 */	"\xC1\x55", "\xEE\xBE", "\xC1\x56", "\xC1\x57",
  /* U+7F7C */	"\xC1\x58", "\xC1\x59", "\xEE\xC0", "\xC1\x5A",
  /* U+7F80 */	"\xC1\x5B", "\xEE\xBF", "\xC1\x5C", "\xC1\x5D",
  /* U+7F84 */	"\xC1\x5E", "\xC1\x5F", "\xC1\x60", "\xC1\x61",
  /* U+7F88 */	"\xC1\x62", "\xC1\x63", "\xD1\xF2", "\xC1\x64",
  /* U+7F8C */	"\xC7\xBC", "\xC1\x65", "\xC3\xC0", "\xC1\x66",
  /* U+7F90 */	"\xC1\x67", "\xC1\x68", "\xC1\x69", "\xC1\x6A",
  /* U+7F94 */	"\xB8\xE1", "\xC1\x6B", "\xC1\x6C", "\xC1\x6D",
  /* U+7F98 */	"\xC1\x6E", "\xC1\x6F", "\xC1\xE7", "\xC1\x70",
  /* U+7F9C */	"\xC1\x71", "\xF4\xC6", "\xD0\xDF", "\xF4\xC7",
  /* U+7FA0 */	"\xC1\x72", "\xCF\xDB", "\xC1\x73", "\xC1\x74",
  /* U+7FA4 */	"\xC8\xBA", "\xC1\x75", "\xC1\x76", "\xF4\xC8",
  /* U+7FA8 */	"\xC1\x77", "\xC1\x78", "\xC1\x79", "\xC1\x7A",
  /* U+7FAC */	"\xC1\x7B", "\xC1\x7C", "\xC1\x7D", "\xF4\xC9",
  /* U+7FB0 */	"\xF4\xCA", "\xC1\x7E", "\xF4\xCB", "\xC1\x80",
  /* U+7FB4 */	"\xC1\x81", "\xC1\x82", "\xC1\x83", "\xC1\x84",
  /* U+7FB8 */	"\xD9\xFA", "\xB8\xFE", "\xC1\x85", "\xC1\x86",
  /* U+7FBC */	"\xE5\xF1", "\xD3\xF0", "\xC1\x87", "\xF4\xE0",
  /* U+7FC0 */	"\xC1\x88", "\xCE\xCC", "\xC1\x89", "\xC1\x8A",
  /* U+7FC4 */	"\xC1\x8B", "\xB3\xE1", "\xC1\x8C", "\xC1\x8D",
  /* U+7FC8 */	"\xC1\x8E", "\xC1\x8F", "\xF1\xB4", "\xC1\x90",
  /* U+7FCC */	"\xD2\xEE", "\xC1\x91", "\xF4\xE1", "\xC1\x92",
  /* U+7FD0 */	"\xC1\x93", "\xC1\x94", "\xC1\x95", "\xC1\x96",
  /* U+7FD4 */	"\xCF\xE8", "\xF4\xE2", "\xC1\x97", "\xC1\x98",
  /* U+7FD8 */	"\xC7\xCC", "\xC1\x99", "\xC1\x9A", "\xC1\x9B",
  /* U+7FDC */	"\xC1\x9C", "\xC1\x9D", "\xC1\x9E", "\xB5\xD4",
  /* U+7FE0 */	"\xB4\xE4", "\xF4\xE4", "\xC1\x9F", "\xC1\xA0",
  /* U+7FE4 */	"\xC2\x40", "\xF4\xE3", "\xF4\xE5", "\xC2\x41",
  /* U+7FE8 */	"\xC2\x42", "\xF4\xE6", "\xC2\x43", "\xC2\x44",
  /* U+7FEC */	"\xC2\x45", "\xC2\x46", "\xF4\xE7", "\xC2\x47",
  /* U+7FF0 */	"\xBA\xB2", "\xB0\xBF", "\xC2\x48", "\xF4\xE8",
  /* U+7FF4 */	"\xC2\x49", "\xC2\x4A", "\xC2\x4B", "\xC2\x4C",
  /* U+7FF8 */	"\xC2\x4D", "\xC2\x4E", "\xC2\x4F", "\xB7\xAD",
  /* U+7FFC */	"\xD2\xED", "\xC2\x50", "\xC2\x51", "\xC2\x52",
  /* U+8000 */	"\xD2\xAB", "\xC0\xCF", "\xC2\x53", "\xBF\xBC",
  /* U+8004 */	"\xEB\xA3", "\xD5\xDF", "\xEA\xC8", "\xC2\x54",
  /* U+8008 */	"\xC2\x55", "\xC2\x56", "\xC2\x57", "\xF1\xF3",
  /* U+800C */	"\xB6\xF8", "\xCB\xA3", "\xC2\x58", "\xC2\x59",
  /* U+8010 */	"\xC4\xCD", "\xC2\x5A", "\xF1\xE7", "\xC2\x5B",
  /* U+8014 */	"\xF1\xE8", "\xB8\xFB", "\xF1\xE9", "\xBA\xC4",
  /* U+8018 */	"\xD4\xC5", "\xB0\xD2", "\xC2\x5C", "\xC2\x5D",
  /* U+801C */	"\xF1\xEA", "\xC2\x5E", "\xC2\x5F", "\xC2\x60",
  /* U+8020 */	"\xF1\xEB", "\xC2\x61", "\xF1\xEC", "\xC2\x62",
  /* U+8024 */	"\xC2\x63", "\xF1\xED", "\xF1\xEE", "\xF1\xEF",
  /* U+8028 */	"\xF1\xF1", "\xF1\xF0", "\xC5\xD5", "\xC2\x64",
  /* U+802C */	"\xC2\x65", "\xC2\x66", "\xC2\x67", "\xC2\x68",
  /* U+8030 */	"\xC2\x69", "\xF1\xF2", "\xC2\x6A", "\xB6\xFA",
  /* U+8034 */	"\xC2\x6B", "\xF1\xF4", "\xD2\xAE", "\xDE\xC7",
  /* U+8038 */	"\xCB\xCA", "\xC2\x6C", "\xC2\x6D", "\xB3\xDC",
  /* U+803C */	"\xC2\x6E", "\xB5\xA2", "\xC2\x6F", "\xB9\xA2",
  /* U+8040 */	"\xC2\x70", "\xC2\x71", "\xC4\xF4", "\xF1\xF5",
  /* U+8044 */	"\xC2\x72", "\xC2\x73", "\xF1\xF6", "\xC2\x74",
  /* U+8048 */	"\xC2\x75", "\xC2\x76", "\xC1\xC4", "\xC1\xFB",
  /* U+804C */	"\xD6\xB0", "\xF1\xF7", "\xC2\x77", "\xC2\x78",
  /* U+8050 */	"\xC2\x79", "\xC2\x7A", "\xF1\xF8", "\xC2\x7B",
  /* U+8054 */	"\xC1\xAA", "\xC2\x7C", "\xC2\x7D", "\xC2\x7E",
  /* U+8058 */	"\xC6\xB8", "\xC2\x80", "\xBE\xDB", "\xC2\x81",
  /* U+805C */	"\xC2\x82", "\xC2\x83", "\xC2\x84", "\xC2\x85",
  /* U+8060 */	"\xC2\x86", "\xC2\x87", "\xC2\x88", "\xC2\x89",
  /* U+8064 */	"\xC2\x8A", "\xC2\x8B", "\xC2\x8C", "\xC2\x8D",
  /* U+8068 */	"\xC2\x8E", "\xF1\xF9", "\xB4\xCF", "\xC2\x8F",
  /* U+806C */	"\xC2\x90", "\xC2\x91", "\xC2\x92", "\xC2\x93",
  /* U+8070 */	"\xC2\x94", "\xF1\xFA", "\xC2\x95", "\xC2\x96",
  /* U+8074 */	"\xC2\x97", "\xC2\x98", "\xC2\x99", "\xC2\x9A",
  /* U+8078 */	"\xC2\x9B", "\xC2\x9C", "\xC2\x9D", "\xC2\x9E",
  /* U+807C */	"\xC2\x9F", "\xC2\xA0", "\xC3\x40", "\xED\xB2",
  /* U+8080 */	"\xED\xB1", "\xC3\x41", "\xC3\x42", "\xCB\xE0",
  /* U+8084 */	"\xD2\xDE", "\xC3\x43", "\xCB\xC1", "\xD5\xD8",
  /* U+8088 */	"\xC3\x44", "\xC8\xE2", "\xC3\x45", "\xC0\xDF",
  /* U+808C */	"\xBC\xA1", "\xC3\x46", "\xC3\x47", "\xC3\x48",
  /* U+8090 */	"\xC3\x49", "\xC3\x4A", "\xC3\x4B", "\xEB\xC1",
  /* U+8094 */	"\xC3\x4C", "\xC3\x4D", "\xD0\xA4", "\xC3\x4E",
  /* U+8098 */	"\xD6\xE2", "\xC3\x4F", "\xB6\xC7", "\xB8\xD8",
  /* U+809C */	"\xEB\xC0", "\xB8\xCE", "\xC3\x50", "\xEB\xBF",
  /* U+80A0 */	"\xB3\xA6", "\xB9\xC9", "\xD6\xAB", "\xC3\x51",
  /* U+80A4 */	"\xB7\xF4", "\xB7\xCA", "\xC3\x52", "\xC3\x53",
  /* U+80A8 */	"\xC3\x54", "\xBC\xE7", "\xB7\xBE", "\xEB\xC6",
  /* U+80AC */	"\xC3\x55", "\xEB\xC7", "\xB0\xB9", "\xBF\xCF",
  /* U+80B0 */	"\xC3\x56", "\xEB\xC5", "\xD3\xFD", "\xC3\x57",
  /* U+80B4 */	"\xEB\xC8", "\xC3\x58", "\xC3\x59", "\xEB\xC9",
  /* U+80B8 */	"\xC3\x5A", "\xC3\x5B", "\xB7\xCE", "\xC3\x5C",
  /* U+80BC */	"\xEB\xC2", "\xEB\xC4", "\xC9\xF6", "\xD6\xD7",
  /* U+80C0 */	"\xD5\xCD", "\xD0\xB2", "\xEB\xCF", "\xCE\xB8",
  /* U+80C4 */	"\xEB\xD0", "\xC3\x5D", "\xB5\xA8", "\xC3\x5E",
  /* U+80C8 */	"\xC3\x5F", "\xC3\x60", "\xC3\x61", "\xC3\x62",
  /* U+80CC */	"\xB1\xB3", "\xEB\xD2", "\xCC\xA5", "\xC3\x63",
  /* U+80D0 */	"\xC3\x64", "\xC3\x65", "\xC3\x66", "\xC3\x67",
  /* U+80D4 */	"\xC3\x68", "\xC3\x69", "\xC5\xD6", "\xEB\xD3",
  /* U+80D8 */	"\xC3\x6A", "\xEB\xD1", "\xC5\xDF", "\xEB\xCE",
  /* U+80DC */	"\xCA\xA4", "\xEB\xD5", "\xB0\xFB", "\xC3\x6B",
  /* U+80E0 */	"\xC3\x6C", "\xBA\xFA", "\xC3\x6D", "\xC3\x6E",
  /* U+80E4 */	"\xD8\xB7", "\xF1\xE3", "\xC3\x6F", "\xEB\xCA",
  /* U+80E8 */	"\xEB\xCB", "\xEB\xCC", "\xEB\xCD", "\xEB\xD6",
  /* U+80EC */	"\xE6\xC0", "\xEB\xD9", "\xC3\x70", "\xBF\xE8",
  /* U+80F0 */	"\xD2\xC8", "\xEB\xD7", "\xEB\xDC", "\xB8\xEC",
  /* U+80F4 */	"\xEB\xD8", "\xC3\x71", "\xBD\xBA", "\xC3\x72",
  /* U+80F8 */	"\xD0\xD8", "\xC3\x73", "\xB0\xB7", "\xC3\x74",
  /* U+80FC */	"\xEB\xDD", "\xC4\xDC", "\xC3\x75", "\xC3\x76",
  /* U+8100 */	"\xC3\x77", "\xC3\x78", "\xD6\xAC", "\xC3\x79",
  /* U+8104 */	"\xC3\x7A", "\xC3\x7B", "\xB4\xE0", "\xC3\x7C",
  /* U+8108 */	"\xC3\x7D", "\xC2\xF6", "\xBC\xB9", "\xC3\x7E",
  /* U+810C */	"\xC3\x80", "\xEB\xDA", "\xEB\xDB", "\xD4\xE0",
  /* U+8110 */	"\xC6\xEA", "\xC4\xD4", "\xEB\xDF", "\xC5\xA7",
  /* U+8114 */	"\xD9\xF5", "\xC3\x81", "\xB2\xB1", "\xC3\x82",
  /* U+8118 */	"\xEB\xE4", "\xC3\x83", "\xBD\xC5", "\xC3\x84",
  /* U+811C */	"\xC3\x85", "\xC3\x86", "\xEB\xE2", "\xC3\x87",
  /* U+8120 */	"\xC3\x88", "\xC3\x89", "\xC3\x8A", "\xC3\x8B",
  /* U+8124 */	"\xC3\x8C", "\xC3\x8D", "\xC3\x8E", "\xC3\x8F",
  /* U+8128 */	"\xC3\x90", "\xC3\x91", "\xC3\x92", "\xC3\x93",
  /* U+812C */	"\xEB\xE3", "\xC3\x94", "\xC3\x95", "\xB8\xAC",
  /* U+8130 */	"\xC3\x96", "\xCD\xD1", "\xEB\xE5", "\xC3\x97",
  /* U+8134 */	"\xC3\x98", "\xC3\x99", "\xEB\xE1", "\xC3\x9A",
  /* U+8138 */	"\xC1\xB3", "\xC3\x9B", "\xC3\x9C", "\xC3\x9D",
  /* U+813C */	"\xC3\x9E", "\xC3\x9F", "\xC6\xA2", "\xC3\xA0",
  /* U+8140 */	"\xC4\x40", "\xC4\x41", "\xC4\x42", "\xC4\x43",
  /* U+8144 */	"\xC4\x44", "\xC4\x45", "\xCC\xF3", "\xC4\x46",
  /* U+8148 */	"\xEB\xE6", "\xC4\x47", "\xC0\xB0", "\xD2\xB8",
  /* U+814C */	"\xEB\xE7", "\xC4\x48", "\xC4\x49", "\xC4\x4A",
  /* U+8150 */	"\xB8\xAF", "\xB8\xAD", "\xC4\x4B", "\xEB\xE8",
  /* U+8154 */	"\xC7\xBB", "\xCD\xF3", "\xC4\x4C", "\xC4\x4D",
  /* U+8158 */	"\xC4\x4E", "\xEB\xEA", "\xEB\xEB", "\xC4\x4F",
  /* U+815C */	"\xC4\x50", "\xC4\x51", "\xC4\x52", "\xC4\x53",
  /* U+8160 */	"\xEB\xED", "\xC4\x54", "\xC4\x55", "\xC4\x56",
  /* U+8164 */	"\xC4\x57", "\xD0\xC8", "\xC4\x58", "\xEB\xF2",
  /* U+8168 */	"\xC4\x59", "\xEB\xEE", "\xC4\x5A", "\xC4\x5B",
  /* U+816C */	"\xC4\x5C", "\xEB\xF1", "\xC8\xF9", "\xC4\x5D",
  /* U+8170 */	"\xD1\xFC", "\xEB\xEC", "\xC4\x5E", "\xC4\x5F",
  /* U+8174 */	"\xEB\xE9", "\xC4\x60", "\xC4\x61", "\xC4\x62",
  /* U+8178 */	"\xC4\x63", "\xB8\xB9", "\xCF\xD9", "\xC4\xE5",
  /* U+817C */	"\xEB\xEF", "\xEB\xF0", "\xCC\xDA", "\xCD\xC8",
  /* U+8180 */	"\xB0\xF2", "\xC4\x64", "\xEB\xF6", "\xC4\x65",
  /* U+8184 */	"\xC4\x66", "\xC4\x67", "\xC4\x68", "\xC4\x69",
  /* U+8188 */	"\xEB\xF5", "\xC4\x6A", "\xB2\xB2", "\xC4\x6B",
  /* U+818C */	"\xC4\x6C", "\xC4\x6D", "\xC4\x6E", "\xB8\xE0",
  /* U+8190 */	"\xC4\x6F", "\xEB\xF7", "\xC4\x70", "\xC4\x71",
  /* U+8194 */	"\xC4\x72", "\xC4\x73", "\xC4\x74", "\xC4\x75",
  /* U+8198 */	"\xB1\xEC", "\xC4\x76", "\xC4\x77", "\xCC\xC5",
  /* U+819C */	"\xC4\xA4", "\xCF\xA5", "\xC4\x78", "\xC4\x79",
  /* U+81A0 */	"\xC4\x7A", "\xC4\x7B", "\xC4\x7C", "\xEB\xF9",
  /* U+81A4 */	"\xC4\x7D", "\xC4\x7E", "\xEC\xA2", "\xC4\x80",
  /* U+81A8 */	"\xC5\xF2", "\xC4\x81", "\xEB\xFA", "\xC4\x82",
  /* U+81AC */	"\xC4\x83", "\xC4\x84", "\xC4\x85", "\xC4\x86",
  /* U+81B0 */	"\xC4\x87", "\xC4\x88", "\xC4\x89", "\xC9\xC5",
  /* U+81B4 */	"\xC4\x8A", "\xC4\x8B", "\xC4\x8C", "\xC4\x8D",
  /* U+81B8 */	"\xC4\x8E", "\xC4\x8F", "\xE2\xDF", "\xEB\xFE",
  /* U+81BC */	"\xC4\x90", "\xC4\x91", "\xC4\x92", "\xC4\x93",
  /* U+81C0 */	"\xCD\xCE", "\xEC\xA1", "\xB1\xDB", "\xD3\xB7",
  /* U+81C4 */	"\xC4\x94", "\xC4\x95", "\xD2\xDC", "\xC4\x96",
  /* U+81C8 */	"\xC4\x97", "\xC4\x98", "\xEB\xFD", "\xC4\x99",
  /* U+81CC */	"\xEB\xFB", "\xC4\x9A", "\xC4\x9B", "\xC4\x9C",
  /* U+81D0 */	"\xC4\x9D", "\xC4\x9E", "\xC4\x9F", "\xC4\xA0",
  /* U+81D4 */	"\xC5\x40", "\xC5\x41", "\xC5\x42", "\xC5\x43",
  /* U+81D8 */	"\xC5\x44", "\xC5\x45", "\xC5\x46", "\xC5\x47",
  /* U+81DC */	"\xC5\x48", "\xC5\x49", "\xC5\x4A", "\xC5\x4B",
  /* U+81E0 */	"\xC5\x4C", "\xC5\x4D", "\xC5\x4E", "\xB3\xBC",
  /* U+81E4 */	"\xC5\x4F", "\xC5\x50", "\xC5\x51", "\xEA\xB0",
  /* U+81E8 */	"\xC5\x52", "\xC5\x53", "\xD7\xD4", "\xC5\x54",
  /* U+81EC */	"\xF4\xAB", "\xB3\xF4", "\xC5\x55", "\xC5\x56",
  /* U+81F0 */	"\xC5\x57", "\xC5\x58", "\xC5\x59", "\xD6\xC1",
  /* U+81F4 */	"\xD6\xC2", "\xC5\x5A", "\xC5\x5B", "\xC5\x5C",
  /* U+81F8 */	"\xC5\x5D", "\xC5\x5E", "\xC5\x5F", "\xD5\xE9",
  /* U+81FC */	"\xBE\xCA", "\xC5\x60", "\xF4\xA7", "\xC5\x61",
  /* U+8200 */	"\xD2\xA8", "\xF4\xA8", "\xF4\xA9", "\xC5\x62",
  /* U+8204 */	"\xF4\xAA", "\xBE\xCB", "\xD3\xDF", "\xC5\x63",
  /* U+8208 */	"\xC5\x64", "\xC5\x65", "\xC5\x66", "\xC5\x67",
  /* U+820C */	"\xC9\xE0", "\xC9\xE1", "\xC5\x68", "\xC5\x69",
  /* U+8210 */	"\xF3\xC2", "\xC5\x6A", "\xCA\xE6", "\xC5\x6B",
  /* U+8214 */	"\xCC\xF2", "\xC5\x6C", "\xC5\x6D", "\xC5\x6E",
  /* U+8218 */	"\xC5\x6F", "\xC5\x70", "\xC5\x71", "\xE2\xB6",
  /* U+821C */	"\xCB\xB4", "\xC5\x72", "\xCE\xE8", "\xD6\xDB",
  /* U+8220 */	"\xC5\x73", "\xF4\xAD", "\xF4\xAE", "\xF4\xAF",
  /* U+8224 */	"\xC5\x74", "\xC5\x75", "\xC5\x76", "\xC5\x77",
  /* U+8228 */	"\xF4\xB2", "\xC5\x78", "\xBA\xBD", "\xF4\xB3",
  /* U+822C */	"\xB0\xE3", "\xF4\xB0", "\xC5\x79", "\xF4\xB1",
  /* U+8230 */	"\xBD\xA2", "\xB2\xD5", "\xC5\x7A", "\xF4\xB6",
  /* U+8234 */	"\xF4\xB7", "\xB6\xE6", "\xB2\xB0", "\xCF\xCF",
  /* U+8238 */	"\xF4\xB4", "\xB4\xAC", "\xC5\x7B", "\xF4\xB5",
  /* U+823C */	"\xC5\x7C", "\xC5\x7D", "\xF4\xB8", "\xC5\x7E",
  /* U+8240 */	"\xC5\x80", "\xC5\x81", "\xC5\x82", "\xC5\x83",
  /* U+8244 */	"\xF4\xB9", "\xC5\x84", "\xC5\x85", "\xCD\xA7",
  /* U+8248 */	"\xC5\x86", "\xF4\xBA", "\xC5\x87", "\xF4\xBB",
  /* U+824C */	"\xC5\x88", "\xC5\x89", "\xC5\x8A", "\xF4\xBC",
  /* U+8250 */	"\xC5\x8B", "\xC5\x8C", "\xC5\x8D", "\xC5\x8E",
  /* U+8254 */	"\xC5\x8F", "\xC5\x90", "\xC5\x91", "\xC5\x92",
  /* U+8258 */	"\xCB\xD2", "\xC5\x93", "\xF4\xBD", "\xC5\x94",
  /* U+825C */	"\xC5\x95", "\xC5\x96", "\xC5\x97", "\xF4\xBE",
  /* U+8260 */	"\xC5\x98", "\xC5\x99", "\xC5\x9A", "\xC5\x9B",
  /* U+8264 */	"\xC5\x9C", "\xC5\x9D", "\xC5\x9E", "\xC5\x9F",
  /* U+8268 */	"\xF4\xBF", "\xC5\xA0", "\xC6\x40", "\xC6\x41",
  /* U+826C */	"\xC6\x42", "\xC6\x43", "\xF4\xDE", "\xC1\xBC",
  /* U+8270 */	"\xBC\xE8", "\xC6\x44", "\xC9\xAB", "\xD1\xDE",
  /* U+8274 */	"\xE5\xF5", "\xC6\x45", "\xC6\x46", "\xC6\x47",
  /* U+8278 */	"\xC6\x48", "\xDC\xB3", "\xD2\xD5", "\xC6\x49",
  /* U+827C */	"\xC6\x4A", "\xDC\xB4", "\xB0\xAC", "\xDC\xB5",
  /* U+8280 */	"\xC6\x4B", "\xC6\x4C", "\xBD\xDA", "\xC6\x4D",
  /* U+8284 */	"\xDC\xB9", "\xC6\x4E", "\xC6\x4F", "\xC6\x50",
  /* U+8288 */	"\xD8\xC2", "\xC6\x51", "\xDC\xB7", "\xD3\xF3",
  /* U+828C */	"\xC6\x52", "\xC9\xD6", "\xDC\xBA", "\xDC\xB6",
  /* U+8290 */	"\xC6\x53", "\xDC\xBB", "\xC3\xA2", "\xC6\x54",
  /* U+8294 */	"\xC6\x55", "\xC6\x56", "\xC6\x57", "\xDC\xBC",
  /* U+8298 */	"\xDC\xC5", "\xDC\xBD", "\xC6\x58", "\xC6\x59",
  /* U+829C */	"\xCE\xDF", "\xD6\xA5", "\xC6\x5A", "\xDC\xCF",
  /* U+82A0 */	"\xC6\x5B", "\xDC\xCD", "\xC6\x5C", "\xC6\x5D",
  /* U+82A4 */	"\xDC\xD2", "\xBD\xE6", "\xC2\xAB", "\xC6\x5E",
  /* U+82A8 */	"\xDC\xB8", "\xDC\xCB", "\xDC\xCE", "\xDC\xBE",
  /* U+82AC */	"\xB7\xD2", "\xB0\xC5", "\xDC\xC7", "\xD0\xBE",
  /* U+82B0 */	"\xDC\xC1", "\xBB\xA8", "\xC6\x5F", "\xB7\xBC",
  /* U+82B4 */	"\xDC\xCC", "\xC6\x60", "\xC6\x61", "\xDC\xC6",
  /* U+82B8 */	"\xDC\xBF", "\xC7\xDB", "\xC6\x62", "\xC6\x63",
  /* U+82BC */	"\xC6\x64", "\xD1\xBF", "\xDC\xC0", "\xC6\x65",
  /* U+82C0 */	"\xC6\x66", "\xDC\xCA", "\xC6\x67", "\xC6\x68",
  /* U+82C4 */	"\xDC\xD0", "\xC6\x69", "\xC6\x6A", "\xCE\xAD",
  /* U+82C8 */	"\xDC\xC2", "\xC6\x6B", "\xDC\xC3", "\xDC\xC8",
  /* U+82CC */	"\xDC\xC9", "\xB2\xD4", "\xDC\xD1", "\xCB\xD5",
  /* U+82D0 */	"\xC6\x6C", "\xD4\xB7", "\xDC\xDB", "\xDC\xDF",
  /* U+82D4 */	"\xCC\xA6", "\xDC\xE6", "\xC6\x6D", "\xC3\xE7",
  /* U+82D8 */	"\xDC\xDC", "\xC6\x6E", "\xC6\x6F", "\xBF\xC1",
  /* U+82DC */	"\xDC\xD9", "\xC6\x70", "\xB0\xFA", "\xB9\xB6",
  /* U+82E0 */	"\xDC\xE5", "\xDC\xD3", "\xC6\x71", "\xDC\xC4",
  /* U+82E4 */	"\xDC\xD6", "\xC8\xF4", "\xBF\xE0", "\xC6\x72",
  /* U+82E8 */	"\xC6\x73", "\xC6\x74", "\xC6\x75", "\xC9\xBB",
  /* U+82EC */	"\xC6\x76", "\xC6\x77", "\xC6\x78", "\xB1\xBD",
  /* U+82F0 */	"\xC6\x79", "\xD3\xA2", "\xC6\x7A", "\xC6\x7B",
  /* U+82F4 */	"\xDC\xDA", "\xC6\x7C", "\xC6\x7D", "\xDC\xD5",
  /* U+82F8 */	"\xC6\x7E", "\xC6\xBB", "\xC6\x80", "\xDC\xDE",
  /* U+82FC */	"\xC6\x81", "\xC6\x82", "\xC6\x83", "\xC6\x84",
  /* U+8300 */	"\xC6\x85", "\xD7\xC2", "\xC3\xAF", "\xB7\xB6",
  /* U+8304 */	"\xC7\xD1", "\xC3\xA9", "\xDC\xE2", "\xDC\xD8",
  /* U+8308 */	"\xDC\xEB", "\xDC\xD4", "\xC6\x86", "\xC6\x87",
  /* U+830C */	"\xDC\xDD", "\xC6\x88", "\xBE\xA5", "\xDC\xD7",
  /* U+8310 */	"\xC6\x89", "\xDC\xE0", "\xC6\x8A", "\xC6\x8B",
  /* U+8314 */	"\xDC\xE3", "\xDC\xE4", "\xC6\x8C", "\xDC\xF8",
  /* U+8318 */	"\xC6\x8D", "\xC6\x8E", "\xDC\xE1", "\xDD\xA2",
  /* U+831C */	"\xDC\xE7", "\xC6\x8F", "\xC6\x90", "\xC6\x91",
  /* U+8320 */	"\xC6\x92", "\xC6\x93", "\xC6\x94", "\xC6\x95",
  /* U+8324 */	"\xC6\x96", "\xC6\x97", "\xC6\x98", "\xBC\xEB",
  /* U+8328 */	"\xB4\xC4", "\xC6\x99", "\xC6\x9A", "\xC3\xA3",
  /* U+832C */	"\xB2\xE7", "\xDC\xFA", "\xC6\x9B", "\xDC\xF2",
  /* U+8330 */	"\xC6\x9C", "\xDC\xEF", "\xC6\x9D", "\xDC\xFC",
  /* U+8334 */	"\xDC\xEE", "\xD2\xF0", "\xB2\xE8", "\xC6\x9E",
  /* U+8338 */	"\xC8\xD7", "\xC8\xE3", "\xDC\xFB", "\xC6\x9F",
  /* U+833C */	"\xDC\xED", "\xC6\xA0", "\xC7\x40", "\xC7\x41",
  /* U+8340 */	"\xDC\xF7", "\xC7\x42", "\xC7\x43", "\xDC\xF5",
  /* U+8344 */	"\xC7\x44", "\xC7\x45", "\xBE\xA3", "\xDC\xF4",
  /* U+8348 */	"\xC7\x46", "\xB2\xDD", "\xC7\x47", "\xC7\x48",
  /* U+834C */	"\xC7\x49", "\xC7\x4A", "\xC7\x4B", "\xDC\xF3",
  /* U+8350 */	"\xBC\xF6", "\xDC\xE8", "\xBB\xC4", "\xC7\x4C",
  /* U+8354 */	"\xC0\xF3", "\xC7\x4D", "\xC7\x4E", "\xC7\x4F",
  /* U+8358 */	"\xC7\x50", "\xC7\x51", "\xBC\xD4", "\xDC\xE9",
  /* U+835C */	"\xDC\xEA", "\xC7\x52", "\xDC\xF1", "\xDC\xF6",
  /* U+8360 */	"\xDC\xF9", "\xB5\xB4", "\xC7\x53", "\xC8\xD9",
  /* U+8364 */	"\xBB\xE7", "\xDC\xFE", "\xDC\xFD", "\xD3\xAB",
  /* U+8368 */	"\xDD\xA1", "\xDD\xA3", "\xDD\xA5", "\xD2\xF1",
  /* U+836C */	"\xDD\xA4", "\xDD\xA6", "\xDD\xA7", "\xD2\xA9",
  /* U+8370 */	"\xC7\x54", "\xC7\x55", "\xC7\x56", "\xC7\x57",
  /* U+8374 */	"\xC7\x58", "\xC7\x59", "\xC7\x5A", "\xBA\xC9",
  /* U+8378 */	"\xDD\xA9", "\xC7\x5B", "\xC7\x5C", "\xDD\xB6",
  /* U+837C */	"\xDD\xB1", "\xDD\xB4", "\xC7\x5D", "\xC7\x5E",
  /* U+8380 */	"\xC7\x5F", "\xC7\x60", "\xC7\x61", "\xC7\x62",
  /* U+8384 */	"\xC7\x63", "\xDD\xB0", "\xC6\xCE", "\xC7\x64",
  /* U+8388 */	"\xC7\x65", "\xC0\xF2", "\xC7\x66", "\xC7\x67",
  /* U+838C */	"\xC7\x68", "\xC7\x69", "\xC9\xAF", "\xC7\x6A",
  /* U+8390 */	"\xC7\x6B", "\xC7\x6C", "\xDC\xEC", "\xDD\xAE",
  /* U+8394 */	"\xC7\x6D", "\xC7\x6E", "\xC7\x6F", "\xC7\x70",
  /* U+8398 */	"\xDD\xB7", "\xC7\x71", "\xC7\x72", "\xDC\xF0",
  /* U+839C */	"\xDD\xAF", "\xC7\x73", "\xDD\xB8", "\xC7\x74",
  /* U+83A0 */	"\xDD\xAC", "\xC7\x75", "\xC7\x76", "\xC7\x77",
  /* U+83A4 */	"\xC7\x78", "\xC7\x79", "\xC7\x7A", "\xC7\x7B",
  /* U+83A8 */	"\xDD\xB9", "\xDD\xB3", "\xDD\xAD", "\xC4\xAA",
  /* U+83AC */	"\xC7\x7C", "\xC7\x7D", "\xC7\x7E", "\xC7\x80",
  /* U+83B0 */	"\xDD\xA8", "\xC0\xB3", "\xC1\xAB", "\xDD\xAA",
  /* U+83B4 */	"\xDD\xAB", "\xC7\x81", "\xDD\xB2", "\xBB\xF1",
  /* U+83B8 */	"\xDD\xB5", "\xD3\xA8", "\xDD\xBA", "\xC7\x82",
  /* U+83BC */	"\xDD\xBB", "\xC3\xA7", "\xC7\x83", "\xC7\x84",
  /* U+83C0 */	"\xDD\xD2", "\xDD\xBC", "\xC7\x85", "\xC7\x86",
  /* U+83C4 */	"\xC7\x87", "\xDD\xD1", "\xC7\x88", "\xB9\xBD",
  /* U+83C8 */	"\xC7\x89", "\xC7\x8A", "\xBE\xD5", "\xC7\x8B",
  /* U+83CC */	"\xBE\xFA", "\xC7\x8C", "\xC7\x8D", "\xBA\xCA",
  /* U+83D0 */	"\xC7\x8E", "\xC7\x8F", "\xC7\x90", "\xC7\x91",
  /* U+83D4 */	"\xDD\xCA", "\xC7\x92", "\xDD\xC5", "\xC7\x93",
  /* U+83D8 */	"\xDD\xBF", "\xC7\x94", "\xC7\x95", "\xC7\x96",
  /* U+83DC */	"\xB2\xCB", "\xDD\xC3", "\xC7\x97", "\xDD\xCB",
  /* U+83E0 */	"\xB2\xA4", "\xDD\xD5", "\xC7\x98", "\xC7\x99",
  /* U+83E4 */	"\xC7\x9A", "\xDD\xBE", "\xC7\x9B", "\xC7\x9C",
  /* U+83E8 */	"\xC7\x9D", "\xC6\xD0", "\xDD\xD0", "\xC7\x9E",
  /* U+83EC */	"\xC7\x9F", "\xC7\xA0", "\xC8\x40", "\xC8\x41",
  /* U+83F0 */	"\xDD\xD4", "\xC1\xE2", "\xB7\xC6", "\xC8\x42",
  /* U+83F4 */	"\xC8\x43", "\xC8\x44", "\xC8\x45", "\xC8\x46",
  /* U+83F8 */	"\xDD\xCE", "\xDD\xCF", "\xC8\x47", "\xC8\x48",
  /* U+83FC */	"\xC8\x49", "\xDD\xC4", "\xC8\x4A", "\xC8\x4B",
  /* U+8400 */	"\xC8\x4C", "\xDD\xBD", "\xC8\x4D", "\xDD\xCD",
  /* U+8404 */	"\xCC\xD1", "\xC8\x4E", "\xDD\xC9", "\xC8\x4F",
  /* U+8408 */	"\xC8\x50", "\xC8\x51", "\xC8\x52", "\xDD\xC2",
  /* U+840C */	"\xC3\xC8", "\xC6\xBC", "\xCE\xAE", "\xDD\xCC",
  /* U+8410 */	"\xC8\x53", "\xDD\xC8", "\xC8\x54", "\xC8\x55",
  /* U+8414 */	"\xC8\x56", "\xC8\x57", "\xC8\x58", "\xC8\x59",
  /* U+8418 */	"\xDD\xC1", "\xC8\x5A", "\xC8\x5B", "\xC8\x5C",
  /* U+841C */	"\xDD\xC6", "\xC2\xDC", "\xC8\x5D", "\xC8\x5E",
  /* U+8420 */	"\xC8\x5F", "\xC8\x60", "\xC8\x61", "\xC8\x62",
  /* U+8424 */	"\xD3\xA9", "\xD3\xAA", "\xDD\xD3", "\xCF\xF4",
  /* U+8428 */	"\xC8\xF8", "\xC8\x63", "\xC8\x64", "\xC8\x65",
  /* U+842C */	"\xC8\x66", "\xC8\x67", "\xC8\x68", "\xC8\x69",
  /* U+8430 */	"\xC8\x6A", "\xDD\xE6", "\xC8\x6B", "\xC8\x6C",
  /* U+8434 */	"\xC8\x6D", "\xC8\x6E", "\xC8\x6F", "\xC8\x70",
  /* U+8438 */	"\xDD\xC7", "\xC8\x71", "\xC8\x72", "\xC8\x73",
  /* U+843C */	"\xDD\xE0", "\xC2\xE4", "\xC8\x74", "\xC8\x75",
  /* U+8440 */	"\xC8\x76", "\xC8\x77", "\xC8\x78", "\xC8\x79",
  /* U+8444 */	"\xC8\x7A", "\xC8\x7B", "\xDD\xE1", "\xC8\x7C",
  /* U+8448 */	"\xC8\x7D", "\xC8\x7E", "\xC8\x80", "\xC8\x81",
  /* U+844C */	"\xC8\x82", "\xC8\x83", "\xC8\x84", "\xC8\x85",
  /* U+8450 */	"\xC8\x86", "\xDD\xD7", "\xC8\x87", "\xC8\x88",
  /* U+8454 */	"\xC8\x89", "\xC8\x8A", "\xC8\x8B", "\xD6\xF8",
  /* U+8458 */	"\xC8\x8C", "\xDD\xD9", "\xDD\xD8", "\xB8\xF0",
  /* U+845C */	"\xDD\xD6", "\xC8\x8D", "\xC8\x8E", "\xC8\x8F",
  /* U+8460 */	"\xC8\x90", "\xC6\xCF", "\xC8\x91", "\xB6\xAD",
  /* U+8464 */	"\xC8\x92", "\xC8\x93", "\xC8\x94", "\xC8\x95",
  /* U+8468 */	"\xC8\x96", "\xDD\xE2", "\xC8\x97", "\xBA\xF9",
  /* U+846C */	"\xD4\xE1", "\xDD\xE7", "\xC8\x98", "\xC8\x99",
  /* U+8470 */	"\xC8\x9A", "\xB4\xD0", "\xC8\x9B", "\xDD\xDA",
  /* U+8474 */	"\xC8\x9C", "\xBF\xFB", "\xDD\xE3", "\xC8\x9D",
  /* U+8478 */	"\xDD\xDF", "\xC8\x9E", "\xDD\xDD", "\xC8\x9F",
  /* U+847C */	"\xC8\xA0", "\xC9\x40", "\xC9\x41", "\xC9\x42",
  /* U+8480 */	"\xC9\x43", "\xC9\x44", "\xB5\xD9", "\xC9\x45",
  /* U+8484 */	"\xC9\x46", "\xC9\x47", "\xC9\x48", "\xDD\xDB",
  /* U+8488 */	"\xDD\xDC", "\xDD\xDE", "\xC9\x49", "\xBD\xAF",
  /* U+848C */	"\xDD\xE4", "\xC9\x4A", "\xDD\xE5", "\xC9\x4B",
  /* U+8490 */	"\xC9\x4C", "\xC9\x4D", "\xC9\x4E", "\xC9\x4F",
  /* U+8494 */	"\xC9\x50", "\xC9\x51", "\xC9\x52", "\xDD\xF5",
  /* U+8498 */	"\xC9\x53", "\xC3\xC9", "\xC9\x54", "\xC9\x55",
  /* U+849C */	"\xCB\xE2", "\xC9\x56", "\xC9\x57", "\xC9\x58",
  /* U+84A0 */	"\xC9\x59", "\xDD\xF2", "\xC9\x5A", "\xC9\x5B",
  /* U+84A4 */	"\xC9\x5C", "\xC9\x5D", "\xC9\x5E", "\xC9\x5F",
  /* U+84A8 */	"\xC9\x60", "\xC9\x61", "\xC9\x62", "\xC9\x63",
  /* U+84AC */	"\xC9\x64", "\xC9\x65", "\xC9\x66", "\xD8\xE1",
  /* U+84B0 */	"\xC9\x67", "\xC9\x68", "\xC6\xD1", "\xC9\x69",
  /* U+84B4 */	"\xDD\xF4", "\xC9\x6A", "\xC9\x6B", "\xC9\x6C",
  /* U+84B8 */	"\xD5\xF4", "\xDD\xF3", "\xDD\xF0", "\xC9\x6D",
  /* U+84BC */	"\xC9\x6E", "\xDD\xEC", "\xC9\x6F", "\xDD\xEF",
  /* U+84C0 */	"\xC9\x70", "\xDD\xE8", "\xC9\x71", "\xC9\x72",
  /* U+84C4 */	"\xD0\xEE", "\xC9\x73", "\xC9\x74", "\xC9\x75",
  /* U+84C8 */	"\xC9\x76", "\xC8\xD8", "\xDD\xEE", "\xC9\x77",
  /* U+84CC */	"\xC9\x78", "\xDD\xE9", "\xC9\x79", "\xC9\x7A",
  /* U+84D0 */	"\xDD\xEA", "\xCB\xF2", "\xC9\x7B", "\xDD\xED",
  /* U+84D4 */	"\xC9\x7C", "\xC9\x7D", "\xB1\xCD", "\xC9\x7E",
  /* U+84D8 */	"\xC9\x80", "\xC9\x81", "\xC9\x82", "\xC9\x83",
  /* U+84DC */	"\xC9\x84", "\xC0\xB6", "\xC9\x85", "\xBC\xBB",
  /* U+84E0 */	"\xDD\xF1", "\xC9\x86", "\xC9\x87", "\xDD\xF7",
  /* U+84E4 */	"\xC9\x88", "\xDD\xF6", "\xDD\xEB", "\xC9\x89",
  /* U+84E8 */	"\xC9\x8A", "\xC9\x8B", "\xC9\x8C", "\xC9\x8D",
  /* U+84EC */	"\xC5\xEE", "\xC9\x8E", "\xC9\x8F", "\xC9\x90",
  /* U+84F0 */	"\xDD\xFB", "\xC9\x91", "\xC9\x92", "\xC9\x93",
  /* U+84F4 */	"\xC9\x94", "\xC9\x95", "\xC9\x96", "\xC9\x97",
  /* U+84F8 */	"\xC9\x98", "\xC9\x99", "\xC9\x9A", "\xC9\x9B",
  /* U+84FC */	"\xDE\xA4", "\xC9\x9C", "\xC9\x9D", "\xDE\xA3",
  /* U+8500 */	"\xC9\x9E", "\xC9\x9F", "\xC9\xA0", "\xCA\x40",
  /* U+8504 */	"\xCA\x41", "\xCA\x42", "\xCA\x43", "\xCA\x44",
  /* U+8508 */	"\xCA\x45", "\xCA\x46", "\xCA\x47", "\xCA\x48",
  /* U+850C */	"\xDD\xF8", "\xCA\x49", "\xCA\x4A", "\xCA\x4B",
  /* U+8510 */	"\xCA\x4C", "\xC3\xEF", "\xCA\x4D", "\xC2\xFB",
  /* U+8514 */	"\xCA\x4E", "\xCA\x4F", "\xCA\x50", "\xD5\xE1",
  /* U+8518 */	"\xCA\x51", "\xCA\x52", "\xCE\xB5", "\xCA\x53",
  /* U+851C */	"\xCA\x54", "\xCA\x55", "\xCA\x56", "\xDD\xFD",
  /* U+8520 */	"\xCA\x57", "\xB2\xCC", "\xCA\x58", "\xCA\x59",
  /* U+8524 */	"\xCA\x5A", "\xCA\x5B", "\xCA\x5C", "\xCA\x5D",
  /* U+8528 */	"\xCA\x5E", "\xCA\x5F", "\xCA\x60", "\xC4\xE8",
  /* U+852C */	"\xCA\xDF", "\xCA\x61", "\xCA\x62", "\xCA\x63",
  /* U+8530 */	"\xCA\x64", "\xCA\x65", "\xCA\x66", "\xCA\x67",
  /* U+8534 */	"\xCA\x68", "\xCA\x69", "\xCA\x6A", "\xC7\xBE",
  /* U+8538 */	"\xDD\xFA", "\xDD\xFC", "\xDD\xFE", "\xDE\xA2",
  /* U+853C */	"\xB0\xAA", "\xB1\xCE", "\xCA\x6B", "\xCA\x6C",
  /* U+8540 */	"\xCA\x6D", "\xCA\x6E", "\xCA\x6F", "\xDE\xAC",
  /* U+8544 */	"\xCA\x70", "\xCA\x71", "\xCA\x72", "\xCA\x73",
  /* U+8548 */	"\xDE\xA6", "\xBD\xB6", "\xC8\xEF", "\xCA\x74",
  /* U+854C */	"\xCA\x75", "\xCA\x76", "\xCA\x77", "\xCA\x78",
  /* U+8550 */	"\xCA\x79", "\xCA\x7A", "\xCA\x7B", "\xCA\x7C",
  /* U+8554 */	"\xCA\x7D", "\xCA\x7E", "\xDE\xA1", "\xCA\x80",
  /* U+8558 */	"\xCA\x81", "\xDE\xA5", "\xCA\x82", "\xCA\x83",
  /* U+855C */	"\xCA\x84", "\xCA\x85", "\xDE\xA9", "\xCA\x86",
  /* U+8560 */	"\xCA\x87", "\xCA\x88", "\xCA\x89", "\xCA\x8A",
  /* U+8564 */	"\xDE\xA8", "\xCA\x8B", "\xCA\x8C", "\xCA\x8D",
  /* U+8568 */	"\xDE\xA7", "\xCA\x8E", "\xCA\x8F", "\xCA\x90",
  /* U+856C */	"\xCA\x91", "\xCA\x92", "\xCA\x93", "\xCA\x94",
  /* U+8570 */	"\xCA\x95", "\xCA\x96", "\xDE\xAD", "\xCA\x97",
  /* U+8574 */	"\xD4\xCC", "\xCA\x98", "\xCA\x99", "\xCA\x9A",
  /* U+8578 */	"\xCA\x9B", "\xDE\xB3", "\xDE\xAA", "\xDE\xAE",
  /* U+857C */	"\xCA\x9C", "\xCA\x9D", "\xC0\xD9", "\xCA\x9E",
  /* U+8580 */	"\xCA\x9F", "\xCA\xA0", "\xCB\x40", "\xCB\x41",
  /* U+8584 */	"\xB1\xA1", "\xDE\xB6", "\xCB\x42", "\xDE\xB1",
  /* U+8588 */	"\xCB\x43", "\xCB\x44", "\xCB\x45", "\xCB\x46",
  /* U+858C */	"\xCB\x47", "\xCB\x48", "\xCB\x49", "\xDE\xB2",
  /* U+8590 */	"\xCB\x4A", "\xCB\x4B", "\xCB\x4C", "\xCB\x4D",
  /* U+8594 */	"\xCB\x4E", "\xCB\x4F", "\xCB\x50", "\xCB\x51",
  /* U+8598 */	"\xCB\x52", "\xCB\x53", "\xCB\x54", "\xD1\xA6",
  /* U+859C */	"\xDE\xB5", "\xCB\x55", "\xCB\x56", "\xCB\x57",
  /* U+85A0 */	"\xCB\x58", "\xCB\x59", "\xCB\x5A", "\xCB\x5B",
  /* U+85A4 */	"\xDE\xAF", "\xCB\x5C", "\xCB\x5D", "\xCB\x5E",
  /* U+85A8 */	"\xDE\xB0", "\xCB\x5F", "\xD0\xBD", "\xCB\x60",
  /* U+85AC */	"\xCB\x61", "\xCB\x62", "\xDE\xB4", "\xCA\xED",
  /* U+85B0 */	"\xDE\xB9", "\xCB\x63", "\xCB\x64", "\xCB\x65",
  /* U+85B4 */	"\xCB\x66", "\xCB\x67", "\xCB\x68", "\xDE\xB8",
  /* U+85B8 */	"\xCB\x69", "\xDE\xB7", "\xCB\x6A", "\xCB\x6B",
  /* U+85BC */	"\xCB\x6C", "\xCB\x6D", "\xCB\x6E", "\xCB\x6F",
  /* U+85C0 */	"\xCB\x70", "\xDE\xBB", "\xCB\x71", "\xCB\x72",
  /* U+85C4 */	"\xCB\x73", "\xCB\x74", "\xCB\x75", "\xCB\x76",
  /* U+85C8 */	"\xCB\x77", "\xBD\xE5", "\xCB\x78", "\xCB\x79",
  /* U+85CC */	"\xCB\x7A", "\xCB\x7B", "\xCB\x7C", "\xB2\xD8",
  /* U+85D0 */	"\xC3\xEA", "\xCB\x7D", "\xCB\x7E", "\xDE\xBA",
  /* U+85D4 */	"\xCB\x80", "\xC5\xBA", "\xCB\x81", "\xCB\x82",
  /* U+85D8 */	"\xCB\x83", "\xCB\x84", "\xCB\x85", "\xCB\x86",
  /* U+85DC */	"\xDE\xBC", "\xCB\x87", "\xCB\x88", "\xCB\x89",
  /* U+85E0 */	"\xCB\x8A", "\xCB\x8B", "\xCB\x8C", "\xCB\x8D",
  /* U+85E4 */	"\xCC\xD9", "\xCB\x8E", "\xCB\x8F", "\xCB\x90",
  /* U+85E8 */	"\xCB\x91", "\xB7\xAA", "\xCB\x92", "\xCB\x93",
  /* U+85EC */	"\xCB\x94", "\xCB\x95", "\xCB\x96", "\xCB\x97",
  /* U+85F0 */	"\xCB\x98", "\xCB\x99", "\xCB\x9A", "\xCB\x9B",
  /* U+85F4 */	"\xCB\x9C", "\xCB\x9D", "\xCB\x9E", "\xCB\x9F",
  /* U+85F8 */	"\xCB\xA0", "\xCC\x40", "\xCC\x41", "\xD4\xE5",
  /* U+85FC */	"\xCC\x42", "\xCC\x43", "\xCC\x44", "\xDE\xBD",
  /* U+8600 */	"\xCC\x45", "\xCC\x46", "\xCC\x47", "\xCC\x48",
  /* U+8604 */	"\xCC\x49", "\xDE\xBF", "\xCC\x4A", "\xCC\x4B",
  /* U+8608 */	"\xCC\x4C", "\xCC\x4D", "\xCC\x4E", "\xCC\x4F",
  /* U+860C */	"\xCC\x50", "\xCC\x51", "\xCC\x52", "\xCC\x53",
  /* U+8610 */	"\xCC\x54", "\xC4\xA2", "\xCC\x55", "\xCC\x56",
  /* U+8614 */	"\xCC\x57", "\xCC\x58", "\xDE\xC1", "\xCC\x59",
  /* U+8618 */	"\xCC\x5A", "\xCC\x5B", "\xCC\x5C", "\xCC\x5D",
  /* U+861C */	"\xCC\x5E", "\xCC\x5F", "\xCC\x60", "\xCC\x61",
  /* U+8620 */	"\xCC\x62", "\xCC\x63", "\xCC\x64", "\xCC\x65",
  /* U+8624 */	"\xCC\x66", "\xCC\x67", "\xCC\x68", "\xDE\xBE",
  /* U+8628 */	"\xCC\x69", "\xDE\xC0", "\xCC\x6A", "\xCC\x6B",
  /* U+862C */	"\xCC\x6C", "\xCC\x6D", "\xCC\x6E", "\xCC\x6F",
  /* U+8630 */	"\xCC\x70", "\xCC\x71", "\xCC\x72", "\xCC\x73",
  /* U+8634 */	"\xCC\x74", "\xCC\x75", "\xCC\x76", "\xCC\x77",
  /* U+8638 */	"\xD5\xBA", "\xCC\x78", "\xCC\x79", "\xCC\x7A",
  /* U+863C */	"\xDE\xC2", "\xCC\x7B", "\xCC\x7C", "\xCC\x7D",
  /* U+8640 */	"\xCC\x7E", "\xCC\x80", "\xCC\x81", "\xCC\x82",
  /* U+8644 */	"\xCC\x83", "\xCC\x84", "\xCC\x85", "\xCC\x86",
  /* U+8648 */	"\xCC\x87", "\xCC\x88", "\xCC\x89", "\xCC\x8A",
  /* U+864C */	"\xCC\x8B", "\xF2\xAE", "\xBB\xA2", "\xC2\xB2",
  /* U+8650 */	"\xC5\xB0", "\xC2\xC7", "\xCC\x8C", "\xCC\x8D",
  /* U+8654 */	"\xF2\xAF", "\xCC\x8E", "\xCC\x8F", "\xCC\x90",
  /* U+8658 */	"\xCC\x91", "\xCC\x92", "\xD0\xE9", "\xCC\x93",
  /* U+865C */	"\xCC\x94", "\xCC\x95", "\xD3\xDD", "\xCC\x96",
  /* U+8660 */	"\xCC\x97", "\xCC\x98", "\xEB\xBD", "\xCC\x99",
  /* U+8664 */	"\xCC\x9A", "\xCC\x9B", "\xCC\x9C", "\xCC\x9D",
  /* U+8668 */	"\xCC\x9E", "\xCC\x9F", "\xCC\xA0", "\xB3\xE6",
  /* U+866C */	"\xF2\xB0", "\xCD\x40", "\xF2\xB1", "\xCD\x41",
  /* U+8670 */	"\xCD\x42", "\xCA\xAD", "\xCD\x43", "\xCD\x44",
  /* U+8674 */	"\xCD\x45", "\xCD\x46", "\xCD\x47", "\xCD\x48",
  /* U+8678 */	"\xCD\x49", "\xBA\xE7", "\xF2\xB3", "\xF2\xB5",
  /* U+867C */	"\xF2\xB4", "\xCB\xE4", "\xCF\xBA", "\xF2\xB2",
  /* U+8680 */	"\xCA\xB4", "\xD2\xCF", "\xC2\xEC", "\xCD\x4A",
  /* U+8684 */	"\xCD\x4B", "\xCD\x4C", "\xCD\x4D", "\xCD\x4E",
  /* U+8688 */	"\xCD\x4F", "\xCD\x50", "\xCE\xC3", "\xF2\xB8",
  /* U+868C */	"\xB0\xF6", "\xF2\xB7", "\xCD\x51", "\xCD\x52",
  /* U+8690 */	"\xCD\x53", "\xCD\x54", "\xCD\x55", "\xF2\xBE",
  /* U+8694 */	"\xCD\x56", "\xB2\xCF", "\xCD\x57", "\xCD\x58",
  /* U+8698 */	"\xCD\x59", "\xCD\x5A", "\xCD\x5B", "\xCD\x5C",
  /* U+869C */	"\xD1\xC1", "\xF2\xBA", "\xCD\x5D", "\xCD\x5E",
  /* U+86A0 */	"\xCD\x5F", "\xCD\x60", "\xCD\x61", "\xF2\xBC",
  /* U+86A4 */	"\xD4\xE9", "\xCD\x62", "\xCD\x63", "\xF2\xBB",
  /* U+86A8 */	"\xF2\xB6", "\xF2\xBF", "\xF2\xBD", "\xCD\x64",
  /* U+86AC */	"\xF2\xB9", "\xCD\x65", "\xCD\x66", "\xF2\xC7",
  /* U+86B0 */	"\xF2\xC4", "\xF2\xC6", "\xCD\x67", "\xCD\x68",
  /* U+86B4 */	"\xF2\xCA", "\xF2\xC2", "\xF2\xC0", "\xCD\x69",
  /* U+86B8 */	"\xCD\x6A", "\xCD\x6B", "\xF2\xC5", "\xCD\x6C",
  /* U+86BC */	"\xCD\x6D", "\xCD\x6E", "\xCD\x6F", "\xCD\x70",
  /* U+86C0 */	"\xD6\xFB", "\xCD\x71", "\xCD\x72", "\xCD\x73",
  /* U+86C4 */	"\xF2\xC1", "\xCD\x74", "\xC7\xF9", "\xC9\xDF",
  /* U+86C8 */	"\xCD\x75", "\xF2\xC8", "\xB9\xC6", "\xB5\xB0",
  /* U+86CC */	"\xCD\x76", "\xCD\x77", "\xF2\xC3", "\xF2\xC9",
  /* U+86D0 */	"\xF2\xD0", "\xF2\xD6", "\xCD\x78", "\xCD\x79",
  /* U+86D4 */	"\xBB\xD7", "\xCD\x7A", "\xCD\x7B", "\xCD\x7C",
  /* U+86D8 */	"\xF2\xD5", "\xCD\xDC", "\xCD\x7D", "\xD6\xEB",
  /* U+86DC */	"\xCD\x7E", "\xCD\x80", "\xF2\xD2", "\xF2\xD4",
  /* U+86E0 */	"\xCD\x81", "\xCD\x82", "\xCD\x83", "\xCD\x84",
  /* U+86E4 */	"\xB8\xF2", "\xCD\x85", "\xCD\x86", "\xCD\x87",
  /* U+86E8 */	"\xCD\x88", "\xF2\xCB", "\xCD\x89", "\xCD\x8A",
  /* U+86EC */	"\xCD\x8B", "\xF2\xCE", "\xC2\xF9", "\xCD\x8C",
  /* U+86F0 */	"\xD5\xDD", "\xF2\xCC", "\xF2\xCD", "\xF2\xCF",
  /* U+86F4 */	"\xF2\xD3", "\xCD\x8D", "\xCD\x8E", "\xCD\x8F",
  /* U+86F8 */	"\xF2\xD9", "\xD3\xBC", "\xCD\x90", "\xCD\x91",
  /* U+86FC */	"\xCD\x92", "\xCD\x93", "\xB6\xEA", "\xCD\x94",
  /* U+8700 */	"\xCA\xF1", "\xCD\x95", "\xB7\xE4", "\xF2\xD7",
  /* U+8704 */	"\xCD\x96", "\xCD\x97", "\xCD\x98", "\xF2\xD8",
  /* U+8708 */	"\xF2\xDA", "\xF2\xDD", "\xF2\xDB", "\xCD\x99",
  /* U+870C */	"\xCD\x9A", "\xF2\xDC", "\xCD\x9B", "\xCD\x9C",
  /* U+8710 */	"\xCD\x9D", "\xCD\x9E", "\xD1\xD1", "\xF2\xD1",
  /* U+8714 */	"\xCD\x9F", "\xCD\xC9", "\xCD\xA0", "\xCE\xCF",
  /* U+8718 */	"\xD6\xA9", "\xCE\x40", "\xF2\xE3", "\xCE\x41",
  /* U+871C */	"\xC3\xDB", "\xCE\x42", "\xF2\xE0", "\xCE\x43",
  /* U+8720 */	"\xCE\x44", "\xC0\xAF", "\xF2\xEC", "\xF2\xDE",
  /* U+8724 */	"\xCE\x45", "\xF2\xE1", "\xCE\x46", "\xCE\x47",
  /* U+8728 */	"\xCE\x48", "\xF2\xE8", "\xCE\x49", "\xCE\x4A",
  /* U+872C */	"\xCE\x4B", "\xCE\x4C", "\xF2\xE2", "\xCE\x4D",
  /* U+8730 */	"\xCE\x4E", "\xF2\xE7", "\xCE\x4F", "\xCE\x50",
  /* U+8734 */	"\xF2\xE6", "\xCE\x51", "\xCE\x52", "\xF2\xE9",
  /* U+8738 */	"\xCE\x53", "\xCE\x54", "\xCE\x55", "\xF2\xDF",
  /* U+873C */	"\xCE\x56", "\xCE\x57", "\xF2\xE4", "\xF2\xEA",
  /* U+8740 */	"\xCE\x58", "\xCE\x59", "\xCE\x5A", "\xCE\x5B",
  /* U+8744 */	"\xCE\x5C", "\xCE\x5D", "\xCE\x5E", "\xD3\xAC",
  /* U+8748 */	"\xF2\xE5", "\xB2\xF5", "\xCE\x5F", "\xCE\x60",
  /* U+874C */	"\xF2\xF2", "\xCE\x61", "\xD0\xAB", "\xCE\x62",
  /* U+8750 */	"\xCE\x63", "\xCE\x64", "\xCE\x65", "\xF2\xF5",
  /* U+8754 */	"\xCE\x66", "\xCE\x67", "\xCE\x68", "\xBB\xC8",
  /* U+8758 */	"\xCE\x69", "\xF2\xF9", "\xCE\x6A", "\xCE\x6B",
  /* U+875C */	"\xCE\x6C", "\xCE\x6D", "\xCE\x6E", "\xCE\x6F",
  /* U+8760 */	"\xF2\xF0", "\xCE\x70", "\xCE\x71", "\xF2\xF6",
  /* U+8764 */	"\xF2\xF8", "\xF2\xFA", "\xCE\x72", "\xCE\x73",
  /* U+8768 */	"\xCE\x74", "\xCE\x75", "\xCE\x76", "\xCE\x77",
  /* U+876C */	"\xCE\x78", "\xCE\x79", "\xF2\xF3", "\xCE\x7A",
  /* U+8770 */	"\xF2\xF1", "\xCE\x7B", "\xCE\x7C", "\xCE\x7D",
  /* U+8774 */	"\xBA\xFB", "\xCE\x7E", "\xB5\xFB", "\xCE\x80",
  /* U+8778 */	"\xCE\x81", "\xCE\x82", "\xCE\x83", "\xF2\xEF",
  /* U+877C */	"\xF2\xF7", "\xF2\xED", "\xF2\xEE", "\xCE\x84",
  /* U+8780 */	"\xCE\x85", "\xCE\x86", "\xF2\xEB", "\xF3\xA6",
  /* U+8784 */	"\xCE\x87", "\xF3\xA3", "\xCE\x88", "\xCE\x89",
  /* U+8788 */	"\xF3\xA2", "\xCE\x8A", "\xCE\x8B", "\xF2\xF4",
  /* U+878C */	"\xCE\x8C", "\xC8\xDA", "\xCE\x8D", "\xCE\x8E",
  /* U+8790 */	"\xCE\x8F", "\xCE\x90", "\xCE\x91", "\xF2\xFB",
  /* U+8794 */	"\xCE\x92", "\xCE\x93", "\xCE\x94", "\xF3\xA5",
  /* U+8798 */	"\xCE\x95", "\xCE\x96", "\xCE\x97", "\xCE\x98",
  /* U+879C */	"\xCE\x99", "\xCE\x9A", "\xCE\x9B", "\xC3\xF8",
  /* U+87A0 */	"\xCE\x9C", "\xCE\x9D", "\xCE\x9E", "\xCE\x9F",
  /* U+87A4 */	"\xCE\xA0", "\xCF\x40", "\xCF\x41", "\xCF\x42",
  /* U+87A8 */	"\xF2\xFD", "\xCF\x43", "\xCF\x44", "\xF3\xA7",
  /* U+87AC */	"\xF3\xA9", "\xF3\xA4", "\xCF\x45", "\xF2\xFC",
  /* U+87B0 */	"\xCF\x46", "\xCF\x47", "\xCF\x48", "\xF3\xAB",
  /* U+87B4 */	"\xCF\x49", "\xF3\xAA", "\xCF\x4A", "\xCF\x4B",
  /* U+87B8 */	"\xCF\x4C", "\xCF\x4D", "\xC2\xDD", "\xCF\x4E",
  /* U+87BC */	"\xCF\x4F", "\xF3\xAE", "\xCF\x50", "\xCF\x51",
  /* U+87C0 */	"\xF3\xB0", "\xCF\x52", "\xCF\x53", "\xCF\x54",
  /* U+87C4 */	"\xCF\x55", "\xCF\x56", "\xF3\xA1", "\xCF\x57",
  /* U+87C8 */	"\xCF\x58", "\xCF\x59", "\xF3\xB1", "\xF3\xAC",
  /* U+87CC */	"\xCF\x5A", "\xCF\x5B", "\xCF\x5C", "\xCF\x5D",
  /* U+87D0 */	"\xCF\x5E", "\xF3\xAF", "\xF2\xFE", "\xF3\xAD",
  /* U+87D4 */	"\xCF\x5F", "\xCF\x60", "\xCF\x61", "\xCF\x62",
  /* U+87D8 */	"\xCF\x63", "\xCF\x64", "\xCF\x65", "\xF3\xB2",
  /* U+87DC */	"\xCF\x66", "\xCF\x67", "\xCF\x68", "\xCF\x69",
  /* U+87E0 */	"\xF3\xB4", "\xCF\x6A", "\xCF\x6B", "\xCF\x6C",
  /* U+87E4 */	"\xCF\x6D", "\xF3\xA8", "\xCF\x6E", "\xCF\x6F",
  /* U+87E8 */	"\xCF\x70", "\xCF\x71", "\xF3\xB3", "\xCF\x72",
  /* U+87EC */	"\xCF\x73", "\xCF\x74", "\xF3\xB5", "\xCF\x75",
  /* U+87F0 */	"\xCF\x76", "\xCF\x77", "\xCF\x78", "\xCF\x79",
  /* U+87F4 */	"\xCF\x7A", "\xCF\x7B", "\xCF\x7C", "\xCF\x7D",
  /* U+87F8 */	"\xCF\x7E", "\xD0\xB7", "\xCF\x80", "\xCF\x81",
  /* U+87FC */	"\xCF\x82", "\xCF\x83", "\xF3\xB8", "\xCF\x84",
  /* U+8800 */	"\xCF\x85", "\xCF\x86", "\xCF\x87", "\xD9\xF9",
  /* U+8804 */	"\xCF\x88", "\xCF\x89", "\xCF\x8A", "\xCF\x8B",
  /* U+8808 */	"\xCF\x8C", "\xCF\x8D", "\xF3\xB9", "\xCF\x8E",
  /* U+880C */	"\xCF\x8F", "\xCF\x90", "\xCF\x91", "\xCF\x92",
  /* U+8810 */	"\xCF\x93", "\xCF\x94", "\xCF\x95", "\xF3\xB7",
  /* U+8814 */	"\xCF\x96", "\xC8\xE4", "\xF3\xB6", "\xCF\x97",
  /* U+8818 */	"\xCF\x98", "\xCF\x99", "\xCF\x9A", "\xF3\xBA",
  /* U+881C */	"\xCF\x9B", "\xCF\x9C", "\xCF\x9D", "\xCF\x9E",
  /* U+8820 */	"\xCF\x9F", "\xF3\xBB", "\xB4\xC0", "\xCF\xA0",
  /* U+8824 */	"\xD0\x40", "\xD0\x41", "\xD0\x42", "\xD0\x43",
  /* U+8828 */	"\xD0\x44", "\xD0\x45", "\xD0\x46", "\xD0\x47",
  /* U+882C */	"\xD0\x48", "\xD0\x49", "\xD0\x4A", "\xD0\x4B",
  /* U+8830 */	"\xD0\x4C", "\xD0\x4D", "\xEE\xC3", "\xD0\x4E",
  /* U+8834 */	"\xD0\x4F", "\xD0\x50", "\xD0\x51", "\xD0\x52",
  /* U+8838 */	"\xD0\x53", "\xF3\xBC", "\xD0\x54", "\xD0\x55",
  /* U+883C */	"\xF3\xBD", "\xD0\x56", "\xD0\x57", "\xD0\x58",
  /* U+8840 */	"\xD1\xAA", "\xD0\x59", "\xD0\x5A", "\xD0\x5B",
  /* U+8844 */	"\xF4\xAC", "\xD0\xC6", "\xD0\x5C", "\xD0\x5D",
  /* U+8848 */	"\xD0\x5E", "\xD0\x5F", "\xD0\x60", "\xD0\x61",
  /* U+884C */	"\xD0\xD0", "\xD1\xDC", "\xD0\x62", "\xD0\x63",
  /* U+8850 */	"\xD0\x64", "\xD0\x65", "\xD0\x66", "\xD0\x67",
  /* U+8854 */	"\xCF\xCE", "\xD0\x68", "\xD0\x69", "\xBD\xD6",
  /* U+8858 */	"\xD0\x6A", "\xD1\xC3", "\xD0\x6B", "\xD0\x6C",
  /* U+885C */	"\xD0\x6D", "\xD0\x6E", "\xD0\x6F", "\xD0\x70",
  /* U+8860 */	"\xD0\x71", "\xBA\xE2", "\xE1\xE9", "\xD2\xC2",
  /* U+8864 */	"\xF1\xC2", "\xB2\xB9", "\xD0\x72", "\xD0\x73",
  /* U+8868 */	"\xB1\xED", "\xF1\xC3", "\xD0\x74", "\xC9\xC0",
  /* U+886C */	"\xB3\xC4", "\xD0\x75", "\xD9\xF2", "\xD0\x76",
  /* U+8870 */	"\xCB\xA5", "\xD0\x77", "\xF1\xC4", "\xD0\x78",
  /* U+8874 */	"\xD0\x79", "\xD0\x7A", "\xD0\x7B", "\xD6\xD4",
  /* U+8878 */	"\xD0\x7C", "\xD0\x7D", "\xD0\x7E", "\xD0\x80",
  /* U+887C */	"\xD0\x81", "\xF1\xC5", "\xF4\xC0", "\xF1\xC6",
  /* U+8880 */	"\xD0\x82", "\xD4\xAC", "\xF1\xC7", "\xD0\x83",
  /* U+8884 */	"\xB0\xC0", "\xF4\xC1", "\xD0\x84", "\xD0\x85",
  /* U+8888 */	"\xF4\xC2", "\xD0\x86", "\xD0\x87", "\xB4\xFC",
  /* U+888C */	"\xD0\x88", "\xC5\xDB", "\xD0\x89", "\xD0\x8A",
  /* U+8890 */	"\xD0\x8B", "\xD0\x8C", "\xCC\xBB", "\xD0\x8D",
  /* U+8894 */	"\xD0\x8E", "\xD0\x8F", "\xD0\xE4", "\xD0\x90",
  /* U+8898 */	"\xD0\x91", "\xD0\x92", "\xD0\x93", "\xD0\x94",
  /* U+889C */	"\xCD\xE0", "\xD0\x95", "\xD0\x96", "\xD0\x97",
  /* U+88A0 */	"\xD0\x98", "\xD0\x99", "\xF1\xC8", "\xD0\x9A",
  /* U+88A4 */	"\xD9\xF3", "\xD0\x9B", "\xD0\x9C", "\xD0\x9D",
  /* U+88A8 */	"\xD0\x9E", "\xD0\x9F", "\xD0\xA0", "\xB1\xBB",
  /* U+88AC */	"\xD1\x40", "\xCF\xAE", "\xD1\x41", "\xD1\x42",
  /* U+88B0 */	"\xD1\x43", "\xB8\xA4", "\xD1\x44", "\xD1\x45",
  /* U+88B4 */	"\xD1\x46", "\xD1\x47", "\xD1\x48", "\xF1\xCA",
  /* U+88B8 */	"\xD1\x49", "\xD1\x4A", "\xD1\x4B", "\xD1\x4C",
  /* U+88BC */	"\xF1\xCB", "\xD1\x4D", "\xD1\x4E", "\xD1\x4F",
  /* U+88C0 */	"\xD1\x50", "\xB2\xC3", "\xC1\xD1", "\xD1\x51",
  /* U+88C4 */	"\xD1\x52", "\xD7\xB0", "\xF1\xC9", "\xD1\x53",
  /* U+88C8 */	"\xD1\x54", "\xF1\xCC", "\xD1\x55", "\xD1\x56",
  /* U+88CC */	"\xD1\x57", "\xD1\x58", "\xF1\xCE", "\xD1\x59",
  /* U+88D0 */	"\xD1\x5A", "\xD1\x5B", "\xD9\xF6", "\xD1\x5C",
  /* U+88D4 */	"\xD2\xE1", "\xD4\xA3", "\xD1\x5D", "\xD1\x5E",
  /* U+88D8 */	"\xF4\xC3", "\xC8\xB9", "\xD1\x5F", "\xD1\x60",
  /* U+88DC */	"\xD1\x61", "\xD1\x62", "\xD1\x63", "\xF4\xC4",
  /* U+88E0 */	"\xD1\x64", "\xD1\x65", "\xF1\xCD", "\xF1\xCF",
  /* U+88E4 */	"\xBF\xE3", "\xF1\xD0", "\xD1\x66", "\xD1\x67",
  /* U+88E8 */	"\xF1\xD4", "\xD1\x68", "\xD1\x69", "\xD1\x6A",
  /* U+88EC */	"\xD1\x6B", "\xD1\x6C", "\xD1\x6D", "\xD1\x6E",
  /* U+88F0 */	"\xF1\xD6", "\xF1\xD1", "\xD1\x6F", "\xC9\xD1",
  /* U+88F4 */	"\xC5\xE1", "\xD1\x70", "\xD1\x71", "\xD1\x72",
  /* U+88F8 */	"\xC2\xE3", "\xB9\xFC", "\xD1\x73", "\xD1\x74",
  /* U+88FC */	"\xF1\xD3", "\xD1\x75", "\xF1\xD5", "\xD1\x76",
  /* U+8900 */	"\xD1\x77", "\xD1\x78", "\xB9\xD3", "\xD1\x79",
  /* U+8904 */	"\xD1\x7A", "\xD1\x7B", "\xD1\x7C", "\xD1\x7D",
  /* U+8908 */	"\xD1\x7E", "\xD1\x80", "\xF1\xDB", "\xD1\x81",
  /* U+890C */	"\xD1\x82", "\xD1\x83", "\xD1\x84", "\xD1\x85",
  /* U+8910 */	"\xBA\xD6", "\xD1\x86", "\xB0\xFD", "\xF1\xD9",
  /* U+8914 */	"\xD1\x87", "\xD1\x88", "\xD1\x89", "\xD1\x8A",
  /* U+8918 */	"\xD1\x8B", "\xF1\xD8", "\xF1\xD2", "\xF1\xDA",
  /* U+891C */	"\xD1\x8C", "\xD1\x8D", "\xD1\x8E", "\xD1\x8F",
  /* U+8920 */	"\xD1\x90", "\xF1\xD7", "\xD1\x91", "\xD1\x92",
  /* U+8924 */	"\xD1\x93", "\xC8\xEC", "\xD1\x94", "\xD1\x95",
  /* U+8928 */	"\xD1\x96", "\xD1\x97", "\xCD\xCA", "\xF1\xDD",
  /* U+892C */	"\xD1\x98", "\xD1\x99", "\xD1\x9A", "\xD1\x9B",
  /* U+8930 */	"\xE5\xBD", "\xD1\x9C", "\xD1\x9D", "\xD1\x9E",
  /* U+8934 */	"\xF1\xDC", "\xD1\x9F", "\xF1\xDE", "\xD1\xA0",
  /* U+8938 */	"\xD2\x40", "\xD2\x41", "\xD2\x42", "\xD2\x43",
  /* U+893C */	"\xD2\x44", "\xD2\x45", "\xD2\x46", "\xD2\x47",
  /* U+8940 */	"\xD2\x48", "\xF1\xDF", "\xD2\x49", "\xD2\x4A",
  /* U+8944 */	"\xCF\xE5", "\xD2\x4B", "\xD2\x4C", "\xD2\x4D",
  /* U+8948 */	"\xD2\x4E", "\xD2\x4F", "\xD2\x50", "\xD2\x51",
  /* U+894C */	"\xD2\x52", "\xD2\x53", "\xD2\x54", "\xD2\x55",
  /* U+8950 */	"\xD2\x56", "\xD2\x57", "\xD2\x58", "\xD2\x59",
  /* U+8954 */	"\xD2\x5A", "\xD2\x5B", "\xD2\x5C", "\xD2\x5D",
  /* U+8958 */	"\xD2\x5E", "\xD2\x5F", "\xD2\x60", "\xD2\x61",
  /* U+895C */	"\xD2\x62", "\xD2\x63", "\xF4\xC5", "\xBD\xF3",
  /* U+8960 */	"\xD2\x64", "\xD2\x65", "\xD2\x66", "\xD2\x67",
  /* U+8964 */	"\xD2\x68", "\xD2\x69", "\xF1\xE0", "\xD2\x6A",
  /* U+8968 */	"\xD2\x6B", "\xD2\x6C", "\xD2\x6D", "\xD2\x6E",
  /* U+896C */	"\xD2\x6F", "\xD2\x70", "\xD2\x71", "\xD2\x72",
  /* U+8970 */	"\xD2\x73", "\xD2\x74", "\xD2\x75", "\xD2\x76",
  /* U+8974 */	"\xD2\x77", "\xD2\x78", "\xD2\x79", "\xD2\x7A",
  /* U+8978 */	"\xD2\x7B", "\xD2\x7C", "\xD2\x7D", "\xF1\xE1",
  /* U+897C */	"\xD2\x7E", "\xD2\x80", "\xD2\x81", "\xCE\xF7",
  /* U+8980 */	"\xD2\x82", "\xD2\xAA", "\xD2\x83", "\xF1\xFB",
  /* U+8984 */	"\xD2\x84", "\xD2\x85", "\xB8\xB2", "\xD2\x86",
  /* U+8988 */	"\xD2\x87", "\xD2\x88", "\xD2\x89", "\xD2\x8A",
  /* U+898C */	"\xD2\x8B", "\xD2\x8C", "\xD2\x8D", "\xD2\x8E",
  /* U+8990 */	"\xD2\x8F", "\xD2\x90", "\xD2\x91", "\xD2\x92",
  /* U+8994 */	"\xD2\x93", "\xD2\x94", "\xD2\x95", "\xD2\x96",
  /* U+8998 */	"\xD2\x97", "\xD2\x98", "\xD2\x99", "\xD2\x9A",
  /* U+899C */	"\xD2\x9B", "\xD2\x9C", "\xD2\x9D", "\xD2\x9E",
  /* U+89A0 */	"\xD2\x9F", "\xD2\xA0", "\xD3\x40", "\xD3\x41",
  /* U+89A4 */	"\xD3\x42", "\xD3\x43", "\xD3\x44", "\xD3\x45",
  /* U+89A8 */	"\xD3\x46", "\xD3\x47", "\xD3\x48", "\xD3\x49",
  /* U+89AC */	"\xD3\x4A", "\xD3\x4B", "\xD3\x4C", "\xD3\x4D",
  /* U+89B0 */	"\xD3\x4E", "\xD3\x4F", "\xD3\x50", "\xD3\x51",
  /* U+89B4 */	"\xD3\x52", "\xD3\x53", "\xD3\x54", "\xD3\x55",
  /* U+89B8 */	"\xD3\x56", "\xD3\x57", "\xD3\x58", "\xD3\x59",
  /* U+89BC */	"\xD3\x5A", "\xD3\x5B", "\xD3\x5C", "\xD3\x5D",
  /* U+89C0 */	"\xD3\x5E", "\xBC\xFB", "\xB9\xDB", "\xD3\x5F",
  /* U+89C4 */	"\xB9\xE6", "\xC3\xD9", "\xCA\xD3", "\xEA\xE8",
  /* U+89C8 */	"\xC0\xC0", "\xBE\xF5", "\xEA\xE9", "\xEA\xEA",
  /* U+89CC */	"\xEA\xEB", "\xD3\x60", "\xEA\xEC", "\xEA\xED",
  /* U+89D0 */	"\xEA\xEE", "\xEA\xEF", "\xBD\xC7", "\xD3\x61",
  /* U+89D4 */	"\xD3\x62", "\xD3\x63", "\xF5\xFB", "\xD3\x64",
  /* U+89D8 */	"\xD3\x65", "\xD3\x66", "\xF5\xFD", "\xD3\x67",
  /* U+89DC */	"\xF5\xFE", "\xD3\x68", "\xF5\xFC", "\xD3\x69",
  /* U+89E0 */	"\xD3\x6A", "\xD3\x6B", "\xD3\x6C", "\xBD\xE2",
  /* U+89E4 */	"\xD3\x6D", "\xF6\xA1", "\xB4\xA5", "\xD3\x6E",
  /* U+89E8 */	"\xD3\x6F", "\xD3\x70", "\xD3\x71", "\xF6\xA2",
  /* U+89EC */	"\xD3\x72", "\xD3\x73", "\xD3\x74", "\xF6\xA3",
  /* U+89F0 */	"\xD3\x75", "\xD3\x76", "\xD3\x77", "\xEC\xB2",
  /* U+89F4 */	"\xD3\x78", "\xD3\x79", "\xD3\x7A", "\xD3\x7B",
  /* U+89F8 */	"\xD3\x7C", "\xD3\x7D", "\xD3\x7E", "\xD3\x80",
  /* U+89FC */	"\xD3\x81", "\xD3\x82", "\xD3\x83", "\xD3\x84",
  /* U+8A00 */	"\xD1\xD4", "\xD3\x85", "\xD3\x86", "\xD3\x87",
  /* U+8A04 */	"\xD3\x88", "\xD3\x89", "\xD3\x8A", "\xD9\xEA",
  /* U+8A08 */	"\xD3\x8B", "\xD3\x8C", "\xD3\x8D", "\xD3\x8E",
  /* U+8A0C */	"\xD3\x8F", "\xD3\x90", "\xD3\x91", "\xD3\x92",
  /* U+8A10 */	"\xD3\x93", "\xD3\x94", "\xD3\x95", "\xD3\x96",
  /* U+8A14 */	"\xD3\x97", "\xD3\x98", "\xD3\x99", "\xD3\x9A",
  /* U+8A18 */	"\xD3\x9B", "\xD3\x9C", "\xD3\x9D", "\xD3\x9E",
  /* U+8A1C */	"\xD3\x9F", "\xD3\xA0", "\xD4\x40", "\xD4\x41",
  /* U+8A20 */	"\xD4\x42", "\xD4\x43", "\xD4\x44", "\xD4\x45",
  /* U+8A24 */	"\xD4\x46", "\xD4\x47", "\xD4\x48", "\xD4\x49",
  /* U+8A28 */	"\xD4\x4A", "\xD4\x4B", "\xD4\x4C", "\xD4\x4D",
  /* U+8A2C */	"\xD4\x4E", "\xD4\x4F", "\xD4\x50", "\xD4\x51",
  /* U+8A30 */	"\xD4\x52", "\xD4\x53", "\xD4\x54", "\xD4\x55",
  /* U+8A34 */	"\xD4\x56", "\xD4\x57", "\xD4\x58", "\xD4\x59",
  /* U+8A38 */	"\xD4\x5A", "\xD4\x5B", "\xD4\x5C", "\xD4\x5D",
  /* U+8A3C */	"\xD4\x5E", "\xD4\x5F", "\xF6\xA4", "\xD4\x60",
  /* U+8A40 */	"\xD4\x61", "\xD4\x62", "\xD4\x63", "\xD4\x64",
  /* U+8A44 */	"\xD4\x65", "\xD4\x66", "\xD4\x67", "\xD4\x68",
  /* U+8A48 */	"\xEE\xBA", "\xD4\x69", "\xD4\x6A", "\xD4\x6B",
  /* U+8A4C */	"\xD4\x6C", "\xD4\x6D", "\xD4\x6E", "\xD4\x6F",
  /* U+8A50 */	"\xD4\x70", "\xD4\x71", "\xD4\x72", "\xD4\x73",
  /* U+8A54 */	"\xD4\x74", "\xD4\x75", "\xD4\x76", "\xD4\x77",
  /* U+8A58 */	"\xD4\x78", "\xD4\x79", "\xD4\x7A", "\xD4\x7B",
  /* U+8A5C */	"\xD4\x7C", "\xD4\x7D", "\xD4\x7E", "\xD4\x80",
  /* U+8A60 */	"\xD4\x81", "\xD4\x82", "\xD4\x83", "\xD4\x84",
  /* U+8A64 */	"\xD4\x85", "\xD4\x86", "\xD4\x87", "\xD4\x88",
  /* U+8A68 */	"\xD4\x89", "\xD4\x8A", "\xD4\x8B", "\xD4\x8C",
  /* U+8A6C */	"\xD4\x8D", "\xD4\x8E", "\xD4\x8F", "\xD4\x90",
  /* U+8A70 */	"\xD4\x91", "\xD4\x92", "\xD4\x93", "\xD4\x94",
  /* U+8A74 */	"\xD4\x95", "\xD4\x96", "\xD4\x97", "\xD4\x98",
  /* U+8A78 */	"\xD4\x99", "\xD5\xB2", "\xD4\x9A", "\xD4\x9B",
  /* U+8A7C */	"\xD4\x9C", "\xD4\x9D", "\xD4\x9E", "\xD4\x9F",
  /* U+8A80 */	"\xD4\xA0", "\xD5\x40", "\xD5\x41", "\xD5\x42",
  /* U+8A84 */	"\xD5\x43", "\xD5\x44", "\xD5\x45", "\xD5\x46",
  /* U+8A88 */	"\xD5\x47", "\xD3\xFE", "\xCC\xDC", "\xD5\x48",
  /* U+8A8C */	"\xD5\x49", "\xD5\x4A", "\xD5\x4B", "\xD5\x4C",
  /* U+8A90 */	"\xD5\x4D", "\xD5\x4E", "\xD5\x4F", "\xCA\xC4",
  /* U+8A94 */	"\xD5\x50", "\xD5\x51", "\xD5\x52", "\xD5\x53",
  /* U+8A98 */	"\xD5\x54", "\xD5\x55", "\xD5\x56", "\xD5\x57",
  /* U+8A9C */	"\xD5\x58", "\xD5\x59", "\xD5\x5A", "\xD5\x5B",
  /* U+8AA0 */	"\xD5\x5C", "\xD5\x5D", "\xD5\x5E", "\xD5\x5F",
  /* U+8AA4 */	"\xD5\x60", "\xD5\x61", "\xD5\x62", "\xD5\x63",
  /* U+8AA8 */	"\xD5\x64", "\xD5\x65", "\xD5\x66", "\xD5\x67",
  /* U+8AAC */	"\xD5\x68", "\xD5\x69", "\xD5\x6A", "\xD5\x6B",
  /* U+8AB0 */	"\xD5\x6C", "\xD5\x6D", "\xD5\x6E", "\xD5\x6F",
  /* U+8AB4 */	"\xD5\x70", "\xD5\x71", "\xD5\x72", "\xD5\x73",
  /* U+8AB8 */	"\xD5\x74", "\xD5\x75", "\xD5\x76", "\xD5\x77",
  /* U+8ABC */	"\xD5\x78", "\xD5\x79", "\xD5\x7A", "\xD5\x7B",
  /* U+8AC0 */	"\xD5\x7C", "\xD5\x7D", "\xD5\x7E", "\xD5\x80",
  /* U+8AC4 */	"\xD5\x81", "\xD5\x82", "\xD5\x83", "\xD5\x84",
  /* U+8AC8 */	"\xD5\x85", "\xD5\x86", "\xD5\x87", "\xD5\x88",
  /* U+8ACC */	"\xD5\x89", "\xD5\x8A", "\xD5\x8B", "\xD5\x8C",
  /* U+8AD0 */	"\xD5\x8D", "\xD5\x8E", "\xD5\x8F", "\xD5\x90",
  /* U+8AD4 */	"\xD5\x91", "\xD5\x92", "\xD5\x93", "\xD5\x94",
  /* U+8AD8 */	"\xD5\x95", "\xD5\x96", "\xD5\x97", "\xD5\x98",
  /* U+8ADC */	"\xD5\x99", "\xD5\x9A", "\xD5\x9B", "\xD5\x9C",
  /* U+8AE0 */	"\xD5\x9D", "\xD5\x9E", "\xD5\x9F", "\xD5\xA0",
  /* U+8AE4 */	"\xD6\x40", "\xD6\x41", "\xD6\x42", "\xD6\x43",
  /* U+8AE8 */	"\xD6\x44", "\xD6\x45", "\xD6\x46", "\xD6\x47",
  /* U+8AEC */	"\xD6\x48", "\xD6\x49", "\xD6\x4A", "\xD6\x4B",
  /* U+8AF0 */	"\xD6\x4C", "\xD6\x4D", "\xD6\x4E", "\xD6\x4F",
  /* U+8AF4 */	"\xD6\x50", "\xD6\x51", "\xD6\x52", "\xD6\x53",
  /* U+8AF8 */	"\xD6\x54", "\xD6\x55", "\xD6\x56", "\xD6\x57",
  /* U+8AFC */	"\xD6\x58", "\xD6\x59", "\xD6\x5A", "\xD6\x5B",
  /* U+8B00 */	"\xD6\x5C", "\xD6\x5D", "\xD6\x5E", "\xD6\x5F",
  /* U+8B04 */	"\xD6\x60", "\xD6\x61", "\xD6\x62", "\xE5\xC0",
  /* U+8B08 */	"\xD6\x63", "\xD6\x64", "\xD6\x65", "\xD6\x66",
  /* U+8B0C */	"\xD6\x67", "\xD6\x68", "\xD6\x69", "\xD6\x6A",
  /* U+8B10 */	"\xD6\x6B", "\xD6\x6C", "\xD6\x6D", "\xD6\x6E",
  /* U+8B14 */	"\xD6\x6F", "\xD6\x70", "\xD6\x71", "\xD6\x72",
  /* U+8B18 */	"\xD6\x73", "\xD6\x74", "\xD6\x75", "\xD6\x76",
  /* U+8B1C */	"\xD6\x77", "\xD6\x78", "\xD6\x79", "\xD6\x7A",
  /* U+8B20 */	"\xD6\x7B", "\xD6\x7C", "\xD6\x7D", "\xD6\x7E",
  /* U+8B24 */	"\xD6\x80", "\xD6\x81", "\xF6\xA5", "\xD6\x82",
  /* U+8B28 */	"\xD6\x83", "\xD6\x84", "\xD6\x85", "\xD6\x86",
  /* U+8B2C */	"\xD6\x87", "\xD6\x88", "\xD6\x89", "\xD6\x8A",
  /* U+8B30 */	"\xD6\x8B", "\xD6\x8C", "\xD6\x8D", "\xD6\x8E",
  /* U+8B34 */	"\xD6\x8F", "\xD6\x90", "\xD6\x91", "\xD6\x92",
  /* U+8B38 */	"\xD6\x93", "\xD6\x94", "\xD6\x95", "\xD6\x96",
  /* U+8B3C */	"\xD6\x97", "\xD6\x98", "\xD6\x99", "\xD6\x9A",
  /* U+8B40 */	"\xD6\x9B", "\xD6\x9C", "\xD6\x9D", "\xD6\x9E",
  /* U+8B44 */	"\xD6\x9F", "\xD6\xA0", "\xD7\x40", "\xD7\x41",
  /* U+8B48 */	"\xD7\x42", "\xD7\x43", "\xD7\x44", "\xD7\x45",
  /* U+8B4C */	"\xD7\x46", "\xD7\x47", "\xD7\x48", "\xD7\x49",
  /* U+8B50 */	"\xD7\x4A", "\xD7\x4B", "\xD7\x4C", "\xD7\x4D",
  /* U+8B54 */	"\xD7\x4E", "\xD7\x4F", "\xD7\x50", "\xD7\x51",
  /* U+8B58 */	"\xD7\x52", "\xD7\x53", "\xD7\x54", "\xD7\x55",
  /* U+8B5C */	"\xD7\x56", "\xD7\x57", "\xD7\x58", "\xD7\x59",
  /* U+8B60 */	"\xD7\x5A", "\xD7\x5B", "\xD7\x5C", "\xD7\x5D",
  /* U+8B64 */	"\xD7\x5E", "\xD7\x5F", "\xBE\xAF", "\xD7\x60",
  /* U+8B68 */	"\xD7\x61", "\xD7\x62", "\xD7\x63", "\xD7\x64",
  /* U+8B6C */	"\xC6\xA9", "\xD7\x65", "\xD7\x66", "\xD7\x67",
  /* U+8B70 */	"\xD7\x68", "\xD7\x69", "\xD7\x6A", "\xD7\x6B",
  /* U+8B74 */	"\xD7\x6C", "\xD7\x6D", "\xD7\x6E", "\xD7\x6F",
  /* U+8B78 */	"\xD7\x70", "\xD7\x71", "\xD7\x72", "\xD7\x73",
  /* U+8B7C */	"\xD7\x74", "\xD7\x75", "\xD7\x76", "\xD7\x77",
  /* U+8B80 */	"\xD7\x78", "\xD7\x79", "\xD7\x7A", "\xD7\x7B",
  /* U+8B84 */	"\xD7\x7C", "\xD7\x7D", "\xD7\x7E", "\xD7\x80",
  /* U+8B88 */	"\xD7\x81", "\xD7\x82", "\xD7\x83", "\xD7\x84",
  /* U+8B8C */	"\xD7\x85", "\xD7\x86", "\xD7\x87", "\xD7\x88",
  /* U+8B90 */	"\xD7\x89", "\xD7\x8A", "\xD7\x8B", "\xD7\x8C",
  /* U+8B94 */	"\xD7\x8D", "\xD7\x8E", "\xD7\x8F", "\xD7\x90",
  /* U+8B98 */	"\xD7\x91", "\xD7\x92", "\xD7\x93", "\xD7\x94",
  /* U+8B9C */	"\xD7\x95", "\xD7\x96", "\xD7\x97", "\xD7\x98",
  /* U+8BA0 */	"\xDA\xA5", "\xBC\xC6", "\xB6\xA9", "\xB8\xBC",
  /* U+8BA4 */	"\xC8\xCF", "\xBC\xA5", "\xDA\xA6", "\xDA\xA7",
  /* U+8BA8 */	"\xCC\xD6", "\xC8\xC3", "\xDA\xA8", "\xC6\xFD",
  /* U+8BAC */	"\xD7\x99", "\xD1\xB5", "\xD2\xE9", "\xD1\xB6",
  /* U+8BB0 */	"\xBC\xC7", "\xD7\x9A", "\xBD\xB2", "\xBB\xE4",
  /* U+8BB4 */	"\xDA\xA9", "\xDA\xAA", "\xD1\xC8", "\xDA\xAB",
  /* U+8BB8 */	"\xD0\xED", "\xB6\xEF", "\xC2\xDB", "\xD7\x9B",
  /* U+8BBC */	"\xCB\xCF", "\xB7\xED", "\xC9\xE8", "\xB7\xC3",
  /* U+8BC0 */	"\xBE\xF7", "\xD6\xA4", "\xDA\xAC", "\xDA\xAD",
  /* U+8BC4 */	"\xC6\xC0", "\xD7\xE7", "\xCA\xB6", "\xD7\x9C",
  /* U+8BC8 */	"\xD5\xA9", "\xCB\xDF", "\xD5\xEF", "\xDA\xAE",
  /* U+8BCC */	"\xD6\xDF", "\xB4\xCA", "\xDA\xB0", "\xDA\xAF",
  /* U+8BD0 */	"\xD7\x9D", "\xD2\xEB", "\xDA\xB1", "\xDA\xB2",
  /* U+8BD4 */	"\xDA\xB3", "\xCA\xD4", "\xDA\xB4", "\xCA\xAB",
  /* U+8BD8 */	"\xDA\xB5", "\xDA\xB6", "\xB3\xCF", "\xD6\xEF",
  /* U+8BDC */	"\xDA\xB7", "\xBB\xB0", "\xB5\xAE", "\xDA\xB8",
  /* U+8BE0 */	"\xDA\xB9", "\xB9\xEE", "\xD1\xAF", "\xD2\xE8",
  /* U+8BE4 */	"\xDA\xBA", "\xB8\xC3", "\xCF\xEA", "\xB2\xEF",
  /* U+8BE8 */	"\xDA\xBB", "\xDA\xBC", "\xD7\x9E", "\xBD\xEB",
  /* U+8BEC */	"\xCE\xDC", "\xD3\xEF", "\xDA\xBD", "\xCE\xF3",
  /* U+8BF0 */	"\xDA\xBE", "\xD3\xD5", "\xBB\xE5", "\xDA\xBF",
  /* U+8BF4 */	"\xCB\xB5", "\xCB\xD0", "\xDA\xC0", "\xC7\xEB",
  /* U+8BF8 */	"\xD6\xEE", "\xDA\xC1", "\xC5\xB5", "\xB6\xC1",
  /* U+8BFC */	"\xDA\xC2", "\xB7\xCC", "\xBF\xCE", "\xDA\xC3",
  /* U+8C00 */	"\xDA\xC4", "\xCB\xAD", "\xDA\xC5", "\xB5\xF7",
  /* U+8C04 */	"\xDA\xC6", "\xC1\xC2", "\xD7\xBB", "\xDA\xC7",
  /* U+8C08 */	"\xCC\xB8", "\xD7\x9F", "\xD2\xEA", "\xC4\xB1",
  /* U+8C0C */	"\xDA\xC8", "\xB5\xFD", "\xBB\xD1", "\xDA\xC9",
  /* U+8C10 */	"\xD0\xB3", "\xDA\xCA", "\xDA\xCB", "\xCE\xBD",
  /* U+8C14 */	"\xDA\xCC", "\xDA\xCD", "\xDA\xCE", "\xB2\xF7",
  /* U+8C18 */	"\xDA\xD1", "\xDA\xCF", "\xD1\xE8", "\xDA\xD0",
  /* U+8C1C */	"\xC3\xD5", "\xDA\xD2", "\xD7\xA0", "\xDA\xD3",
  /* U+8C20 */	"\xDA\xD4", "\xDA\xD5", "\xD0\xBB", "\xD2\xA5",
  /* U+8C24 */	"\xB0\xF9", "\xDA\xD6", "\xC7\xAB", "\xDA\xD7",
  /* U+8C28 */	"\xBD\xF7", "\xC3\xA1", "\xDA\xD8", "\xDA\xD9",
  /* U+8C2C */	"\xC3\xFD", "\xCC\xB7", "\xDA\xDA", "\xDA\xDB",
  /* U+8C30 */	"\xC0\xBE", "\xC6\xD7", "\xDA\xDC", "\xDA\xDD",
  /* U+8C34 */	"\xC7\xB4", "\xDA\xDE", "\xDA\xDF", "\xB9\xC8",
  /* U+8C38 */	"\xD8\x40", "\xD8\x41", "\xD8\x42", "\xD8\x43",
  /* U+8C3C */	"\xD8\x44", "\xD8\x45", "\xD8\x46", "\xD8\x47",
  /* U+8C40 */	"\xD8\x48", "\xBB\xED", "\xD8\x49", "\xD8\x4A",
  /* U+8C44 */	"\xD8\x4B", "\xD8\x4C", "\xB6\xB9", "\xF4\xF8",
  /* U+8C48 */	"\xD8\x4D", "\xF4\xF9", "\xD8\x4E", "\xD8\x4F",
  /* U+8C4C */	"\xCD\xE3", "\xD8\x50", "\xD8\x51", "\xD8\x52",
  /* U+8C50 */	"\xD8\x53", "\xD8\x54", "\xD8\x55", "\xD8\x56",
  /* U+8C54 */	"\xD8\x57", "\xF5\xB9", "\xD8\x58", "\xD8\x59",
  /* U+8C58 */	"\xD8\x5A", "\xD8\x5B", "\xEB\xE0", "\xD8\x5C",
  /* U+8C5C */	"\xD8\x5D", "\xD8\x5E", "\xD8\x5F", "\xD8\x60",
  /* U+8C60 */	"\xD8\x61", "\xCF\xF3", "\xBB\xBF", "\xD8\x62",
  /* U+8C64 */	"\xD8\x63", "\xD8\x64", "\xD8\x65", "\xD8\x66",
  /* U+8C68 */	"\xD8\x67", "\xD8\x68", "\xBA\xC0", "\xD4\xA5",
  /* U+8C6C */	"\xD8\x69", "\xD8\x6A", "\xD8\x6B", "\xD8\x6C",
  /* U+8C70 */	"\xD8\x6D", "\xD8\x6E", "\xD8\x6F", "\xE1\xD9",
  /* U+8C74 */	"\xD8\x70", "\xD8\x71", "\xD8\x72", "\xD8\x73",
  /* U+8C78 */	"\xF5\xF4", "\xB1\xAA", "\xB2\xF2", "\xD8\x74",
  /* U+8C7C */	"\xD8\x75", "\xD8\x76", "\xD8\x77", "\xD8\x78",
  /* U+8C80 */	"\xD8\x79", "\xD8\x7A", "\xF5\xF5", "\xD8\x7B",
  /* U+8C84 */	"\xD8\x7C", "\xF5\xF7", "\xD8\x7D", "\xD8\x7E",
  /* U+8C88 */	"\xD8\x80", "\xBA\xD1", "\xF5\xF6", "\xD8\x81",
  /* U+8C8C */	"\xC3\xB2", "\xD8\x82", "\xD8\x83", "\xD8\x84",
  /* U+8C90 */	"\xD8\x85", "\xD8\x86", "\xD8\x87", "\xD8\x88",
  /* U+8C94 */	"\xF5\xF9", "\xD8\x89", "\xD8\x8A", "\xD8\x8B",
  /* U+8C98 */	"\xF5\xF8", "\xD8\x8C", "\xD8\x8D", "\xD8\x8E",
  /* U+8C9C */	"\xD8\x8F", "\xD8\x90", "\xD8\x91", "\xD8\x92",
  /* U+8CA0 */	"\xD8\x93", "\xD8\x94", "\xD8\x95", "\xD8\x96",
  /* U+8CA4 */	"\xD8\x97", "\xD8\x98", "\xD8\x99", "\xD8\x9A",
  /* U+8CA8 */	"\xD8\x9B", "\xD8\x9C", "\xD8\x9D", "\xD8\x9E",
  /* U+8CAC */	"\xD8\x9F", "\xD8\xA0", "\xD9\x40", "\xD9\x41",
  /* U+8CB0 */	"\xD9\x42", "\xD9\x43", "\xD9\x44", "\xD9\x45",
  /* U+8CB4 */	"\xD9\x46", "\xD9\x47", "\xD9\x48", "\xD9\x49",
  /* U+8CB8 */	"\xD9\x4A", "\xD9\x4B", "\xD9\x4C", "\xD9\x4D",
  /* U+8CBC */	"\xD9\x4E", "\xD9\x4F", "\xD9\x50", "\xD9\x51",
  /* U+8CC0 */	"\xD9\x52", "\xD9\x53", "\xD9\x54", "\xD9\x55",
  /* U+8CC4 */	"\xD9\x56", "\xD9\x57", "\xD9\x58", "\xD9\x59",
  /* U+8CC8 */	"\xD9\x5A", "\xD9\x5B", "\xD9\x5C", "\xD9\x5D",
  /* U+8CCC */	"\xD9\x5E", "\xD9\x5F", "\xD9\x60", "\xD9\x61",
  /* U+8CD0 */	"\xD9\x62", "\xD9\x63", "\xD9\x64", "\xD9\x65",
  /* U+8CD4 */	"\xD9\x66", "\xD9\x67", "\xD9\x68", "\xD9\x69",
  /* U+8CD8 */	"\xD9\x6A", "\xD9\x6B", "\xD9\x6C", "\xD9\x6D",
  /* U+8CDC */	"\xD9\x6E", "\xD9\x6F", "\xD9\x70", "\xD9\x71",
  /* U+8CE0 */	"\xD9\x72", "\xD9\x73", "\xD9\x74", "\xD9\x75",
  /* U+8CE4 */	"\xD9\x76", "\xD9\x77", "\xD9\x78", "\xD9\x79",
  /* U+8CE8 */	"\xD9\x7A", "\xD9\x7B", "\xD9\x7C", "\xD9\x7D",
  /* U+8CEC */	"\xD9\x7E", "\xD9\x80", "\xD9\x81", "\xD9\x82",
  /* U+8CF0 */	"\xD9\x83", "\xD9\x84", "\xD9\x85", "\xD9\x86",
  /* U+8CF4 */	"\xD9\x87", "\xD9\x88", "\xD9\x89", "\xD9\x8A",
  /* U+8CF8 */	"\xD9\x8B", "\xD9\x8C", "\xD9\x8D", "\xD9\x8E",
  /* U+8CFC */	"\xD9\x8F", "\xD9\x90", "\xD9\x91", "\xD9\x92",
  /* U+8D00 */	"\xD9\x93", "\xD9\x94", "\xD9\x95", "\xD9\x96",
  /* U+8D04 */	"\xD9\x97", "\xD9\x98", "\xD9\x99", "\xD9\x9A",
  /* U+8D08 */	"\xD9\x9B", "\xD9\x9C", "\xD9\x9D", "\xD9\x9E",
  /* U+8D0C */	"\xD9\x9F", "\xD9\xA0", "\xDA\x40", "\xDA\x41",
  /* U+8D10 */	"\xDA\x42", "\xDA\x43", "\xDA\x44", "\xDA\x45",
  /* U+8D14 */	"\xDA\x46", "\xDA\x47", "\xDA\x48", "\xDA\x49",
  /* U+8D18 */	"\xDA\x4A", "\xDA\x4B", "\xDA\x4C", "\xDA\x4D",
  /* U+8D1C */	"\xDA\x4E", "\xB1\xB4", "\xD5\xEA", "\xB8\xBA",
  /* U+8D20 */	"\xDA\x4F", "\xB9\xB1", "\xB2\xC6", "\xD4\xF0",
  /* U+8D24 */	"\xCF\xCD", "\xB0\xDC", "\xD5\xCB", "\xBB\xF5",
  /* U+8D28 */	"\xD6\xCA", "\xB7\xB7", "\xCC\xB0", "\xC6\xB6",
  /* U+8D2C */	"\xB1\xE1", "\xB9\xBA", "\xD6\xFC", "\xB9\xE1",
  /* U+8D30 */	"\xB7\xA1", "\xBC\xFA", "\xEA\xDA", "\xEA\xDB",
  /* U+8D34 */	"\xCC\xF9", "\xB9\xF3", "\xEA\xDC", "\xB4\xFB",
  /* U+8D38 */	"\xC3\xB3", "\xB7\xD1", "\xBA\xD8", "\xEA\xDD",
  /* U+8D3C */	"\xD4\xF4", "\xEA\xDE", "\xBC\xD6", "\xBB\xDF",
  /* U+8D40 */	"\xEA\xDF", "\xC1\xDE", "\xC2\xB8", "\xD4\xDF",
  /* U+8D44 */	"\xD7\xCA", "\xEA\xE0", "\xEA\xE1", "\xEA\xE4",
  /* U+8D48 */	"\xEA\xE2", "\xEA\xE3", "\xC9\xDE", "\xB8\xB3",
  /* U+8D4C */	"\xB6\xC4", "\xEA\xE5", "\xCA\xEA", "\xC9\xCD",
  /* U+8D50 */	"\xB4\xCD", "\xDA\x50", "\xDA\x51", "\xE2\xD9",
  /* U+8D54 */	"\xC5\xE2", "\xEA\xE6", "\xC0\xB5", "\xDA\x52",
  /* U+8D58 */	"\xD7\xB8", "\xEA\xE7", "\xD7\xAC", "\xC8\xFC",
  /* U+8D5C */	"\xD8\xD3", "\xD8\xCD", "\xD4\xDE", "\xDA\x53",
  /* U+8D60 */	"\xD4\xF9", "\xC9\xC4", "\xD3\xAE", "\xB8\xD3",
  /* U+8D64 */	"\xB3\xE0", "\xDA\x54", "\xC9\xE2", "\xF4\xF6",
  /* U+8D68 */	"\xDA\x55", "\xDA\x56", "\xDA\x57", "\xBA\xD5",
  /* U+8D6C */	"\xDA\x58", "\xF4\xF7", "\xDA\x59", "\xDA\x5A",
  /* U+8D70 */	"\xD7\xDF", "\xDA\x5B", "\xDA\x5C", "\xF4\xF1",
  /* U+8D74 */	"\xB8\xB0", "\xD5\xD4", "\xB8\xCF", "\xC6\xF0",
  /* U+8D78 */	"\xDA\x5D", "\xDA\x5E", "\xDA\x5F", "\xDA\x60",
  /* U+8D7C */	"\xDA\x61", "\xDA\x62", "\xDA\x63", "\xDA\x64",
  /* U+8D80 */	"\xDA\x65", "\xB3\xC3", "\xDA\x66", "\xDA\x67",
  /* U+8D84 */	"\xF4\xF2", "\xB3\xAC", "\xDA\x68", "\xDA\x69",
  /* U+8D88 */	"\xDA\x6A", "\xDA\x6B", "\xD4\xBD", "\xC7\xF7",
  /* U+8D8C */	"\xDA\x6C", "\xDA\x6D", "\xDA\x6E", "\xDA\x6F",
  /* U+8D90 */	"\xDA\x70", "\xF4\xF4", "\xDA\x71", "\xDA\x72",
  /* U+8D94 */	"\xF4\xF3", "\xDA\x73", "\xDA\x74", "\xDA\x75",
  /* U+8D98 */	"\xDA\x76", "\xDA\x77", "\xDA\x78", "\xDA\x79",
  /* U+8D9C */	"\xDA\x7A", "\xDA\x7B", "\xDA\x7C", "\xCC\xCB",
  /* U+8DA0 */	"\xDA\x7D", "\xDA\x7E", "\xDA\x80", "\xC8\xA4",
  /* U+8DA4 */	"\xDA\x81", "\xDA\x82", "\xDA\x83", "\xDA\x84",
  /* U+8DA8 */	"\xDA\x85", "\xDA\x86", "\xDA\x87", "\xDA\x88",
  /* U+8DAC */	"\xDA\x89", "\xDA\x8A", "\xDA\x8B", "\xDA\x8C",
  /* U+8DB0 */	"\xDA\x8D", "\xF4\xF5", "\xDA\x8E", "\xD7\xE3",
  /* U+8DB4 */	"\xC5\xBF", "\xF5\xC0", "\xDA\x8F", "\xDA\x90",
  /* U+8DB8 */	"\xF5\xBB", "\xDA\x91", "\xF5\xC3", "\xDA\x92",
  /* U+8DBC */	"\xF5\xC2", "\xDA\x93", "\xD6\xBA", "\xF5\xC1",
  /* U+8DC0 */	"\xDA\x94", "\xDA\x95", "\xDA\x96", "\xD4\xBE",
  /* U+8DC4 */	"\xF5\xC4", "\xDA\x97", "\xF5\xCC", "\xDA\x98",
  /* U+8DC8 */	"\xDA\x99", "\xDA\x9A", "\xDA\x9B", "\xB0\xCF",
  /* U+8DCC */	"\xB5\xF8", "\xDA\x9C", "\xF5\xC9", "\xF5\xCA",
  /* U+8DD0 */	"\xDA\x9D", "\xC5\xDC", "\xDA\x9E", "\xDA\x9F",
  /* U+8DD4 */	"\xDA\xA0", "\xDB\x40", "\xF5\xC5", "\xF5\xC6",
  /* U+8DD8 */	"\xDB\x41", "\xDB\x42", "\xF5\xC7", "\xF5\xCB",
  /* U+8DDC */	"\xDB\x43", "\xBE\xE0", "\xF5\xC8", "\xB8\xFA",
  /* U+8DE0 */	"\xDB\x44", "\xDB\x45", "\xDB\x46", "\xF5\xD0",
  /* U+8DE4 */	"\xF5\xD3", "\xDB\x47", "\xDB\x48", "\xDB\x49",
  /* U+8DE8 */	"\xBF\xE7", "\xDB\x4A", "\xB9\xF2", "\xF5\xBC",
  /* U+8DEC */	"\xF5\xCD", "\xDB\x4B", "\xDB\x4C", "\xC2\xB7",
  /* U+8DF0 */	"\xDB\x4D", "\xDB\x4E", "\xDB\x4F", "\xCC\xF8",
  /* U+8DF4 */	"\xDB\x50", "\xBC\xF9", "\xDB\x51", "\xF5\xCE",
  /* U+8DF8 */	"\xF5\xCF", "\xF5\xD1", "\xB6\xE5", "\xF5\xD2",
  /* U+8DFC */	"\xDB\x52", "\xF5\xD5", "\xDB\x53", "\xDB\x54",
  /* U+8E00 */	"\xDB\x55", "\xDB\x56", "\xDB\x57", "\xDB\x58",
  /* U+8E04 */	"\xDB\x59", "\xF5\xBD", "\xDB\x5A", "\xDB\x5B",
  /* U+8E08 */	"\xDB\x5C", "\xF5\xD4", "\xD3\xBB", "\xDB\x5D",
  /* U+8E0C */	"\xB3\xEC", "\xDB\x5E", "\xDB\x5F", "\xCC\xA4",
  /* U+8E10 */	"\xDB\x60", "\xDB\x61", "\xDB\x62", "\xDB\x63",
  /* U+8E14 */	"\xF5\xD6", "\xDB\x64", "\xDB\x65", "\xDB\x66",
  /* U+8E18 */	"\xDB\x67", "\xDB\x68", "\xDB\x69", "\xDB\x6A",
  /* U+8E1C */	"\xDB\x6B", "\xF5\xD7", "\xBE\xE1", "\xF5\xD8",
  /* U+8E20 */	"\xDB\x6C", "\xDB\x6D", "\xCC\xDF", "\xF5\xDB",
  /* U+8E24 */	"\xDB\x6E", "\xDB\x6F", "\xDB\x70", "\xDB\x71",
  /* U+8E28 */	"\xDB\x72", "\xB2\xC8", "\xD7\xD9", "\xDB\x73",
  /* U+8E2C */	"\xF5\xD9", "\xDB\x74", "\xF5\xDA", "\xF5\xDC",
  /* U+8E30 */	"\xDB\x75", "\xF5\xE2", "\xDB\x76", "\xDB\x77",
  /* U+8E34 */	"\xDB\x78", "\xF5\xE0", "\xDB\x79", "\xDB\x7A",
  /* U+8E38 */	"\xDB\x7B", "\xF5\xDF", "\xF5\xDD", "\xDB\x7C",
  /* U+8E3C */	"\xDB\x7D", "\xF5\xE1", "\xDB\x7E", "\xDB\x80",
  /* U+8E40 */	"\xF5\xDE", "\xF5\xE4", "\xF5\xE5", "\xDB\x81",
  /* U+8E44 */	"\xCC\xE3", "\xDB\x82", "\xDB\x83", "\xE5\xBF",
  /* U+8E48 */	"\xB5\xB8", "\xF5\xE3", "\xF5\xE8", "\xCC\xA3",
  /* U+8E4C */	"\xDB\x84", "\xDB\x85", "\xDB\x86", "\xDB\x87",
  /* U+8E50 */	"\xDB\x88", "\xF5\xE6", "\xF5\xE7", "\xDB\x89",
  /* U+8E54 */	"\xDB\x8A", "\xDB\x8B", "\xDB\x8C", "\xDB\x8D",
  /* U+8E58 */	"\xDB\x8E", "\xF5\xBE", "\xDB\x8F", "\xDB\x90",
  /* U+8E5C */	"\xDB\x91", "\xDB\x92", "\xDB\x93", "\xDB\x94",
  /* U+8E60 */	"\xDB\x95", "\xDB\x96", "\xDB\x97", "\xDB\x98",
  /* U+8E64 */	"\xDB\x99", "\xDB\x9A", "\xB1\xC4", "\xDB\x9B",
  /* U+8E68 */	"\xDB\x9C", "\xF5\xBF", "\xDB\x9D", "\xDB\x9E",
  /* U+8E6C */	"\xB5\xC5", "\xB2\xE4", "\xDB\x9F", "\xF5\xEC",
  /* U+8E70 */	"\xF5\xE9", "\xDB\xA0", "\xB6\xD7", "\xDC\x40",
  /* U+8E74 */	"\xF5\xED", "\xDC\x41", "\xF5\xEA", "\xDC\x42",
  /* U+8E78 */	"\xDC\x43", "\xDC\x44", "\xDC\x45", "\xDC\x46",
  /* U+8E7C */	"\xF5\xEB", "\xDC\x47", "\xDC\x48", "\xB4\xDA",
  /* U+8E80 */	"\xDC\x49", "\xD4\xEA", "\xDC\x4A", "\xDC\x4B",
  /* U+8E84 */	"\xDC\x4C", "\xF5\xEE", "\xDC\x4D", "\xB3\xF9",
  /* U+8E88 */	"\xDC\x4E", "\xDC\x4F", "\xDC\x50", "\xDC\x51",
  /* U+8E8C */	"\xDC\x52", "\xDC\x53", "\xDC\x54", "\xF5\xEF",
  /* U+8E90 */	"\xF5\xF1", "\xDC\x55", "\xDC\x56", "\xDC\x57",
  /* U+8E94 */	"\xF5\xF0", "\xDC\x58", "\xDC\x59", "\xDC\x5A",
  /* U+8E98 */	"\xDC\x5B", "\xDC\x5C", "\xDC\x5D", "\xDC\x5E",
  /* U+8E9C */	"\xF5\xF2", "\xDC\x5F", "\xF5\xF3", "\xDC\x60",
  /* U+8EA0 */	"\xDC\x61", "\xDC\x62", "\xDC\x63", "\xDC\x64",
  /* U+8EA4 */	"\xDC\x65", "\xDC\x66", "\xDC\x67", "\xDC\x68",
  /* U+8EA8 */	"\xDC\x69", "\xDC\x6A", "\xDC\x6B", "\xC9\xED",
  /* U+8EAC */	"\xB9\xAA", "\xDC\x6C", "\xDC\x6D", "\xC7\xFB",
  /* U+8EB0 */	"\xDC\x6E", "\xDC\x6F", "\xB6\xE3", "\xDC\x70",
  /* U+8EB4 */	"\xDC\x71", "\xDC\x72", "\xDC\x73", "\xDC\x74",
  /* U+8EB8 */	"\xDC\x75", "\xDC\x76", "\xCC\xC9", "\xDC\x77",
  /* U+8EBC */	"\xDC\x78", "\xDC\x79", "\xDC\x7A", "\xDC\x7B",
  /* U+8EC0 */	"\xDC\x7C", "\xDC\x7D", "\xDC\x7E", "\xDC\x80",
  /* U+8EC4 */	"\xDC\x81", "\xDC\x82", "\xDC\x83", "\xDC\x84",
  /* U+8EC8 */	"\xDC\x85", "\xDC\x86", "\xDC\x87", "\xDC\x88",
  /* U+8ECC */	"\xDC\x89", "\xDC\x8A", "\xEA\xA6", "\xDC\x8B",
  /* U+8ED0 */	"\xDC\x8C", "\xDC\x8D", "\xDC\x8E", "\xDC\x8F",
  /* U+8ED4 */	"\xDC\x90", "\xDC\x91", "\xDC\x92", "\xDC\x93",
  /* U+8ED8 */	"\xDC\x94", "\xDC\x95", "\xDC\x96", "\xDC\x97",
  /* U+8EDC */	"\xDC\x98", "\xDC\x99", "\xDC\x9A", "\xDC\x9B",
  /* U+8EE0 */	"\xDC\x9C", "\xDC\x9D", "\xDC\x9E", "\xDC\x9F",
  /* U+8EE4 */	"\xDC\xA0", "\xDD\x40", "\xDD\x41", "\xDD\x42",
  /* U+8EE8 */	"\xDD\x43", "\xDD\x44", "\xDD\x45", "\xDD\x46",
  /* U+8EEC */	"\xDD\x47", "\xDD\x48", "\xDD\x49", "\xDD\x4A",
  /* U+8EF0 */	"\xDD\x4B", "\xDD\x4C", "\xDD\x4D", "\xDD\x4E",
  /* U+8EF4 */	"\xDD\x4F", "\xDD\x50", "\xDD\x51", "\xDD\x52",
  /* U+8EF8 */	"\xDD\x53", "\xDD\x54", "\xDD\x55", "\xDD\x56",
  /* U+8EFC */	"\xDD\x57", "\xDD\x58", "\xDD\x59", "\xDD\x5A",
  /* U+8F00 */	"\xDD\x5B", "\xDD\x5C", "\xDD\x5D", "\xDD\x5E",
  /* U+8F04 */	"\xDD\x5F", "\xDD\x60", "\xDD\x61", "\xDD\x62",
  /* U+8F08 */	"\xDD\x63", "\xDD\x64", "\xDD\x65", "\xDD\x66",
  /* U+8F0C */	"\xDD\x67", "\xDD\x68", "\xDD\x69", "\xDD\x6A",
  /* U+8F10 */	"\xDD\x6B", "\xDD\x6C", "\xDD\x6D", "\xDD\x6E",
  /* U+8F14 */	"\xDD\x6F", "\xDD\x70", "\xDD\x71", "\xDD\x72",
  /* U+8F18 */	"\xDD\x73", "\xDD\x74", "\xDD\x75", "\xDD\x76",
  /* U+8F1C */	"\xDD\x77", "\xDD\x78", "\xDD\x79", "\xDD\x7A",
  /* U+8F20 */	"\xDD\x7B", "\xDD\x7C", "\xDD\x7D", "\xDD\x7E",
  /* U+8F24 */	"\xDD\x80", "\xDD\x81", "\xDD\x82", "\xDD\x83",
  /* U+8F28 */	"\xDD\x84", "\xDD\x85", "\xDD\x86", "\xDD\x87",
  /* U+8F2C */	"\xDD\x88", "\xDD\x89", "\xDD\x8A", "\xDD\x8B",
  /* U+8F30 */	"\xDD\x8C", "\xDD\x8D", "\xDD\x8E", "\xDD\x8F",
  /* U+8F34 */	"\xDD\x90", "\xDD\x91", "\xDD\x92", "\xDD\x93",
  /* U+8F38 */	"\xDD\x94", "\xDD\x95", "\xDD\x96", "\xDD\x97",
  /* U+8F3C */	"\xDD\x98", "\xDD\x99", "\xDD\x9A", "\xDD\x9B",
  /* U+8F40 */	"\xDD\x9C", "\xDD\x9D", "\xDD\x9E", "\xDD\x9F",
  /* U+8F44 */	"\xDD\xA0", "\xDE\x40", "\xDE\x41", "\xDE\x42",
  /* U+8F48 */	"\xDE\x43", "\xDE\x44", "\xDE\x45", "\xDE\x46",
  /* U+8F4C */	"\xDE\x47", "\xDE\x48", "\xDE\x49", "\xDE\x4A",
  /* U+8F50 */	"\xDE\x4B", "\xDE\x4C", "\xDE\x4D", "\xDE\x4E",
  /* U+8F54 */	"\xDE\x4F", "\xDE\x50", "\xDE\x51", "\xDE\x52",
  /* U+8F58 */	"\xDE\x53", "\xDE\x54", "\xDE\x55", "\xDE\x56",
  /* U+8F5C */	"\xDE\x57", "\xDE\x58", "\xDE\x59", "\xDE\x5A",
  /* U+8F60 */	"\xDE\x5B", "\xDE\x5C", "\xDE\x5D", "\xDE\x5E",
  /* U+8F64 */	"\xDE\x5F", "\xDE\x60", "\xB3\xB5", "\xD4\xFE",
  /* U+8F68 */	"\xB9\xEC", "\xD0\xF9", "\xDE\x61", "\xE9\xED",
  /* U+8F6C */	"\xD7\xAA", "\xE9\xEE", "\xC2\xD6", "\xC8\xED",
  /* U+8F70 */	"\xBA\xE4", "\xE9\xEF", "\xE9\xF0", "\xE9\xF1",
  /* U+8F74 */	"\xD6\xE1", "\xE9\xF2", "\xE9\xF3", "\xE9\xF5",
  /* U+8F78 */	"\xE9\xF4", "\xE9\xF6", "\xE9\xF7", "\xC7\xE1",
  /* U+8F7C */	"\xE9\xF8", "\xD4\xD8", "\xE9\xF9", "\xBD\xCE",
  /* U+8F80 */	"\xDE\x62", "\xE9\xFA", "\xE9\xFB", "\xBD\xCF",
  /* U+8F84 */	"\xE9\xFC", "\xB8\xA8", "\xC1\xBE", "\xE9\xFD",
  /* U+8F88 */	"\xB1\xB2", "\xBB\xD4", "\xB9\xF5", "\xE9\xFE",
  /* U+8F8C */	"\xDE\x63", "\xEA\xA1", "\xEA\xA2", "\xEA\xA3",
  /* U+8F90 */	"\xB7\xF8", "\xBC\xAD", "\xDE\x64", "\xCA\xE4",
  /* U+8F94 */	"\xE0\xCE", "\xD4\xAF", "\xCF\xBD", "\xD5\xB7",
  /* U+8F98 */	"\xEA\xA4", "\xD5\xDE", "\xEA\xA5", "\xD0\xC1",
  /* U+8F9C */	"\xB9\xBC", "\xDE\x65", "\xB4\xC7", "\xB1\xD9",
  /* U+8FA0 */	"\xDE\x66", "\xDE\x67", "\xDE\x68", "\xC0\xB1",
  /* U+8FA4 */	"\xDE\x69", "\xDE\x6A", "\xDE\x6B", "\xDE\x6C",
  /* U+8FA8 */	"\xB1\xE6", "\xB1\xE7", "\xDE\x6D", "\xB1\xE8",
  /* U+8FAC */	"\xDE\x6E", "\xDE\x6F", "\xDE\x70", "\xDE\x71",
  /* U+8FB0 */	"\xB3\xBD", "\xC8\xE8", "\xDE\x72", "\xDE\x73",
  /* U+8FB4 */	"\xDE\x74", "\xDE\x75", "\xE5\xC1", "\xDE\x76",
  /* U+8FB8 */	"\xDE\x77", "\xB1\xDF", "\xDE\x78", "\xDE\x79",
  /* U+8FBC */	"\xDE\x7A", "\xC1\xC9", "\xB4\xEF", "\xDE\x7B",
  /* U+8FC0 */	"\xDE\x7C", "\xC7\xA8", "\xD3\xD8", "\xDE\x7D",
  /* U+8FC4 */	"\xC6\xF9", "\xD1\xB8", "\xDE\x7E", "\xB9\xFD",
  /* U+8FC8 */	"\xC2\xF5", "\xDE\x80", "\xDE\x81", "\xDE\x82",
  /* U+8FCC */	"\xDE\x83", "\xDE\x84", "\xD3\xAD", "\xDE\x85",
  /* U+8FD0 */	"\xD4\xCB", "\xBD\xFC", "\xDE\x86", "\xE5\xC2",
  /* U+8FD4 */	"\xB7\xB5", "\xE5\xC3", "\xDE\x87", "\xDE\x88",
  /* U+8FD8 */	"\xBB\xB9", "\xD5\xE2", "\xDE\x89", "\xBD\xF8",
  /* U+8FDC */	"\xD4\xB6", "\xCE\xA5", "\xC1\xAC", "\xB3\xD9",
  /* U+8FE0 */	"\xDE\x8A", "\xDE\x8B", "\xCC\xF6", "\xDE\x8C",
  /* U+8FE4 */	"\xE5\xC6", "\xE5\xC4", "\xE5\xC8", "\xDE\x8D",
  /* U+8FE8 */	"\xE5\xCA", "\xE5\xC7", "\xB5\xCF", "\xC6\xC8",
  /* U+8FEC */	"\xDE\x8E", "\xB5\xFC", "\xE5\xC5", "\xDE\x8F",
  /* U+8FF0 */	"\xCA\xF6", "\xDE\x90", "\xDE\x91", "\xE5\xC9",
  /* U+8FF4 */	"\xDE\x92", "\xDE\x93", "\xDE\x94", "\xC3\xD4",
  /* U+8FF8 */	"\xB1\xC5", "\xBC\xA3", "\xDE\x95", "\xDE\x96",
  /* U+8FFC */	"\xDE\x97", "\xD7\xB7", "\xDE\x98", "\xDE\x99",
  /* U+9000 */	"\xCD\xCB", "\xCB\xCD", "\xCA\xCA", "\xCC\xD3",
  /* U+9004 */	"\xE5\xCC", "\xE5\xCB", "\xC4\xE6", "\xDE\x9A",
  /* U+9008 */	"\xDE\x9B", "\xD1\xA1", "\xD1\xB7", "\xE5\xCD",
  /* U+900C */	"\xDE\x9C", "\xE5\xD0", "\xDE\x9D", "\xCD\xB8",
  /* U+9010 */	"\xD6\xF0", "\xE5\xCF", "\xB5\xDD", "\xDE\x9E",
  /* U+9014 */	"\xCD\xBE", "\xDE\x9F", "\xE5\xD1", "\xB6\xBA",
  /* U+9018 */	"\xDE\xA0", "\xDF\x40", "\xCD\xA8", "\xB9\xE4",
  /* U+901C */	"\xDF\x41", "\xCA\xC5", "\xB3\xD1", "\xCB\xD9",
  /* U+9020 */	"\xD4\xEC", "\xE5\xD2", "\xB7\xEA", "\xDF\x42",
  /* U+9024 */	"\xDF\x43", "\xDF\x44", "\xE5\xCE", "\xDF\x45",
  /* U+9028 */	"\xDF\x46", "\xDF\x47", "\xDF\x48", "\xDF\x49",
  /* U+902C */	"\xDF\x4A", "\xE5\xD5", "\xB4\xFE", "\xE5\xD6",
  /* U+9030 */	"\xDF\x4B", "\xDF\x4C", "\xDF\x4D", "\xDF\x4E",
  /* U+9034 */	"\xDF\x4F", "\xE5\xD3", "\xE5\xD4", "\xDF\x50",
  /* U+9038 */	"\xD2\xDD", "\xDF\x51", "\xDF\x52", "\xC2\xDF",
  /* U+903C */	"\xB1\xC6", "\xDF\x53", "\xD3\xE2", "\xDF\x54",
  /* U+9040 */	"\xDF\x55", "\xB6\xDD", "\xCB\xEC", "\xDF\x56",
  /* U+9044 */	"\xE5\xD7", "\xDF\x57", "\xDF\x58", "\xD3\xF6",
  /* U+9048 */	"\xDF\x59", "\xDF\x5A", "\xDF\x5B", "\xDF\x5C",
  /* U+904C */	"\xDF\x5D", "\xB1\xE9", "\xDF\x5E", "\xB6\xF4",
  /* U+9050 */	"\xE5\xDA", "\xE5\xD8", "\xE5\xD9", "\xB5\xC0",
  /* U+9054 */	"\xDF\x5F", "\xDF\x60", "\xDF\x61", "\xD2\xC5",
  /* U+9058 */	"\xE5\xDC", "\xDF\x62", "\xDF\x63", "\xE5\xDE",
  /* U+905C */	"\xDF\x64", "\xDF\x65", "\xDF\x66", "\xDF\x67",
  /* U+9060 */	"\xDF\x68", "\xDF\x69", "\xE5\xDD", "\xC7\xB2",
  /* U+9064 */	"\xDF\x6A", "\xD2\xA3", "\xDF\x6B", "\xDF\x6C",
  /* U+9068 */	"\xE5\xDB", "\xDF\x6D", "\xDF\x6E", "\xDF\x6F",
  /* U+906C */	"\xDF\x70", "\xD4\xE2", "\xD5\xDA", "\xDF\x71",
  /* U+9070 */	"\xDF\x72", "\xDF\x73", "\xDF\x74", "\xDF\x75",
  /* U+9074 */	"\xE5\xE0", "\xD7\xF1", "\xDF\x76", "\xDF\x77",
  /* U+9078 */	"\xDF\x78", "\xDF\x79", "\xDF\x7A", "\xDF\x7B",
  /* U+907C */	"\xDF\x7C", "\xE5\xE1", "\xDF\x7D", "\xB1\xDC",
  /* U+9080 */	"\xD1\xFB", "\xDF\x7E", "\xE5\xE2", "\xE5\xE4",
  /* U+9084 */	"\xDF\x80", "\xDF\x81", "\xDF\x82", "\xDF\x83",
  /* U+9088 */	"\xE5\xE3", "\xDF\x84", "\xDF\x85", "\xE5\xE5",
  /* U+908C */	"\xDF\x86", "\xDF\x87", "\xDF\x88", "\xDF\x89",
  /* U+9090 */	"\xDF\x8A", "\xD2\xD8", "\xDF\x8B", "\xB5\xCB",
  /* U+9094 */	"\xDF\x8C", "\xE7\xDF", "\xDF\x8D", "\xDA\xF5",
  /* U+9098 */	"\xDF\x8E", "\xDA\xF8", "\xDF\x8F", "\xDA\xF6",
  /* U+909C */	"\xDF\x90", "\xDA\xF7", "\xDF\x91", "\xDF\x92",
  /* U+90A0 */	"\xDF\x93", "\xDA\xFA", "\xD0\xCF", "\xC4\xC7",
  /* U+90A4 */	"\xDF\x94", "\xDF\x95", "\xB0\xEE", "\xDF\x96",
  /* U+90A8 */	"\xDF\x97", "\xDF\x98", "\xD0\xB0", "\xDF\x99",
  /* U+90AC */	"\xDA\xF9", "\xDF\x9A", "\xD3\xCA", "\xBA\xAA",
  /* U+90B0 */	"\xDB\xA2", "\xC7\xF1", "\xDF\x9B", "\xDA\xFC",
  /* U+90B4 */	"\xDA\xFB", "\xC9\xDB", "\xDA\xFD", "\xDF\x9C",
  /* U+90B8 */	"\xDB\xA1", "\xD7\xDE", "\xDA\xFE", "\xC1\xDA",
  /* U+90BC */	"\xDF\x9D", "\xDF\x9E", "\xDB\xA5", "\xDF\x9F",
  /* U+90C0 */	"\xDF\xA0", "\xD3\xF4", "\xE0\x40", "\xE0\x41",
  /* U+90C4 */	"\xDB\xA7", "\xDB\xA4", "\xE0\x42", "\xDB\xA8",
  /* U+90C8 */	"\xE0\x43", "\xE0\x44", "\xBD\xBC", "\xE0\x45",
  /* U+90CC */	"\xE0\x46", "\xE0\x47", "\xC0\xC9", "\xDB\xA3",
  /* U+90D0 */	"\xDB\xA6", "\xD6\xA3", "\xE0\x48", "\xDB\xA9",
  /* U+90D4 */	"\xE0\x49", "\xE0\x4A", "\xE0\x4B", "\xDB\xAD",
  /* U+90D8 */	"\xE0\x4C", "\xE0\x4D", "\xE0\x4E", "\xDB\xAE",
  /* U+90DC */	"\xDB\xAC", "\xBA\xC2", "\xE0\x4F", "\xE0\x50",
  /* U+90E0 */	"\xE0\x51", "\xBF\xA4", "\xDB\xAB", "\xE0\x52",
  /* U+90E4 */	"\xE0\x53", "\xE0\x54", "\xDB\xAA", "\xD4\xC7",
  /* U+90E8 */	"\xB2\xBF", "\xE0\x55", "\xE0\x56", "\xDB\xAF",
  /* U+90EC */	"\xE0\x57", "\xB9\xF9", "\xE0\x58", "\xDB\xB0",
  /* U+90F0 */	"\xE0\x59", "\xE0\x5A", "\xE0\x5B", "\xE0\x5C",
  /* U+90F4 */	"\xB3\xBB", "\xE0\x5D", "\xE0\x5E", "\xE0\x5F",
  /* U+90F8 */	"\xB5\xA6", "\xE0\x60", "\xE0\x61", "\xE0\x62",
  /* U+90FC */	"\xE0\x63", "\xB6\xBC", "\xDB\xB1", "\xE0\x64",
  /* U+9100 */	"\xE0\x65", "\xE0\x66", "\xB6\xF5", "\xE0\x67",
  /* U+9104 */	"\xDB\xB2", "\xE0\x68", "\xE0\x69", "\xE0\x6A",
  /* U+9108 */	"\xE0\x6B", "\xE0\x6C", "\xE0\x6D", "\xE0\x6E",
  /* U+910C */	"\xE0\x6F", "\xE0\x70", "\xE0\x71", "\xE0\x72",
  /* U+9110 */	"\xE0\x73", "\xE0\x74", "\xE0\x75", "\xE0\x76",
  /* U+9114 */	"\xE0\x77", "\xE0\x78", "\xE0\x79", "\xE0\x7A",
  /* U+9118 */	"\xE0\x7B", "\xB1\xC9", "\xE0\x7C", "\xE0\x7D",
  /* U+911C */	"\xE0\x7E", "\xE0\x80", "\xDB\xB4", "\xE0\x81",
  /* U+9120 */	"\xE0\x82", "\xE0\x83", "\xDB\xB3", "\xDB\xB5",
  /* U+9124 */	"\xE0\x84", "\xE0\x85", "\xE0\x86", "\xE0\x87",
  /* U+9128 */	"\xE0\x88", "\xE0\x89", "\xE0\x8A", "\xE0\x8B",
  /* U+912C */	"\xE0\x8C", "\xE0\x8D", "\xE0\x8E", "\xDB\xB7",
  /* U+9130 */	"\xE0\x8F", "\xDB\xB6", "\xE0\x90", "\xE0\x91",
  /* U+9134 */	"\xE0\x92", "\xE0\x93", "\xE0\x94", "\xE0\x95",
  /* U+9138 */	"\xE0\x96", "\xDB\xB8", "\xE0\x97", "\xE0\x98",
  /* U+913C */	"\xE0\x99", "\xE0\x9A", "\xE0\x9B", "\xE0\x9C",
  /* U+9140 */	"\xE0\x9D", "\xE0\x9E", "\xE0\x9F", "\xDB\xB9",
  /* U+9144 */	"\xE0\xA0", "\xE1\x40", "\xDB\xBA", "\xE1\x41",
  /* U+9148 */	"\xE1\x42", "\xD3\xCF", "\xF4\xFA", "\xC7\xF5",
  /* U+914C */	"\xD7\xC3", "\xC5\xE4", "\xF4\xFC", "\xF4\xFD",
  /* U+9150 */	"\xF4\xFB", "\xE1\x43", "\xBE\xC6", "\xE1\x44",
  /* U+9154 */	"\xE1\x45", "\xE1\x46", "\xE1\x47", "\xD0\xEF",
  /* U+9158 */	"\xE1\x48", "\xE1\x49", "\xB7\xD3", "\xE1\x4A",
  /* U+915C */	"\xE1\x4B", "\xD4\xCD", "\xCC\xAA", "\xE1\x4C",
  /* U+9160 */	"\xE1\x4D", "\xF5\xA2", "\xF5\xA1", "\xBA\xA8",
  /* U+9164 */	"\xF4\xFE", "\xCB\xD6", "\xE1\x4E", "\xE1\x4F",
  /* U+9168 */	"\xE1\x50", "\xF5\xA4", "\xC0\xD2", "\xE1\x51",
  /* U+916C */	"\xB3\xEA", "\xE1\x52", "\xCD\xAA", "\xF5\xA5",
  /* U+9170 */	"\xF5\xA3", "\xBD\xB4", "\xF5\xA8", "\xE1\x53",
  /* U+9174 */	"\xF5\xA9", "\xBD\xCD", "\xC3\xB8", "\xBF\xE1",
  /* U+9178 */	"\xCB\xE1", "\xF5\xAA", "\xE1\x54", "\xE1\x55",
  /* U+917C */	"\xE1\x56", "\xF5\xA6", "\xF5\xA7", "\xC4\xF0",
  /* U+9180 */	"\xE1\x57", "\xE1\x58", "\xE1\x59", "\xE1\x5A",
  /* U+9184 */	"\xE1\x5B", "\xF5\xAC", "\xE1\x5C", "\xB4\xBC",
  /* U+9188 */	"\xE1\x5D", "\xD7\xED", "\xE1\x5E", "\xB4\xD7",
  /* U+918C */	"\xF5\xAB", "\xF5\xAE", "\xE1\x5F", "\xE1\x60",
  /* U+9190 */	"\xF5\xAD", "\xF5\xAF", "\xD0\xD1", "\xE1\x61",
  /* U+9194 */	"\xE1\x62", "\xE1\x63", "\xE1\x64", "\xE1\x65",
  /* U+9198 */	"\xE1\x66", "\xE1\x67", "\xC3\xD1", "\xC8\xA9",
  /* U+919C */	"\xE1\x68", "\xE1\x69", "\xE1\x6A", "\xE1\x6B",
  /* U+91A0 */	"\xE1\x6C", "\xE1\x6D", "\xF5\xB0", "\xF5\xB1",
  /* U+91A4 */	"\xE1\x6E", "\xE1\x6F", "\xE1\x70", "\xE1\x71",
  /* U+91A8 */	"\xE1\x72", "\xE1\x73", "\xF5\xB2", "\xE1\x74",
  /* U+91AC */	"\xE1\x75", "\xF5\xB3", "\xF5\xB4", "\xF5\xB5",
  /* U+91B0 */	"\xE1\x76", "\xE1\x77", "\xE1\x78", "\xE1\x79",
  /* U+91B4 */	"\xF5\xB7", "\xF5\xB6", "\xE1\x7A", "\xE1\x7B",
  /* U+91B8 */	"\xE1\x7C", "\xE1\x7D", "\xF5\xB8", "\xE1\x7E",
  /* U+91BC */	"\xE1\x80", "\xE1\x81", "\xE1\x82", "\xE1\x83",
  /* U+91C0 */	"\xE1\x84", "\xE1\x85", "\xE1\x86", "\xE1\x87",
  /* U+91C4 */	"\xE1\x88", "\xE1\x89", "\xE1\x8A", "\xB2\xC9",
  /* U+91C8 */	"\xE1\x8B", "\xD3\xD4", "\xCA\xCD", "\xE1\x8C",
  /* U+91CC */	"\xC0\xEF", "\xD6\xD8", "\xD2\xB0", "\xC1\xBF",
  /* U+91D0 */	"\xE1\x8D", "\xBD\xF0", "\xE1\x8E", "\xE1\x8F",
  /* U+91D4 */	"\xE1\x90", "\xE1\x91", "\xE1\x92", "\xE1\x93",
  /* U+91D8 */	"\xE1\x94", "\xE1\x95", "\xE1\x96", "\xE1\x97",
  /* U+91DC */	"\xB8\xAA", "\xE1\x98", "\xE1\x99", "\xE1\x9A",
  /* U+91E0 */	"\xE1\x9B", "\xE1\x9C", "\xE1\x9D", "\xE1\x9E",
  /* U+91E4 */	"\xE1\x9F", "\xE1\xA0", "\xE2\x40", "\xE2\x41",
  /* U+91E8 */	"\xE2\x42", "\xE2\x43", "\xE2\x44", "\xE2\x45",
  /* U+91EC */	"\xE2\x46", "\xE2\x47", "\xE2\x48", "\xE2\x49",
  /* U+91F0 */	"\xE2\x4A", "\xE2\x4B", "\xE2\x4C", "\xE2\x4D",
  /* U+91F4 */	"\xE2\x4E", "\xE2\x4F", "\xE2\x50", "\xE2\x51",
  /* U+91F8 */	"\xE2\x52", "\xE2\x53", "\xE2\x54", "\xE2\x55",
  /* U+91FC */	"\xE2\x56", "\xE2\x57", "\xE2\x58", "\xE2\x59",
  /* U+9200 */	"\xE2\x5A", "\xE2\x5B", "\xE2\x5C", "\xE2\x5D",
  /* U+9204 */	"\xE2\x5E", "\xE2\x5F", "\xE2\x60", "\xE2\x61",
  /* U+9208 */	"\xE2\x62", "\xE2\x63", "\xE2\x64", "\xE2\x65",
  /* U+920C */	"\xE2\x66", "\xE2\x67", "\xE2\x68", "\xE2\x69",
  /* U+9210 */	"\xE2\x6A", "\xE2\x6B", "\xE2\x6C", "\xE2\x6D",
  /* U+9214 */	"\xE2\x6E", "\xE2\x6F", "\xE2\x70", "\xE2\x71",
  /* U+9218 */	"\xE2\x72", "\xE2\x73", "\xE2\x74", "\xE2\x75",
  /* U+921C */	"\xE2\x76", "\xE2\x77", "\xE2\x78", "\xE2\x79",
  /* U+9220 */	"\xE2\x7A", "\xE2\x7B", "\xE2\x7C", "\xE2\x7D",
  /* U+9224 */	"\xE2\x7E", "\xE2\x80", "\xE2\x81", "\xE2\x82",
  /* U+9228 */	"\xE2\x83", "\xE2\x84", "\xE2\x85", "\xE2\x86",
  /* U+922C */	"\xE2\x87", "\xE2\x88", "\xE2\x89", "\xE2\x8A",
  /* U+9230 */	"\xE2\x8B", "\xE2\x8C", "\xE2\x8D", "\xE2\x8E",
  /* U+9234 */	"\xE2\x8F", "\xE2\x90", "\xE2\x91", "\xE2\x92",
  /* U+9238 */	"\xE2\x93", "\xE2\x94", "\xE2\x95", "\xE2\x96",
  /* U+923C */	"\xE2\x97", "\xE2\x98", "\xE2\x99", "\xE2\x9A",
  /* U+9240 */	"\xE2\x9B", "\xE2\x9C", "\xE2\x9D", "\xE2\x9E",
  /* U+9244 */	"\xE2\x9F", "\xE2\xA0", "\xE3\x40", "\xE3\x41",
  /* U+9248 */	"\xE3\x42", "\xE3\x43", "\xE3\x44", "\xE3\x45",
  /* U+924C */	"\xE3\x46", "\xE3\x47", "\xE3\x48", "\xE3\x49",
  /* U+9250 */	"\xE3\x4A", "\xE3\x4B", "\xE3\x4C", "\xE3\x4D",
  /* U+9254 */	"\xE3\x4E", "\xE3\x4F", "\xE3\x50", "\xE3\x51",
  /* U+9258 */	"\xE3\x52", "\xE3\x53", "\xE3\x54", "\xE3\x55",
  /* U+925C */	"\xE3\x56", "\xE3\x57", "\xE3\x58", "\xE3\x59",
  /* U+9260 */	"\xE3\x5A", "\xE3\x5B", "\xE3\x5C", "\xE3\x5D",
  /* U+9264 */	"\xE3\x5E", "\xE3\x5F", "\xE3\x60", "\xE3\x61",
  /* U+9268 */	"\xE3\x62", "\xE3\x63", "\xE3\x64", "\xE3\x65",
  /* U+926C */	"\xE3\x66", "\xE3\x67", "\xE3\x68", "\xE3\x69",
  /* U+9270 */	"\xE3\x6A", "\xE3\x6B", "\xE3\x6C", "\xE3\x6D",
  /* U+9274 */	"\xBC\xF8", "\xE3\x6E", "\xE3\x6F", "\xE3\x70",
  /* U+9278 */	"\xE3\x71", "\xE3\x72", "\xE3\x73", "\xE3\x74",
  /* U+927C */	"\xE3\x75", "\xE3\x76", "\xE3\x77", "\xE3\x78",
  /* U+9280 */	"\xE3\x79", "\xE3\x7A", "\xE3\x7B", "\xE3\x7C",
  /* U+9284 */	"\xE3\x7D", "\xE3\x7E", "\xE3\x80", "\xE3\x81",
  /* U+9288 */	"\xE3\x82", "\xE3\x83", "\xE3\x84", "\xE3\x85",
  /* U+928C */	"\xE3\x86", "\xE3\x87", "\xF6\xC6", "\xE3\x88",
  /* U+9290 */	"\xE3\x89", "\xE3\x8A", "\xE3\x8B", "\xE3\x8C",
  /* U+9294 */	"\xE3\x8D", "\xE3\x8E", "\xE3\x8F", "\xE3\x90",
  /* U+9298 */	"\xE3\x91", "\xE3\x92", "\xE3\x93", "\xE3\x94",
  /* U+929C */	"\xE3\x95", "\xE3\x96", "\xE3\x97", "\xE3\x98",
  /* U+92A0 */	"\xE3\x99", "\xE3\x9A", "\xE3\x9B", "\xE3\x9C",
  /* U+92A4 */	"\xE3\x9D", "\xE3\x9E", "\xE3\x9F", "\xE3\xA0",
  /* U+92A8 */	"\xE4\x40", "\xE4\x41", "\xE4\x42", "\xE4\x43",
  /* U+92AC */	"\xE4\x44", "\xE4\x45", "\xF6\xC7", "\xE4\x46",
  /* U+92B0 */	"\xE4\x47", "\xE4\x48", "\xE4\x49", "\xE4\x4A",
  /* U+92B4 */	"\xE4\x4B", "\xE4\x4C", "\xE4\x4D", "\xE4\x4E",
  /* U+92B8 */	"\xE4\x4F", "\xE4\x50", "\xE4\x51", "\xE4\x52",
  /* U+92BC */	"\xE4\x53", "\xE4\x54", "\xE4\x55", "\xE4\x56",
  /* U+92C0 */	"\xE4\x57", "\xE4\x58", "\xE4\x59", "\xE4\x5A",
  /* U+92C4 */	"\xE4\x5B", "\xE4\x5C", "\xE4\x5D", "\xE4\x5E",
  /* U+92C8 */	"\xF6\xC8", "\xE4\x5F", "\xE4\x60", "\xE4\x61",
  /* U+92CC */	"\xE4\x62", "\xE4\x63", "\xE4\x64", "\xE4\x65",
  /* U+92D0 */	"\xE4\x66", "\xE4\x67", "\xE4\x68", "\xE4\x69",
  /* U+92D4 */	"\xE4\x6A", "\xE4\x6B", "\xE4\x6C", "\xE4\x6D",
  /* U+92D8 */	"\xE4\x6E", "\xE4\x6F", "\xE4\x70", "\xE4\x71",
  /* U+92DC */	"\xE4\x72", "\xE4\x73", "\xE4\x74", "\xE4\x75",
  /* U+92E0 */	"\xE4\x76", "\xE4\x77", "\xE4\x78", "\xE4\x79",
  /* U+92E4 */	"\xE4\x7A", "\xE4\x7B", "\xE4\x7C", "\xE4\x7D",
  /* U+92E8 */	"\xE4\x7E", "\xE4\x80", "\xE4\x81", "\xE4\x82",
  /* U+92EC */	"\xE4\x83", "\xE4\x84", "\xE4\x85", "\xE4\x86",
  /* U+92F0 */	"\xE4\x87", "\xE4\x88", "\xE4\x89", "\xE4\x8A",
  /* U+92F4 */	"\xE4\x8B", "\xE4\x8C", "\xE4\x8D", "\xE4\x8E",
  /* U+92F8 */	"\xE4\x8F", "\xE4\x90", "\xE4\x91", "\xE4\x92",
  /* U+92FC */	"\xE4\x93", "\xE4\x94", "\xE4\x95", "\xE4\x96",
  /* U+9300 */	"\xE4\x97", "\xE4\x98", "\xE4\x99", "\xE4\x9A",
  /* U+9304 */	"\xE4\x9B", "\xE4\x9C", "\xE4\x9D", "\xE4\x9E",
  /* U+9308 */	"\xE4\x9F", "\xE4\xA0", "\xE5\x40", "\xE5\x41",
  /* U+930C */	"\xE5\x42", "\xE5\x43", "\xE5\x44", "\xE5\x45",
  /* U+9310 */	"\xE5\x46", "\xE5\x47", "\xE5\x48", "\xE5\x49",
  /* U+9314 */	"\xE5\x4A", "\xE5\x4B", "\xE5\x4C", "\xE5\x4D",
  /* U+9318 */	"\xE5\x4E", "\xE5\x4F", "\xE5\x50", "\xE5\x51",
  /* U+931C */	"\xE5\x52", "\xE5\x53", "\xE5\x54", "\xE5\x55",
  /* U+9320 */	"\xE5\x56", "\xE5\x57", "\xE5\x58", "\xE5\x59",
  /* U+9324 */	"\xE5\x5A", "\xE5\x5B", "\xE5\x5C", "\xE5\x5D",
  /* U+9328 */	"\xE5\x5E", "\xE5\x5F", "\xE5\x60", "\xE5\x61",
  /* U+932C */	"\xE5\x62", "\xE5\x63", "\xE5\x64", "\xE5\x65",
  /* U+9330 */	"\xE5\x66", "\xE5\x67", "\xE5\x68", "\xE5\x69",
  /* U+9334 */	"\xE5\x6A", "\xE5\x6B", "\xE5\x6C", "\xE5\x6D",
  /* U+9338 */	"\xE5\x6E", "\xE5\x6F", "\xE5\x70", "\xE5\x71",
  /* U+933C */	"\xE5\x72", "\xE5\x73", "\xF6\xC9", "\xE5\x74",
  /* U+9340 */	"\xE5\x75", "\xE5\x76", "\xE5\x77", "\xE5\x78",
  /* U+9344 */	"\xE5\x79", "\xE5\x7A", "\xE5\x7B", "\xE5\x7C",
  /* U+9348 */	"\xE5\x7D", "\xE5\x7E", "\xE5\x80", "\xE5\x81",
  /* U+934C */	"\xE5\x82", "\xE5\x83", "\xE5\x84", "\xE5\x85",
  /* U+9350 */	"\xE5\x86", "\xE5\x87", "\xE5\x88", "\xE5\x89",
  /* U+9354 */	"\xE5\x8A", "\xE5\x8B", "\xE5\x8C", "\xE5\x8D",
  /* U+9358 */	"\xE5\x8E", "\xE5\x8F", "\xE5\x90", "\xE5\x91",
  /* U+935C */	"\xE5\x92", "\xE5\x93", "\xE5\x94", "\xE5\x95",
  /* U+9360 */	"\xE5\x96", "\xE5\x97", "\xE5\x98", "\xE5\x99",
  /* U+9364 */	"\xE5\x9A", "\xE5\x9B", "\xE5\x9C", "\xE5\x9D",
  /* U+9368 */	"\xE5\x9E", "\xE5\x9F", "\xF6\xCA", "\xE5\xA0",
  /* U+936C */	"\xE6\x40", "\xE6\x41", "\xE6\x42", "\xE6\x43",
  /* U+9370 */	"\xE6\x44", "\xE6\x45", "\xE6\x46", "\xE6\x47",
  /* U+9374 */	"\xE6\x48", "\xE6\x49", "\xE6\x4A", "\xE6\x4B",
  /* U+9378 */	"\xE6\x4C", "\xE6\x4D", "\xE6\x4E", "\xE6\x4F",
  /* U+937C */	"\xE6\x50", "\xE6\x51", "\xE6\x52", "\xE6\x53",
  /* U+9380 */	"\xE6\x54", "\xE6\x55", "\xE6\x56", "\xE6\x57",
  /* U+9384 */	"\xE6\x58", "\xE6\x59", "\xE6\x5A", "\xE6\x5B",
  /* U+9388 */	"\xE6\x5C", "\xE6\x5D", "\xE6\x5E", "\xE6\x5F",
  /* U+938C */	"\xE6\x60", "\xE6\x61", "\xE6\x62", "\xF6\xCC",
  /* U+9390 */	"\xE6\x63", "\xE6\x64", "\xE6\x65", "\xE6\x66",
  /* U+9394 */	"\xE6\x67", "\xE6\x68", "\xE6\x69", "\xE6\x6A",
  /* U+9398 */	"\xE6\x6B", "\xE6\x6C", "\xE6\x6D", "\xE6\x6E",
  /* U+939C */	"\xE6\x6F", "\xE6\x70", "\xE6\x71", "\xE6\x72",
  /* U+93A0 */	"\xE6\x73", "\xE6\x74", "\xE6\x75", "\xE6\x76",
  /* U+93A4 */	"\xE6\x77", "\xE6\x78", "\xE6\x79", "\xE6\x7A",
  /* U+93A8 */	"\xE6\x7B", "\xE6\x7C", "\xE6\x7D", "\xE6\x7E",
  /* U+93AC */	"\xE6\x80", "\xE6\x81", "\xE6\x82", "\xE6\x83",
  /* U+93B0 */	"\xE6\x84", "\xE6\x85", "\xE6\x86", "\xE6\x87",
  /* U+93B4 */	"\xE6\x88", "\xE6\x89", "\xE6\x8A", "\xE6\x8B",
  /* U+93B8 */	"\xE6\x8C", "\xE6\x8D", "\xE6\x8E", "\xE6\x8F",
  /* U+93BC */	"\xE6\x90", "\xE6\x91", "\xE6\x92", "\xE6\x93",
  /* U+93C0 */	"\xE6\x94", "\xE6\x95", "\xE6\x96", "\xE6\x97",
  /* U+93C4 */	"\xE6\x98", "\xE6\x99", "\xE6\x9A", "\xE6\x9B",
  /* U+93C8 */	"\xE6\x9C", "\xE6\x9D", "\xF6\xCB", "\xE6\x9E",
  /* U+93CC */	"\xE6\x9F", "\xE6\xA0", "\xE7\x40", "\xE7\x41",
  /* U+93D0 */	"\xE7\x42", "\xE7\x43", "\xE7\x44", "\xE7\x45",
  /* U+93D4 */	"\xE7\x46", "\xE7\x47", "\xF7\xE9", "\xE7\x48",
  /* U+93D8 */	"\xE7\x49", "\xE7\x4A", "\xE7\x4B", "\xE7\x4C",
  /* U+93DC */	"\xE7\x4D", "\xE7\x4E", "\xE7\x4F", "\xE7\x50",
  /* U+93E0 */	"\xE7\x51", "\xE7\x52", "\xE7\x53", "\xE7\x54",
  /* U+93E4 */	"\xE7\x55", "\xE7\x56", "\xE7\x57", "\xE7\x58",
  /* U+93E8 */	"\xE7\x59", "\xE7\x5A", "\xE7\x5B", "\xE7\x5C",
  /* U+93EC */	"\xE7\x5D", "\xE7\x5E", "\xE7\x5F", "\xE7\x60",
  /* U+93F0 */	"\xE7\x61", "\xE7\x62", "\xE7\x63", "\xE7\x64",
  /* U+93F4 */	"\xE7\x65", "\xE7\x66", "\xE7\x67", "\xE7\x68",
  /* U+93F8 */	"\xE7\x69", "\xE7\x6A", "\xE7\x6B", "\xE7\x6C",
  /* U+93FC */	"\xE7\x6D", "\xE7\x6E", "\xE7\x6F", "\xE7\x70",
  /* U+9400 */	"\xE7\x71", "\xE7\x72", "\xE7\x73", "\xE7\x74",
  /* U+9404 */	"\xE7\x75", "\xE7\x76", "\xE7\x77", "\xE7\x78",
  /* U+9408 */	"\xE7\x79", "\xE7\x7A", "\xE7\x7B", "\xE7\x7C",
  /* U+940C */	"\xE7\x7D", "\xE7\x7E", "\xE7\x80", "\xE7\x81",
  /* U+9410 */	"\xE7\x82", "\xE7\x83", "\xE7\x84", "\xE7\x85",
  /* U+9414 */	"\xE7\x86", "\xE7\x87", "\xE7\x88", "\xE7\x89",
  /* U+9418 */	"\xE7\x8A", "\xE7\x8B", "\xE7\x8C", "\xE7\x8D",
  /* U+941C */	"\xE7\x8E", "\xE7\x8F", "\xE7\x90", "\xE7\x91",
  /* U+9420 */	"\xE7\x92", "\xE7\x93", "\xE7\x94", "\xE7\x95",
  /* U+9424 */	"\xE7\x96", "\xE7\x97", "\xE7\x98", "\xE7\x99",
  /* U+9428 */	"\xE7\x9A", "\xE7\x9B", "\xE7\x9C", "\xE7\x9D",
  /* U+942C */	"\xE7\x9E", "\xE7\x9F", "\xE7\xA0", "\xE8\x40",
  /* U+9430 */	"\xE8\x41", "\xE8\x42", "\xE8\x43", "\xE8\x44",
  /* U+9434 */	"\xE8\x45", "\xE8\x46", "\xE8\x47", "\xE8\x48",
  /* U+9438 */	"\xE8\x49", "\xE8\x4A", "\xE8\x4B", "\xE8\x4C",
  /* U+943C */	"\xE8\x4D", "\xE8\x4E", "\xF6\xCD", "\xE8\x4F",
  /* U+9440 */	"\xE8\x50", "\xE8\x51", "\xE8\x52", "\xE8\x53",
  /* U+9444 */	"\xE8\x54", "\xE8\x55", "\xE8\x56", "\xE8\x57",
  /* U+9448 */	"\xE8\x58", "\xE8\x59", "\xE8\x5A", "\xE8\x5B",
  /* U+944C */	"\xE8\x5C", "\xE8\x5D", "\xE8\x5E", "\xE8\x5F",
  /* U+9450 */	"\xE8\x60", "\xE8\x61", "\xE8\x62", "\xE8\x63",
  /* U+9454 */	"\xE8\x64", "\xE8\x65", "\xE8\x66", "\xE8\x67",
  /* U+9458 */	"\xE8\x68", "\xE8\x69", "\xE8\x6A", "\xE8\x6B",
  /* U+945C */	"\xE8\x6C", "\xE8\x6D", "\xE8\x6E", "\xE8\x6F",
  /* U+9460 */	"\xE8\x70", "\xE8\x71", "\xE8\x72", "\xE8\x73",
  /* U+9464 */	"\xE8\x74", "\xE8\x75", "\xE8\x76", "\xE8\x77",
  /* U+9468 */	"\xE8\x78", "\xE8\x79", "\xE8\x7A", "\xF6\xCE",
  /* U+946C */	"\xE8\x7B", "\xE8\x7C", "\xE8\x7D", "\xE8\x7E",
  /* U+9470 */	"\xE8\x80", "\xE8\x81", "\xE8\x82", "\xE8\x83",
  /* U+9474 */	"\xE8\x84", "\xE8\x85", "\xE8\x86", "\xE8\x87",
  /* U+9478 */	"\xE8\x88", "\xE8\x89", "\xE8\x8A", "\xE8\x8B",
  /* U+947C */	"\xE8\x8C", "\xE8\x8D", "\xE8\x8E", "\xE8\x8F",
  /* U+9480 */	"\xE8\x90", "\xE8\x91", "\xE8\x92", "\xE8\x93",
  /* U+9484 */	"\xE8\x94", "\xEE\xC4", "\xEE\xC5", "\xEE\xC6",
  /* U+9488 */	"\xD5\xEB", "\xB6\xA4", "\xEE\xC8", "\xEE\xC7",
  /* U+948C */	"\xEE\xC9", "\xEE\xCA", "\xC7\xA5", "\xEE\xCB",
  /* U+9490 */	"\xEE\xCC", "\xE8\x95", "\xB7\xB0", "\xB5\xF6",
  /* U+9494 */	"\xEE\xCD", "\xEE\xCF", "\xE8\x96", "\xEE\xCE",
  /* U+9498 */	"\xE8\x97", "\xB8\xC6", "\xEE\xD0", "\xEE\xD1",
  /* U+949C */	"\xEE\xD2", "\xB6\xDB", "\xB3\xAE", "\xD6\xD3",
  /* U+94A0 */	"\xC4\xC6", "\xB1\xB5", "\xB8\xD6", "\xEE\xD3",
  /* U+94A4 */	"\xEE\xD4", "\xD4\xBF", "\xC7\xD5", "\xBE\xFB",
  /* U+94A8 */	"\xCE\xD9", "\xB9\xB3", "\xEE\xD6", "\xEE\xD5",
  /* U+94AC */	"\xEE\xD8", "\xEE\xD7", "\xC5\xA5", "\xEE\xD9",
  /* U+94B0 */	"\xEE\xDA", "\xC7\xAE", "\xEE\xDB", "\xC7\xAF",
  /* U+94B4 */	"\xEE\xDC", "\xB2\xA7", "\xEE\xDD", "\xEE\xDE",
  /* U+94B8 */	"\xEE\xDF", "\xEE\xE0", "\xEE\xE1", "\xD7\xEA",
  /* U+94BC */	"\xEE\xE2", "\xEE\xE3", "\xBC\xD8", "\xEE\xE4",
  /* U+94C0 */	"\xD3\xCB", "\xCC\xFA", "\xB2\xAC", "\xC1\xE5",
  /* U+94C4 */	"\xEE\xE5", "\xC7\xA6", "\xC3\xAD", "\xE8\x98",
  /* U+94C8 */	"\xEE\xE6", "\xEE\xE7", "\xEE\xE8", "\xEE\xE9",
  /* U+94CC */	"\xEE\xEA", "\xEE\xEB", "\xEE\xEC", "\xE8\x99",
  /* U+94D0 */	"\xEE\xED", "\xEE\xEE", "\xEE\xEF", "\xE8\x9A",
  /* U+94D4 */	"\xE8\x9B", "\xEE\xF0", "\xEE\xF1", "\xEE\xF2",
  /* U+94D8 */	"\xEE\xF4", "\xEE\xF3", "\xE8\x9C", "\xEE\xF5",
  /* U+94DC */	"\xCD\xAD", "\xC2\xC1", "\xEE\xF6", "\xEE\xF7",
  /* U+94E0 */	"\xEE\xF8", "\xD5\xA1", "\xEE\xF9", "\xCF\xB3",
  /* U+94E4 */	"\xEE\xFA", "\xEE\xFB", "\xE8\x9D", "\xEE\xFC",
  /* U+94E8 */	"\xEE\xFD", "\xEF\xA1", "\xEE\xFE", "\xEF\xA2",
  /* U+94EC */	"\xB8\xF5", "\xC3\xFA", "\xEF\xA3", "\xEF\xA4",
  /* U+94F0 */	"\xBD\xC2", "\xD2\xBF", "\xB2\xF9", "\xEF\xA5",
  /* U+94F4 */	"\xEF\xA6", "\xEF\xA7", "\xD2\xF8", "\xEF\xA8",
  /* U+94F8 */	"\xD6\xFD", "\xEF\xA9", "\xC6\xCC", "\xE8\x9E",
  /* U+94FC */	"\xEF\xAA", "\xEF\xAB", "\xC1\xB4", "\xEF\xAC",
  /* U+9500 */	"\xCF\xFA", "\xCB\xF8", "\xEF\xAE", "\xEF\xAD",
  /* U+9504 */	"\xB3\xFA", "\xB9\xF8", "\xEF\xAF", "\xEF\xB0",
  /* U+9508 */	"\xD0\xE2", "\xEF\xB1", "\xEF\xB2", "\xB7\xE6",
  /* U+950C */	"\xD0\xBF", "\xEF\xB3", "\xEF\xB4", "\xEF\xB5",
  /* U+9510 */	"\xC8\xF1", "\xCC\xE0", "\xEF\xB6", "\xEF\xB7",
  /* U+9514 */	"\xEF\xB8", "\xEF\xB9", "\xEF\xBA", "\xD5\xE0",
  /* U+9518 */	"\xEF\xBB", "\xB4\xED", "\xC3\xAA", "\xEF\xBC",
  /* U+951C */	"\xE8\x9F", "\xEF\xBD", "\xEF\xBE", "\xEF\xBF",
  /* U+9520 */	"\xE8\xA0", "\xCE\xFD", "\xEF\xC0", "\xC2\xE0",
  /* U+9524 */	"\xB4\xB8", "\xD7\xB6", "\xBD\xF5", "\xE9\x40",
  /* U+9528 */	"\xCF\xC7", "\xEF\xC3", "\xEF\xC1", "\xEF\xC2",
  /* U+952C */	"\xEF\xC4", "\xB6\xA7", "\xBC\xFC", "\xBE\xE2",
  /* U+9530 */	"\xC3\xCC", "\xEF\xC5", "\xEF\xC6", "\xE9\x41",
  /* U+9534 */	"\xEF\xC7", "\xEF\xCF", "\xEF\xC8", "\xEF\xC9",
  /* U+9538 */	"\xEF\xCA", "\xC7\xC2", "\xEF\xF1", "\xB6\xCD",
  /* U+953C */	"\xEF\xCB", "\xE9\x42", "\xEF\xCC", "\xEF\xCD",
  /* U+9540 */	"\xB6\xC6", "\xC3\xBE", "\xEF\xCE", "\xE9\x43",
  /* U+9544 */	"\xEF\xD0", "\xEF\xD1", "\xEF\xD2", "\xD5\xF2",
  /* U+9548 */	"\xE9\x44", "\xEF\xD3", "\xC4\xF7", "\xE9\x45",
  /* U+954C */	"\xEF\xD4", "\xC4\xF8", "\xEF\xD5", "\xEF\xD6",
  /* U+9550 */	"\xB8\xE4", "\xB0\xF7", "\xEF\xD7", "\xEF\xD8",
  /* U+9554 */	"\xEF\xD9", "\xE9\x46", "\xEF\xDA", "\xEF\xDB",
  /* U+9558 */	"\xEF\xDC", "\xEF\xDD", "\xE9\x47", "\xEF\xDE",
  /* U+955C */	"\xBE\xB5", "\xEF\xE1", "\xEF\xDF", "\xEF\xE0",
  /* U+9560 */	"\xE9\x48", "\xEF\xE2", "\xEF\xE3", "\xC1\xCD",
  /* U+9564 */	"\xEF\xE4", "\xEF\xE5", "\xEF\xE6", "\xEF\xE7",
  /* U+9568 */	"\xEF\xE8", "\xEF\xE9", "\xEF\xEA", "\xEF\xEB",
  /* U+956C */	"\xEF\xEC", "\xC0\xD8", "\xE9\x49", "\xEF\xED",
  /* U+9570 */	"\xC1\xAD", "\xEF\xEE", "\xEF\xEF", "\xEF\xF0",
  /* U+9574 */	"\xE9\x4A", "\xE9\x4B", "\xCF\xE2", "\xE9\x4C",
  /* U+9578 */	"\xE9\x4D", "\xE9\x4E", "\xE9\x4F", "\xE9\x50",
  /* U+957C */	"\xE9\x51", "\xE9\x52", "\xE9\x53", "\xB3\xA4",
  /* U+9580 */	"\xE9\x54", "\xE9\x55", "\xE9\x56", "\xE9\x57",
  /* U+9584 */	"\xE9\x58", "\xE9\x59", "\xE9\x5A", "\xE9\x5B",
  /* U+9588 */	"\xE9\x5C", "\xE9\x5D", "\xE9\x5E", "\xE9\x5F",
  /* U+958C */	"\xE9\x60", "\xE9\x61", "\xE9\x62", "\xE9\x63",
  /* U+9590 */	"\xE9\x64", "\xE9\x65", "\xE9\x66", "\xE9\x67",
  /* U+9594 */	"\xE9\x68", "\xE9\x69", "\xE9\x6A", "\xE9\x6B",
  /* U+9598 */	"\xE9\x6C", "\xE9\x6D", "\xE9\x6E", "\xE9\x6F",
  /* U+959C */	"\xE9\x70", "\xE9\x71", "\xE9\x72", "\xE9\x73",
  /* U+95A0 */	"\xE9\x74", "\xE9\x75", "\xE9\x76", "\xE9\x77",
  /* U+95A4 */	"\xE9\x78", "\xE9\x79", "\xE9\x7A", "\xE9\x7B",
  /* U+95A8 */	"\xE9\x7C", "\xE9\x7D", "\xE9\x7E", "\xE9\x80",
  /* U+95AC */	"\xE9\x81", "\xE9\x82", "\xE9\x83", "\xE9\x84",
  /* U+95B0 */	"\xE9\x85", "\xE9\x86", "\xE9\x87", "\xE9\x88",
  /* U+95B4 */	"\xE9\x89", "\xE9\x8A", "\xE9\x8B", "\xE9\x8C",
  /* U+95B8 */	"\xE9\x8D", "\xE9\x8E", "\xE9\x8F", "\xE9\x90",
  /* U+95BC */	"\xE9\x91", "\xE9\x92", "\xE9\x93", "\xE9\x94",
  /* U+95C0 */	"\xE9\x95", "\xE9\x96", "\xE9\x97", "\xE9\x98",
  /* U+95C4 */	"\xE9\x99", "\xE9\x9A", "\xE9\x9B", "\xE9\x9C",
  /* U+95C8 */	"\xE9\x9D", "\xE9\x9E", "\xE9\x9F", "\xE9\xA0",
  /* U+95CC */	"\xEA\x40", "\xEA\x41", "\xEA\x42", "\xEA\x43",
  /* U+95D0 */	"\xEA\x44", "\xEA\x45", "\xEA\x46", "\xEA\x47",
  /* U+95D4 */	"\xEA\x48", "\xEA\x49", "\xEA\x4A", "\xEA\x4B",
  /* U+95D8 */	"\xEA\x4C", "\xEA\x4D", "\xEA\x4E", "\xEA\x4F",
  /* U+95DC */	"\xEA\x50", "\xEA\x51", "\xEA\x52", "\xEA\x53",
  /* U+95E0 */	"\xEA\x54", "\xEA\x55", "\xEA\x56", "\xEA\x57",
  /* U+95E4 */	"\xEA\x58", "\xEA\x59", "\xEA\x5A", "\xEA\x5B",
  /* U+95E8 */	"\xC3\xC5", "\xE3\xC5", "\xC9\xC1", "\xE3\xC6",
  /* U+95EC */	"\xEA\x5C", "\xB1\xD5", "\xCE\xCA", "\xB4\xB3",
  /* U+95F0 */	"\xC8\xF2", "\xE3\xC7", "\xCF\xD0", "\xE3\xC8",
  /* U+95F4 */	"\xBC\xE4", "\xE3\xC9", "\xE3\xCA", "\xC3\xC6",
  /* U+95F8 */	"\xD5\xA2", "\xC4\xD6", "\xB9\xEB", "\xCE\xC5",
  /* U+95FC */	"\xE3\xCB", "\xC3\xF6", "\xE3\xCC", "\xEA\x5D",
  /* U+9600 */	"\xB7\xA7", "\xB8\xF3", "\xBA\xD2", "\xE3\xCD",
  /* U+9604 */	"\xE3\xCE", "\xD4\xC4", "\xE3\xCF", "\xEA\x5E",
  /* U+9608 */	"\xE3\xD0", "\xD1\xCB", "\xE3\xD1", "\xE3\xD2",
  /* U+960C */	"\xE3\xD3", "\xE3\xD4", "\xD1\xD6", "\xE3\xD5",
  /* U+9610 */	"\xB2\xFB", "\xC0\xBB", "\xE3\xD6", "\xEA\x5F",
  /* U+9614 */	"\xC0\xAB", "\xE3\xD7", "\xE3\xD8", "\xE3\xD9",
  /* U+9618 */	"\xEA\x60", "\xE3\xDA", "\xE3\xDB", "\xEA\x61",
  /* U+961C */	"\xB8\xB7", "\xDA\xE2", "\xEA\x62", "\xB6\xD3",
  /* U+9620 */	"\xEA\x63", "\xDA\xE4", "\xDA\xE3", "\xEA\x64",
  /* U+9624 */	"\xEA\x65", "\xEA\x66", "\xEA\x67", "\xEA\x68",
  /* U+9628 */	"\xEA\x69", "\xEA\x6A", "\xDA\xE6", "\xEA\x6B",
  /* U+962C */	"\xEA\x6C", "\xEA\x6D", "\xC8\xEE", "\xEA\x6E",
  /* U+9630 */	"\xEA\x6F", "\xDA\xE5", "\xB7\xC0", "\xD1\xF4",
  /* U+9634 */	"\xD2\xF5", "\xD5\xF3", "\xBD\xD7", "\xEA\x70",
  /* U+9638 */	"\xEA\x71", "\xEA\x72", "\xEA\x73", "\xD7\xE8",
  /* U+963C */	"\xDA\xE8", "\xDA\xE7", "\xEA\x74", "\xB0\xA2",
  /* U+9640 */	"\xCD\xD3", "\xEA\x75", "\xDA\xE9", "\xEA\x76",
  /* U+9644 */	"\xB8\xBD", "\xBC\xCA", "\xC2\xBD", "\xC2\xA4",
  /* U+9648 */	"\xB3\xC2", "\xDA\xEA", "\xEA\x77", "\xC2\xAA",
  /* U+964C */	"\xC4\xB0", "\xBD\xB5", "\xEA\x78", "\xEA\x79",
  /* U+9650 */	"\xCF\xDE", "\xEA\x7A", "\xEA\x7B", "\xEA\x7C",
  /* U+9654 */	"\xDA\xEB", "\xC9\xC2", "\xEA\x7D", "\xEA\x7E",
  /* U+9658 */	"\xEA\x80", "\xEA\x81", "\xEA\x82", "\xB1\xDD",
  /* U+965C */	"\xEA\x83", "\xEA\x84", "\xEA\x85", "\xDA\xEC",
  /* U+9660 */	"\xEA\x86", "\xB6\xB8", "\xD4\xBA", "\xEA\x87",
  /* U+9664 */	"\xB3\xFD", "\xEA\x88", "\xEA\x89", "\xDA\xED",
  /* U+9668 */	"\xD4\xC9", "\xCF\xD5", "\xC5\xE3", "\xEA\x8A",
  /* U+966C */	"\xDA\xEE", "\xEA\x8B", "\xEA\x8C", "\xEA\x8D",
  /* U+9670 */	"\xEA\x8E", "\xEA\x8F", "\xDA\xEF", "\xEA\x90",
  /* U+9674 */	"\xDA\xF0", "\xC1\xEA", "\xCC\xD5", "\xCF\xDD",
  /* U+9678 */	"\xEA\x91", "\xEA\x92", "\xEA\x93", "\xEA\x94",
  /* U+967C */	"\xEA\x95", "\xEA\x96", "\xEA\x97", "\xEA\x98",
  /* U+9680 */	"\xEA\x99", "\xEA\x9A", "\xEA\x9B", "\xEA\x9C",
  /* U+9684 */	"\xEA\x9D", "\xD3\xE7", "\xC2\xA1", "\xEA\x9E",
  /* U+9688 */	"\xDA\xF1", "\xEA\x9F", "\xEA\xA0", "\xCB\xE5",
  /* U+968C */	"\xEB\x40", "\xDA\xF2", "\xEB\x41", "\xCB\xE6",
  /* U+9690 */	"\xD2\xFE", "\xEB\x42", "\xEB\x43", "\xEB\x44",
  /* U+9694 */	"\xB8\xF4", "\xEB\x45", "\xEB\x46", "\xDA\xF3",
  /* U+9698 */	"\xB0\xAF", "\xCF\xB6", "\xEB\x47", "\xEB\x48",
  /* U+969C */	"\xD5\xCF", "\xEB\x49", "\xEB\x4A", "\xEB\x4B",
  /* U+96A0 */	"\xEB\x4C", "\xEB\x4D", "\xEB\x4E", "\xEB\x4F",
  /* U+96A4 */	"\xEB\x50", "\xEB\x51", "\xEB\x52", "\xCB\xED",
  /* U+96A8 */	"\xEB\x53", "\xEB\x54", "\xEB\x55", "\xEB\x56",
  /* U+96AC */	"\xEB\x57", "\xEB\x58", "\xEB\x59", "\xEB\x5A",
  /* U+96B0 */	"\xDA\xF4", "\xEB\x5B", "\xEB\x5C", "\xE3\xC4",
  /* U+96B4 */	"\xEB\x5D", "\xEB\x5E", "\xC1\xA5", "\xEB\x5F",
  /* U+96B8 */	"\xEB\x60", "\xF6\xBF", "\xEB\x61", "\xEB\x62",
  /* U+96BC */	"\xF6\xC0", "\xF6\xC1", "\xC4\xD1", "\xEB\x63",
  /* U+96C0 */	"\xC8\xB8", "\xD1\xE3", "\xEB\x64", "\xEB\x65",
  /* U+96C4 */	"\xD0\xDB", "\xD1\xC5", "\xBC\xAF", "\xB9\xCD",
  /* U+96C8 */	"\xEB\x66", "\xEF\xF4", "\xEB\x67", "\xEB\x68",
  /* U+96CC */	"\xB4\xC6", "\xD3\xBA", "\xF6\xC2", "\xB3\xFB",
  /* U+96D0 */	"\xEB\x69", "\xEB\x6A", "\xF6\xC3", "\xEB\x6B",
  /* U+96D4 */	"\xEB\x6C", "\xB5\xF1", "\xEB\x6D", "\xEB\x6E",
  /* U+96D8 */	"\xEB\x6F", "\xEB\x70", "\xEB\x71", "\xEB\x72",
  /* U+96DC */	"\xEB\x73", "\xEB\x74", "\xEB\x75", "\xEB\x76",
  /* U+96E0 */	"\xF6\xC5", "\xEB\x77", "\xEB\x78", "\xEB\x79",
  /* U+96E4 */	"\xEB\x7A", "\xEB\x7B", "\xEB\x7C", "\xEB\x7D",
  /* U+96E8 */	"\xD3\xEA", "\xF6\xA7", "\xD1\xA9", "\xEB\x7E",
  /* U+96EC */	"\xEB\x80", "\xEB\x81", "\xEB\x82", "\xF6\xA9",
  /* U+96F0 */	"\xEB\x83", "\xEB\x84", "\xEB\x85", "\xF6\xA8",
  /* U+96F4 */	"\xEB\x86", "\xEB\x87", "\xC1\xE3", "\xC0\xD7",
  /* U+96F8 */	"\xEB\x88", "\xB1\xA2", "\xEB\x89", "\xEB\x8A",
  /* U+96FC */	"\xEB\x8B", "\xEB\x8C", "\xCE\xED", "\xEB\x8D",
  /* U+9700 */	"\xD0\xE8", "\xF6\xAB", "\xEB\x8E", "\xEB\x8F",
  /* U+9704 */	"\xCF\xF6", "\xEB\x90", "\xF6\xAA", "\xD5\xF0",
  /* U+9708 */	"\xF6\xAC", "\xC3\xB9", "\xEB\x91", "\xEB\x92",
  /* U+970C */	"\xEB\x93", "\xBB\xF4", "\xF6\xAE", "\xF6\xAD",
  /* U+9710 */	"\xEB\x94", "\xEB\x95", "\xEB\x96", "\xC4\xDE",
  /* U+9714 */	"\xEB\x97", "\xEB\x98", "\xC1\xD8", "\xEB\x99",
  /* U+9718 */	"\xEB\x9A", "\xEB\x9B", "\xEB\x9C", "\xEB\x9D",
  /* U+971C */	"\xCB\xAA", "\xEB\x9E", "\xCF\xBC", "\xEB\x9F",
  /* U+9720 */	"\xEB\xA0", "\xEC\x40", "\xEC\x41", "\xEC\x42",
  /* U+9724 */	"\xEC\x43", "\xEC\x44", "\xEC\x45", "\xEC\x46",
  /* U+9728 */	"\xEC\x47", "\xEC\x48", "\xF6\xAF", "\xEC\x49",
  /* U+972C */	"\xEC\x4A", "\xF6\xB0", "\xEC\x4B", "\xEC\x4C",
  /* U+9730 */	"\xF6\xB1", "\xEC\x4D", "\xC2\xB6", "\xEC\x4E",
  /* U+9734 */	"\xEC\x4F", "\xEC\x50", "\xEC\x51", "\xEC\x52",
  /* U+9738 */	"\xB0\xD4", "\xC5\xF9", "\xEC\x53", "\xEC\x54",
  /* U+973C */	"\xEC\x55", "\xEC\x56", "\xF6\xB2", "\xEC\x57",
  /* U+9740 */	"\xEC\x58", "\xEC\x59", "\xEC\x5A", "\xEC\x5B",
  /* U+9744 */	"\xEC\x5C", "\xEC\x5D", "\xEC\x5E", "\xEC\x5F",
  /* U+9748 */	"\xEC\x60", "\xEC\x61", "\xEC\x62", "\xEC\x63",
  /* U+974C */	"\xEC\x64", "\xEC\x65", "\xEC\x66", "\xEC\x67",
  /* U+9750 */	"\xEC\x68", "\xEC\x69", "\xC7\xE0", "\xF6\xA6",
  /* U+9754 */	"\xEC\x6A", "\xEC\x6B", "\xBE\xB8", "\xEC\x6C",
  /* U+9758 */	"\xEC\x6D", "\xBE\xB2", "\xEC\x6E", "\xB5\xE5",
  /* U+975C */	"\xEC\x6F", "\xEC\x70", "\xB7\xC7", "\xEC\x71",
  /* U+9760 */	"\xBF\xBF", "\xC3\xD2", "\xC3\xE6", "\xEC\x72",
  /* U+9764 */	"\xEC\x73", "\xD8\xCC", "\xEC\x74", "\xEC\x75",
  /* U+9768 */	"\xEC\x76", "\xB8\xEF", "\xEC\x77", "\xEC\x78",
  /* U+976C */	"\xEC\x79", "\xEC\x7A", "\xEC\x7B", "\xEC\x7C",
  /* U+9770 */	"\xEC\x7D", "\xEC\x7E", "\xEC\x80", "\xBD\xF9",
  /* U+9774 */	"\xD1\xA5", "\xEC\x81", "\xB0\xD0", "\xEC\x82",
  /* U+9778 */	"\xEC\x83", "\xEC\x84", "\xEC\x85", "\xEC\x86",
  /* U+977C */	"\xF7\xB0", "\xEC\x87", "\xEC\x88", "\xEC\x89",
  /* U+9780 */	"\xEC\x8A", "\xEC\x8B", "\xEC\x8C", "\xEC\x8D",
  /* U+9784 */	"\xEC\x8E", "\xF7\xB1", "\xEC\x8F", "\xEC\x90",
  /* U+9788 */	"\xEC\x91", "\xEC\x92", "\xEC\x93", "\xD0\xAC",
  /* U+978C */	"\xEC\x94", "\xB0\xB0", "\xEC\x95", "\xEC\x96",
  /* U+9790 */	"\xEC\x97", "\xF7\xB2", "\xF7\xB3", "\xEC\x98",
  /* U+9794 */	"\xF7\xB4", "\xEC\x99", "\xEC\x9A", "\xEC\x9B",
  /* U+9798 */	"\xC7\xCA", "\xEC\x9C", "\xEC\x9D", "\xEC\x9E",
  /* U+979C */	"\xEC\x9F", "\xEC\xA0", "\xED\x40", "\xED\x41",
  /* U+97A0 */	"\xBE\xCF", "\xED\x42", "\xED\x43", "\xF7\xB7",
  /* U+97A4 */	"\xED\x44", "\xED\x45", "\xED\x46", "\xED\x47",
  /* U+97A8 */	"\xED\x48", "\xED\x49", "\xED\x4A", "\xF7\xB6",
  /* U+97AC */	"\xED\x4B", "\xB1\xDE", "\xED\x4C", "\xF7\xB5",
  /* U+97B0 */	"\xED\x4D", "\xED\x4E", "\xF7\xB8", "\xED\x4F",
  /* U+97B4 */	"\xF7\xB9", "\xED\x50", "\xED\x51", "\xED\x52",
  /* U+97B8 */	"\xED\x53", "\xED\x54", "\xED\x55", "\xED\x56",
  /* U+97BC */	"\xED\x57", "\xED\x58", "\xED\x59", "\xED\x5A",
  /* U+97C0 */	"\xED\x5B", "\xED\x5C", "\xED\x5D", "\xED\x5E",
  /* U+97C4 */	"\xED\x5F", "\xED\x60", "\xED\x61", "\xED\x62",
  /* U+97C8 */	"\xED\x63", "\xED\x64", "\xED\x65", "\xED\x66",
  /* U+97CC */	"\xED\x67", "\xED\x68", "\xED\x69", "\xED\x6A",
  /* U+97D0 */	"\xED\x6B", "\xED\x6C", "\xED\x6D", "\xED\x6E",
  /* U+97D4 */	"\xED\x6F", "\xED\x70", "\xED\x71", "\xED\x72",
  /* U+97D8 */	"\xED\x73", "\xED\x74", "\xED\x75", "\xED\x76",
  /* U+97DC */	"\xED\x77", "\xED\x78", "\xED\x79", "\xED\x7A",
  /* U+97E0 */	"\xED\x7B", "\xED\x7C", "\xED\x7D", "\xED\x7E",
  /* U+97E4 */	"\xED\x80", "\xED\x81", "\xCE\xA4", "\xC8\xCD",
  /* U+97E8 */	"\xED\x82", "\xBA\xAB", "\xE8\xB8", "\xE8\xB9",
  /* U+97EC */	"\xE8\xBA", "\xBE\xC2", "\xED\x83", "\xED\x84",
  /* U+97F0 */	"\xED\x85", "\xED\x86", "\xED\x87", "\xD2\xF4",
  /* U+97F4 */	"\xED\x88", "\xD4\xCF", "\xC9\xD8", "\xED\x89",
  /* U+97F8 */	"\xED\x8A", "\xED\x8B", "\xED\x8C", "\xED\x8D",
  /* U+97FC */	"\xED\x8E", "\xED\x8F", "\xED\x90", "\xED\x91",
  /* U+9800 */	"\xED\x92", "\xED\x93", "\xED\x94", "\xED\x95",
  /* U+9804 */	"\xED\x96", "\xED\x97", "\xED\x98", "\xED\x99",
  /* U+9808 */	"\xED\x9A", "\xED\x9B", "\xED\x9C", "\xED\x9D",
  /* U+980C */	"\xED\x9E", "\xED\x9F", "\xED\xA0", "\xEE\x40",
  /* U+9810 */	"\xEE\x41", "\xEE\x42", "\xEE\x43", "\xEE\x44",
  /* U+9814 */	"\xEE\x45", "\xEE\x46", "\xEE\x47", "\xEE\x48",
  /* U+9818 */	"\xEE\x49", "\xEE\x4A", "\xEE\x4B", "\xEE\x4C",
  /* U+981C */	"\xEE\x4D", "\xEE\x4E", "\xEE\x4F", "\xEE\x50",
  /* U+9820 */	"\xEE\x51", "\xEE\x52", "\xEE\x53", "\xEE\x54",
  /* U+9824 */	"\xEE\x55", "\xEE\x56", "\xEE\x57", "\xEE\x58",
  /* U+9828 */	"\xEE\x59", "\xEE\x5A", "\xEE\x5B", "\xEE\x5C",
  /* U+982C */	"\xEE\x5D", "\xEE\x5E", "\xEE\x5F", "\xEE\x60",
  /* U+9830 */	"\xEE\x61", "\xEE\x62", "\xEE\x63", "\xEE\x64",
  /* U+9834 */	"\xEE\x65", "\xEE\x66", "\xEE\x67", "\xEE\x68",
  /* U+9838 */	"\xEE\x69", "\xEE\x6A", "\xEE\x6B", "\xEE\x6C",
  /* U+983C */	"\xEE\x6D", "\xEE\x6E", "\xEE\x6F", "\xEE\x70",
  /* U+9840 */	"\xEE\x71", "\xEE\x72", "\xEE\x73", "\xEE\x74",
  /* U+9844 */	"\xEE\x75", "\xEE\x76", "\xEE\x77", "\xEE\x78",
  /* U+9848 */	"\xEE\x79", "\xEE\x7A", "\xEE\x7B", "\xEE\x7C",
  /* U+984C */	"\xEE\x7D", "\xEE\x7E", "\xEE\x80", "\xEE\x81",
  /* U+9850 */	"\xEE\x82", "\xEE\x83", "\xEE\x84", "\xEE\x85",
  /* U+9854 */	"\xEE\x86", "\xEE\x87", "\xEE\x88", "\xEE\x89",
  /* U+9858 */	"\xEE\x8A", "\xEE\x8B", "\xEE\x8C", "\xEE\x8D",
  /* U+985C */	"\xEE\x8E", "\xEE\x8F", "\xEE\x90", "\xEE\x91",
  /* U+9860 */	"\xEE\x92", "\xEE\x93", "\xEE\x94", "\xEE\x95",
  /* U+9864 */	"\xEE\x96", "\xEE\x97", "\xEE\x98", "\xEE\x99",
  /* U+9868 */	"\xEE\x9A", "\xEE\x9B", "\xEE\x9C", "\xEE\x9D",
  /* U+986C */	"\xEE\x9E", "\xEE\x9F", "\xEE\xA0", "\xEF\x40",
  /* U+9870 */	"\xEF\x41", "\xEF\x42", "\xEF\x43", "\xEF\x44",
  /* U+9874 */	"\xEF\x45", "\xD2\xB3", "\xB6\xA5", "\xC7\xEA",
  /* U+9878 */	"\xF1\xFC", "\xCF\xEE", "\xCB\xB3", "\xD0\xEB",
  /* U+987C */	"\xE7\xEF", "\xCD\xE7", "\xB9\xCB", "\xB6\xD9",
  /* U+9880 */	"\xF1\xFD", "\xB0\xE4", "\xCB\xCC", "\xF1\xFE",
  /* U+9884 */	"\xD4\xA4", "\xC2\xAD", "\xC1\xEC", "\xC6\xC4",
  /* U+9888 */	"\xBE\xB1", "\xF2\xA1", "\xBC\xD5", "\xEF\x46",
  /* U+988C */	"\xF2\xA2", "\xF2\xA3", "\xEF\x47", "\xF2\xA4",
  /* U+9890 */	"\xD2\xC3", "\xC6\xB5", "\xEF\x48", "\xCD\xC7",
  /* U+9894 */	"\xF2\xA5", "\xEF\x49", "\xD3\xB1", "\xBF\xC5",
  /* U+9898 */	"\xCC\xE2", "\xEF\x4A", "\xF2\xA6", "\xF2\xA7",
  /* U+989C */	"\xD1\xD5", "\xB6\xEE", "\xF2\xA8", "\xF2\xA9",
  /* U+98A0 */	"\xB5\xDF", "\xF2\xAA", "\xF2\xAB", "\xEF\x4B",
  /* U+98A4 */	"\xB2\xFC", "\xF2\xAC", "\xF2\xAD", "\xC8\xA7",
  /* U+98A8 */	"\xEF\x4C", "\xEF\x4D", "\xEF\x4E", "\xEF\x4F",
  /* U+98AC */	"\xEF\x50", "\xEF\x51", "\xEF\x52", "\xEF\x53",
  /* U+98B0 */	"\xEF\x54", "\xEF\x55", "\xEF\x56", "\xEF\x57",
  /* U+98B4 */	"\xEF\x58", "\xEF\x59", "\xEF\x5A", "\xEF\x5B",
  /* U+98B8 */	"\xEF\x5C", "\xEF\x5D", "\xEF\x5E", "\xEF\x5F",
  /* U+98BC */	"\xEF\x60", "\xEF\x61", "\xEF\x62", "\xEF\x63",
  /* U+98C0 */	"\xEF\x64", "\xEF\x65", "\xEF\x66", "\xEF\x67",
  /* U+98C4 */	"\xEF\x68", "\xEF\x69", "\xEF\x6A", "\xEF\x6B",
  /* U+98C8 */	"\xEF\x6C", "\xEF\x6D", "\xEF\x6E", "\xEF\x6F",
  /* U+98CC */	"\xEF\x70", "\xEF\x71", "\xB7\xE7", "\xEF\x72",
  /* U+98D0 */	"\xEF\x73", "\xEC\xA9", "\xEC\xAA", "\xEC\xAB",
  /* U+98D4 */	"\xEF\x74", "\xEC\xAC", "\xEF\x75", "\xEF\x76",
  /* U+98D8 */	"\xC6\xAE", "\xEC\xAD", "\xEC\xAE", "\xEF\x77",
  /* U+98DC */	"\xEF\x78", "\xEF\x79", "\xB7\xC9", "\xCA\xB3",
  /* U+98E0 */	"\xEF\x7A", "\xEF\x7B", "\xEF\x7C", "\xEF\x7D",
  /* U+98E4 */	"\xEF\x7E", "\xEF\x80", "\xEF\x81", "\xE2\xB8",
  /* U+98E8 */	"\xF7\xCF", "\xEF\x82", "\xEF\x83", "\xEF\x84",
  /* U+98EC */	"\xEF\x85", "\xEF\x86", "\xEF\x87", "\xEF\x88",
  /* U+98F0 */	"\xEF\x89", "\xEF\x8A", "\xEF\x8B", "\xEF\x8C",
  /* U+98F4 */	"\xEF\x8D", "\xEF\x8E", "\xEF\x8F", "\xEF\x90",
  /* U+98F8 */	"\xEF\x91", "\xEF\x92", "\xEF\x93", "\xEF\x94",
  /* U+98FC */	"\xEF\x95", "\xEF\x96", "\xEF\x97", "\xEF\x98",
  /* U+9900 */	"\xEF\x99", "\xEF\x9A", "\xEF\x9B", "\xEF\x9C",
  /* U+9904 */	"\xEF\x9D", "\xEF\x9E", "\xEF\x9F", "\xEF\xA0",
  /* U+9908 */	"\xF0\x40", "\xF0\x41", "\xF0\x42", "\xF0\x43",
  /* U+990C */	"\xF0\x44", "\xF7\xD0", "\xF0\x45", "\xF0\x46",
  /* U+9910 */	"\xB2\xCD", "\xF0\x47", "\xF0\x48", "\xF0\x49",
  /* U+9914 */	"\xF0\x4A", "\xF0\x4B", "\xF0\x4C", "\xF0\x4D",
  /* U+9918 */	"\xF0\x4E", "\xF0\x4F", "\xF0\x50", "\xF0\x51",
  /* U+991C */	"\xF0\x52", "\xF0\x53", "\xF0\x54", "\xF0\x55",
  /* U+9920 */	"\xF0\x56", "\xF0\x57", "\xF0\x58", "\xF0\x59",
  /* U+9924 */	"\xF0\x5A", "\xF0\x5B", "\xF0\x5C", "\xF0\x5D",
  /* U+9928 */	"\xF0\x5E", "\xF0\x5F", "\xF0\x60", "\xF0\x61",
  /* U+992C */	"\xF0\x62", "\xF0\x63", "\xF7\xD1", "\xF0\x64",
  /* U+9930 */	"\xF0\x65", "\xF0\x66", "\xF0\x67", "\xF0\x68",
  /* U+9934 */	"\xF0\x69", "\xF0\x6A", "\xF0\x6B", "\xF0\x6C",
  /* U+9938 */	"\xF0\x6D", "\xF0\x6E", "\xF0\x6F", "\xF0\x70",
  /* U+993C */	"\xF0\x71", "\xF0\x72", "\xF0\x73", "\xF0\x74",
  /* U+9940 */	"\xF0\x75", "\xF0\x76", "\xF0\x77", "\xF0\x78",
  /* U+9944 */	"\xF0\x79", "\xF0\x7A", "\xF0\x7B", "\xF0\x7C",
  /* U+9948 */	"\xF0\x7D", "\xF0\x7E", "\xF0\x80", "\xF0\x81",
  /* U+994C */	"\xF0\x82", "\xF0\x83", "\xF0\x84", "\xF0\x85",
  /* U+9950 */	"\xF0\x86", "\xF0\x87", "\xF0\x88", "\xF0\x89",
  /* U+9954 */	"\xF7\xD3", "\xF7\xD2", "\xF0\x8A", "\xF0\x8B",
  /* U+9958 */	"\xF0\x8C", "\xF0\x8D", "\xF0\x8E", "\xF0\x8F",
  /* U+995C */	"\xF0\x90", "\xF0\x91", "\xF0\x92", "\xF0\x93",
  /* U+9960 */	"\xF0\x94", "\xF0\x95", "\xF0\x96", "\xE2\xBB",
  /* U+9964 */	"\xF0\x97", "\xBC\xA2", "\xF0\x98", "\xE2\xBC",
  /* U+9968 */	"\xE2\xBD", "\xE2\xBE", "\xE2\xBF", "\xE2\xC0",
  /* U+996C */	"\xE2\xC1", "\xB7\xB9", "\xD2\xFB", "\xBD\xA4",
  /* U+9970 */	"\xCA\xCE", "\xB1\xA5", "\xCB\xC7", "\xF0\x99",
  /* U+9974 */	"\xE2\xC2", "\xB6\xFC", "\xC8\xC4", "\xE2\xC3",
  /* U+9978 */	"\xF0\x9A", "\xF0\x9B", "\xBD\xC8", "\xF0\x9C",
  /* U+997C */	"\xB1\xFD", "\xE2\xC4", "\xF0\x9D", "\xB6\xF6",
  /* U+9980 */	"\xE2\xC5", "\xC4\xD9", "\xF0\x9E", "\xF0\x9F",
  /* U+9984 */	"\xE2\xC6", "\xCF\xDA", "\xB9\xDD", "\xE2\xC7",
  /* U+9988 */	"\xC0\xA1", "\xF0\xA0", "\xE2\xC8", "\xB2\xF6",
  /* U+998C */	"\xF1\x40", "\xE2\xC9", "\xF1\x41", "\xC1\xF3",
  /* U+9990 */	"\xE2\xCA", "\xE2\xCB", "\xC2\xF8", "\xE2\xCC",
  /* U+9994 */	"\xE2\xCD", "\xE2\xCE", "\xCA\xD7", "\xD8\xB8",
  /* U+9998 */	"\xD9\xE5", "\xCF\xE3", "\xF1\x42", "\xF1\x43",
  /* U+999C */	"\xF1\x44", "\xF1\x45", "\xF1\x46", "\xF1\x47",
  /* U+99A0 */	"\xF1\x48", "\xF1\x49", "\xF1\x4A", "\xF1\x4B",
  /* U+99A4 */	"\xF1\x4C", "\xF0\xA5", "\xF1\x4D", "\xF1\x4E",
  /* U+99A8 */	"\xDC\xB0", "\xF1\x4F", "\xF1\x50", "\xF1\x51",
  /* U+99AC */	"\xF1\x52", "\xF1\x53", "\xF1\x54", "\xF1\x55",
  /* U+99B0 */	"\xF1\x56", "\xF1\x57", "\xF1\x58", "\xF1\x59",
  /* U+99B4 */	"\xF1\x5A", "\xF1\x5B", "\xF1\x5C", "\xF1\x5D",
  /* U+99B8 */	"\xF1\x5E", "\xF1\x5F", "\xF1\x60", "\xF1\x61",
  /* U+99BC */	"\xF1\x62", "\xF1\x63", "\xF1\x64", "\xF1\x65",
  /* U+99C0 */	"\xF1\x66", "\xF1\x67", "\xF1\x68", "\xF1\x69",
  /* U+99C4 */	"\xF1\x6A", "\xF1\x6B", "\xF1\x6C", "\xF1\x6D",
  /* U+99C8 */	"\xF1\x6E", "\xF1\x6F", "\xF1\x70", "\xF1\x71",
  /* U+99CC */	"\xF1\x72", "\xF1\x73", "\xF1\x74", "\xF1\x75",
  /* U+99D0 */	"\xF1\x76", "\xF1\x77", "\xF1\x78", "\xF1\x79",
  /* U+99D4 */	"\xF1\x7A", "\xF1\x7B", "\xF1\x7C", "\xF1\x7D",
  /* U+99D8 */	"\xF1\x7E", "\xF1\x80", "\xF1\x81", "\xF1\x82",
  /* U+99DC */	"\xF1\x83", "\xF1\x84", "\xF1\x85", "\xF1\x86",
  /* U+99E0 */	"\xF1\x87", "\xF1\x88", "\xF1\x89", "\xF1\x8A",
  /* U+99E4 */	"\xF1\x8B", "\xF1\x8C", "\xF1\x8D", "\xF1\x8E",
  /* U+99E8 */	"\xF1\x8F", "\xF1\x90", "\xF1\x91", "\xF1\x92",
  /* U+99EC */	"\xF1\x93", "\xF1\x94", "\xF1\x95", "\xF1\x96",
  /* U+99F0 */	"\xF1\x97", "\xF1\x98", "\xF1\x99", "\xF1\x9A",
  /* U+99F4 */	"\xF1\x9B", "\xF1\x9C", "\xF1\x9D", "\xF1\x9E",
  /* U+99F8 */	"\xF1\x9F", "\xF1\xA0", "\xF2\x40", "\xF2\x41",
  /* U+99FC */	"\xF2\x42", "\xF2\x43", "\xF2\x44", "\xF2\x45",
  /* U+9A00 */	"\xF2\x46", "\xF2\x47", "\xF2\x48", "\xF2\x49",
  /* U+9A04 */	"\xF2\x4A", "\xF2\x4B", "\xF2\x4C", "\xF2\x4D",
  /* U+9A08 */	"\xF2\x4E", "\xF2\x4F", "\xF2\x50", "\xF2\x51",
  /* U+9A0C */	"\xF2\x52", "\xF2\x53", "\xF2\x54", "\xF2\x55",
  /* U+9A10 */	"\xF2\x56", "\xF2\x57", "\xF2\x58", "\xF2\x59",
  /* U+9A14 */	"\xF2\x5A", "\xF2\x5B", "\xF2\x5C", "\xF2\x5D",
  /* U+9A18 */	"\xF2\x5E", "\xF2\x5F", "\xF2\x60", "\xF2\x61",
  /* U+9A1C */	"\xF2\x62", "\xF2\x63", "\xF2\x64", "\xF2\x65",
  /* U+9A20 */	"\xF2\x66", "\xF2\x67", "\xF2\x68", "\xF2\x69",
  /* U+9A24 */	"\xF2\x6A", "\xF2\x6B", "\xF2\x6C", "\xF2\x6D",
  /* U+9A28 */	"\xF2\x6E", "\xF2\x6F", "\xF2\x70", "\xF2\x71",
  /* U+9A2C */	"\xF2\x72", "\xF2\x73", "\xF2\x74", "\xF2\x75",
  /* U+9A30 */	"\xF2\x76", "\xF2\x77", "\xF2\x78", "\xF2\x79",
  /* U+9A34 */	"\xF2\x7A", "\xF2\x7B", "\xF2\x7C", "\xF2\x7D",
  /* U+9A38 */	"\xF2\x7E", "\xF2\x80", "\xF2\x81", "\xF2\x82",
  /* U+9A3C */	"\xF2\x83", "\xF2\x84", "\xF2\x85", "\xF2\x86",
  /* U+9A40 */	"\xF2\x87", "\xF2\x88", "\xF2\x89", "\xF2\x8A",
  /* U+9A44 */	"\xF2\x8B", "\xF2\x8C", "\xF2\x8D", "\xF2\x8E",
  /* U+9A48 */	"\xF2\x8F", "\xF2\x90", "\xF2\x91", "\xF2\x92",
  /* U+9A4C */	"\xF2\x93", "\xF2\x94", "\xF2\x95", "\xF2\x96",
  /* U+9A50 */	"\xF2\x97", "\xF2\x98", "\xF2\x99", "\xF2\x9A",
  /* U+9A54 */	"\xF2\x9B", "\xF2\x9C", "\xF2\x9D", "\xF2\x9E",
  /* U+9A58 */	"\xF2\x9F", "\xF2\xA0", "\xF3\x40", "\xF3\x41",
  /* U+9A5C */	"\xF3\x42", "\xF3\x43", "\xF3\x44", "\xF3\x45",
  /* U+9A60 */	"\xF3\x46", "\xF3\x47", "\xF3\x48", "\xF3\x49",
  /* U+9A64 */	"\xF3\x4A", "\xF3\x4B", "\xF3\x4C", "\xF3\x4D",
  /* U+9A68 */	"\xF3\x4E", "\xF3\x4F", "\xF3\x50", "\xF3\x51",
  /* U+9A6C */	"\xC2\xED", "\xD4\xA6", "\xCD\xD4", "\xD1\xB1",
  /* U+9A70 */	"\xB3\xDB", "\xC7\xFD", "\xF3\x52", "\xB2\xB5",
  /* U+9A74 */	"\xC2\xBF", "\xE6\xE0", "\xCA\xBB", "\xE6\xE1",
  /* U+9A78 */	"\xE6\xE2", "\xBE\xD4", "\xE6\xE3", "\xD7\xA4",
  /* U+9A7C */	"\xCD\xD5", "\xE6\xE5", "\xBC\xDD", "\xE6\xE4",
  /* U+9A80 */	"\xE6\xE6", "\xE6\xE7", "\xC2\xEE", "\xF3\x53",
  /* U+9A84 */	"\xBD\xBE", "\xE6\xE8", "\xC2\xE6", "\xBA\xA7",
  /* U+9A88 */	"\xE6\xE9", "\xF3\x54", "\xE6\xEA", "\xB3\xD2",
  /* U+9A8C */	"\xD1\xE9", "\xF3\x55", "\xF3\x56", "\xBF\xA5",
  /* U+9A90 */	"\xE6\xEB", "\xC6\xEF", "\xE6\xEC", "\xE6\xED",
  /* U+9A94 */	"\xF3\x57", "\xF3\x58", "\xE6\xEE", "\xC6\xAD",
  /* U+9A98 */	"\xE6\xEF", "\xF3\x59", "\xC9\xA7", "\xE6\xF0",
  /* U+9A9C */	"\xE6\xF1", "\xE6\xF2", "\xE5\xB9", "\xE6\xF3",
  /* U+9AA0 */	"\xE6\xF4", "\xC2\xE2", "\xE6\xF5", "\xE6\xF6",
  /* U+9AA4 */	"\xD6\xE8", "\xE6\xF7", "\xF3\x5A", "\xE6\xF8",
  /* U+9AA8 */	"\xB9\xC7", "\xF3\x5B", "\xF3\x5C", "\xF3\x5D",
  /* U+9AAC */	"\xF3\x5E", "\xF3\x5F", "\xF3\x60", "\xF3\x61",
  /* U+9AB0 */	"\xF7\xBB", "\xF7\xBA", "\xF3\x62", "\xF3\x63",
  /* U+9AB4 */	"\xF3\x64", "\xF3\x65", "\xF7\xBE", "\xF7\xBC",
  /* U+9AB8 */	"\xBA\xA1", "\xF3\x66", "\xF7\xBF", "\xF3\x67",
  /* U+9ABC */	"\xF7\xC0", "\xF3\x68", "\xF3\x69", "\xF3\x6A",
  /* U+9AC0 */	"\xF7\xC2", "\xF7\xC1", "\xF7\xC4", "\xF3\x6B",
  /* U+9AC4 */	"\xF3\x6C", "\xF7\xC3", "\xF3\x6D", "\xF3\x6E",
  /* U+9AC8 */	"\xF3\x6F", "\xF3\x70", "\xF3\x71", "\xF7\xC5",
  /* U+9ACC */	"\xF7\xC6", "\xF3\x72", "\xF3\x73", "\xF3\x74",
  /* U+9AD0 */	"\xF3\x75", "\xF7\xC7", "\xF3\x76", "\xCB\xE8",
  /* U+9AD4 */	"\xF3\x77", "\xF3\x78", "\xF3\x79", "\xF3\x7A",
  /* U+9AD8 */	"\xB8\xDF", "\xF3\x7B", "\xF3\x7C", "\xF3\x7D",
  /* U+9ADC */	"\xF3\x7E", "\xF3\x80", "\xF3\x81", "\xF7\xD4",
  /* U+9AE0 */	"\xF3\x82", "\xF7\xD5", "\xF3\x83", "\xF3\x84",
  /* U+9AE4 */	"\xF3\x85", "\xF3\x86", "\xF7\xD6", "\xF3\x87",
  /* U+9AE8 */	"\xF3\x88", "\xF3\x89", "\xF3\x8A", "\xF7\xD8",
  /* U+9AEC */	"\xF3\x8B", "\xF7\xDA", "\xF3\x8C", "\xF7\xD7",
  /* U+9AF0 */	"\xF3\x8D", "\xF3\x8E", "\xF3\x8F", "\xF3\x90",
  /* U+9AF4 */	"\xF3\x91", "\xF3\x92", "\xF3\x93", "\xF3\x94",
  /* U+9AF8 */	"\xF3\x95", "\xF7\xDB", "\xF3\x96", "\xF7\xD9",
  /* U+9AFC */	"\xF3\x97", "\xF3\x98", "\xF3\x99", "\xF3\x9A",
  /* U+9B00 */	"\xF3\x9B", "\xF3\x9C", "\xF3\x9D", "\xD7\xD7",
  /* U+9B04 */	"\xF3\x9E", "\xF3\x9F", "\xF3\xA0", "\xF4\x40",
  /* U+9B08 */	"\xF7\xDC", "\xF4\x41", "\xF4\x42", "\xF4\x43",
  /* U+9B0C */	"\xF4\x44", "\xF4\x45", "\xF4\x46", "\xF7\xDD",
  /* U+9B10 */	"\xF4\x47", "\xF4\x48", "\xF4\x49", "\xF7\xDE",
  /* U+9B14 */	"\xF4\x4A", "\xF4\x4B", "\xF4\x4C", "\xF4\x4D",
  /* U+9B18 */	"\xF4\x4E", "\xF4\x4F", "\xF4\x50", "\xF4\x51",
  /* U+9B1C */	"\xF4\x52", "\xF4\x53", "\xF4\x54", "\xF7\xDF",
  /* U+9B20 */	"\xF4\x55", "\xF4\x56", "\xF4\x57", "\xF7\xE0",
  /* U+9B24 */	"\xF4\x58", "\xF4\x59", "\xF4\x5A", "\xF4\x5B",
  /* U+9B28 */	"\xF4\x5C", "\xF4\x5D", "\xF4\x5E", "\xF4\x5F",
  /* U+9B2C */	"\xF4\x60", "\xF4\x61", "\xF4\x62", "\xDB\xCB",
  /* U+9B30 */	"\xF4\x63", "\xF4\x64", "\xD8\xAA", "\xF4\x65",
  /* U+9B34 */	"\xF4\x66", "\xF4\x67", "\xF4\x68", "\xF4\x69",
  /* U+9B38 */	"\xF4\x6A", "\xF4\x6B", "\xF4\x6C", "\xE5\xF7",
  /* U+9B3C */	"\xB9\xED", "\xF4\x6D", "\xF4\x6E", "\xF4\x6F",
  /* U+9B40 */	"\xF4\x70", "\xBF\xFD", "\xBB\xEA", "\xF7\xC9",
  /* U+9B44 */	"\xC6\xC7", "\xF7\xC8", "\xF4\x71", "\xF7\xCA",
  /* U+9B48 */	"\xF7\xCC", "\xF7\xCB", "\xF4\x72", "\xF4\x73",
  /* U+9B4C */	"\xF4\x74", "\xF7\xCD", "\xF4\x75", "\xCE\xBA",
  /* U+9B50 */	"\xF4\x76", "\xF7\xCE", "\xF4\x77", "\xF4\x78",
  /* U+9B54 */	"\xC4\xA7", "\xF4\x79", "\xF4\x7A", "\xF4\x7B",
  /* U+9B58 */	"\xF4\x7C", "\xF4\x7D", "\xF4\x7E", "\xF4\x80",
  /* U+9B5C */	"\xF4\x81", "\xF4\x82", "\xF4\x83", "\xF4\x84",
  /* U+9B60 */	"\xF4\x85", "\xF4\x86", "\xF4\x87", "\xF4\x88",
  /* U+9B64 */	"\xF4\x89", "\xF4\x8A", "\xF4\x8B", "\xF4\x8C",
  /* U+9B68 */	"\xF4\x8D", "\xF4\x8E", "\xF4\x8F", "\xF4\x90",
  /* U+9B6C */	"\xF4\x91", "\xF4\x92", "\xF4\x93", "\xF4\x94",
  /* U+9B70 */	"\xF4\x95", "\xF4\x96", "\xF4\x97", "\xF4\x98",
  /* U+9B74 */	"\xF4\x99", "\xF4\x9A", "\xF4\x9B", "\xF4\x9C",
  /* U+9B78 */	"\xF4\x9D", "\xF4\x9E", "\xF4\x9F", "\xF4\xA0",
  /* U+9B7C */	"\xF5\x40", "\xF5\x41", "\xF5\x42", "\xF5\x43",
  /* U+9B80 */	"\xF5\x44", "\xF5\x45", "\xF5\x46", "\xF5\x47",
  /* U+9B84 */	"\xF5\x48", "\xF5\x49", "\xF5\x4A", "\xF5\x4B",
  /* U+9B88 */	"\xF5\x4C", "\xF5\x4D", "\xF5\x4E", "\xF5\x4F",
  /* U+9B8C */	"\xF5\x50", "\xF5\x51", "\xF5\x52", "\xF5\x53",
  /* U+9B90 */	"\xF5\x54", "\xF5\x55", "\xF5\x56", "\xF5\x57",
  /* U+9B94 */	"\xF5\x58", "\xF5\x59", "\xF5\x5A", "\xF5\x5B",
  /* U+9B98 */	"\xF5\x5C", "\xF5\x5D", "\xF5\x5E", "\xF5\x5F",
  /* U+9B9C */	"\xF5\x60", "\xF5\x61", "\xF5\x62", "\xF5\x63",
  /* U+9BA0 */	"\xF5\x64", "\xF5\x65", "\xF5\x66", "\xF5\x67",
  /* U+9BA4 */	"\xF5\x68", "\xF5\x69", "\xF5\x6A", "\xF5\x6B",
  /* U+9BA8 */	"\xF5\x6C", "\xF5\x6D", "\xF5\x6E", "\xF5\x6F",
  /* U+9BAC */	"\xF5\x70", "\xF5\x71", "\xF5\x72", "\xF5\x73",
  /* U+9BB0 */	"\xF5\x74", "\xF5\x75", "\xF5\x76", "\xF5\x77",
  /* U+9BB4 */	"\xF5\x78", "\xF5\x79", "\xF5\x7A", "\xF5\x7B",
  /* U+9BB8 */	"\xF5\x7C", "\xF5\x7D", "\xF5\x7E", "\xF5\x80",
  /* U+9BBC */	"\xF5\x81", "\xF5\x82", "\xF5\x83", "\xF5\x84",
  /* U+9BC0 */	"\xF5\x85", "\xF5\x86", "\xF5\x87", "\xF5\x88",
  /* U+9BC4 */	"\xF5\x89", "\xF5\x8A", "\xF5\x8B", "\xF5\x8C",
  /* U+9BC8 */	"\xF5\x8D", "\xF5\x8E", "\xF5\x8F", "\xF5\x90",
  /* U+9BCC */	"\xF5\x91", "\xF5\x92", "\xF5\x93", "\xF5\x94",
  /* U+9BD0 */	"\xF5\x95", "\xF5\x96", "\xF5\x97", "\xF5\x98",
  /* U+9BD4 */	"\xF5\x99", "\xF5\x9A", "\xF5\x9B", "\xF5\x9C",
  /* U+9BD8 */	"\xF5\x9D", "\xF5\x9E", "\xF5\x9F", "\xF5\xA0",
  /* U+9BDC */	"\xF6\x40", "\xF6\x41", "\xF6\x42", "\xF6\x43",
  /* U+9BE0 */	"\xF6\x44", "\xF6\x45", "\xF6\x46", "\xF6\x47",
  /* U+9BE4 */	"\xF6\x48", "\xF6\x49", "\xF6\x4A", "\xF6\x4B",
  /* U+9BE8 */	"\xF6\x4C", "\xF6\x4D", "\xF6\x4E", "\xF6\x4F",
  /* U+9BEC */	"\xF6\x50", "\xF6\x51", "\xF6\x52", "\xF6\x53",
  /* U+9BF0 */	"\xF6\x54", "\xF6\x55", "\xF6\x56", "\xF6\x57",
  /* U+9BF4 */	"\xF6\x58", "\xF6\x59", "\xF6\x5A", "\xF6\x5B",
  /* U+9BF8 */	"\xF6\x5C", "\xF6\x5D", "\xF6\x5E", "\xF6\x5F",
  /* U+9BFC */	"\xF6\x60", "\xF6\x61", "\xF6\x62", "\xF6\x63",
  /* U+9C00 */	"\xF6\x64", "\xF6\x65", "\xF6\x66", "\xF6\x67",
  /* U+9C04 */	"\xF6\x68", "\xF6\x69", "\xF6\x6A", "\xF6\x6B",
  /* U+9C08 */	"\xF6\x6C", "\xF6\x6D", "\xF6\x6E", "\xF6\x6F",
  /* U+9C0C */	"\xF6\x70", "\xF6\x71", "\xF6\x72", "\xF6\x73",
  /* U+9C10 */	"\xF6\x74", "\xF6\x75", "\xF6\x76", "\xF6\x77",
  /* U+9C14 */	"\xF6\x78", "\xF6\x79", "\xF6\x7A", "\xF6\x7B",
  /* U+9C18 */	"\xF6\x7C", "\xF6\x7D", "\xF6\x7E", "\xF6\x80",
  /* U+9C1C */	"\xF6\x81", "\xF6\x82", "\xF6\x83", "\xF6\x84",
  /* U+9C20 */	"\xF6\x85", "\xF6\x86", "\xF6\x87", "\xF6\x88",
  /* U+9C24 */	"\xF6\x89", "\xF6\x8A", "\xF6\x8B", "\xF6\x8C",
  /* U+9C28 */	"\xF6\x8D", "\xF6\x8E", "\xF6\x8F", "\xF6\x90",
  /* U+9C2C */	"\xF6\x91", "\xF6\x92", "\xF6\x93", "\xF6\x94",
  /* U+9C30 */	"\xF6\x95", "\xF6\x96", "\xF6\x97", "\xF6\x98",
  /* U+9C34 */	"\xF6\x99", "\xF6\x9A", "\xF6\x9B", "\xF6\x9C",
  /* U+9C38 */	"\xF6\x9D", "\xF6\x9E", "\xF6\x9F", "\xF6\xA0",
  /* U+9C3C */	"\xF7\x40", "\xF7\x41", "\xF7\x42", "\xF7\x43",
  /* U+9C40 */	"\xF7\x44", "\xF7\x45", "\xF7\x46", "\xF7\x47",
  /* U+9C44 */	"\xF7\x48", "\xF7\x49", "\xF7\x4A", "\xF7\x4B",
  /* U+9C48 */	"\xF7\x4C", "\xF7\x4D", "\xF7\x4E", "\xF7\x4F",
  /* U+9C4C */	"\xF7\x50", "\xF7\x51", "\xF7\x52", "\xF7\x53",
  /* U+9C50 */	"\xF7\x54", "\xF7\x55", "\xF7\x56", "\xF7\x57",
  /* U+9C54 */	"\xF7\x58", "\xF7\x59", "\xF7\x5A", "\xF7\x5B",
  /* U+9C58 */	"\xF7\x5C", "\xF7\x5D", "\xF7\x5E", "\xF7\x5F",
  /* U+9C5C */	"\xF7\x60", "\xF7\x61", "\xF7\x62", "\xF7\x63",
  /* U+9C60 */	"\xF7\x64", "\xF7\x65", "\xF7\x66", "\xF7\x67",
  /* U+9C64 */	"\xF7\x68", "\xF7\x69", "\xF7\x6A", "\xF7\x6B",
  /* U+9C68 */	"\xF7\x6C", "\xF7\x6D", "\xF7\x6E", "\xF7\x6F",
  /* U+9C6C */	"\xF7\x70", "\xF7\x71", "\xF7\x72", "\xF7\x73",
  /* U+9C70 */	"\xF7\x74", "\xF7\x75", "\xF7\x76", "\xF7\x77",
  /* U+9C74 */	"\xF7\x78", "\xF7\x79", "\xF7\x7A", "\xF7\x7B",
  /* U+9C78 */	"\xF7\x7C", "\xF7\x7D", "\xF7\x7E", "\xF7\x80",
  /* U+9C7C */	"\xD3\xE3", "\xF7\x81", "\xF7\x82", "\xF6\xCF",
  /* U+9C80 */	"\xF7\x83", "\xC2\xB3", "\xF6\xD0", "\xF7\x84",
  /* U+9C84 */	"\xF7\x85", "\xF6\xD1", "\xF6\xD2", "\xF6\xD3",
  /* U+9C88 */	"\xF6\xD4", "\xF7\x86", "\xF7\x87", "\xF6\xD6",
  /* U+9C8C */	"\xF7\x88", "\xB1\xAB", "\xF6\xD7", "\xF7\x89",
  /* U+9C90 */	"\xF6\xD8", "\xF6\xD9", "\xF6\xDA", "\xF7\x8A",
  /* U+9C94 */	"\xF6\xDB", "\xF6\xDC", "\xF7\x8B", "\xF7\x8C",
  /* U+9C98 */	"\xF7\x8D", "\xF7\x8E", "\xF6\xDD", "\xF6\xDE",
  /* U+9C9C */	"\xCF\xCA", "\xF7\x8F", "\xF6\xDF", "\xF6\xE0",
  /* U+9CA0 */	"\xF6\xE1", "\xF6\xE2", "\xF6\xE3", "\xF6\xE4",
  /* U+9CA4 */	"\xC0\xF0", "\xF6\xE5", "\xF6\xE6", "\xF6\xE7",
  /* U+9CA8 */	"\xF6\xE8", "\xF6\xE9", "\xF7\x90", "\xF6\xEA",
  /* U+9CAC */	"\xF7\x91", "\xF6\xEB", "\xF6\xEC", "\xF7\x92",
  /* U+9CB0 */	"\xF6\xED", "\xF6\xEE", "\xF6\xEF", "\xF6\xF0",
  /* U+9CB4 */	"\xF6\xF1", "\xF6\xF2", "\xF6\xF3", "\xF6\xF4",
  /* U+9CB8 */	"\xBE\xA8", "\xF7\x93", "\xF6\xF5", "\xF6\xF6",
  /* U+9CBC */	"\xF6\xF7", "\xF6\xF8", "\xF7\x94", "\xF7\x95",
  /* U+9CC0 */	"\xF7\x96", "\xF7\x97", "\xF7\x98", "\xC8\xFA",
  /* U+9CC4 */	"\xF6\xF9", "\xF6\xFA", "\xF6\xFB", "\xF6\xFC",
  /* U+9CC8 */	"\xF7\x99", "\xF7\x9A", "\xF6\xFD", "\xF6\xFE",
  /* U+9CCC */	"\xF7\xA1", "\xF7\xA2", "\xF7\xA3", "\xF7\xA4",
  /* U+9CD0 */	"\xF7\xA5", "\xF7\x9B", "\xF7\x9C", "\xF7\xA6",
  /* U+9CD4 */	"\xF7\xA7", "\xF7\xA8", "\xB1\xEE", "\xF7\xA9",
  /* U+9CD8 */	"\xF7\xAA", "\xF7\xAB", "\xF7\x9D", "\xF7\x9E",
  /* U+9CDC */	"\xF7\xAC", "\xF7\xAD", "\xC1\xDB", "\xF7\xAE",
  /* U+9CE0 */	"\xF7\x9F", "\xF7\xA0", "\xF7\xAF", "\xF8\x40",
  /* U+9CE4 */	"\xF8\x41", "\xF8\x42", "\xF8\x43", "\xF8\x44",
  /* U+9CE8 */	"\xF8\x45", "\xF8\x46", "\xF8\x47", "\xF8\x48",
  /* U+9CEC */	"\xF8\x49", "\xF8\x4A", "\xF8\x4B", "\xF8\x4C",
  /* U+9CF0 */	"\xF8\x4D", "\xF8\x4E", "\xF8\x4F", "\xF8\x50",
  /* U+9CF4 */	"\xF8\x51", "\xF8\x52", "\xF8\x53", "\xF8\x54",
  /* U+9CF8 */	"\xF8\x55", "\xF8\x56", "\xF8\x57", "\xF8\x58",
  /* U+9CFC */	"\xF8\x59", "\xF8\x5A", "\xF8\x5B", "\xF8\x5C",
  /* U+9D00 */	"\xF8\x5D", "\xF8\x5E", "\xF8\x5F", "\xF8\x60",
  /* U+9D04 */	"\xF8\x61", "\xF8\x62", "\xF8\x63", "\xF8\x64",
  /* U+9D08 */	"\xF8\x65", "\xF8\x66", "\xF8\x67", "\xF8\x68",
  /* U+9D0C */	"\xF8\x69", "\xF8\x6A", "\xF8\x6B", "\xF8\x6C",
  /* U+9D10 */	"\xF8\x6D", "\xF8\x6E", "\xF8\x6F", "\xF8\x70",
  /* U+9D14 */	"\xF8\x71", "\xF8\x72", "\xF8\x73", "\xF8\x74",
  /* U+9D18 */	"\xF8\x75", "\xF8\x76", "\xF8\x77", "\xF8\x78",
  /* U+9D1C */	"\xF8\x79", "\xF8\x7A", "\xF8\x7B", "\xF8\x7C",
  /* U+9D20 */	"\xF8\x7D", "\xF8\x7E", "\xF8\x80", "\xF8\x81",
  /* U+9D24 */	"\xF8\x82", "\xF8\x83", "\xF8\x84", "\xF8\x85",
  /* U+9D28 */	"\xF8\x86", "\xF8\x87", "\xF8\x88", "\xF8\x89",
  /* U+9D2C */	"\xF8\x8A", "\xF8\x8B", "\xF8\x8C", "\xF8\x8D",
  /* U+9D30 */	"\xF8\x8E", "\xF8\x8F", "\xF8\x90", "\xF8\x91",
  /* U+9D34 */	"\xF8\x92", "\xF8\x93", "\xF8\x94", "\xF8\x95",
  /* U+9D38 */	"\xF8\x96", "\xF8\x97", "\xF8\x98", "\xF8\x99",
  /* U+9D3C */	"\xF8\x9A", "\xF8\x9B", "\xF8\x9C", "\xF8\x9D",
  /* U+9D40 */	"\xF8\x9E", "\xF8\x9F", "\xF8\xA0", "\xF9\x40",
  /* U+9D44 */	"\xF9\x41", "\xF9\x42", "\xF9\x43", "\xF9\x44",
  /* U+9D48 */	"\xF9\x45", "\xF9\x46", "\xF9\x47", "\xF9\x48",
  /* U+9D4C */	"\xF9\x49", "\xF9\x4A", "\xF9\x4B", "\xF9\x4C",
  /* U+9D50 */	"\xF9\x4D", "\xF9\x4E", "\xF9\x4F", "\xF9\x50",
  /* U+9D54 */	"\xF9\x51", "\xF9\x52", "\xF9\x53", "\xF9\x54",
  /* U+9D58 */	"\xF9\x55", "\xF9\x56", "\xF9\x57", "\xF9\x58",
  /* U+9D5C */	"\xF9\x59", "\xF9\x5A", "\xF9\x5B", "\xF9\x5C",
  /* U+9D60 */	"\xF9\x5D", "\xF9\x5E", "\xF9\x5F", "\xF9\x60",
  /* U+9D64 */	"\xF9\x61", "\xF9\x62", "\xF9\x63", "\xF9\x64",
  /* U+9D68 */	"\xF9\x65", "\xF9\x66", "\xF9\x67", "\xF9\x68",
  /* U+9D6C */	"\xF9\x69", "\xF9\x6A", "\xF9\x6B", "\xF9\x6C",
  /* U+9D70 */	"\xF9\x6D", "\xF9\x6E", "\xF9\x6F", "\xF9\x70",
  /* U+9D74 */	"\xF9\x71", "\xF9\x72", "\xF9\x73", "\xF9\x74",
  /* U+9D78 */	"\xF9\x75", "\xF9\x76", "\xF9\x77", "\xF9\x78",
  /* U+9D7C */	"\xF9\x79", "\xF9\x7A", "\xF9\x7B", "\xF9\x7C",
  /* U+9D80 */	"\xF9\x7D", "\xF9\x7E", "\xF9\x80", "\xF9\x81",
  /* U+9D84 */	"\xF9\x82", "\xF9\x83", "\xF9\x84", "\xF9\x85",
  /* U+9D88 */	"\xF9\x86", "\xF9\x87", "\xF9\x88", "\xF9\x89",
  /* U+9D8C */	"\xF9\x8A", "\xF9\x8B", "\xF9\x8C", "\xF9\x8D",
  /* U+9D90 */	"\xF9\x8E", "\xF9\x8F", "\xF9\x90", "\xF9\x91",
  /* U+9D94 */	"\xF9\x92", "\xF9\x93", "\xF9\x94", "\xF9\x95",
  /* U+9D98 */	"\xF9\x96", "\xF9\x97", "\xF9\x98", "\xF9\x99",
  /* U+9D9C */	"\xF9\x9A", "\xF9\x9B", "\xF9\x9C", "\xF9\x9D",
  /* U+9DA0 */	"\xF9\x9E", "\xF9\x9F", "\xF9\xA0", "\xFA\x40",
  /* U+9DA4 */	"\xFA\x41", "\xFA\x42", "\xFA\x43", "\xFA\x44",
  /* U+9DA8 */	"\xFA\x45", "\xFA\x46", "\xFA\x47", "\xFA\x48",
  /* U+9DAC */	"\xFA\x49", "\xFA\x4A", "\xFA\x4B", "\xFA\x4C",
  /* U+9DB0 */	"\xFA\x4D", "\xFA\x4E", "\xFA\x4F", "\xFA\x50",
  /* U+9DB4 */	"\xFA\x51", "\xFA\x52", "\xFA\x53", "\xFA\x54",
  /* U+9DB8 */	"\xFA\x55", "\xFA\x56", "\xFA\x57", "\xFA\x58",
  /* U+9DBC */	"\xFA\x59", "\xFA\x5A", "\xFA\x5B", "\xFA\x5C",
  /* U+9DC0 */	"\xFA\x5D", "\xFA\x5E", "\xFA\x5F", "\xFA\x60",
  /* U+9DC4 */	"\xFA\x61", "\xFA\x62", "\xFA\x63", "\xFA\x64",
  /* U+9DC8 */	"\xFA\x65", "\xFA\x66", "\xFA\x67", "\xFA\x68",
  /* U+9DCC */	"\xFA\x69", "\xFA\x6A", "\xFA\x6B", "\xFA\x6C",
  /* U+9DD0 */	"\xFA\x6D", "\xFA\x6E", "\xFA\x6F", "\xFA\x70",
  /* U+9DD4 */	"\xFA\x71", "\xFA\x72", "\xFA\x73", "\xFA\x74",
  /* U+9DD8 */	"\xFA\x75", "\xFA\x76", "\xFA\x77", "\xFA\x78",
  /* U+9DDC */	"\xFA\x79", "\xFA\x7A", "\xFA\x7B", "\xFA\x7C",
  /* U+9DE0 */	"\xFA\x7D", "\xFA\x7E", "\xFA\x80", "\xFA\x81",
  /* U+9DE4 */	"\xFA\x82", "\xFA\x83", "\xFA\x84", "\xFA\x85",
  /* U+9DE8 */	"\xFA\x86", "\xFA\x87", "\xFA\x88", "\xFA\x89",
  /* U+9DEC */	"\xFA\x8A", "\xFA\x8B", "\xFA\x8C", "\xFA\x8D",
  /* U+9DF0 */	"\xFA\x8E", "\xFA\x8F", "\xFA\x90", "\xFA\x91",
  /* U+9DF4 */	"\xFA\x92", "\xFA\x93", "\xFA\x94", "\xFA\x95",
  /* U+9DF8 */	"\xFA\x96", "\xFA\x97", "\xFA\x98", "\xFA\x99",
  /* U+9DFC */	"\xFA\x9A", "\xFA\x9B", "\xFA\x9C", "\xFA\x9D",
  /* U+9E00 */	"\xFA\x9E", "\xFA\x9F", "\xFA\xA0", "\xFB\x40",
  /* U+9E04 */	"\xFB\x41", "\xFB\x42", "\xFB\x43", "\xFB\x44",
  /* U+9E08 */	"\xFB\x45", "\xFB\x46", "\xFB\x47", "\xFB\x48",
  /* U+9E0C */	"\xFB\x49", "\xFB\x4A", "\xFB\x4B", "\xFB\x4C",
  /* U+9E10 */	"\xFB\x4D", "\xFB\x4E", "\xFB\x4F", "\xFB\x50",
  /* U+9E14 */	"\xFB\x51", "\xFB\x52", "\xFB\x53", "\xFB\x54",
  /* U+9E18 */	"\xFB\x55", "\xFB\x56", "\xFB\x57", "\xFB\x58",
  /* U+9E1C */	"\xFB\x59", "\xFB\x5A", "\xFB\x5B", "\xC4\xF1",
  /* U+9E20 */	"\xF0\xAF", "\xBC\xA6", "\xF0\xB0", "\xC3\xF9",
  /* U+9E24 */	"\xFB\x5C", "\xC5\xB8", "\xD1\xBB", "\xFB\x5D",
  /* U+9E28 */	"\xF0\xB1", "\xF0\xB2", "\xF0\xB3", "\xF0\xB4",
  /* U+9E2C */	"\xF0\xB5", "\xD1\xBC", "\xFB\x5E", "\xD1\xEC",
  /* U+9E30 */	"\xFB\x5F", "\xF0\xB7", "\xF0\xB6", "\xD4\xA7",
  /* U+9E34 */	"\xFB\x60", "\xCD\xD2", "\xF0\xB8", "\xF0\xBA",
  /* U+9E38 */	"\xF0\xB9", "\xF0\xBB", "\xF0\xBC", "\xFB\x61",
  /* U+9E3C */	"\xFB\x62", "\xB8\xEB", "\xF0\xBD", "\xBA\xE8",
  /* U+9E40 */	"\xFB\x63", "\xF0\xBE", "\xF0\xBF", "\xBE\xE9",
  /* U+9E44 */	"\xF0\xC0", "\xB6\xEC", "\xF0\xC1", "\xF0\xC2",
  /* U+9E48 */	"\xF0\xC3", "\xF0\xC4", "\xC8\xB5", "\xF0\xC5",
  /* U+9E4C */	"\xF0\xC6", "\xFB\x64", "\xF0\xC7", "\xC5\xF4",
  /* U+9E50 */	"\xFB\x65", "\xF0\xC8", "\xFB\x66", "\xFB\x67",
  /* U+9E54 */	"\xFB\x68", "\xF0\xC9", "\xFB\x69", "\xF0\xCA",
  /* U+9E58 */	"\xF7\xBD", "\xFB\x6A", "\xF0\xCB", "\xF0\xCC",
  /* U+9E5C */	"\xF0\xCD", "\xFB\x6B", "\xF0\xCE", "\xFB\x6C",
  /* U+9E60 */	"\xFB\x6D", "\xFB\x6E", "\xFB\x6F", "\xF0\xCF",
  /* U+9E64 */	"\xBA\xD7", "\xFB\x70", "\xF0\xD0", "\xF0\xD1",
  /* U+9E68 */	"\xF0\xD2", "\xF0\xD3", "\xF0\xD4", "\xF0\xD5",
  /* U+9E6C */	"\xF0\xD6", "\xF0\xD8", "\xFB\x71", "\xFB\x72",
  /* U+9E70 */	"\xD3\xA5", "\xF0\xD7", "\xFB\x73", "\xF0\xD9",
  /* U+9E74 */	"\xFB\x74", "\xFB\x75", "\xFB\x76", "\xFB\x77",
  /* U+9E78 */	"\xFB\x78", "\xFB\x79", "\xFB\x7A", "\xFB\x7B",
  /* U+9E7C */	"\xFB\x7C", "\xFB\x7D", "\xF5\xBA", "\xC2\xB9",
  /* U+9E80 */	"\xFB\x7E", "\xFB\x80", "\xF7\xE4", "\xFB\x81",
  /* U+9E84 */	"\xFB\x82", "\xFB\x83", "\xFB\x84", "\xF7\xE5",
  /* U+9E88 */	"\xF7\xE6", "\xFB\x85", "\xFB\x86", "\xF7\xE7",
  /* U+9E8C */	"\xFB\x87", "\xFB\x88", "\xFB\x89", "\xFB\x8A",
  /* U+9E90 */	"\xFB\x8B", "\xFB\x8C", "\xF7\xE8", "\xC2\xB4",
  /* U+9E94 */	"\xFB\x8D", "\xFB\x8E", "\xFB\x8F", "\xFB\x90",
  /* U+9E98 */	"\xFB\x91", "\xFB\x92", "\xFB\x93", "\xFB\x94",
  /* U+9E9C */	"\xFB\x95", "\xF7\xEA", "\xFB\x96", "\xF7\xEB",
  /* U+9EA0 */	"\xFB\x97", "\xFB\x98", "\xFB\x99", "\xFB\x9A",
  /* U+9EA4 */	"\xFB\x9B", "\xFB\x9C", "\xC2\xF3", "\xFB\x9D",
  /* U+9EA8 */	"\xFB\x9E", "\xFB\x9F", "\xFB\xA0", "\xFC\x40",
  /* U+9EAC */	"\xFC\x41", "\xFC\x42", "\xFC\x43", "\xFC\x44",
  /* U+9EB0 */	"\xFC\x45", "\xFC\x46", "\xFC\x47", "\xFC\x48",
  /* U+9EB4 */	"\xF4\xF0", "\xFC\x49", "\xFC\x4A", "\xFC\x4B",
  /* U+9EB8 */	"\xF4\xEF", "\xFC\x4C", "\xFC\x4D", "\xC2\xE9",
  /* U+9EBC */	"\xFC\x4E", "\xF7\xE1", "\xF7\xE2", "\xFC\x4F",
  /* U+9EC0 */	"\xFC\x50", "\xFC\x51", "\xFC\x52", "\xFC\x53",
  /* U+9EC4 */	"\xBB\xC6", "\xFC\x54", "\xFC\x55", "\xFC\x56",
  /* U+9EC8 */	"\xFC\x57", "\xD9\xE4", "\xFC\x58", "\xFC\x59",
  /* U+9ECC */	"\xFC\x5A", "\xCA\xF2", "\xC0\xE8", "\xF0\xA4",
  /* U+9ED0 */	"\xFC\x5B", "\xBA\xDA", "\xFC\x5C", "\xFC\x5D",
  /* U+9ED4 */	"\xC7\xAD", "\xFC\x5E", "\xFC\x5F", "\xFC\x60",
  /* U+9ED8 */	"\xC4\xAC", "\xFC\x61", "\xFC\x62", "\xF7\xEC",
  /* U+9EDC */	"\xF7\xED", "\xF7\xEE", "\xFC\x63", "\xF7\xF0",
  /* U+9EE0 */	"\xF7\xEF", "\xFC\x64", "\xF7\xF1", "\xFC\x65",
  /* U+9EE4 */	"\xFC\x66", "\xF7\xF4", "\xFC\x67", "\xF7\xF3",
  /* U+9EE8 */	"\xFC\x68", "\xF7\xF2", "\xF7\xF5", "\xFC\x69",
  /* U+9EEC */	"\xFC\x6A", "\xFC\x6B", "\xFC\x6C", "\xF7\xF6",
  /* U+9EF0 */	"\xFC\x6D", "\xFC\x6E", "\xFC\x6F", "\xFC\x70",
  /* U+9EF4 */	"\xFC\x71", "\xFC\x72", "\xFC\x73", "\xFC\x74",
  /* U+9EF8 */	"\xFC\x75", "\xED\xE9", "\xFC\x76", "\xED\xEA",
  /* U+9EFC */	"\xED\xEB", "\xFC\x77", "\xF6\xBC", "\xFC\x78",
  /* U+9F00 */	"\xFC\x79", "\xFC\x7A", "\xFC\x7B", "\xFC\x7C",
  /* U+9F04 */	"\xFC\x7D", "\xFC\x7E", "\xFC\x80", "\xFC\x81",
  /* U+9F08 */	"\xFC\x82", "\xFC\x83", "\xFC\x84", "\xF6\xBD",
  /* U+9F0C */	"\xFC\x85", "\xF6\xBE", "\xB6\xA6", "\xFC\x86",
  /* U+9F10 */	"\xD8\xBE", "\xFC\x87", "\xFC\x88", "\xB9\xC4",
  /* U+9F14 */	"\xFC\x89", "\xFC\x8A", "\xFC\x8B", "\xD8\xBB",
  /* U+9F18 */	"\xFC\x8C", "\xDC\xB1", "\xFC\x8D", "\xFC\x8E",
  /* U+9F1C */	"\xFC\x8F", "\xFC\x90", "\xFC\x91", "\xFC\x92",
  /* U+9F20 */	"\xCA\xF3", "\xFC\x93", "\xF7\xF7", "\xFC\x94",
  /* U+9F24 */	"\xFC\x95", "\xFC\x96", "\xFC\x97", "\xFC\x98",
  /* U+9F28 */	"\xFC\x99", "\xFC\x9A", "\xFC\x9B", "\xFC\x9C",
  /* U+9F2C */	"\xF7\xF8", "\xFC\x9D", "\xFC\x9E", "\xF7\xF9",
  /* U+9F30 */	"\xFC\x9F", "\xFC\xA0", "\xFD\x40", "\xFD\x41",
  /* U+9F34 */	"\xFD\x42", "\xFD\x43", "\xFD\x44", "\xF7\xFB",
  /* U+9F38 */	"\xFD\x45", "\xF7\xFA", "\xFD\x46", "\xB1\xC7",
  /* U+9F3C */	"\xFD\x47", "\xF7\xFC", "\xF7\xFD", "\xFD\x48",
  /* U+9F40 */	"\xFD\x49", "\xFD\x4A", "\xFD\x4B", "\xFD\x4C",
  /* U+9F44 */	"\xF7\xFE", "\xFD\x4D", "\xFD\x4E", "\xFD\x4F",
  /* U+9F48 */	"\xFD\x50", "\xFD\x51", "\xFD\x52", "\xFD\x53",
  /* U+9F4C */	"\xFD\x54", "\xFD\x55", "\xFD\x56", "\xFD\x57",
  /* U+9F50 */	"\xC6\xEB", "\xEC\xB4", "\xFD\x58", "\xFD\x59",
  /* U+9F54 */	"\xFD\x5A", "\xFD\x5B", "\xFD\x5C", "\xFD\x5D",
  /* U+9F58 */	"\xFD\x5E", "\xFD\x5F", "\xFD\x60", "\xFD\x61",
  /* U+9F5C */	"\xFD\x62", "\xFD\x63", "\xFD\x64", "\xFD\x65",
  /* U+9F60 */	"\xFD\x66", "\xFD\x67", "\xFD\x68", "\xFD\x69",
  /* U+9F64 */	"\xFD\x6A", "\xFD\x6B", "\xFD\x6C", "\xFD\x6D",
  /* U+9F68 */	"\xFD\x6E", "\xFD\x6F", "\xFD\x70", "\xFD\x71",
  /* U+9F6C */	"\xFD\x72", "\xFD\x73", "\xFD\x74", "\xFD\x75",
  /* U+9F70 */	"\xFD\x76", "\xFD\x77", "\xFD\x78", "\xFD\x79",
  /* U+9F74 */	"\xFD\x7A", "\xFD\x7B", "\xFD\x7C", "\xFD\x7D",
  /* U+9F78 */	"\xFD\x7E", "\xFD\x80", "\xFD\x81", "\xFD\x82",
  /* U+9F7C */	"\xFD\x83", "\xFD\x84", "\xFD\x85", "\xB3\xDD",
  /* U+9F80 */	"\xF6\xB3", "\xFD\x86", "\xFD\x87", "\xF6\xB4",
  /* U+9F84 */	"\xC1\xE4", "\xF6\xB5", "\xF6\xB6", "\xF6\xB7",
  /* U+9F88 */	"\xF6\xB8", "\xF6\xB9", "\xF6\xBA", "\xC8\xA3",
  /* U+9F8C */	"\xF6\xBB", "\xFD\x88", "\xFD\x89", "\xFD\x8A",
  /* U+9F90 */	"\xFD\x8B", "\xFD\x8C", "\xFD\x8D", "\xFD\x8E",
  /* U+9F94 */	"\xFD\x8F", "\xFD\x90", "\xFD\x91", "\xFD\x92",
  /* U+9F98 */	"\xFD\x93", "\xC1\xFA", "\xB9\xA8", "\xED\xE8",
  /* U+9F9C */	"\xFD\x94", "\xFD\x95", "\xFD\x96", "\xB9\xEA",
  /* U+9FA0 */	"\xD9\xDF", "\xFD\x97", "\xFD\x98", "\xFD\x99",
  /* U+9FA4 */	"\xFD\x9A", "\xFD\x9B", 
  /* Contiguous area: U+E766 .. U+E864 */
  /* U+E766 */				"\xA2\xAB", "\xA2\xAC",
  /* U+E768 */	"\xA2\xAD", "\xA2\xAE", "\xA2\xAF", "\xA2\xB0",
  /* U+E76C */	"\x64\x69", "\xA2\xE4", "\xA2\xEF", "\xA2\xF0",
  /* U+E770 */	"\xA2\xFD", "\xA2\xFE", "\xA4\xF4", "\xA4\xF5",
  /* U+E774 */	"\xA4\xF6", "\xA4\xF7", "\xA4\xF8", "\xA4\xF9",
  /* U+E778 */	"\xA4\xFA", "\xA4\xFB", "\xA4\xFC", "\xA4\xFD",
  /* U+E77C */	"\xA4\xFE", "\xA5\xF7", "\xA5\xF8", "\xA5\xF9",
  /* U+E780 */	"\xA5\xFA", "\xA5\xFB", "\xA5\xFC", "\xA5\xFD",
  /* U+E784 */	"\xA5\xFE", "\xA6\xB9", "\xA6\xBA", "\xA6\xBB",
  /* U+E788 */	"\xA6\xBC", "\xA6\xBD", "\xA6\xBE", "\xA6\xBF",
  /* U+E78C */	"\xA6\xC0", "\xA6\xD9", "\xA6\xDA", "\xA6\xDB",
  /* U+E790 */	"\xA6\xDC", "\xA6\xDD", "\xA6\xDE", "\xA6\xDF",
  /* U+E794 */	"\xA6\xEC", "\xA6\xED", "\xA6\xF3", "\xA6\xF6",
  /* U+E798 */	"\xA6\xF7", "\xA6\xF8", "\xA6\xF9", "\xA6\xFA",
  /* U+E79C */	"\xA6\xFB", "\xA6\xFC", "\xA6\xFD", "\xA6\xFE",
  /* U+E7A0 */	"\xA7\xC2", "\xA7\xC3", "\xA7\xC4", "\xA7\xC5",
  /* U+E7A4 */	"\xA7\xC6", "\xA7\xC7", "\xA7\xC8", "\xA7\xC9",
  /* U+E7A8 */	"\xA7\xCA", "\xA7\xCB", "\xA7\xCC", "\xA7\xCD",
  /* U+E7AC */	"\xA7\xCE", "\xA7\xCF", "\xA7\xD0", "\xA7\xF2",
  /* U+E7B0 */	"\xA7\xF3", "\xA7\xF4", "\xA7\xF5", "\xA7\xF6",
  /* U+E7B4 */	"\xA7\xF7", "\xA7\xF8", "\xA7\xF9", "\xA7\xFA",
  /* U+E7B8 */	"\xA7\xFB", "\xA7\xFC", "\xA7\xFD", "\xA7\xFE",
  /* U+E7BC */	"\xA8\x96", "\xA8\x97", "\xA8\x98", "\xA8\x99",
  /* U+E7C0 */	"\xA8\x9A", "\xA8\x9B", "\xA8\x9C", "\xA8\x9D",
  /* U+E7C4 */	"\xA8\x9E", "\xA8\x9F", "\xA8\xA0", "\xA8\xBC",
  /* U+E7C8 */	"\x64\x70", "\xA8\xC1", "\xA8\xC2", "\xA8\xC3",
  /* U+E7CC */	"\xA8\xC4", "\xA8\xEA", "\xA8\xEB", "\xA8\xEC",
  /* U+E7D0 */	"\xA8\xED", "\xA8\xEE", "\xA8\xEF", "\xA8\xF0",
  /* U+E7D4 */	"\xA8\xF1", "\xA8\xF2", "\xA8\xF3", "\xA8\xF4",
  /* U+E7D8 */	"\xA8\xF5", "\xA8\xF6", "\xA8\xF7", "\xA8\xF8",
  /* U+E7DC */	"\xA8\xF9", "\xA8\xFA", "\xA8\xFB", "\xA8\xFC",
  /* U+E7E0 */	"\xA8\xFD", "\xA8\xFE", "\xA9\x58", "\xA9\x5B",
  /* U+E7E4 */	"\xA9\x5D", "\xA9\x5E", "\xA9\x5F", "\x64\x71",
  /* U+E7E8 */	"\x64\x72", "\x64\x73", "\x64\x74", "\x64\x75",
  /* U+E7EC */	"\x64\x76", "\x64\x77", "\x64\x78", "\x64\x79",
  /* U+E7F0 */	"\x64\x80", "\x64\x81", "\x64\x82", "\x64\x83",
  /* U+E7F4 */	"\xA9\x97", "\xA9\x98", "\xA9\x99", "\xA9\x9A",
  /* U+E7F8 */	"\xA9\x9B", "\xA9\x9C", "\xA9\x9D", "\xA9\x9E",
  /* U+E7FC */	"\xA9\x9F", "\xA9\xA0", "\xA9\xA1", "\xA9\xA2",
  /* U+E800 */	"\xA9\xA3", "\xA9\xF0", "\xA9\xF1", "\xA9\xF2",
  /* U+E804 */	"\xA9\xF3", "\xA9\xF4", "\xA9\xF5", "\xA9\xF6",
  /* U+E808 */	"\xA9\xF7", "\xA9\xF8", "\xA9\xF9", "\xA9\xFA",
  /* U+E80C */	"\xA9\xFB", "\xA9\xFC", "\xA9\xFD", "\xA9\xFE",
  /* U+E810 */	"\xD7\xFA", "\xD7\xFB", "\xD7\xFC", "\xD7\xFD",
  /* U+E814 */	"\xD7\xFE", "\x64\x84", "\xFE\x51", "\xFE\x52",
  /* U+E818 */	"\xFE\x53", "\x64\x85", "\x64\x86", "\x64\x87",
  /* U+E81C */	"\x64\x88", "\x64\x89", "\xFE\x59", "\x64\x90",
  /* U+E820 */	"\x64\x91", "\x64\x92", "\x64\x93", "\x64\x94",
  /* U+E824 */	"\x64\x95", "\x64\x96", "\xFE\x61", "\x64\x97",
  /* U+E828 */	"\x64\x98", "\x64\x99", "\x64\xA0", "\xFE\x66",
  /* U+E82C */	"\xFE\x67", "\x64\xA1", "\x64\xA2", "\x64\xA3",
  /* U+E830 */	"\x64\xA4", "\xFE\x6C", "\xFE\x6D", "\x64\xA5",
  /* U+E834 */	"\x64\xA6", "\x64\xA7", "\x64\xA8", "\x64\xA9",
  /* U+E838 */	"\x64\xB0", "\x64\xB1", "\x64\xB2", "\xFE\x76",
  /* U+E83C */	"\x64\xB3", "\x64\xB4", "\x64\xB5", "\x64\xB6",
  /* U+E840 */	"\x64\xB7", "\x64\xB8", "\x64\xB9", "\xFE\x7E",
  /* U+E844 */	"\x64\xC0", "\x64\xC1", "\x64\xC2", "\x64\xC3",
  /* U+E848 */	"\x64\xC4", "\x64\xC5", "\x64\xC6", "\x64\xC7",
  /* U+E84C */	"\x64\xC8", "\x64\xC9", "\x64\xD0", "\x64\xD1",
  /* U+E850 */	"\x64\xD2", "\x64\xD3", "\x64\xD4", "\x64\xD5",
  /* U+E854 */	"\xFE\x90", "\xFE\x91", "\x64\xD6", "\x64\xD7",
  /* U+E858 */	"\x64\xD8", "\x64\xD9", "\x64\xE0", "\x64\xE1",
  /* U+E85C */	"\x64\xE2", "\x64\xE3", "\x64\xE4", "\x64\xE5",
  /* U+E860 */	"\x64\xE6", "\x64\xE7", "\x64\xE8", "\x64\xE9",
  /* U+E864 */	"\xFE\xA0", 
  /* Contiguous area: U+F92C .. U+FA29 */
  /* U+F92C */	"\xFD\x9C", "\x70\x45", "\x70\x46", "\x70\x47",
  /* U+F930 */	"\x70\x48", "\x70\x49", "\x70\x50", "\x70\x51",
  /* U+F934 */	"\x70\x52", "\x70\x53", "\x70\x54", "\x70\x55",
  /* U+F938 */	"\x70\x56", "\x70\x57", "\x70\x58", "\x70\x59",
  /* U+F93C */	"\x70\x60", "\x70\x61", "\x70\x62", "\x70\x63",
  /* U+F940 */	"\x70\x64", "\x70\x65", "\x70\x66", "\x70\x67",
  /* U+F944 */	"\x70\x68", "\x70\x69", "\x70\x70", "\x70\x71",
  /* U+F948 */	"\x70\x72", "\x70\x73", "\x70\x74", "\x70\x75",
  /* U+F94C */	"\x70\x76", "\x70\x77", "\x70\x78", "\x70\x79",
  /* U+F950 */	"\x70\x80", "\x70\x81", "\x70\x82", "\x70\x83",
  /* U+F954 */	"\x70\x84", "\x70\x85", "\x70\x86", "\x70\x87",
  /* U+F958 */	"\x70\x88", "\x70\x89", "\x70\x90", "\x70\x91",
  /* U+F95C */	"\x70\x92", "\x70\x93", "\x70\x94", "\x70\x95",
  /* U+F960 */	"\x70\x96", "\x70\x97", "\x70\x98", "\x70\x99",
  /* U+F964 */	"\x70\xA0", "\x70\xA1", "\x70\xA2", "\x70\xA3",
  /* U+F968 */	"\x70\xA4", "\x70\xA5", "\x70\xA6", "\x70\xA7",
  /* U+F96C */	"\x70\xA8", "\x70\xA9", "\x70\xB0", "\x70\xB1",
  /* U+F970 */	"\x70\xB2", "\x70\xB3", "\x70\xB4", "\x70\xB5",
  /* U+F974 */	"\x70\xB6", "\x70\xB7", "\x70\xB8", "\x70\xB9",
  /* U+F978 */	"\x70\xC0", "\xFD\x9D", "\x70\xC1", "\x70\xC2",
  /* U+F97C */	"\x70\xC3", "\x70\xC4", "\x70\xC5", "\x70\xC6",
  /* U+F980 */	"\x70\xC7", "\x70\xC8", "\x70\xC9", "\x70\xD0",
  /* U+F984 */	"\x70\xD1", "\x70\xD2", "\x70\xD3", "\x70\xD4",
  /* U+F988 */	"\x70\xD5", "\x70\xD6", "\x70\xD7", "\x70\xD8",
  /* U+F98C */	"\x70\xD9", "\x70\xE0", "\x70\xE1", "\x70\xE2",
  /* U+F990 */	"\x70\xE3", "\x70\xE4", "\x70\xE5", "\x70\xE6",
  /* U+F994 */	"\x70\xE7", "\xFD\x9E", "\x70\xE8", "\x70\xE9",
  /* U+F998 */	"\x70\xF0", "\x70\xF1", "\x70\xF2", "\x70\xF3",
  /* U+F99C */	"\x70\xF4", "\x70\xF5", "\x70\xF6", "\x70\xF7",
  /* U+F9A0 */	"\x70\xF8", "\x70\xF9", "\x71\x00", "\x71\x01",
  /* U+F9A4 */	"\x71\x02", "\x71\x03", "\x71\x04", "\x71\x05",
  /* U+F9A8 */	"\x71\x06", "\x71\x07", "\x71\x08", "\x71\x09",
  /* U+F9AC */	"\x71\x10", "\x71\x11", "\x71\x12", "\x71\x13",
  /* U+F9B0 */	"\x71\x14", "\x71\x15", "\x71\x16", "\x71\x17",
  /* U+F9B4 */	"\x71\x18", "\x71\x19", "\x71\x20", "\x71\x21",
  /* U+F9B8 */	"\x71\x22", "\x71\x23", "\x71\x24", "\x71\x25",
  /* U+F9BC */	"\x71\x26", "\x71\x27", "\x71\x28", "\x71\x29",
  /* U+F9C0 */	"\x71\x30", "\x71\x31", "\x71\x32", "\x71\x33",
  /* U+F9C4 */	"\x71\x34", "\x71\x35", "\x71\x36", "\x71\x37",
  /* U+F9C8 */	"\x71\x38", "\x71\x39", "\x71\x40", "\x71\x41",
  /* U+F9CC */	"\x71\x42", "\x71\x43", "\x71\x44", "\x71\x45",
  /* U+F9D0 */	"\x71\x46", "\x71\x47", "\x71\x48", "\x71\x49",
  /* U+F9D4 */	"\x71\x50", "\x71\x51", "\x71\x52", "\x71\x53",
  /* U+F9D8 */	"\x71\x54", "\x71\x55", "\x71\x56", "\x71\x57",
  /* U+F9DC */	"\x71\x58", "\x71\x59", "\x71\x60", "\x71\x61",
  /* U+F9E0 */	"\x71\x62", "\x71\x63", "\x71\x64", "\x71\x65",
  /* U+F9E4 */	"\x71\x66", "\x71\x67", "\x71\x68", "\xFD\x9F",
  /* U+F9E8 */	"\x71\x69", "\x71\x70", "\x71\x71", "\x71\x72",
  /* U+F9EC */	"\x71\x73", "\x71\x74", "\x71\x75", "\x71\x76",
  /* U+F9F0 */	"\x71\x77", "\xFD\xA0", "\x71\x78", "\x71\x79",
  /* U+F9F4 */	"\x71\x80", "\x71\x81", "\x71\x82", "\x71\x83",
  /* U+F9F8 */	"\x71\x84", "\x71\x85", "\x71\x86", "\x71\x87",
  /* U+F9FC */	"\x71\x88", "\x71\x89", "\x71\x90", "\x71\x91",
  /* U+FA00 */	"\x71\x92", "\x71\x93", "\x71\x94", "\x71\x95",
  /* U+FA04 */	"\x71\x96", "\x71\x97", "\x71\x98", "\x71\x99",
  /* U+FA08 */	"\x71\xA0", "\x71\xA1", "\x71\xA2", "\x71\xA3",
  /* U+FA0C */	"\xFE\x40", "\xFE\x41", "\xFE\x42", "\xFE\x43",
  /* U+FA10 */	"\x71\xA4", "\xFE\x44", "\x71\xA5", "\xFE\x45",
  /* U+FA14 */	"\xFE\x46", "\x71\xA6", "\x71\xA7", "\x71\xA8",
  /* U+FA18 */	"\xFE\x47", "\x71\xA9", "\x71\xB0", "\x71\xB1",
  /* U+FA1C */	"\x71\xB2", "\x71\xB3", "\x71\xB4", "\xFE\x48",
  /* U+FA20 */	"\xFE\x49", "\xFE\x4A", "\x71\xB5", "\xFE\x4B",
  /* U+FA24 */	"\xFE\x4C", "\x71\xB6", "\x71\xB7", "\xFE\x4D",
  /* U+FA28 */	"\xFE\x4E", "\xFE\x4F", 
  /* Contiguous area: U+FE30 .. U+FFE5 */
  /* U+FE30 */	"\xA9\x55", "\xA6\xF2", "\x78\x48", "\xA6\xF4",
  /* U+FE34 */	"\xA6\xF5", "\xA6\xE0", "\xA6\xE1", "\xA6\xF0",
  /* U+FE38 */	"\xA6\xF1", "\xA6\xE2", "\xA6\xE3", "\xA6\xEE",
  /* U+FE3C */	"\xA6\xEF", "\xA6\xE6", "\xA6\xE7", "\xA6\xE4",
  /* U+FE40 */	"\xA6\xE5", "\xA6\xE8", "\xA6\xE9", "\xA6\xEA",
  /* U+FE44 */	"\xA6\xEB", "\x78\x49", "\x78\x50", "\x78\x51",
  /* U+FE48 */	"\x78\x52", "\xA9\x68", "\xA9\x69", "\xA9\x6A",
  /* U+FE4C */	"\xA9\x6B", "\xA9\x6C", "\xA9\x6D", "\xA9\x6E",
  /* U+FE50 */	"\xA9\x6F", "\xA9\x70", "\xA9\x71", "\x78\x53",
  /* U+FE54 */	"\xA9\x72", "\xA9\x73", "\xA9\x74", "\xA9\x75",
  /* U+FE58 */	"\x78\x54", "\xA9\x76", "\xA9\x77", "\xA9\x78",
  /* U+FE5C */	"\xA9\x79", "\xA9\x7A", "\xA9\x7B", "\xA9\x7C",
  /* U+FE60 */	"\xA9\x7D", "\xA9\x7E", "\xA9\x80", "\xA9\x81",
  /* U+FE64 */	"\xA9\x82", "\xA9\x83", "\xA9\x84", "\x78\x55",
  /* U+FE68 */	"\xA9\x85", "\xA9\x86", "\xA9\x87", "\xA9\x88",
  /* U+FE6C */	"\x78\x56", "\x78\x57", "\x78\x58", "\x78\x59",
  /* U+FE70 */	"\x78\x60", "\x78\x61", "\x78\x62", "\x78\x63",
  /* U+FE74 */	"\x78\x64", "\x78\x65", "\x78\x66", "\x78\x67",
  /* U+FE78 */	"\x78\x68", "\x78\x69", "\x78\x70", "\x78\x71",
  /* U+FE7C */	"\x78\x72", "\x78\x73", "\x78\x74", "\x78\x75",
  /* U+FE80 */	"\x78\x76", "\x78\x77", "\x78\x78", "\x78\x79",
  /* U+FE84 */	"\x78\x80", "\x78\x81", "\x78\x82", "\x78\x83",
  /* U+FE88 */	"\x78\x84", "\x78\x85", "\x78\x86", "\x78\x87",
  /* U+FE8C */	"\x78\x88", "\x78\x89", "\x78\x90", "\x78\x91",
  /* U+FE90 */	"\x78\x92", "\x78\x93", "\x78\x94", "\x78\x95",
  /* U+FE94 */	"\x78\x96", "\x78\x97", "\x78\x98", "\x78\x99",
  /* U+FE98 */	"\x78\xA0", "\x78\xA1", "\x78\xA2", "\x78\xA3",
  /* U+FE9C */	"\x78\xA4", "\x78\xA5", "\x78\xA6", "\x78\xA7",
  /* U+FEA0 */	"\x78\xA8", "\x78\xA9", "\x78\xB0", "\x78\xB1",
  /* U+FEA4 */	"\x78\xB2", "\x78\xB3", "\x78\xB4", "\x78\xB5",
  /* U+FEA8 */	"\x78\xB6", "\x78\xB7", "\x78\xB8", "\x78\xB9",
  /* U+FEAC */	"\x78\xC0", "\x78\xC1", "\x78\xC2", "\x78\xC3",
  /* U+FEB0 */	"\x78\xC4", "\x78\xC5", "\x78\xC6", "\x78\xC7",
  /* U+FEB4 */	"\x78\xC8", "\x78\xC9", "\x78\xD0", "\x78\xD1",
  /* U+FEB8 */	"\x78\xD2", "\x78\xD3", "\x78\xD4", "\x78\xD5",
  /* U+FEBC */	"\x78\xD6", "\x78\xD7", "\x78\xD8", "\x78\xD9",
  /* U+FEC0 */	"\x78\xE0", "\x78\xE1", "\x78\xE2", "\x78\xE3",
  /* U+FEC4 */	"\x78\xE4", "\x78\xE5", "\x78\xE6", "\x78\xE7",
  /* U+FEC8 */	"\x78\xE8", "\x78\xE9", "\x78\xF0", "\x78\xF1",
  /* U+FECC */	"\x78\xF2", "\x78\xF3", "\x78\xF4", "\x78\xF5",
  /* U+FED0 */	"\x78\xF6", "\x78\xF7", "\x78\xF8", "\x78\xF9",
  /* U+FED4 */	"\x79\x00", "\x79\x01", "\x79\x02", "\x79\x03",
  /* U+FED8 */	"\x79\x04", "\x79\x05", "\x79\x06", "\x79\x07",
  /* U+FEDC */	"\x79\x08", "\x79\x09", "\x79\x10", "\x79\x11",
  /* U+FEE0 */	"\x79\x12", "\x79\x13", "\x79\x14", "\x79\x15",
  /* U+FEE4 */	"\x79\x16", "\x79\x17", "\x79\x18", "\x79\x19",
  /* U+FEE8 */	"\x79\x20", "\x79\x21", "\x79\x22", "\x79\x23",
  /* U+FEEC */	"\x79\x24", "\x79\x25", "\x79\x26", "\x79\x27",
  /* U+FEF0 */	"\x79\x28", "\x79\x29", "\x79\x30", "\x79\x31",
  /* U+FEF4 */	"\x79\x32", "\x79\x33", "\x79\x34", "\x79\x35",
  /* U+FEF8 */	"\x79\x36", "\x79\x37", "\x79\x38", "\x79\x39",
  /* U+FEFC */	"\x79\x40", "\x79\x41", "\x79\x42", "\x79\x43",
  /* U+FF00 */	"\x79\x44", "\xA3\xA1", "\xA3\xA2", "\xA3\xA3",
  /* U+FF04 */	"\xA1\xE7", "\xA3\xA5", "\xA3\xA6", "\xA3\xA7",
  /* U+FF08 */	"\xA3\xA8", "\xA3\xA9", "\xA3\xAA", "\xA3\xAB",
  /* U+FF0C */	"\xA3\xAC", "\xA3\xAD", "\xA3\xAE", "\xA3\xAF",
  /* U+FF10 */	"\xA3\xB0", "\xA3\xB1", "\xA3\xB2", "\xA3\xB3",
  /* U+FF14 */	"\xA3\xB4", "\xA3\xB5", "\xA3\xB6", "\xA3\xB7",
  /* U+FF18 */	"\xA3\xB8", "\xA3\xB9", "\xA3\xBA", "\xA3\xBB",
  /* U+FF1C */	"\xA3\xBC", "\xA3\xBD", "\xA3\xBE", "\xA3\xBF",
  /* U+FF20 */	"\xA3\xC0", "\xA3\xC1", "\xA3\xC2", "\xA3\xC3",
  /* U+FF24 */	"\xA3\xC4", "\xA3\xC5", "\xA3\xC6", "\xA3\xC7",
  /* U+FF28 */	"\xA3\xC8", "\xA3\xC9", "\xA3\xCA", "\xA3\xCB",
  /* U+FF2C */	"\xA3\xCC", "\xA3\xCD", "\xA3\xCE", "\xA3\xCF",
  /* U+FF30 */	"\xA3\xD0", "\xA3\xD1", "\xA3\xD2", "\xA3\xD3",
  /* U+FF34 */	"\xA3\xD4", "\xA3\xD5", "\xA3\xD6", "\xA3\xD7",
  /* U+FF38 */	"\xA3\xD8", "\xA3\xD9", "\xA3\xDA", "\xA3\xDB",
  /* U+FF3C */	"\xA3\xDC", "\xA3\xDD", "\xA3\xDE", "\xA3\xDF",
  /* U+FF40 */	"\xA3\xE0", "\xA3\xE1", "\xA3\xE2", "\xA3\xE3",
  /* U+FF44 */	"\xA3\xE4", "\xA3\xE5", "\xA3\xE6", "\xA3\xE7",
  /* U+FF48 */	"\xA3\xE8", "\xA3\xE9", "\xA3\xEA", "\xA3\xEB",
  /* U+FF4C */	"\xA3\xEC", "\xA3\xED", "\xA3\xEE", "\xA3\xEF",
  /* U+FF50 */	"\xA3\xF0", "\xA3\xF1", "\xA3\xF2", "\xA3\xF3",
  /* U+FF54 */	"\xA3\xF4", "\xA3\xF5", "\xA3\xF6", "\xA3\xF7",
  /* U+FF58 */	"\xA3\xF8", "\xA3\xF9", "\xA3\xFA", "\xA3\xFB",
  /* U+FF5C */	"\xA3\xFC", "\xA3\xFD", "\xA1\xAB", "\x79\x45",
  /* U+FF60 */	"\x79\x46", "\x79\x47", "\x79\x48", "\x79\x49",
  /* U+FF64 */	"\x79\x50", "\x79\x51", "\x79\x52", "\x79\x53",
  /* U+FF68 */	"\x79\x54", "\x79\x55", "\x79\x56", "\x79\x57",
  /* U+FF6C */	"\x79\x58", "\x79\x59", "\x79\x60", "\x79\x61",
  /* U+FF70 */	"\x79\x62", "\x79\x63", "\x79\x64", "\x79\x65",
  /* U+FF74 */	"\x79\x66", "\x79\x67", "\x79\x68", "\x79\x69",
  /* U+FF78 */	"\x79\x70", "\x79\x71", "\x79\x72", "\x79\x73",
  /* U+FF7C */	"\x79\x74", "\x79\x75", "\x79\x76", "\x79\x77",
  /* U+FF80 */	"\x79\x78", "\x79\x79", "\x79\x80", "\x79\x81",
  /* U+FF84 */	"\x79\x82", "\x79\x83", "\x79\x84", "\x79\x85",
  /* U+FF88 */	"\x79\x86", "\x79\x87", "\x79\x88", "\x79\x89",
  /* U+FF8C */	"\x79\x90", "\x79\x91", "\x79\x92", "\x79\x93",
  /* U+FF90 */	"\x79\x94", "\x79\x95", "\x79\x96", "\x79\x97",
  /* U+FF94 */	"\x79\x98", "\x79\x99", "\x79\xA0", "\x79\xA1",
  /* U+FF98 */	"\x79\xA2", "\x79\xA3", "\x79\xA4", "\x79\xA5",
  /* U+FF9C */	"\x79\xA6", "\x79\xA7", "\x79\xA8", "\x79\xA9",
  /* U+FFA0 */	"\x79\xB0", "\x79\xB1", "\x79\xB2", "\x79\xB3",
  /* U+FFA4 */	"\x79\xB4", "\x79\xB5", "\x79\xB6", "\x79\xB7",
  /* U+FFA8 */	"\x79\xB8", "\x79\xB9", "\x79\xC0", "\x79\xC1",
  /* U+FFAC */	"\x79\xC2", "\x79\xC3", "\x79\xC4", "\x79\xC5",
  /* U+FFB0 */	"\x79\xC6", "\x79\xC7", "\x79\xC8", "\x79\xC9",
  /* U+FFB4 */	"\x79\xD0", "\x79\xD1", "\x79\xD2", "\x79\xD3",
  /* U+FFB8 */	"\x79\xD4", "\x79\xD5", "\x79\xD6", "\x79\xD7",
  /* U+FFBC */	"\x79\xD8", "\x79\xD9", "\x79\xE0", "\x79\xE1",
  /* U+FFC0 */	"\x79\xE2", "\x79\xE3", "\x79\xE4", "\x79\xE5",
  /* U+FFC4 */	"\x79\xE6", "\x79\xE7", "\x79\xE8", "\x79\xE9",
  /* U+FFC8 */	"\x79\xF0", "\x79\xF1", "\x79\xF2", "\x79\xF3",
  /* U+FFCC */	"\x79\xF4", "\x79\xF5", "\x79\xF6", "\x79\xF7",
  /* U+FFD0 */	"\x79\xF8", "\x79\xF9", "\x7A\x00", "\x7A\x01",
  /* U+FFD4 */	"\x7A\x02", "\x7A\x03", "\x7A\x04", "\x7A\x05",
  /* U+FFD8 */	"\x7A\x06", "\x7A\x07", "\x7A\x08", "\x7A\x09",
  /* U+FFDC */	"\x7A\x10", "\x7A\x11", "\x7A\x12", "\x7A\x13",
  /* U+FFE0 */	"\xA1\xE9", "\xA1\xEA", "\xA9\x56", "\xA3\xFE",
  /* U+FFE4 */	"\xA9\x57", "\xA3\xA4", 
};

static const uint16_t __gb18030_2byte_to_ucs[22046] = {
	/* GB 0x8140..0x817E */
	0x4E02,	0x4E04,	0x4E05,	0x4E06,	0x4E0F,	0x4E12,	0x4E17,	0x4E1F,
	0x4E20,	0x4E21,	0x4E23,	0x4E26,	0x4E29,	0x4E2E,	0x4E2F,	0x4E31,
	0x4E33,	0x4E35,	0x4E37,	0x4E3C,	0x4E40,	0x4E41,	0x4E42,	0x4E44,
	0x4E46,	0x4E4A,	0x4E51,	0x4E55,	0x4E57,	0x4E5A,	0x4E5B,	0x4E62,
	0x4E63,	0x4E64,	0x4E65,	0x4E67,	0x4E68,	0x4E6A,	0x4E6B,	0x4E6C,
	0x4E6D,	0x4E6E,	0x4E6F,	0x4E72,	0x4E74,	0x4E75,	0x4E76,	0x4E77,
	0x4E78,	0x4E79,	0x4E7A,	0x4E7B,	0x4E7C,	0x4E7D,	0x4E7F,	0x4E80,
	0x4E81,	0x4E82,	0x4E83,	0x4E84,	0x4E85,	0x4E87,	0x4E8A,
	/* GB 0x8180..0x81FE */
	0x4E90,	0x4E96,	0x4E97,	0x4E99,	0x4E9C,	0x4E9D,	0x4E9E,	0x4EA3,
	0x4EAA,	0x4EAF,	0x4EB0,	0x4EB1,	0x4EB4,	0x4EB6,	0x4EB7,	0x4EB8,
	0x4EB9,	0x4EBC,	0x4EBD,	0x4EBE,	0x4EC8,	0x4ECC,	0x4ECF,	0x4ED0,
	0x4ED2,	0x4EDA,	0x4EDB,	0x4EDC,	0x4EE0,	0x4EE2,	0x4EE6,	0x4EE7,
	0x4EE9,	0x4EED,	0x4EEE,	0x4EEF,	0x4EF1,	0x4EF4,	0x4EF8,	0x4EF9,
	0x4EFA,	0x4EFC,	0x4EFE,	0x4F00,	0x4F02,	0x4F03,	0x4F04,	0x4F05,
	0x4F06,	0x4F07,	0x4F08,	0x4F0B,	0x4F0C,	0x4F12,	0x4F13,	0x4F14,
	0x4F15,	0x4F16,	0x4F1C,	0x4F1D,	0x4F21,	0x4F23,	0x4F28,	0x4F29,
	0x4F2C,	0x4F2D,	0x4F2E,	0x4F31,	0x4F33,	0x4F35,	0x4F37,	0x4F39,
	0x4F3B,	0x4F3E,	0x4F3F,	0x4F40,	0x4F41,	0x4F42,	0x4F44,	0x4F45,
	0x4F47,	0x4F48,	0x4F49,	0x4F4A,	0x4F4B,	0x4F4C,	0x4F52,	0x4F54,
	0x4F56,	0x4F61,	0x4F62,	0x4F66,	0x4F68,	0x4F6A,	0x4F6B,	0x4F6D,
	0x4F6E,	0x4F71,	0x4F72,	0x4F75,	0x4F77,	0x4F78,	0x4F79,	0x4F7A,
	0x4F7D,	0x4F80,	0x4F81,	0x4F82,	0x4F85,	0x4F86,	0x4F87,	0x4F8A,
	0x4F8C,	0x4F8E,	0x4F90,	0x4F92,	0x4F93,	0x4F95,	0x4F96,	0x4F98,
	0x4F99,	0x4F9A,	0x4F9C,	0x4F9E,	0x4F9F,	0x4FA1,	0x4FA2,
	/* GB 0x8240..0x827E */
	0x4FA4,	0x4FAB,	0x4FAD,	0x4FB0,	0x4FB1,	0x4FB2,	0x4FB3,	0x4FB4,
	0x4FB6,	0x4FB7,	0x4FB8,	0x4FB9,	0x4FBA,	0x4FBB,	0x4FBC,	0x4FBD,
	0x4FBE,	0x4FC0,	0x4FC1,	0x4FC2,	0x4FC6,	0x4FC7,	0x4FC8,	0x4FC9,
	0x4FCB,	0x4FCC,	0x4FCD,	0x4FD2,	0x4FD3,	0x4FD4,	0x4FD5,	0x4FD6,
	0x4FD9,	0x4FDB,	0x4FE0,	0x4FE2,	0x4FE4,	0x4FE5,	0x4FE7,	0x4FEB,
	0x4FEC,	0x4FF0,	0x4FF2,	0x4FF4,	0x4FF5,	0x4FF6,	0x4FF7,	0x4FF9,
	0x4FFB,	0x4FFC,	0x4FFD,	0x4FFF,	0x5000,	0x5001,	0x5002,	0x5003,
	0x5004,	0x5005,	0x5006,	0x5007,	0x5008,	0x5009,	0x500A,
	/* GB 0x8280..0x82FE */
	0x500B,	0x500E,	0x5010,	0x5011,	0x5013,	0x5015,	0x5016,	0x5017,
	0x501B,	0x501D,	0x501E,	0x5020,	0x5022,	0x5023,	0x5024,	0x5027,
	0x502B,	0x502F,	0x5030,	0x5031,	0x5032,	0x5033,	0x5034,	0x5035,
	0x5036,	0x5037,	0x5038,	0x5039,	0x503B,	0x503D,	0x503F,	0x5040,
	0x5041,	0x5042,	0x5044,	0x5045,	0x5046,	0x5049,	0x504A,	0x504B,
	0x504D,	0x5050,	0x5051,	0x5052,	0x5053,	0x5054,	0x5056,	0x5057,
	0x5058,	0x5059,	0x505B,	0x505D,	0x505E,	0x505F,	0x5060,	0x5061,
	0x5062,	0x5063,	0x5064,	0x5066,	0x5067,	0x5068,	0x5069,	0x506A,
	0x506B,	0x506D,	0x506E,	0x506F,	0x5070,	0x5071,	0x5072,	0x5073,
	0x5074,	0x5075,	0x5078,	0x5079,	0x507A,	0x507C,	0x507D,	0x5081,
	0x5082,	0x5083,	0x5084,	0x5086,	0x5087,	0x5089,	0x508A,	0x508B,
	0x508C,	0x508E,	0x508F,	0x5090,	0x5091,	0x5092,	0x5093,	0x5094,
	0x5095,	0x5096,	0x5097,	0x5098,	0x5099,	0x509A,	0x509B,	0x509C,
	0x509D,	0x509E,	0x509F,	0x50A0,	0x50A1,	0x50A2,	0x50A4,	0x50A6,
	0x50AA,	0x50AB,	0x50AD,	0x50AE,	0x50AF,	0x50B0,	0x50B1,	0x50B3,
	0x50B4,	0x50B5,	0x50B6,	0x50B7,	0x50B8,	0x50B9,	0x50BC,
	/* GB 0x8340..0x837E */
	0x50BD,	0x50BE,	0x50BF,	0x50C0,	0x50C1,	0x50C2,	0x50C3,	0x50C4,
	0x50C5,	0x50C6,	0x50C7,	0x50C8,	0x50C9,	0x50CA,	0x50CB,	0x50CC,
	0x50CD,	0x50CE,	0x50D0,	0x50D1,	0x50D2,	0x50D3,	0x50D4,	0x50D5,
	0x50D7,	0x50D8,	0x50D9,	0x50DB,	0x50DC,	0x50DD,	0x50DE,	0x50DF,
	0x50E0,	0x50E1,	0x50E2,	0x50E3,	0x50E4,	0x50E5,	0x50E8,	0x50E9,
	0x50EA,	0x50EB,	0x50EF,	0x50F0,	0x50F1,	0x50F2,	0x50F4,	0x50F6,
	0x50F7,	0x50F8,	0x50F9,	0x50FA,	0x50FC,	0x50FD,	0x50FE,	0x50FF,
	0x5100,	0x5101,	0x5102,	0x5103,	0x5104,	0x5105,	0x5108,
	/* GB 0x8380..0x83FE */
	0x5109,	0x510A,	0x510C,	0x510D,	0x510E,	0x510F,	0x5110,	0x5111,
	0x5113,	0x5114,	0x5115,	0x5116,	0x5117,	0x5118,	0x5119,	0x511A,
	0x511B,	0x511C,	0x511D,	0x511E,	0x511F,	0x5120,	0x5122,	0x5123,
	0x5124,	0x5125,	0x5126,	0x5127,	0x5128,	0x5129,	0x512A,	0x512B,
	0x512C,	0x512D,	0x512E,	0x512F,	0x5130,	0x5131,	0x5132,	0x5133,
	0x5134,	0x5135,	0x5136,	0x5137,	0x5138,	0x5139,	0x513A,	0x513B,
	0x513C,	0x513D,	0x513E,	0x5142,	0x5147,	0x514A,	0x514C,	0x514E,
	0x514F,	0x5150,	0x5152,	0x5153,	0x5157,	0x5158,	0x5159,	0x515B,
	0x515D,	0x515E,	0x515F,	0x5160,	0x5161,	0x5163,	0x5164,	0x5166,
	0x5167,	0x5169,	0x516A,	0x516F,	0x5172,	0x517A,	0x517E,	0x517F,
	0x5183,	0x5184,	0x5186,	0x5187,	0x518A,	0x518B,	0x518E,	0x518F,
	0x5190,	0x5191,	0x5193,	0x5194,	0x5198,	0x519A,	0x519D,	0x519E,
	0x519F,	0x51A1,	0x51A3,	0x51A6,	0x51A7,	0x51A8,	0x51A9,	0x51AA,
	0x51AD,	0x51AE,	0x51B4,	0x51B8,	0x51B9,	0x51BA,	0x51BE,	0x51BF,
	0x51C1,	0x51C2,	0x51C3,	0x51C5,	0x51C8,	0x51CA,	0x51CD,	0x51CE,
	0x51D0,	0x51D2,	0x51D3,	0x51D4,	0x51D5,	0x51D6,	0x51D7,
	/* GB 0x8440..0x847E */
	0x51D8,	0x51D9,	0x51DA,	0x51DC,	0x51DE,	0x51DF,	0x51E2,	0x51E3,
	0x51E5,	0x51E6,	0x51E7,	0x51E8,	0x51E9,	0x51EA,	0x51EC,	0x51EE,
	0x51F1,	0x51F2,	0x51F4,	0x51F7,	0x51FE,	0x5204,	0x5205,	0x5209,
	0x520B,	0x520C,	0x520F,	0x5210,	0x5213,	0x5214,	0x5215,	0x521C,
	0x521E,	0x521F,	0x5221,	0x5222,	0x5223,	0x5225,	0x5226,	0x5227,
	0x522A,	0x522C,	0x522F,	0x5231,	0x5232,	0x5234,	0x5235,	0x523C,
	0x523E,	0x5244,	0x5245,	0x5246,	0x5247,	0x5248,	0x5249,	0x524B,
	0x524E,	0x524F,	0x5252,	0x5253,	0x5255,	0x5257,	0x5258,
	/* GB 0x8480..0x84FE */
	0x5259,	0x525A,	0x525B,	0x525D,	0x525F,	0x5260,	0x5262,	0x5263,
	0x5264,	0x5266,	0x5268,	0x526B,	0x526C,	0x526D,	0x526E,	0x5270,
	0x5271,	0x5273,	0x5274,	0x5275,	0x5276,	0x5277,	0x5278,	0x5279,
	0x527A,	0x527B,	0x527C,	0x527E,	0x5280,	0x5283,	0x5284,	0x5285,
	0x5286,	0x5287,	0x5289,	0x528A,	0x528B,	0x528C,	0x528D,	0x528E,
	0x528F,	0x5291,	0x5292,	0x5294,	0x5295,	0x5296,	0x5297,	0x5298,
	0x5299,	0x529A,	0x529C,	0x52A4,	0x52A5,	0x52A6,	0x52A7,	0x52AE,
	0x52AF,	0x52B0,	0x52B4,	0x52B5,	0x52B6,	0x52B7,	0x52B8,	0x52B9,
	0x52BA,	0x52BB,	0x52BC,	0x52BD,	0x52C0,	0x52C1,	0x52C2,	0x52C4,
	0x52C5,	0x52C6,	0x52C8,	0x52CA,	0x52CC,	0x52CD,	0x52CE,	0x52CF,
	0x52D1,	0x52D3,	0x52D4,	0x52D5,	0x52D7,	0x52D9,	0x52DA,	0x52DB,
	0x52DC,	0x52DD,	0x52DE,	0x52E0,	0x52E1,	0x52E2,	0x52E3,	0x52E5,
	0x52E6,	0x52E7,	0x52E8,	0x52E9,	0x52EA,	0x52EB,	0x52EC,	0x52ED,
	0x52EE,	0x52EF,	0x52F1,	0x52F2,	0x52F3,	0x52F4,	0x52F5,	0x52F6,
	0x52F7,	0x52F8,	0x52FB,	0x52FC,	0x52FD,	0x5301,	0x5302,	0x5303,
	0x5304,	0x5307,	0x5309,	0x530A,	0x530B,	0x530C,	0x530E,
	/* GB 0x8540..0x857E */
	0x5311,	0x5312,	0x5313,	0x5314,	0x5318,	0x531B,	0x531C,	0x531E,
	0x531F,	0x5322,	0x5324,	0x5325,	0x5327,	0x5328,	0x5329,	0x532B,
	0x532C,	0x532D,	0x532F,	0x5330,	0x5331,	0x5332,	0x5333,	0x5334,
	0x5335,	0x5336,	0x5337,	0x5338,	0x533C,	0x533D,	0x5340,	0x5342,
	0x5344,	0x5346,	0x534B,	0x534C,	0x534D,	0x5350,	0x5354,	0x5358,
	0x5359,	0x535B,	0x535D,	0x5365,	0x5368,	0x536A,	0x536C,	0x536D,
	0x5372,	0x5376,	0x5379,	0x537B,	0x537C,	0x537D,	0x537E,	0x5380,
	0x5381,	0x5383,	0x5387,	0x5388,	0x538A,	0x538E,	0x538F,
	/* GB 0x8580..0x85FE */
	0x5390,	0x5391,	0x5392,	0x5393,	0x5394,	0x5396,	0x5397,	0x5399,
	0x539B,	0x539C,	0x539E,	0x53A0,	0x53A1,	0x53A4,	0x53A7,	0x53AA,
	0x53AB,	0x53AC,	0x53AD,	0x53AF,	0x53B0,	0x53B1,	0x53B2,	0x53B3,
	0x53B4,	0x53B5,	0x53B7,	0x53B8,	0x53B9,	0x53BA,	0x53BC,	0x53BD,
	0x53BE,	0x53C0,	0x53C3,	0x53C4,	0x53C5,	0x53C6,	0x53C7,	0x53CE,
	0x53CF,	0x53D0,	0x53D2,	0x53D3,	0x53D5,	0x53DA,	0x53DC,	0x53DD,
	0x53DE,	0x53E1,	0x53E2,	0x53E7,	0x53F4,	0x53FA,	0x53FE,	0x53FF,
	0x5400,	0x5402,	0x5405,	0x5407,	0x540B,	0x5414,	0x5418,	0x5419,
	0x541A,	0x541C,	0x5422,	0x5424,	0x5425,	0x542A,	0x5430,	0x5433,
	0x5436,	0x5437,	0x543A,	0x543D,	0x543F,	0x5441,	0x5442,	0x5444,
	0x5445,	0x5447,	0x5449,	0x544C,	0x544D,	0x544E,	0x544F,	0x5451,
	0x545A,	0x545D,	0x545E,	0x545F,	0x5460,	0x5461,	0x5463,	0x5465,
	0x5467,	0x5469,	0x546A,	0x546B,	0x546C,	0x546D,	0x546E,	0x546F,
	0x5470,	0x5474,	0x5479,	0x547A,	0x547E,	0x547F,	0x5481,	0x5483,
	0x5485,	0x5487,	0x5488,	0x5489,	0x548A,	0x548D,	0x5491,	0x5493,
	0x5497,	0x5498,	0x549C,	0x549E,	0x549F,	0x54A0,	0x54A1,
	/* GB 0x8640..0x867E */
	0x54A2,	0x54A5,	0x54AE,	0x54B0,	0x54B2,	0x54B5,	0x54B6,	0x54B7,
	0x54B9,	0x54BA,	0x54BC,	0x54BE,	0x54C3,	0x54C5,	0x54CA,	0x54CB,
	0x54D6,	0x54D8,	0x54DB,	0x54E0,	0x54E1,	0x54E2,	0x54E3,	0x54E4,
	0x54EB,	0x54EC,	0x54EF,	0x54F0,	0x54F1,	0x54F4,	0x54F5,	0x54F6,
	0x54F7,	0x54F8,	0x54F9,	0x54FB,	0x54FE,	0x5500,	0x5502,	0x5503,
	0x5504,	0x5505,	0x5508,	0x550A,	0x550B,	0x550C,	0x550D,	0x550E,
	0x5512,	0x5513,	0x5515,	0x5516,	0x5517,	0x5518,	0x5519,	0x551A,
	0x551C,	0x551D,	0x551E,	0x551F,	0x5521,	0x5525,	0x5526,
	/* GB 0x8680..0x86FE */
	0x5528,	0x5529,	0x552B,	0x552D,	0x5532,	0x5534,	0x5535,	0x5536,
	0x5538,	0x5539,	0x553A,	0x553B,	0x553D,	0x5540,	0x5542,	0x5545,
	0x5547,	0x5548,	0x554B,	0x554C,	0x554D,	0x554E,	0x554F,	0x5551,
	0x5552,	0x5553,	0x5554,	0x5557,	0x5558,	0x5559,	0x555A,	0x555B,
	0x555D,	0x555E,	0x555F,	0x5560,	0x5562,	0x5563,	0x5568,	0x5569,
	0x556B,	0x556F,	0x5570,	0x5571,	0x5572,	0x5573,	0x5574,	0x5579,
	0x557A,	0x557D,	0x557F,	0x5585,	0x5586,	0x558C,	0x558D,	0x558E,
	0x5590,	0x5592,	0x5593,	0x5595,	0x5596,	0x5597,	0x559A,	0x559B,
	0x559E,	0x55A0,	0x55A1,	0x55A2,	0x55A3,	0x55A4,	0x55A5,	0x55A6,
	0x55A8,	0x55A9,	0x55AA,	0x55AB,	0x55AC,	0x55AD,	0x55AE,	0x55AF,
	0x55B0,	0x55B2,	0x55B4,	0x55B6,	0x55B8,	0x55BA,	0x55BC,	0x55BF,
	0x55C0,	0x55C1,	0x55C2,	0x55C3,	0x55C6,	0x55C7,	0x55C8,	0x55CA,
	0x55CB,	0x55CE,	0x55CF,	0x55D0,	0x55D5,	0x55D7,	0x55D8,	0x55D9,
	0x55DA,	0x55DB,	0x55DE,	0x55E0,	0x55E2,	0x55E7,	0x55E9,	0x55ED,
	0x55EE,	0x55F0,	0x55F1,	0x55F4,	0x55F6,	0x55F8,	0x55F9,	0x55FA,
	0x55FB,	0x55FC,	0x55FF,	0x5602,	0x5603,	0x5604,	0x5605,
	/* GB 0x8740..0x877E */
	0x5606,	0x5607,	0x560A,	0x560B,	0x560D,	0x5610,	0x5611,	0x5612,
	0x5613,	0x5614,	0x5615,	0x5616,	0x5617,	0x5619,	0x561A,	0x561C,
	0x561D,	0x5620,	0x5621,	0x5622,	0x5625,	0x5626,	0x5628,	0x5629,
	0x562A,	0x562B,	0x562E,	0x562F,	0x5630,	0x5633,	0x5635,	0x5637,
	0x5638,	0x563A,	0x563C,	0x563D,	0x563E,	0x5640,	0x5641,	0x5642,
	0x5643,	0x5644,	0x5645,	0x5646,	0x5647,	0x5648,	0x5649,	0x564A,
	0x564B,	0x564F,	0x5650,	0x5651,	0x5652,	0x5653,	0x5655,	0x5656,
	0x565A,	0x565B,	0x565D,	0x565E,	0x565F,	0x5660,	0x5661,
	/* GB 0x8780..0x87FE */
	0x5663,	0x5665,	0x5666,	0x5667,	0x566D,	0x566E,	0x566F,	0x5670,
	0x5672,	0x5673,	0x5674,	0x5675,	0x5677,	0x5678,	0x5679,	0x567A,
	0x567D,	0x567E,	0x567F,	0x5680,	0x5681,	0x5682,	0x5683,	0x5684,
	0x5687,	0x5688,	0x5689,	0x568A,	0x568B,	0x568C,	0x568D,	0x5690,
	0x5691,	0x5692,	0x5694,	0x5695,	0x5696,	0x5697,	0x5698,	0x5699,
	0x569A,	0x569B,	0x569C,	0x569D,	0x569E,	0x569F,	0x56A0,	0x56A1,
	0x56A2,	0x56A4,	0x56A5,	0x56A6,	0x56A7,	0x56A8,	0x56A9,	0x56AA,
	0x56AB,	0x56AC,	0x56AD,	0x56AE,	0x56B0,	0x56B1,	0x56B2,	0x56B3,
	0x56B4,	0x56B5,	0x56B6,	0x56B8,	0x56B9,	0x56BA,	0x56BB,	0x56BD,
	0x56BE,	0x56BF,	0x56C0,	0x56C1,	0x56C2,	0x56C3,	0x56C4,	0x56C5,
	0x56C6,	0x56C7,	0x56C8,	0x56C9,	0x56CB,	0x56CC,	0x56CD,	0x56CE,
	0x56CF,	0x56D0,	0x56D1,	0x56D2,	0x56D3,	0x56D5,	0x56D6,	0x56D8,
	0x56D9,	0x56DC,	0x56E3,	0x56E5,	0x56E6,	0x56E7,	0x56E8,	0x56E9,
	0x56EA,	0x56EC,	0x56EE,	0x56EF,	0x56F2,	0x56F3,	0x56F6,	0x56F7,
	0x56F8,	0x56FB,	0x56FC,	0x5700,	0x5701,	0x5702,	0x5705,	0x5707,
	0x570B,	0x570C,	0x570D,	0x570E,	0x570F,	0x5710,	0x5711,
	/* GB 0x8840..0x887E */
	0x5712,	0x5713,	0x5714,	0x5715,	0x5716,	0x5717,	0x5718,	0x5719,
	0x571A,	0x571B,	0x571D,	0x571E,	0x5720,	0x5721,	0x5722,	0x5724,
	0x5725,	0x5726,	0x5727,	0x572B,	0x5731,	0x5732,	0x5734,	0x5735,
	0x5736,	0x5737,	0x5738,	0x573C,	0x573D,	0x573F,	0x5741,	0x5743,
	0x5744,	0x5745,	0x5746,	0x5748,	0x5749,	0x574B,	0x5752,	0x5753,
	0x5754,	0x5755,	0x5756,	0x5758,	0x5759,	0x5762,	0x5763,	0x5765,
	0x5767,	0x576C,	0x576E,	0x5770,	0x5771,	0x5772,	0x5774,	0x5775,
	0x5778,	0x5779,	0x577A,	0x577D,	0x577E,	0x577F,	0x5780,
	/* GB 0x8880..0x88FE */
	0x5781,	0x5787,	0x5788,	0x5789,	0x578A,	0x578D,	0x578E,	0x578F,
	0x5790,	0x5791,	0x5794,	0x5795,	0x5796,	0x5797,	0x5798,	0x5799,
	0x579A,	0x579C,	0x579D,	0x579E,	0x579F,	0x57A5,	0x57A8,	0x57AA,
	0x57AC,	0x57AF,	0x57B0,	0x57B1,	0x57B3,	0x57B5,	0x57B6,	0x57B7,
	0x57B9,	0x57BA,	0x57BB,	0x57BC,	0x57BD,	0x57BE,	0x57BF,	0x57C0,
	0x57C1,	0x57C4,	0x57C5,	0x57C6,	0x57C7,	0x57C8,	0x57C9,	0x57CA,
	0x57CC,	0x57CD,	0x57D0,	0x57D1,	0x57D3,	0x57D6,	0x57D7,	0x57DB,
	0x57DC,	0x57DE,	0x57E1,	0x57E2,	0x57E3,	0x57E5,	0x57E6,	0x57E7,
	0x57E8,	0x57E9,	0x57EA,	0x57EB,	0x57EC,	0x57EE,	0x57F0,	0x57F1,
	0x57F2,	0x57F3,	0x57F5,	0x57F6,	0x57F7,	0x57FB,	0x57FC,	0x57FE,
	0x57FF,	0x5801,	0x5803,	0x5804,	0x5805,	0x5808,	0x5809,	0x580A,
	0x580C,	0x580E,	0x580F,	0x5810,	0x5812,	0x5813,	0x5814,	0x5816,
	0x5817,	0x5818,	0x581A,	0x581B,	0x581C,	0x581D,	0x581F,	0x5822,
	0x5823,	0x5825,	0x5826,	0x5827,	0x5828,	0x5829,	0x582B,	0x582C,
	0x582D,	0x582E,	0x582F,	0x5831,	0x5832,	0x5833,	0x5834,	0x5836,
	0x5837,	0x5838,	0x5839,	0x583A,	0x583B,	0x583C,	0x583D,
	/* GB 0x8940..0x897E */
	0x583E,	0x583F,	0x5840,	0x5841,	0x5842,	0x5843,	0x5845,	0x5846,
	0x5847,	0x5848,	0x5849,	0x584A,	0x584B,	0x584E,	0x584F,	0x5850,
	0x5852,	0x5853,	0x5855,	0x5856,	0x5857,	0x5859,	0x585A,	0x585B,
	0x585C,	0x585D,	0x585F,	0x5860,	0x5861,	0x5862,	0x5863,	0x5864,
	0x5866,	0x5867,	0x5868,	0x5869,	0x586A,	0x586D,	0x586E,	0x586F,
	0x5870,	0x5871,	0x5872,	0x5873,	0x5874,	0x5875,	0x5876,	0x5877,
	0x5878,	0x5879,	0x587A,	0x587B,	0x587C,	0x587D,	0x587F,	0x5882,
	0x5884,	0x5886,	0x5887,	0x5888,	0x588A,	0x588B,	0x588C,
	/* GB 0x8980..0x89FE */
	0x588D,	0x588E,	0x588F,	0x5890,	0x5891,	0x5894,	0x5895,	0x5896,
	0x5897,	0x5898,	0x589B,	0x589C,	0x589D,	0x58A0,	0x58A1,	0x58A2,
	0x58A3,	0x58A4,	0x58A5,	0x58A6,	0x58A7,	0x58AA,	0x58AB,	0x58AC,
	0x58AD,	0x58AE,	0x58AF,	0x58B0,	0x58B1,	0x58B2,	0x58B3,	0x58B4,
	0x58B5,	0x58B6,	0x58B7,	0x58B8,	0x58B9,	0x58BA,	0x58BB,	0x58BD,
	0x58BE,	0x58BF,	0x58C0,	0x58C2,	0x58C3,	0x58C4,	0x58C6,	0x58C7,
	0x58C8,	0x58C9,	0x58CA,	0x58CB,	0x58CC,	0x58CD,	0x58CE,	0x58CF,
	0x58D0,	0x58D2,	0x58D3,	0x58D4,	0x58D6,	0x58D7,	0x58D8,	0x58D9,
	0x58DA,	0x58DB,	0x58DC,	0x58DD,	0x58DE,	0x58DF,	0x58E0,	0x58E1,
	0x58E2,	0x58E3,	0x58E5,	0x58E6,	0x58E7,	0x58E8,	0x58E9,	0x58EA,
	0x58ED,	0x58EF,	0x58F1,	0x58F2,	0x58F4,	0x58F5,	0x58F7,	0x58F8,
	0x58FA,	0x58FB,	0x58FC,	0x58FD,	0x58FE,	0x58FF,	0x5900,	0x5901,
	0x5903,	0x5905,	0x5906,	0x5908,	0x5909,	0x590A,	0x590B,	0x590C,
	0x590E,	0x5910,	0x5911,	0x5912,	0x5913,	0x5917,	0x5918,	0x591B,
	0x591D,	0x591E,	0x5920,	0x5921,	0x5922,	0x5923,	0x5926,	0x5928,
	0x592C,	0x5930,	0x5932,	0x5933,	0x5935,	0x5936,	0x593B,
	/* GB 0x8A40..0x8A7E */
	0x593D,	0x593E,	0x593F,	0x5940,	0x5943,	0x5945,	0x5946,	0x594A,
	0x594C,	0x594D,	0x5950,	0x5952,	0x5953,	0x5959,	0x595B,	0x595C,
	0x595D,	0x595E,	0x595F,	0x5961,	0x5963,	0x5964,	0x5966,	0x5967,
	0x5968,	0x5969,	0x596A,	0x596B,	0x596C,	0x596D,	0x596E,	0x596F,
	0x5970,	0x5971,	0x5972,	0x5975,	0x5977,	0x597A,	0x597B,	0x597C,
	0x597E,	0x597F,	0x5980,	0x5985,	0x5989,	0x598B,	0x598C,	0x598E,
	0x598F,	0x5990,	0x5991,	0x5994,	0x5995,	0x5998,	0x599A,	0x599B,
	0x599C,	0x599D,	0x599F,	0x59A0,	0x59A1,	0x59A2,	0x59A6,
	/* GB 0x8A80..0x8AFE */
	0x59A7,	0x59AC,	0x59AD,	0x59B0,	0x59B1,	0x59B3,	0x59B4,	0x59B5,
	0x59B6,	0x59B7,	0x59B8,	0x59BA,	0x59BC,	0x59BD,	0x59BF,	0x59C0,
	0x59C1,	0x59C2,	0x59C3,	0x59C4,	0x59C5,	0x59C7,	0x59C8,	0x59C9,
	0x59CC,	0x59CD,	0x59CE,	0x59CF,	0x59D5,	0x59D6,	0x59D9,	0x59DB,
	0x59DE,	0x59DF,	0x59E0,	0x59E1,	0x59E2,	0x59E4,	0x59E6,	0x59E7,
	0x59E9,	0x59EA,	0x59EB,	0x59ED,	0x59EE,	0x59EF,	0x59F0,	0x59F1,
	0x59F2,	0x59F3,	0x59F4,	0x59F5,	0x59F6,	0x59F7,	0x59F8,	0x59FA,
	0x59FC,	0x59FD,	0x59FE,	0x5A00,	0x5A02,	0x5A0A,	0x5A0B,	0x5A0D,
	0x5A0E,	0x5A0F,	0x5A10,	0x5A12,	0x5A14,	0x5A15,	0x5A16,	0x5A17,
	0x5A19,	0x5A1A,	0x5A1B,	0x5A1D,	0x5A1E,	0x5A21,	0x5A22,	0x5A24,
	0x5A26,	0x5A27,	0x5A28,	0x5A2A,	0x5A2B,	0x5A2C,	0x5A2D,	0x5A2E,
	0x5A2F,	0x5A30,	0x5A33,	0x5A35,	0x5A37,	0x5A38,	0x5A39,	0x5A3A,
	0x5A3B,	0x5A3D,	0x5A3E,	0x5A3F,	0x5A41,	0x5A42,	0x5A43,	0x5A44,
	0x5A45,	0x5A47,	0x5A48,	0x5A4B,	0x5A4C,	0x5A4D,	0x5A4E,	0x5A4F,
	0x5A50,	0x5A51,	0x5A52,	0x5A53,	0x5A54,	0x5A56,	0x5A57,	0x5A58,
	0x5A59,	0x5A5B,	0x5A5C,	0x5A5D,	0x5A5E,	0x5A5F,	0x5A60,
	/* GB 0x8B40..0x8B7E */
	0x5A61,	0x5A63,	0x5A64,	0x5A65,	0x5A66,	0x5A68,	0x5A69,	0x5A6B,
	0x5A6C,	0x5A6D,	0x5A6E,	0x5A6F,	0x5A70,	0x5A71,	0x5A72,	0x5A73,
	0x5A78,	0x5A79,	0x5A7B,	0x5A7C,	0x5A7D,	0x5A7E,	0x5A80,	0x5A81,
	0x5A82,	0x5A83,	0x5A84,	0x5A85,	0x5A86,	0x5A87,	0x5A88,	0x5A89,
	0x5A8A,	0x5A8B,	0x5A8C,	0x5A8D,	0x5A8E,	0x5A8F,	0x5A90,	0x5A91,
	0x5A93,	0x5A94,	0x5A95,	0x5A96,	0x5A97,	0x5A98,	0x5A99,	0x5A9C,
	0x5A9D,	0x5A9E,	0x5A9F,	0x5AA0,	0x5AA1,	0x5AA2,	0x5AA3,	0x5AA4,
	0x5AA5,	0x5AA6,	0x5AA7,	0x5AA8,	0x5AA9,	0x5AAB,	0x5AAC,
	/* GB 0x8B80..0x8BFE */
	0x5AAD,	0x5AAE,	0x5AAF,	0x5AB0,	0x5AB1,	0x5AB4,	0x5AB6,	0x5AB7,
	0x5AB9,	0x5ABA,	0x5ABB,	0x5ABC,	0x5ABD,	0x5ABF,	0x5AC0,	0x5AC3,
	0x5AC4,	0x5AC5,	0x5AC6,	0x5AC7,	0x5AC8,	0x5ACA,	0x5ACB,	0x5ACD,
	0x5ACE,	0x5ACF,	0x5AD0,	0x5AD1,	0x5AD3,	0x5AD5,	0x5AD7,	0x5AD9,
	0x5ADA,	0x5ADB,	0x5ADD,	0x5ADE,	0x5ADF,	0x5AE2,	0x5AE4,	0x5AE5,
	0x5AE7,	0x5AE8,	0x5AEA,	0x5AEC,	0x5AED,	0x5AEE,	0x5AEF,	0x5AF0,
	0x5AF2,	0x5AF3,	0x5AF4,	0x5AF5,	0x5AF6,	0x5AF7,	0x5AF8,	0x5AF9,
	0x5AFA,	0x5AFB,	0x5AFC,	0x5AFD,	0x5AFE,	0x5AFF,	0x5B00,	0x5B01,
	0x5B02,	0x5B03,	0x5B04,	0x5B05,	0x5B06,	0x5B07,	0x5B08,	0x5B0A,
	0x5B0B,	0x5B0C,	0x5B0D,	0x5B0E,	0x5B0F,	0x5B10,	0x5B11,	0x5B12,
	0x5B13,	0x5B14,	0x5B15,	0x5B18,	0x5B19,	0x5B1A,	0x5B1B,	0x5B1C,
	0x5B1D,	0x5B1E,	0x5B1F,	0x5B20,	0x5B21,	0x5B22,	0x5B23,	0x5B24,
	0x5B25,	0x5B26,	0x5B27,	0x5B28,	0x5B29,	0x5B2A,	0x5B2B,	0x5B2C,
	0x5B2D,	0x5B2E,	0x5B2F,	0x5B30,	0x5B31,	0x5B33,	0x5B35,	0x5B36,
	0x5B38,	0x5B39,	0x5B3A,	0x5B3B,	0x5B3C,	0x5B3D,	0x5B3E,	0x5B3F,
	0x5B41,	0x5B42,	0x5B43,	0x5B44,	0x5B45,	0x5B46,	0x5B47,
	/* GB 0x8C40..0x8C7E */
	0x5B48,	0x5B49,	0x5B4A,	0x5B4B,	0x5B4C,	0x5B4D,	0x5B4E,	0x5B4F,
	0x5B52,	0x5B56,	0x5B5E,	0x5B60,	0x5B61,	0x5B67,	0x5B68,	0x5B6B,
	0x5B6D,	0x5B6E,	0x5B6F,	0x5B72,	0x5B74,	0x5B76,	0x5B77,	0x5B78,
	0x5B79,	0x5B7B,	0x5B7C,	0x5B7E,	0x5B7F,	0x5B82,	0x5B86,	0x5B8A,
	0x5B8D,	0x5B8E,	0x5B90,	0x5B91,	0x5B92,	0x5B94,	0x5B96,	0x5B9F,
	0x5BA7,	0x5BA8,	0x5BA9,	0x5BAC,	0x5BAD,	0x5BAE,	0x5BAF,	0x5BB1,
	0x5BB2,	0x5BB7,	0x5BBA,	0x5BBB,	0x5BBC,	0x5BC0,	0x5BC1,	0x5BC3,
	0x5BC8,	0x5BC9,	0x5BCA,	0x5BCB,	0x5BCD,	0x5BCE,	0x5BCF,
	/* GB 0x8C80..0x8CFE */
	0x5BD1,	0x5BD4,	0x5BD5,	0x5BD6,	0x5BD7,	0x5BD8,	0x5BD9,	0x5BDA,
	0x5BDB,	0x5BDC,	0x5BE0,	0x5BE2,	0x5BE3,	0x5BE6,	0x5BE7,	0x5BE9,
	0x5BEA,	0x5BEB,	0x5BEC,	0x5BED,	0x5BEF,	0x5BF1,	0x5BF2,	0x5BF3,
	0x5BF4,	0x5BF5,	0x5BF6,	0x5BF7,	0x5BFD,	0x5BFE,	0x5C00,	0x5C02,
	0x5C03,	0x5C05,	0x5C07,	0x5C08,	0x5C0B,	0x5C0C,	0x5C0D,	0x5C0E,
	0x5C10,	0x5C12,	0x5C13,	0x5C17,	0x5C19,	0x5C1B,	0x5C1E,	0x5C1F,
	0x5C20,	0x5C21,	0x5C23,	0x5C26,	0x5C28,	0x5C29,	0x5C2A,	0x5C2B,
	0x5C2D,	0x5C2E,	0x5C2F,	0x5C30,	0x5C32,	0x5C33,	0x5C35,	0x5C36,
	0x5C37,	0x5C43,	0x5C44,	0x5C46,	0x5C47,	0x5C4C,	0x5C4D,	0x5C52,
	0x5C53,	0x5C54,	0x5C56,	0x5C57,	0x5C58,	0x5C5A,	0x5C5B,	0x5C5C,
	0x5C5D,	0x5C5F,	0x5C62,	0x5C64,	0x5C67,	0x5C68,	0x5C69,	0x5C6A,
	0x5C6B,	0x5C6C,	0x5C6D,	0x5C70,	0x5C72,	0x5C73,	0x5C74,	0x5C75,
	0x5C76,	0x5C77,	0x5C78,	0x5C7B,	0x5C7C,	0x5C7D,	0x5C7E,	0x5C80,
	0x5C83,	0x5C84,	0x5C85,	0x5C86,	0x5C87,	0x5C89,	0x5C8A,	0x5C8B,
	0x5C8E,	0x5C8F,	0x5C92,	0x5C93,	0x5C95,	0x5C9D,	0x5C9E,	0x5C9F,
	0x5CA0,	0x5CA1,	0x5CA4,	0x5CA5,	0x5CA6,	0x5CA7,	0x5CA8,
	/* GB 0x8D40..0x8D7E */
	0x5CAA,	0x5CAE,	0x5CAF,	0x5CB0,	0x5CB2,	0x5CB4,	0x5CB6,	0x5CB9,
	0x5CBA,	0x5CBB,	0x5CBC,	0x5CBE,	0x5CC0,	0x5CC2,	0x5CC3,	0x5CC5,
	0x5CC6,	0x5CC7,	0x5CC8,	0x5CC9,	0x5CCA,	0x5CCC,	0x5CCD,	0x5CCE,
	0x5CCF,	0x5CD0,	0x5CD1,	0x5CD3,	0x5CD4,	0x5CD5,	0x5CD6,	0x5CD7,
	0x5CD8,	0x5CDA,	0x5CDB,	0x5CDC,	0x5CDD,	0x5CDE,	0x5CDF,	0x5CE0,
	0x5CE2,	0x5CE3,	0x5CE7,	0x5CE9,	0x5CEB,	0x5CEC,	0x5CEE,	0x5CEF,
	0x5CF1,	0x5CF2,	0x5CF3,	0x5CF4,	0x5CF5,	0x5CF6,	0x5CF7,	0x5CF8,
	0x5CF9,	0x5CFA,	0x5CFC,	0x5CFD,	0x5CFE,	0x5CFF,	0x5D00,
	/* GB 0x8D80..0x8DFE */
	0x5D01,	0x5D04,	0x5D05,	0x5D08,	0x5D09,	0x5D0A,	0x5D0B,	0x5D0C,
	0x5D0D,	0x5D0F,	0x5D10,	0x5D11,	0x5D12,	0x5D13,	0x5D15,	0x5D17,
	0x5D18,	0x5D19,	0x5D1A,	0x5D1C,	0x5D1D,	0x5D1F,	0x5D20,	0x5D21,
	0x5D22,	0x5D23,	0x5D25,	0x5D28,	0x5D2A,	0x5D2B,	0x5D2C,	0x5D2F,
	0x5D30,	0x5D31,	0x5D32,	0x5D33,	0x5D35,	0x5D36,	0x5D37,	0x5D38,
	0x5D39,	0x5D3A,	0x5D3B,	0x5D3C,	0x5D3F,	0x5D40,	0x5D41,	0x5D42,
	0x5D43,	0x5D44,	0x5D45,	0x5D46,	0x5D48,	0x5D49,	0x5D4D,	0x5D4E,
	0x5D4F,	0x5D50,	0x5D51,	0x5D52,	0x5D53,	0x5D54,	0x5D55,	0x5D56,
	0x5D57,	0x5D59,	0x5D5A,	0x5D5C,	0x5D5E,	0x5D5F,	0x5D60,	0x5D61,
	0x5D62,	0x5D63,	0x5D64,	0x5D65,	0x5D66,	0x5D67,	0x5D68,	0x5D6A,
	0x5D6D,	0x5D6E,	0x5D70,	0x5D71,	0x5D72,	0x5D73,	0x5D75,	0x5D76,
	0x5D77,	0x5D78,	0x5D79,	0x5D7A,	0x5D7B,	0x5D7C,	0x5D7D,	0x5D7E,
	0x5D7F,	0x5D80,	0x5D81,	0x5D83,	0x5D84,	0x5D85,	0x5D86,	0x5D87,
	0x5D88,	0x5D89,	0x5D8A,	0x5D8B,	0x5D8C,	0x5D8D,	0x5D8E,	0x5D8F,
	0x5D90,	0x5D91,	0x5D92,	0x5D93,	0x5D94,	0x5D95,	0x5D96,	0x5D97,
	0x5D98,	0x5D9A,	0x5D9B,	0x5D9C,	0x5D9E,	0x5D9F,	0x5DA0,
	/* GB 0x8E40..0x8E7E */
	0x5DA1,	0x5DA2,	0x5DA3,	0x5DA4,	0x5DA5,	0x5DA6,	0x5DA7,	0x5DA8,
	0x5DA9,	0x5DAA,	0x5DAB,	0x5DAC,	0x5DAD,	0x5DAE,	0x5DAF,	0x5DB0,
	0x5DB1,	0x5DB2,	0x5DB3,	0x5DB4,	0x5DB5,	0x5DB6,	0x5DB8,	0x5DB9,
	0x5DBA,	0x5DBB,	0x5DBC,	0x5DBD,	0x5DBE,	0x5DBF,	0x5DC0,	0x5DC1,
	0x5DC2,	0x5DC3,	0x5DC4,	0x5DC6,	0x5DC7,	0x5DC8,	0x5DC9,	0x5DCA,
	0x5DCB,	0x5DCC,	0x5DCE,	0x5DCF,	0x5DD0,	0x5DD1,	0x5DD2,	0x5DD3,
	0x5DD4,	0x5DD5,	0x5DD6,	0x5DD7,	0x5DD8,	0x5DD9,	0x5DDA,	0x5DDC,
	0x5DDF,	0x5DE0,	0x5DE3,	0x5DE4,	0x5DEA,	0x5DEC,	0x5DED,
	/* GB 0x8E80..0x8EFE */
	0x5DF0,	0x5DF5,	0x5DF6,	0x5DF8,	0x5DF9,	0x5DFA,	0x5DFB,	0x5DFC,
	0x5DFF,	0x5E00,	0x5E04,	0x5E07,	0x5E09,	0x5E0A,	0x5E0B,	0x5E0D,
	0x5E0E,	0x5E12,	0x5E13,	0x5E17,	0x5E1E,	0x5E1F,	0x5E20,	0x5E21,
	0x5E22,	0x5E23,	0x5E24,	0x5E25,	0x5E28,	0x5E29,	0x5E2A,	0x5E2B,
	0x5E2C,	0x5E2F,	0x5E30,	0x5E32,	0x5E33,	0x5E34,	0x5E35,	0x5E36,
	0x5E39,	0x5E3A,	0x5E3E,	0x5E3F,	0x5E40,	0x5E41,	0x5E43,	0x5E46,
	0x5E47,	0x5E48,	0x5E49,	0x5E4A,	0x5E4B,	0x5E4D,	0x5E4E,	0x5E4F,
	0x5E50,	0x5E51,	0x5E52,	0x5E53,	0x5E56,	0x5E57,	0x5E58,	0x5E59,
	0x5E5A,	0x5E5C,	0x5E5D,	0x5E5F,	0x5E60,	0x5E63,	0x5E64,	0x5E65,
	0x5E66,	0x5E67,	0x5E68,	0x5E69,	0x5E6A,	0x5E6B,	0x5E6C,	0x5E6D,
	0x5E6E,	0x5E6F,	0x5E70,	0x5E71,	0x5E75,	0x5E77,	0x5E79,	0x5E7E,
	0x5E81,	0x5E82,	0x5E83,	0x5E85,	0x5E88,	0x5E89,	0x5E8C,	0x5E8D,
	0x5E8E,	0x5E92,	0x5E98,	0x5E9B,	0x5E9D,	0x5EA1,	0x5EA2,	0x5EA3,
	0x5EA4,	0x5EA8,	0x5EA9,	0x5EAA,	0x5EAB,	0x5EAC,	0x5EAE,	0x5EAF,
	0x5EB0,	0x5EB1,	0x5EB2,	0x5EB4,	0x5EBA,	0x5EBB,	0x5EBC,	0x5EBD,
	0x5EBF,	0x5EC0,	0x5EC1,	0x5EC2,	0x5EC3,	0x5EC4,	0x5EC5,
	/* GB 0x8F40..0x8F7E */
	0x5EC6,	0x5EC7,	0x5EC8,	0x5ECB,	0x5ECC,	0x5ECD,	0x5ECE,	0x5ECF,
	0x5ED0,	0x5ED4,	0x5ED5,	0x5ED7,	0x5ED8,	0x5ED9,	0x5EDA,	0x5EDC,
	0x5EDD,	0x5EDE,	0x5EDF,	0x5EE0,	0x5EE1,	0x5EE2,	0x5EE3,	0x5EE4,
	0x5EE5,	0x5EE6,	0x5EE7,	0x5EE9,	0x5EEB,	0x5EEC,	0x5EED,	0x5EEE,
	0x5EEF,	0x5EF0,	0x5EF1,	0x5EF2,	0x5EF3,	0x5EF5,	0x5EF8,	0x5EF9,
	0x5EFB,	0x5EFC,	0x5EFD,	0x5F05,	0x5F06,	0x5F07,	0x5F09,	0x5F0C,
	0x5F0D,	0x5F0E,	0x5F10,	0x5F12,	0x5F14,	0x5F16,	0x5F19,	0x5F1A,
	0x5F1C,	0x5F1D,	0x5F1E,	0x5F21,	0x5F22,	0x5F23,	0x5F24,
	/* GB 0x8F80..0x8FFE */
	0x5F28,	0x5F2B,	0x5F2C,	0x5F2E,	0x5F30,	0x5F32,	0x5F33,	0x5F34,
	0x5F35,	0x5F36,	0x5F37,	0x5F38,	0x5F3B,	0x5F3D,	0x5F3E,	0x5F3F,
	0x5F41,	0x5F42,	0x5F43,	0x5F44,	0x5F45,	0x5F46,	0x5F47,	0x5F48,
	0x5F49,	0x5F4A,	0x5F4B,	0x5F4C,	0x5F4D,	0x5F4E,	0x5F4F,	0x5F51,
	0x5F54,	0x5F59,	0x5F5A,	0x5F5B,	0x5F5C,	0x5F5E,	0x5F5F,	0x5F60,
	0x5F63,	0x5F65,	0x5F67,	0x5F68,	0x5F6B,	0x5F6E,	0x5F6F,	0x5F72,
	0x5F74,	0x5F75,	0x5F76,	0x5F78,	0x5F7A,	0x5F7D,	0x5F7E,	0x5F7F,
	0x5F83,	0x5F86,	0x5F8D,	0x5F8E,	0x5F8F,	0x5F91,	0x5F93,	0x5F94,
	0x5F96,	0x5F9A,	0x5F9B,	0x5F9D,	0x5F9E,	0x5F9F,	0x5FA0,	0x5FA2,
	0x5FA3,	0x5FA4,	0x5FA5,	0x5FA6,	0x5FA7,	0x5FA9,	0x5FAB,	0x5FAC,
	0x5FAF,	0x5FB0,	0x5FB1,	0x5FB2,	0x5FB3,	0x5FB4,	0x5FB6,	0x5FB8,
	0x5FB9,	0x5FBA,	0x5FBB,	0x5FBE,	0x5FBF,	0x5FC0,	0x5FC1,	0x5FC2,
	0x5FC7,	0x5FC8,	0x5FCA,	0x5FCB,	0x5FCE,	0x5FD3,	0x5FD4,	0x5FD5,
	0x5FDA,	0x5FDB,	0x5FDC,	0x5FDE,	0x5FDF,	0x5FE2,	0x5FE3,	0x5FE5,
	0x5FE6,	0x5FE8,	0x5FE9,	0x5FEC,	0x5FEF,	0x5FF0,	0x5FF2,	0x5FF3,
	0x5FF4,	0x5FF6,	0x5FF7,	0x5FF9,	0x5FFA,	0x5FFC,	0x6007,
	/* GB 0x9040..0x907E */
	0x6008,	0x6009,	0x600B,	0x600C,	0x6010,	0x6011,	0x6013,	0x6017,
	0x6018,	0x601A,	0x601E,	0x601F,	0x6022,	0x6023,	0x6024,	0x602C,
	0x602D,	0x602E,	0x6030,	0x6031,	0x6032,	0x6033,	0x6034,	0x6036,
	0x6037,	0x6038,	0x6039,	0x603A,	0x603D,	0x603E,	0x6040,	0x6044,
	0x6045,	0x6046,	0x6047,	0x6048,	0x6049,	0x604A,	0x604C,	0x604E,
	0x604F,	0x6051,	0x6053,	0x6054,	0x6056,	0x6057,	0x6058,	0x605B,
	0x605C,	0x605E,	0x605F,	0x6060,	0x6061,	0x6065,	0x6066,	0x606E,
	0x6071,	0x6072,	0x6074,	0x6075,	0x6077,	0x607E,	0x6080,
	/* GB 0x9080..0x90FE */
	0x6081,	0x6082,	0x6085,	0x6086,	0x6087,	0x6088,	0x608A,	0x608B,
	0x608E,	0x608F,	0x6090,	0x6091,	0x6093,	0x6095,	0x6097,	0x6098,
	0x6099,	0x609C,	0x609E,	0x60A1,	0x60A2,	0x60A4,	0x60A5,	0x60A7,
	0x60A9,	0x60AA,	0x60AE,	0x60B0,	0x60B3,	0x60B5,	0x60B6,	0x60B7,
	0x60B9,	0x60BA,	0x60BD,	0x60BE,	0x60BF,	0x60C0,	0x60C1,	0x60C2,
	0x60C3,	0x60C4,	0x60C7,	0x60C8,	0x60C9,	0x60CC,	0x60CD,	0x60CE,
	0x60CF,	0x60D0,	0x60D2,	0x60D3,	0x60D4,	0x60D6,	0x60D7,	0x60D9,
	0x60DB,	0x60DE,	0x60E1,	0x60E2,	0x60E3,	0x60E4,	0x60E5,	0x60EA,
	0x60F1,	0x60F2,	0x60F5,	0x60F7,	0x60F8,	0x60FB,	0x60FC,	0x60FD,
	0x60FE,	0x60FF,	0x6102,	0x6103,	0x6104,	0x6105,	0x6107,	0x610A,
	0x610B,	0x610C,	0x6110,	0x6111,	0x6112,	0x6113,	0x6114,	0x6116,
	0x6117,	0x6118,	0x6119,	0x611B,	0x611C,	0x611D,	0x611E,	0x6121,
	0x6122,	0x6125,	0x6128,	0x6129,	0x612A,	0x612C,	0x612D,	0x612E,
	0x612F,	0x6130,	0x6131,	0x6132,	0x6133,	0x6134,	0x6135,	0x6136,
	0x6137,	0x6138,	0x6139,	0x613A,	0x613B,	0x613C,	0x613D,	0x613E,
	0x6140,	0x6141,	0x6142,	0x6143,	0x6144,	0x6145,	0x6146,
	/* GB 0x9140..0x917E */
	0x6147,	0x6149,	0x614B,	0x614D,	0x614F,	0x6150,	0x6152,	0x6153,
	0x6154,	0x6156,	0x6157,	0x6158,	0x6159,	0x615A,	0x615B,	0x615C,
	0x615E,	0x615F,	0x6160,	0x6161,	0x6163,	0x6164,	0x6165,	0x6166,
	0x6169,	0x616A,	0x616B,	0x616C,	0x616D,	0x616E,	0x616F,	0x6171,
	0x6172,	0x6173,	0x6174,	0x6176,	0x6178,	0x6179,	0x617A,	0x617B,
	0x617C,	0x617D,	0x617E,	0x617F,	0x6180,	0x6181,	0x6182,	0x6183,
	0x6184,	0x6185,	0x6186,	0x6187,	0x6188,	0x6189,	0x618A,	0x618C,
	0x618D,	0x618F,	0x6190,	0x6191,	0x6192,	0x6193,	0x6195,
	/* GB 0x9180..0x91FE */
	0x6196,	0x6197,	0x6198,	0x6199,	0x619A,	0x619B,	0x619C,	0x619E,
	0x619F,	0x61A0,	0x61A1,	0x61A2,	0x61A3,	0x61A4,	0x61A5,	0x61A6,
	0x61AA,	0x61AB,	0x61AD,	0x61AE,	0x61AF,	0x61B0,	0x61B1,	0x61B2,
	0x61B3,	0x61B4,	0x61B5,	0x61B6,	0x61B8,	0x61B9,	0x61BA,	0x61BB,
	0x61BC,	0x61BD,	0x61BF,	0x61C0,	0x61C1,	0x61C3,	0x61C4,	0x61C5,
	0x61C6,	0x61C7,	0x61C9,	0x61CC,	0x61CD,	0x61CE,	0x61CF,	0x61D0,
	0x61D3,	0x61D5,	0x61D6,	0x61D7,	0x61D8,	0x61D9,	0x61DA,	0x61DB,
	0x61DC,	0x61DD,	0x61DE,	0x61DF,	0x61E0,	0x61E1,	0x61E2,	0x61E3,
	0x61E4,	0x61E5,	0x61E7,	0x61E8,	0x61E9,	0x61EA,	0x61EB,	0x61EC,
	0x61ED,	0x61EE,	0x61EF,	0x61F0,	0x61F1,	0x61F2,	0x61F3,	0x61F4,
	0x61F6,	0x61F7,	0x61F8,	0x61F9,	0x61FA,	0x61FB,	0x61FC,	0x61FD,
	0x61FE,	0x6200,	0x6201,	0x6202,	0x6203,	0x6204,	0x6205,	0x6207,
	0x6209,	0x6213,	0x6214,	0x6219,	0x621C,	0x621D,	0x621E,	0x6220,
	0x6223,	0x6226,	0x6227,	0x6228,	0x6229,	0x622B,	0x622D,	0x622F,
	0x6230,	0x6231,	0x6232,	0x6235,	0x6236,	0x6238,	0x6239,	0x623A,
	0x623B,	0x623C,	0x6242,	0x6244,	0x6245,	0x6246,	0x624A,
	/* GB 0x9240..0x927E */
	0x624F,	0x6250,	0x6255,	0x6256,	0x6257,	0x6259,	0x625A,	0x625C,
	0x625D,	0x625E,	0x625F,	0x6260,	0x6261,	0x6262,	0x6264,	0x6265,
	0x6268,	0x6271,	0x6272,	0x6274,	0x6275,	0x6277,	0x6278,	0x627A,
	0x627B,	0x627D,	0x6281,	0x6282,	0x6283,	0x6285,	0x6286,	0x6287,
	0x6288,	0x628B,	0x628C,	0x628D,	0x628E,	0x628F,	0x6290,	0x6294,
	0x6299,	0x629C,	0x629D,	0x629E,	0x62A3,	0x62A6,	0x62A7,	0x62A9,
	0x62AA,	0x62AD,	0x62AE,	0x62AF,	0x62B0,	0x62B2,	0x62B3,	0x62B4,
	0x62B6,	0x62B7,	0x62B8,	0x62BA,	0x62BE,	0x62C0,	0x62C1,
	/* GB 0x9280..0x92FE */
	0x62C3,	0x62CB,	0x62CF,	0x62D1,	0x62D5,	0x62DD,	0x62DE,	0x62E0,
	0x62E1,	0x62E4,	0x62EA,	0x62EB,	0x62F0,	0x62F2,	0x62F5,	0x62F8,
	0x62F9,	0x62FA,	0x62FB,	0x6300,	0x6303,	0x6304,	0x6305,	0x6306,
	0x630A,	0x630B,	0x630C,	0x630D,	0x630F,	0x6310,	0x6312,	0x6313,
	0x6314,	0x6315,	0x6317,	0x6318,	0x6319,	0x631C,	0x6326,	0x6327,
	0x6329,	0x632C,	0x632D,	0x632E,	0x6330,	0x6331,	0x6333,	0x6334,
	0x6335,	0x6336,	0x6337,	0x6338,	0x633B,	0x633C,	0x633E,	0x633F,
	0x6340,	0x6341,	0x6344,	0x6347,	0x6348,	0x634A,	0x6351,	0x6352,
	0x6353,	0x6354,	0x6356,	0x6357,	0x6358,	0x6359,	0x635A,	0x635B,
	0x635C,	0x635D,	0x6360,	0x6364,	0x6365,	0x6366,	0x6368,	0x636A,
	0x636B,	0x636C,	0x636F,	0x6370,	0x6372,	0x6373,	0x6374,	0x6375,
	0x6378,	0x6379,	0x637C,	0x637D,	0x637E,	0x637F,	0x6381,	0x6383,
	0x6384,	0x6385,	0x6386,	0x638B,	0x638D,	0x6391,	0x6393,	0x6394,
	0x6395,	0x6397,	0x6399,	0x639A,	0x639B,	0x639C,	0x639D,	0x639E,
	0x639F,	0x63A1,	0x63A4,	0x63A6,	0x63AB,	0x63AF,	0x63B1,	0x63B2,
	0x63B5,	0x63B6,	0x63B9,	0x63BB,	0x63BD,	0x63BF,	0x63C0,
	/* GB 0x9340..0x937E */
	0x63C1,	0x63C2,	0x63C3,	0x63C5,	0x63C7,	0x63C8,	0x63CA,	0x63CB,
	0x63CC,	0x63D1,	0x63D3,	0x63D4,	0x63D5,	0x63D7,	0x63D8,	0x63D9,
	0x63DA,	0x63DB,	0x63DC,	0x63DD,	0x63DF,	0x63E2,	0x63E4,	0x63E5,
	0x63E6,	0x63E7,	0x63E8,	0x63EB,	0x63EC,	0x63EE,	0x63EF,	0x63F0,
	0x63F1,	0x63F3,	0x63F5,	0x63F7,	0x63F9,	0x63FA,	0x63FB,	0x63FC,
	0x63FE,	0x6403,	0x6404,	0x6406,	0x6407,	0x6408,	0x6409,	0x640A,
	0x640D,	0x640E,	0x6411,	0x6412,	0x6415,	0x6416,	0x6417,	0x6418,
	0x6419,	0x641A,	0x641D,	0x641F,	0x6422,	0x6423,	0x6424,
	/* GB 0x9380..0x93FE */
	0x6425,	0x6427,	0x6428,	0x6429,	0x642B,	0x642E,	0x642F,	0x6430,
	0x6431,	0x6432,	0x6433,	0x6435,	0x6436,	0x6437,	0x6438,	0x6439,
	0x643B,	0x643C,	0x643E,	0x6440,	0x6442,	0x6443,	0x6449,	0x644B,
	0x644C,	0x644D,	0x644E,	0x644F,	0x6450,	0x6451,	0x6453,	0x6455,
	0x6456,	0x6457,	0x6459,	0x645A,	0x645B,	0x645C,	0x645D,	0x645F,
	0x6460,	0x6461,	0x6462,	0x6463,	0x6464,	0x6465,	0x6466,	0x6468,
	0x646A,	0x646B,	0x646C,	0x646E,	0x646F,	0x6470,	0x6471,	0x6472,
	0x6473,	0x6474,	0x6475,	0x6476,	0x6477,	0x647B,	0x647C,	0x647D,
	0x647E,	0x647F,	0x6480,	0x6481,	0x6483,	0x6486,	0x6488,	0x6489,
	0x648A,	0x648B,	0x648C,	0x648D,	0x648E,	0x648F,	0x6490,	0x6493,
	0x6494,	0x6497,	0x6498,	0x649A,	0x649B,	0x649C,	0x649D,	0x649F,
	0x64A0,	0x64A1,	0x64A2,	0x64A3,	0x64A5,	0x64A6,	0x64A7,	0x64A8,
	0x64AA,	0x64AB,	0x64AF,	0x64B1,	0x64B2,	0x64B3,	0x64B4,	0x64B6,
	0x64B9,	0x64BB,	0x64BD,	0x64BE,	0x64BF,	0x64C1,	0x64C3,	0x64C4,
	0x64C6,	0x64C7,	0x64C8,	0x64C9,	0x64CA,	0x64CB,	0x64CC,	0x64CF,
	0x64D1,	0x64D3,	0x64D4,	0x64D5,	0x64D6,	0x64D9,	0x64DA,
	/* GB 0x9440..0x947E */
	0x64DB,	0x64DC,	0x64DD,	0x64DF,	0x64E0,	0x64E1,	0x64E3,	0x64E5,
	0x64E7,	0x64E8,	0x64E9,	0x64EA,	0x64EB,	0x64EC,	0x64ED,	0x64EE,
	0x64EF,	0x64F0,	0x64F1,	0x64F2,	0x64F3,	0x64F4,	0x64F5,	0x64F6,
	0x64F7,	0x64F8,	0x64F9,	0x64FA,	0x64FB,	0x64FC,	0x64FD,	0x64FE,
	0x64FF,	0x6501,	0x6502,	0x6503,	0x6504,	0x6505,	0x6506,	0x6507,
	0x6508,	0x650A,	0x650B,	0x650C,	0x650D,	0x650E,	0x650F,	0x6510,
	0x6511,	0x6513,	0x6514,	0x6515,	0x6516,	0x6517,	0x6519,	0x651A,
	0x651B,	0x651C,	0x651D,	0x651E,	0x651F,	0x6520,	0x6521,
	/* GB 0x9480..0x94FE */
	0x6522,	0x6523,	0x6524,	0x6526,	0x6527,	0x6528,	0x6529,	0x652A,
	0x652C,	0x652D,	0x6530,	0x6531,	0x6532,	0x6533,	0x6537,	0x653A,
	0x653C,	0x653D,	0x6540,	0x6541,	0x6542,	0x6543,	0x6544,	0x6546,
	0x6547,	0x654A,	0x654B,	0x654D,	0x654E,	0x6550,	0x6552,	0x6553,
	0x6554,	0x6557,	0x6558,	0x655A,	0x655C,	0x655F,	0x6560,	0x6561,
	0x6564,	0x6565,	0x6567,	0x6568,	0x6569,	0x656A,	0x656D,	0x656E,
	0x656F,	0x6571,	0x6573,	0x6575,	0x6576,	0x6578,	0x6579,	0x657A,
	0x657B,	0x657C,	0x657D,	0x657E,	0x657F,	0x6580,	0x6581,	0x6582,
	0x6583,	0x6584,	0x6585,	0x6586,	0x6588,	0x6589,	0x658A,	0x658D,
	0x658E,	0x658F,	0x6592,	0x6594,	0x6595,	0x6596,	0x6598,	0x659A,
	0x659D,	0x659E,	0x65A0,	0x65A2,	0x65A3,	0x65A6,	0x65A8,	0x65AA,
	0x65AC,	0x65AE,	0x65B1,	0x65B2,	0x65B3,	0x65B4,	0x65B5,	0x65B6,
	0x65B7,	0x65B8,	0x65BA,	0x65BB,	0x65BE,	0x65BF,	0x65C0,	0x65C2,
	0x65C7,	0x65C8,	0x65C9,	0x65CA,	0x65CD,	0x65D0,	0x65D1,	0x65D3,
	0x65D4,	0x65D5,	0x65D8,	0x65D9,	0x65DA,	0x65DB,	0x65DC,	0x65DD,
	0x65DE,	0x65DF,	0x65E1,	0x65E3,	0x65E4,	0x65EA,	0x65EB,
	/* GB 0x9540..0x957E */
	0x65F2,	0x65F3,	0x65F4,	0x65F5,	0x65F8,	0x65F9,	0x65FB,	0x65FC,
	0x65FD,	0x65FE,	0x65FF,	0x6601,	0x6604,	0x6605,	0x6607,	0x6608,
	0x6609,	0x660B,	0x660D,	0x6610,	0x6611,	0x6612,	0x6616,	0x6617,
	0x6618,	0x661A,	0x661B,	0x661C,	0x661E,	0x6621,	0x6622,	0x6623,
	0x6624,	0x6626,	0x6629,	0x662A,	0x662B,	0x662C,	0x662E,	0x6630,
	0x6632,	0x6633,	0x6637,	0x6638,	0x6639,	0x663A,	0x663B,	0x663D,
	0x663F,	0x6640,	0x6642,	0x6644,	0x6645,	0x6646,	0x6647,	0x6648,
	0x6649,	0x664A,	0x664D,	0x664E,	0x6650,	0x6651,	0x6658,
	/* GB 0x9580..0x95FE */
	0x6659,	0x665B,	0x665C,	0x665D,	0x665E,	0x6660,	0x6662,	0x6663,
	0x6665,	0x6667,	0x6669,	0x666A,	0x666B,	0x666C,	0x666D,	0x6671,
	0x6672,	0x6673,	0x6675,	0x6678,	0x6679,	0x667B,	0x667C,	0x667D,
	0x667F,	0x6680,	0x6681,	0x6683,	0x6685,	0x6686,	0x6688,	0x6689,
	0x668A,	0x668B,	0x668D,	0x668E,	0x668F,	0x6690,	0x6692,	0x6693,
	0x6694,	0x6695,	0x6698,	0x6699,	0x669A,	0x669B,	0x669C,	0x669E,
	0x669F,	0x66A0,	0x66A1,	0x66A2,	0x66A3,	0x66A4,	0x66A5,	0x66A6,
	0x66A9,	0x66AA,	0x66AB,	0x66AC,	0x66AD,	0x66AF,	0x66B0,	0x66B1,
	0x66B2,	0x66B3,	0x66B5,	0x66B6,	0x66B7,	0x66B8,	0x66BA,	0x66BB,
	0x66BC,	0x66BD,	0x66BF,	0x66C0,	0x66C1,	0x66C2,	0x66C3,	0x66C4,
	0x66C5,	0x66C6,	0x66C7,	0x66C8,	0x66C9,	0x66CA,	0x66CB,	0x66CC,
	0x66CD,	0x66CE,	0x66CF,	0x66D0,	0x66D1,	0x66D2,	0x66D3,	0x66D4,
	0x66D5,	0x66D6,	0x66D7,	0x66D8,	0x66DA,	0x66DE,	0x66DF,	0x66E0,
	0x66E1,	0x66E2,	0x66E3,	0x66E4,	0x66E5,	0x66E7,	0x66E8,	0x66EA,
	0x66EB,	0x66EC,	0x66ED,	0x66EE,	0x66EF,	0x66F1,	0x66F5,	0x66F6,
	0x66F8,	0x66FA,	0x66FB,	0x66FD,	0x6701,	0x6702,	0x6703,
	/* GB 0x9640..0x967E */
	0x6704,	0x6705,	0x6706,	0x6707,	0x670C,	0x670E,	0x670F,	0x6711,
	0x6712,	0x6713,	0x6716,	0x6718,	0x6719,	0x671A,	0x671C,	0x671E,
	0x6720,	0x6721,	0x6722,	0x6723,	0x6724,	0x6725,	0x6727,	0x6729,
	0x672E,	0x6730,	0x6732,	0x6733,	0x6736,	0x6737,	0x6738,	0x6739,
	0x673B,	0x673C,	0x673E,	0x673F,	0x6741,	0x6744,	0x6745,	0x6747,
	0x674A,	0x674B,	0x674D,	0x6752,	0x6754,	0x6755,	0x6757,	0x6758,
	0x6759,	0x675A,	0x675B,	0x675D,	0x6762,	0x6763,	0x6764,	0x6766,
	0x6767,	0x676B,	0x676C,	0x676E,	0x6771,	0x6774,	0x6776,
	/* GB 0x9680..0x96FE */
	0x6778,	0x6779,	0x677A,	0x677B,	0x677D,	0x6780,	0x6782,	0x6783,
	0x6785,	0x6786,	0x6788,	0x678A,	0x678C,	0x678D,	0x678E,	0x678F,
	0x6791,	0x6792,	0x6793,	0x6794,	0x6796,	0x6799,	0x679B,	0x679F,
	0x67A0,	0x67A1,	0x67A4,	0x67A6,	0x67A9,	0x67AC,	0x67AE,	0x67B1,
	0x67B2,	0x67B4,	0x67B9,	0x67BA,	0x67BB,	0x67BC,	0x67BD,	0x67BE,
	0x67BF,	0x67C0,	0x67C2,	0x67C5,	0x67C6,	0x67C7,	0x67C8,	0x67C9,
	0x67CA,	0x67CB,	0x67CC,	0x67CD,	0x67CE,	0x67D5,	0x67D6,	0x67D7,
	0x67DB,	0x67DF,	0x67E1,	0x67E3,	0x67E4,	0x67E6,	0x67E7,	0x67E8,
	0x67EA,	0x67EB,	0x67ED,	0x67EE,	0x67F2,	0x67F5,	0x67F6,	0x67F7,
	0x67F8,	0x67F9,	0x67FA,	0x67FB,	0x67FC,	0x67FE,	0x6801,	0x6802,
	0x6803,	0x6804,	0x6806,	0x680D,	0x6810,	0x6812,	0x6814,	0x6815,
	0x6818,	0x6819,	0x681A,	0x681B,	0x681C,	0x681E,	0x681F,	0x6820,
	0x6822,	0x6823,	0x6824,	0x6825,	0x6826,	0x6827,	0x6828,	0x682B,
	0x682C,	0x682D,	0x682E,	0x682F,	0x6830,	0x6831,	0x6834,	0x6835,
	0x6836,	0x683A,	0x683B,	0x683F,	0x6847,	0x684B,	0x684D,	0x684F,
	0x6852,	0x6856,	0x6857,	0x6858,	0x6859,	0x685A,	0x685B,
	/* GB 0x9740..0x977E */
	0x685C,	0x685D,	0x685E,	0x685F,	0x686A,	0x686C,	0x686D,	0x686E,
	0x686F,	0x6870,	0x6871,	0x6872,	0x6873,	0x6875,	0x6878,	0x6879,
	0x687A,	0x687B,	0x687C,	0x687D,	0x687E,	0x687F,	0x6880,	0x6882,
	0x6884,	0x6887,	0x6888,	0x6889,	0x688A,	0x688B,	0x688C,	0x688D,
	0x688E,	0x6890,	0x6891,	0x6892,	0x6894,	0x6895,	0x6896,	0x6898,
	0x6899,	0x689A,	0x689B,	0x689C,	0x689D,	0x689E,	0x689F,	0x68A0,
	0x68A1,	0x68A3,	0x68A4,	0x68A5,	0x68A9,	0x68AA,	0x68AB,	0x68AC,
	0x68AE,	0x68B1,	0x68B2,	0x68B4,	0x68B6,	0x68B7,	0x68B8,
	/* GB 0x9780..0x97FE */
	0x68B9,	0x68BA,	0x68BB,	0x68BC,	0x68BD,	0x68BE,	0x68BF,	0x68C1,
	0x68C3,	0x68C4,	0x68C5,	0x68C6,	0x68C7,	0x68C8,	0x68CA,	0x68CC,
	0x68CE,	0x68CF,	0x68D0,	0x68D1,	0x68D3,	0x68D4,	0x68D6,	0x68D7,
	0x68D9,	0x68DB,	0x68DC,	0x68DD,	0x68DE,	0x68DF,	0x68E1,	0x68E2,
	0x68E4,	0x68E5,	0x68E6,	0x68E7,	0x68E8,	0x68E9,	0x68EA,	0x68EB,
	0x68EC,	0x68ED,	0x68EF,	0x68F2,	0x68F3,	0x68F4,	0x68F6,	0x68F7,
	0x68F8,	0x68FB,	0x68FD,	0x68FE,	0x68FF,	0x6900,	0x6902,	0x6903,
	0x6904,	0x6906,	0x6907,	0x6908,	0x6909,	0x690A,	0x690C,	0x690F,
	0x6911,	0x6913,	0x6914,	0x6915,	0x6916,	0x6917,	0x6918,	0x6919,
	0x691A,	0x691B,	0x691C,	0x691D,	0x691E,	0x6921,	0x6922,	0x6923,
	0x6925,	0x6926,	0x6927,	0x6928,	0x6929,	0x692A,	0x692B,	0x692C,
	0x692E,	0x692F,	0x6931,	0x6932,	0x6933,	0x6935,	0x6936,	0x6937,
	0x6938,	0x693A,	0x693B,	0x693C,	0x693E,	0x6940,	0x6941,	0x6943,
	0x6944,	0x6945,	0x6946,	0x6947,	0x6948,	0x6949,	0x694A,	0x694B,
	0x694C,	0x694D,	0x694E,	0x694F,	0x6950,	0x6951,	0x6952,	0x6953,
	0x6955,	0x6956,	0x6958,	0x6959,	0x695B,	0x695C,	0x695F,
	/* GB 0x9840..0x987E */
	0x6961,	0x6962,	0x6964,	0x6965,	0x6967,	0x6968,	0x6969,	0x696A,
	0x696C,	0x696D,	0x696F,	0x6970,	0x6972,	0x6973,	0x6974,	0x6975,
	0x6976,	0x697A,	0x697B,	0x697D,	0x697E,	0x697F,	0x6981,	0x6983,
	0x6985,	0x698A,	0x698B,	0x698C,	0x698E,	0x698F,	0x6990,	0x6991,
	0x6992,	0x6993,	0x6996,	0x6997,	0x6999,	0x699A,	0x699D,	0x699E,
	0x699F,	0x69A0,	0x69A1,	0x69A2,	0x69A3,	0x69A4,	0x69A5,	0x69A6,
	0x69A9,	0x69AA,	0x69AC,	0x69AE,	0x69AF,	0x69B0,	0x69B2,	0x69B3,
	0x69B5,	0x69B6,	0x69B8,	0x69B9,	0x69BA,	0x69BC,	0x69BD,
	/* GB 0x9880..0x98FE */
	0x69BE,	0x69BF,	0x69C0,	0x69C2,	0x69C3,	0x69C4,	0x69C5,	0x69C6,
	0x69C7,	0x69C8,	0x69C9,	0x69CB,	0x69CD,	0x69CF,	0x69D1,	0x69D2,
	0x69D3,	0x69D5,	0x69D6,	0x69D7,	0x69D8,	0x69D9,	0x69DA,	0x69DC,
	0x69DD,	0x69DE,	0x69E1,	0x69E2,	0x69E3,	0x69E4,	0x69E5,	0x69E6,
	0x69E7,	0x69E8,	0x69E9,	0x69EA,	0x69EB,	0x69EC,	0x69EE,	0x69EF,
	0x69F0,	0x69F1,	0x69F3,	0x69F4,	0x69F5,	0x69F6,	0x69F7,	0x69F8,
	0x69F9,	0x69FA,	0x69FB,	0x69FC,	0x69FE,	0x6A00,	0x6A01,	0x6A02,
	0x6A03,	0x6A04,	0x6A05,	0x6A06,	0x6A07,	0x6A08,	0x6A09,	0x6A0B,
	0x6A0C,	0x6A0D,	0x6A0E,	0x6A0F,	0x6A10,	0x6A11,	0x6A12,	0x6A13,
	0x6A14,	0x6A15,	0x6A16,	0x6A19,	0x6A1A,	0x6A1B,	0x6A1C,	0x6A1D,
	0x6A1E,	0x6A20,	0x6A22,	0x6A23,	0x6A24,	0x6A25,	0x6A26,	0x6A27,
	0x6A29,	0x6A2B,	0x6A2C,	0x6A2D,	0x6A2E,	0x6A30,	0x6A32,	0x6A33,
	0x6A34,	0x6A36,	0x6A37,	0x6A38,	0x6A39,	0x6A3A,	0x6A3B,	0x6A3C,
	0x6A3F,	0x6A40,	0x6A41,	0x6A42,	0x6A43,	0x6A45,	0x6A46,	0x6A48,
	0x6A49,	0x6A4A,	0x6A4B,	0x6A4C,	0x6A4D,	0x6A4E,	0x6A4F,	0x6A51,
	0x6A52,	0x6A53,	0x6A54,	0x6A55,	0x6A56,	0x6A57,	0x6A5A,
	/* GB 0x9940..0x997E */
	0x6A5C,	0x6A5D,	0x6A5E,	0x6A5F,	0x6A60,	0x6A62,	0x6A63,	0x6A64,
	0x6A66,	0x6A67,	0x6A68,	0x6A69,	0x6A6A,	0x6A6B,	0x6A6C,	0x6A6D,
	0x6A6E,	0x6A6F,	0x6A70,	0x6A72,	0x6A73,	0x6A74,	0x6A75,	0x6A76,
	0x6A77,	0x6A78,	0x6A7A,	0x6A7B,	0x6A7D,	0x6A7E,	0x6A7F,	0x6A81,
	0x6A82,	0x6A83,	0x6A85,	0x6A86,	0x6A87,	0x6A88,	0x6A89,	0x6A8A,
	0x6A8B,	0x6A8C,	0x6A8D,	0x6A8F,	0x6A92,	0x6A93,	0x6A94,	0x6A95,
	0x6A96,	0x6A98,	0x6A99,	0x6A9A,	0x6A9B,	0x6A9C,	0x6A9D,	0x6A9E,
	0x6A9F,	0x6AA1,	0x6AA2,	0x6AA3,	0x6AA4,	0x6AA5,	0x6AA6,
	/* GB 0x9980..0x99FE */
	0x6AA7,	0x6AA8,	0x6AAA,	0x6AAD,	0x6AAE,	0x6AAF,	0x6AB0,	0x6AB1,
	0x6AB2,	0x6AB3,	0x6AB4,	0x6AB5,	0x6AB6,	0x6AB7,	0x6AB8,	0x6AB9,
	0x6ABA,	0x6ABB,	0x6ABC,	0x6ABD,	0x6ABE,	0x6ABF,	0x6AC0,	0x6AC1,
	0x6AC2,	0x6AC3,	0x6AC4,	0x6AC5,	0x6AC6,	0x6AC7,	0x6AC8,	0x6AC9,
	0x6ACA,	0x6ACB,	0x6ACC,	0x6ACD,	0x6ACE,	0x6ACF,	0x6AD0,	0x6AD1,
	0x6AD2,	0x6AD3,	0x6AD4,	0x6AD5,	0x6AD6,	0x6AD7,	0x6AD8,	0x6AD9,
	0x6ADA,	0x6ADB,	0x6ADC,	0x6ADD,	0x6ADE,	0x6ADF,	0x6AE0,	0x6AE1,
	0x6AE2,	0x6AE3,	0x6AE4,	0x6AE5,	0x6AE6,	0x6AE7,	0x6AE8,	0x6AE9,
	0x6AEA,	0x6AEB,	0x6AEC,	0x6AED,	0x6AEE,	0x6AEF,	0x6AF0,	0x6AF1,
	0x6AF2,	0x6AF3,	0x6AF4,	0x6AF5,	0x6AF6,	0x6AF7,	0x6AF8,	0x6AF9,
	0x6AFA,	0x6AFB,	0x6AFC,	0x6AFD,	0x6AFE,	0x6AFF,	0x6B00,	0x6B01,
	0x6B02,	0x6B03,	0x6B04,	0x6B05,	0x6B06,	0x6B07,	0x6B08,	0x6B09,
	0x6B0A,	0x6B0B,	0x6B0C,	0x6B0D,	0x6B0E,	0x6B0F,	0x6B10,	0x6B11,
	0x6B12,	0x6B13,	0x6B14,	0x6B15,	0x6B16,	0x6B17,	0x6B18,	0x6B19,
	0x6B1A,	0x6B1B,	0x6B1C,	0x6B1D,	0x6B1E,	0x6B1F,	0x6B25,	0x6B26,
	0x6B28,	0x6B29,	0x6B2A,	0x6B2B,	0x6B2C,	0x6B2D,	0x6B2E,
	/* GB 0x9A40..0x9A7E */
	0x6B2F,	0x6B30,	0x6B31,	0x6B33,	0x6B34,	0x6B35,	0x6B36,	0x6B38,
	0x6B3B,	0x6B3C,	0x6B3D,	0x6B3F,	0x6B40,	0x6B41,	0x6B42,	0x6B44,
	0x6B45,	0x6B48,	0x6B4A,	0x6B4B,	0x6B4D,	0x6B4E,	0x6B4F,	0x6B50,
	0x6B51,	0x6B52,	0x6B53,	0x6B54,	0x6B55,	0x6B56,	0x6B57,	0x6B58,
	0x6B5A,	0x6B5B,	0x6B5C,	0x6B5D,	0x6B5E,	0x6B5F,	0x6B60,	0x6B61,
	0x6B68,	0x6B69,	0x6B6B,	0x6B6C,	0x6B6D,	0x6B6E,	0x6B6F,	0x6B70,
	0x6B71,	0x6B72,	0x6B73,	0x6B74,	0x6B75,	0x6B76,	0x6B77,	0x6B78,
	0x6B7A,	0x6B7D,	0x6B7E,	0x6B7F,	0x6B80,	0x6B85,	0x6B88,
	/* GB 0x9A80..0x9AFE */
	0x6B8C,	0x6B8E,	0x6B8F,	0x6B90,	0x6B91,	0x6B94,	0x6B95,	0x6B97,
	0x6B98,	0x6B99,	0x6B9C,	0x6B9D,	0x6B9E,	0x6B9F,	0x6BA0,	0x6BA2,
	0x6BA3,	0x6BA4,	0x6BA5,	0x6BA6,	0x6BA7,	0x6BA8,	0x6BA9,	0x6BAB,
	0x6BAC,	0x6BAD,	0x6BAE,	0x6BAF,	0x6BB0,	0x6BB1,	0x6BB2,	0x6BB6,
	0x6BB8,	0x6BB9,	0x6BBA,	0x6BBB,	0x6BBC,	0x6BBD,	0x6BBE,	0x6BC0,
	0x6BC3,	0x6BC4,	0x6BC6,	0x6BC7,	0x6BC8,	0x6BC9,	0x6BCA,	0x6BCC,
	0x6BCE,	0x6BD0,	0x6BD1,	0x6BD8,	0x6BDA,	0x6BDC,	0x6BDD,	0x6BDE,
	0x6BDF,	0x6BE0,	0x6BE2,	0x6BE3,	0x6BE4,	0x6BE5,	0x6BE6,	0x6BE7,
	0x6BE8,	0x6BE9,	0x6BEC,	0x6BED,	0x6BEE,	0x6BF0,	0x6BF1,	0x6BF2,
	0x6BF4,	0x6BF6,	0x6BF7,	0x6BF8,	0x6BFA,	0x6BFB,	0x6BFC,	0x6BFE,
	0x6BFF,	0x6C00,	0x6C01,	0x6C02,	0x6C03,	0x6C04,	0x6C08,	0x6C09,
	0x6C0A,	0x6C0B,	0x6C0C,	0x6C0E,	0x6C12,	0x6C17,	0x6C1C,	0x6C1D,
	0x6C1E,	0x6C20,	0x6C23,	0x6C25,	0x6C2B,	0x6C2C,	0x6C2D,	0x6C31,
	0x6C33,	0x6C36,	0x6C37,	0x6C39,	0x6C3A,	0x6C3B,	0x6C3C,	0x6C3E,
	0x6C3F,	0x6C43,	0x6C44,	0x6C45,	0x6C48,	0x6C4B,	0x6C4C,	0x6C4D,
	0x6C4E,	0x6C4F,	0x6C51,	0x6C52,	0x6C53,	0x6C56,	0x6C58,
	/* GB 0x9B40..0x9B7E */
	0x6C59,	0x6C5A,	0x6C62,	0x6C63,	0x6C65,	0x6C66,	0x6C67,	0x6C6B,
	0x6C6C,	0x6C6D,	0x6C6E,	0x6C6F,	0x6C71,	0x6C73,	0x6C75,	0x6C77,
	0x6C78,	0x6C7A,	0x6C7B,	0x6C7C,	0x6C7F,	0x6C80,	0x6C84,	0x6C87,
	0x6C8A,	0x6C8B,	0x6C8D,	0x6C8E,	0x6C91,	0x6C92,	0x6C95,	0x6C96,
	0x6C97,	0x6C98,	0x6C9A,	0x6C9C,	0x6C9D,	0x6C9E,	0x6CA0,	0x6CA2,
	0x6CA8,	0x6CAC,	0x6CAF,	0x6CB0,	0x6CB4,	0x6CB5,	0x6CB6,	0x6CB7,
	0x6CBA,	0x6CC0,	0x6CC1,	0x6CC2,	0x6CC3,	0x6CC6,	0x6CC7,	0x6CC8,
	0x6CCB,	0x6CCD,	0x6CCE,	0x6CCF,	0x6CD1,	0x6CD2,	0x6CD8,
	/* GB 0x9B80..0x9BFE */
	0x6CD9,	0x6CDA,	0x6CDC,	0x6CDD,	0x6CDF,	0x6CE4,	0x6CE6,	0x6CE7,
	0x6CE9,	0x6CEC,	0x6CED,	0x6CF2,	0x6CF4,	0x6CF9,	0x6CFF,	0x6D00,
	0x6D02,	0x6D03,	0x6D05,	0x6D06,	0x6D08,	0x6D09,	0x6D0A,	0x6D0D,
	0x6D0F,	0x6D10,	0x6D11,	0x6D13,	0x6D14,	0x6D15,	0x6D16,	0x6D18,
	0x6D1C,	0x6D1D,	0x6D1F,	0x6D20,	0x6D21,	0x6D22,	0x6D23,	0x6D24,
	0x6D26,	0x6D28,	0x6D29,	0x6D2C,	0x6D2D,	0x6D2F,	0x6D30,	0x6D34,
	0x6D36,	0x6D37,	0x6D38,	0x6D3A,	0x6D3F,	0x6D40,	0x6D42,	0x6D44,
	0x6D49,	0x6D4C,	0x6D50,	0x6D55,	0x6D56,	0x6D57,	0x6D58,	0x6D5B,
	0x6D5D,	0x6D5F,	0x6D61,	0x6D62,	0x6D64,	0x6D65,	0x6D67,	0x6D68,
	0x6D6B,	0x6D6C,	0x6D6D,	0x6D70,	0x6D71,	0x6D72,	0x6D73,	0x6D75,
	0x6D76,	0x6D79,	0x6D7A,	0x6D7B,	0x6D7D,	0x6D7E,	0x6D7F,	0x6D80,
	0x6D81,	0x6D83,	0x6D84,	0x6D86,	0x6D87,	0x6D8A,	0x6D8B,	0x6D8D,
	0x6D8F,	0x6D90,	0x6D92,	0x6D96,	0x6D97,	0x6D98,	0x6D99,	0x6D9A,
	0x6D9C,	0x6DA2,	0x6DA5,	0x6DAC,	0x6DAD,	0x6DB0,	0x6DB1,	0x6DB3,
	0x6DB4,	0x6DB6,	0x6DB7,	0x6DB9,	0x6DBA,	0x6DBB,	0x6DBC,	0x6DBD,
	0x6DBE,	0x6DC1,	0x6DC2,	0x6DC3,	0x6DC8,	0x6DC9,	0x6DCA,
	/* GB 0x9C40..0x9C7E */
	0x6DCD,	0x6DCE,	0x6DCF,	0x6DD0,	0x6DD2,	0x6DD3,	0x6DD4,	0x6DD5,
	0x6DD7,	0x6DDA,	0x6DDB,	0x6DDC,	0x6DDF,	0x6DE2,	0x6DE3,	0x6DE5,
	0x6DE7,	0x6DE8,	0x6DE9,	0x6DEA,	0x6DED,	0x6DEF,	0x6DF0,	0x6DF2,
	0x6DF4,	0x6DF5,	0x6DF6,	0x6DF8,	0x6DFA,	0x6DFD,	0x6DFE,	0x6DFF,
	0x6E00,	0x6E01,	0x6E02,	0x6E03,	0x6E04,	0x6E06,	0x6E07,	0x6E08,
	0x6E09,	0x6E0B,	0x6E0F,	0x6E12,	0x6E13,	0x6E15,	0x6E18,	0x6E19,
	0x6E1B,	0x6E1C,	0x6E1E,	0x6E1F,	0x6E22,	0x6E26,	0x6E27,	0x6E28,
	0x6E2A,	0x6E2C,	0x6E2E,	0x6E30,	0x6E31,	0x6E33,	0x6E35,
	/* GB 0x9C80..0x9CFE */
	0x6E36,	0x6E37,	0x6E39,	0x6E3B,	0x6E3C,	0x6E3D,	0x6E3E,	0x6E3F,
	0x6E40,	0x6E41,	0x6E42,	0x6E45,	0x6E46,	0x6E47,	0x6E48,	0x6E49,
	0x6E4A,	0x6E4B,	0x6E4C,	0x6E4F,	0x6E50,	0x6E51,	0x6E52,	0x6E55,
	0x6E57,	0x6E59,	0x6E5A,	0x6E5C,	0x6E5D,	0x6E5E,	0x6E60,	0x6E61,
	0x6E62,	0x6E63,	0x6E64,	0x6E65,	0x6E66,	0x6E67,	0x6E68,	0x6E69,
	0x6E6A,	0x6E6C,	0x6E6D,	0x6E6F,	0x6E70,	0x6E71,	0x6E72,	0x6E73,
	0x6E74,	0x6E75,	0x6E76,	0x6E77,	0x6E78,	0x6E79,	0x6E7A,	0x6E7B,
	0x6E7C,	0x6E7D,	0x6E80,	0x6E81,	0x6E82,	0x6E84,	0x6E87,	0x6E88,
	0x6E8A,	0x6E8B,	0x6E8C,	0x6E8D,	0x6E8E,	0x6E91,	0x6E92,	0x6E93,
	0x6E94,	0x6E95,	0x6E96,	0x6E97,	0x6E99,	0x6E9A,	0x6E9B,	0x6E9D,
	0x6E9E,	0x6EA0,	0x6EA1,	0x6EA3,	0x6EA4,	0x6EA6,	0x6EA8,	0x6EA9,
	0x6EAB,	0x6EAC,	0x6EAD,	0x6EAE,	0x6EB0,	0x6EB3,	0x6EB5,	0x6EB8,
	0x6EB9,	0x6EBC,	0x6EBE,	0x6EBF,	0x6EC0,	0x6EC3,	0x6EC4,	0x6EC5,
	0x6EC6,	0x6EC8,	0x6EC9,	0x6ECA,	0x6ECC,	0x6ECD,	0x6ECE,	0x6ED0,
	0x6ED2,	0x6ED6,	0x6ED8,	0x6ED9,	0x6EDB,	0x6EDC,	0x6EDD,	0x6EE3,
	0x6EE7,	0x6EEA,	0x6EEB,	0x6EEC,	0x6EED,	0x6EEE,	0x6EEF,
	/* GB 0x9D40..0x9D7E */
	0x6EF0,	0x6EF1,	0x6EF2,	0x6EF3,	0x6EF5,	0x6EF6,	0x6EF7,	0x6EF8,
	0x6EFA,	0x6EFB,	0x6EFC,	0x6EFD,	0x6EFE,	0x6EFF,	0x6F00,	0x6F01,
	0x6F03,	0x6F04,	0x6F05,	0x6F07,	0x6F08,	0x6F0A,	0x6F0B,	0x6F0C,
	0x6F0D,	0x6F0E,	0x6F10,	0x6F11,	0x6F12,	0x6F16,	0x6F17,	0x6F18,
	0x6F19,	0x6F1A,	0x6F1B,	0x6F1C,	0x6F1D,	0x6F1E,	0x6F1F,	0x6F21,
	0x6F22,	0x6F23,	0x6F25,	0x6F26,	0x6F27,	0x6F28,	0x6F2C,	0x6F2E,
	0x6F30,	0x6F32,	0x6F34,	0x6F35,	0x6F37,	0x6F38,	0x6F39,	0x6F3A,
	0x6F3B,	0x6F3C,	0x6F3D,	0x6F3F,	0x6F40,	0x6F41,	0x6F42,
	/* GB 0x9D80..0x9DFE */
	0x6F43,	0x6F44,	0x6F45,	0x6F48,	0x6F49,	0x6F4A,	0x6F4C,	0x6F4E,
	0x6F4F,	0x6F50,	0x6F51,	0x6F52,	0x6F53,	0x6F54,	0x6F55,	0x6F56,
	0x6F57,	0x6F59,	0x6F5A,	0x6F5B,	0x6F5D,	0x6F5F,	0x6F60,	0x6F61,
	0x6F63,	0x6F64,	0x6F65,	0x6F67,	0x6F68,	0x6F69,	0x6F6A,	0x6F6B,
	0x6F6C,	0x6F6F,	0x6F70,	0x6F71,	0x6F73,	0x6F75,	0x6F76,	0x6F77,
	0x6F79,	0x6F7B,	0x6F7D,	0x6F7E,	0x6F7F,	0x6F80,	0x6F81,	0x6F82,
	0x6F83,	0x6F85,	0x6F86,	0x6F87,	0x6F8A,	0x6F8B,	0x6F8F,	0x6F90,
	0x6F91,	0x6F92,	0x6F93,	0x6F94,	0x6F95,	0x6F96,	0x6F97,	0x6F98,
	0x6F99,	0x6F9A,	0x6F9B,	0x6F9D,	0x6F9E,	0x6F9F,	0x6FA0,	0x6FA2,
	0x6FA3,	0x6FA4,	0x6FA5,	0x6FA6,	0x6FA8,	0x6FA9,	0x6FAA,	0x6FAB,
	0x6FAC,	0x6FAD,	0x6FAE,	0x6FAF,	0x6FB0,	0x6FB1,	0x6FB2,	0x6FB4,
	0x6FB5,	0x6FB7,	0x6FB8,	0x6FBA,	0x6FBB,	0x6FBC,	0x6FBD,	0x6FBE,
	0x6FBF,	0x6FC1,	0x6FC3,	0x6FC4,	0x6FC5,	0x6FC6,	0x6FC7,	0x6FC8,
	0x6FCA,	0x6FCB,	0x6FCC,	0x6FCD,	0x6FCE,	0x6FCF,	0x6FD0,	0x6FD3,
	0x6FD4,	0x6FD5,	0x6FD6,	0x6FD7,	0x6FD8,	0x6FD9,	0x6FDA,	0x6FDB,
	0x6FDC,	0x6FDD,	0x6FDF,	0x6FE2,	0x6FE3,	0x6FE4,	0x6FE5,
	/* GB 0x9E40..0x9E7E */
	0x6FE6,	0x6FE7,	0x6FE8,	0x6FE9,	0x6FEA,	0x6FEB,	0x6FEC,	0x6FED,
	0x6FF0,	0x6FF1,	0x6FF2,	0x6FF3,	0x6FF4,	0x6FF5,	0x6FF6,	0x6FF7,
	0x6FF8,	0x6FF9,	0x6FFA,	0x6FFB,	0x6FFC,	0x6FFD,	0x6FFE,	0x6FFF,
	0x7000,	0x7001,	0x7002,	0x7003,	0x7004,	0x7005,	0x7006,	0x7007,
	0x7008,	0x7009,	0x700A,	0x700B,	0x700C,	0x700D,	0x700E,	0x700F,
	0x7010,	0x7012,	0x7013,	0x7014,	0x7015,	0x7016,	0x7017,	0x7018,
	0x7019,	0x701C,	0x701D,	0x701E,	0x701F,	0x7020,	0x7021,	0x7022,
	0x7024,	0x7025,	0x7026,	0x7027,	0x7028,	0x7029,	0x702A,
	/* GB 0x9E80..0x9EFE */
	0x702B,	0x702C,	0x702D,	0x702E,	0x702F,	0x7030,	0x7031,	0x7032,
	0x7033,	0x7034,	0x7036,	0x7037,	0x7038,	0x703A,	0x703B,	0x703C,
	0x703D,	0x703E,	0x703F,	0x7040,	0x7041,	0x7042,	0x7043,	0x7044,
	0x7045,	0x7046,	0x7047,	0x7048,	0x7049,	0x704A,	0x704B,	0x704D,
	0x704E,	0x7050,	0x7051,	0x7052,	0x7053,	0x7054,	0x7055,	0x7056,
	0x7057,	0x7058,	0x7059,	0x705A,	0x705B,	0x705C,	0x705D,	0x705F,
	0x7060,	0x7061,	0x7062,	0x7063,	0x7064,	0x7065,	0x7066,	0x7067,
	0x7068,	0x7069,	0x706A,	0x706E,	0x7071,	0x7072,	0x7073,	0x7074,
	0x7077,	0x7079,	0x707A,	0x707B,	0x707D,	0x7081,	0x7082,	0x7083,
	0x7084,	0x7086,	0x7087,	0x7088,	0x708B,	0x708C,	0x708D,	0x708F,
	0x7090,	0x7091,	0x7093,	0x7097,	0x7098,	0x709A,	0x709B,	0x709E,
	0x709F,	0x70A0,	0x70A1,	0x70A2,	0x70A3,	0x70A4,	0x70A5,	0x70A6,
	0x70A7,	0x70A8,	0x70A9,	0x70AA,	0x70B0,	0x70B2,	0x70B4,	0x70B5,
	0x70B6,	0x70BA,	0x70BE,	0x70BF,	0x70C4,	0x70C5,	0x70C6,	0x70C7,
	0x70C9,	0x70CB,	0x70CC,	0x70CD,	0x70CE,	0x70CF,	0x70D0,	0x70D1,
	0x70D2,	0x70D3,	0x70D4,	0x70D5,	0x70D6,	0x70D7,	0x70DA,
	/* GB 0x9F40..0x9F7E */
	0x70DC,	0x70DD,	0x70DE,	0x70E0,	0x70E1,	0x70E2,	0x70E3,	0x70E5,
	0x70EA,	0x70EE,	0x70F0,	0x70F1,	0x70F2,	0x70F3,	0x70F4,	0x70F5,
	0x70F6,	0x70F8,	0x70FA,	0x70FB,	0x70FC,	0x70FE,	0x70FF,	0x7100,
	0x7101,	0x7102,	0x7103,	0x7104,	0x7105,	0x7106,	0x7107,	0x7108,
	0x710B,	0x710C,	0x710D,	0x710E,	0x710F,	0x7111,	0x7112,	0x7114,
	0x7117,	0x711B,	0x711C,	0x711D,	0x711E,	0x711F,	0x7120,	0x7121,
	0x7122,	0x7123,	0x7124,	0x7125,	0x7127,	0x7128,	0x7129,	0x712A,
	0x712B,	0x712C,	0x712D,	0x712E,	0x7132,	0x7133,	0x7134,
	/* GB 0x9F80..0x9FFE */
	0x7135,	0x7137,	0x7138,	0x7139,	0x713A,	0x713B,	0x713C,	0x713D,
	0x713E,	0x713F,	0x7140,	0x7141,	0x7142,	0x7143,	0x7144,	0x7146,
	0x7147,	0x7148,	0x7149,	0x714B,	0x714D,	0x714F,	0x7150,	0x7151,
	0x7152,	0x7153,	0x7154,	0x7155,	0x7156,	0x7157,	0x7158,	0x7159,
	0x715A,	0x715B,	0x715D,	0x715F,	0x7160,	0x7161,	0x7162,	0x7163,
	0x7165,	0x7169,	0x716A,	0x716B,	0x716C,	0x716D,	0x716F,	0x7170,
	0x7171,	0x7174,	0x7175,	0x7176,	0x7177,	0x7179,	0x717B,	0x717C,
	0x717E,	0x717F,	0x7180,	0x7181,	0x7182,	0x7183,	0x7185,	0x7186,
	0x7187,	0x7188,	0x7189,	0x718B,	0x718C,	0x718D,	0x718E,	0x7190,
	0x7191,	0x7192,	0x7193,	0x7195,	0x7196,	0x7197,	0x719A,	0x719B,
	0x719C,	0x719D,	0x719E,	0x71A1,	0x71A2,	0x71A3,	0x71A4,	0x71A5,
	0x71A6,	0x71A7,	0x71A9,	0x71AA,	0x71AB,	0x71AD,	0x71AE,	0x71AF,
	0x71B0,	0x71B1,	0x71B2,	0x71B4,	0x71B6,	0x71B7,	0x71B8,	0x71BA,
	0x71BB,	0x71BC,	0x71BD,	0x71BE,	0x71BF,	0x71C0,	0x71C1,	0x71C2,
	0x71C4,	0x71C5,	0x71C6,	0x71C7,	0x71C8,	0x71C9,	0x71CA,	0x71CB,
	0x71CC,	0x71CD,	0x71CF,	0x71D0,	0x71D1,	0x71D2,	0x71D3,
	/* GB 0xA040..0xA07E */
	0x71D6,	0x71D7,	0x71D8,	0x71D9,	0x71DA,	0x71DB,	0x71DC,	0x71DD,
	0x71DE,	0x71DF,	0x71E1,	0x71E2,	0x71E3,	0x71E4,	0x71E6,	0x71E8,
	0x71E9,	0x71EA,	0x71EB,	0x71EC,	0x71ED,	0x71EF,	0x71F0,	0x71F1,
	0x71F2,	0x71F3,	0x71F4,	0x71F5,	0x71F6,	0x71F7,	0x71F8,	0x71FA,
	0x71FB,	0x71FC,	0x71FD,	0x71FE,	0x71FF,	0x7200,	0x7201,	0x7202,
	0x7203,	0x7204,	0x7205,	0x7207,	0x7208,	0x7209,	0x720A,	0x720B,
	0x720C,	0x720D,	0x720E,	0x720F,	0x7210,	0x7211,	0x7212,	0x7213,
	0x7214,	0x7215,	0x7216,	0x7217,	0x7218,	0x7219,	0x721A,
	/* GB 0xA080..0xA0FE */
	0x721B,	0x721C,	0x721E,	0x721F,	0x7220,	0x7221,	0x7222,	0x7223,
	0x7224,	0x7225,	0x7226,	0x7227,	0x7229,	0x722B,	0x722D,	0x722E,
	0x722F,	0x7232,	0x7233,	0x7234,	0x723A,	0x723C,	0x723E,	0x7240,
	0x7241,	0x7242,	0x7243,	0x7244,	0x7245,	0x7246,	0x7249,	0x724A,
	0x724B,	0x724E,	0x724F,	0x7250,	0x7251,	0x7253,	0x7254,	0x7255,
	0x7257,	0x7258,	0x725A,	0x725C,	0x725E,	0x7260,	0x7263,	0x7264,
	0x7265,	0x7268,	0x726A,	0x726B,	0x726C,	0x726D,	0x7270,	0x7271,
	0x7273,	0x7274,	0x7276,	0x7277,	0x7278,	0x727B,	0x727C,	0x727D,
	0x7282,	0x7283,	0x7285,	0x7286,	0x7287,	0x7288,	0x7289,	0x728C,
	0x728E,	0x7290,	0x7291,	0x7293,	0x7294,	0x7295,	0x7296,	0x7297,
	0x7298,	0x7299,	0x729A,	0x729B,	0x729C,	0x729D,	0x729E,	0x72A0,
	0x72A1,	0x72A2,	0x72A3,	0x72A4,	0x72A5,	0x72A6,	0x72A7,	0x72A8,
	0x72A9,	0x72AA,	0x72AB,	0x72AE,	0x72B1,	0x72B2,	0x72B3,	0x72B5,
	0x72BA,	0x72BB,	0x72BC,	0x72BD,	0x72BE,	0x72BF,	0x72C0,	0x72C5,
	0x72C6,	0x72C7,	0x72C9,	0x72CA,	0x72CB,	0x72CC,	0x72CF,	0x72D1,
	0x72D3,	0x72D4,	0x72D5,	0x72D6,	0x72D8,	0x72DA,	0x72DB,
	/* Skip: GB 0xA140..0xA17E, 0xA180..0xA1A0 (UDA 3) */
	/* GB 0xA2A1..0xA2FE */
		0x3000,	0x3001,	0x3002,	0x00B7,	0x02C9,	0x02C7,	0x00A8,
	0x3003,	0x3005,	0x2014,	0xFF5E,	0x2016,	0x2026,	0x2018,	0x2019,
	0x201C,	0x201D,	0x3014,	0x3015,	0x3008,	0x3009,	0x300A,	0x300B,
	0x300C,	0x300D,	0x300E,	0x300F,	0x3016,	0x3017,	0x3010,	0x3011,
	0x00B1,	0x00D7,	0x00F7,	0x2236,	0x2227,	0x2228,	0x2211,	0x220F,
	0x222A,	0x2229,	0x2208,	0x2237,	0x221A,	0x22A5,	0x2225,	0x2220,
	0x2312,	0x2299,	0x222B,	0x222E,	0x2261,	0x224C,	0x2248,	0x223D,
	0x221D,	0x2260,	0x226E,	0x226F,	0x2264,	0x2265,	0x221E,	0x2235,
	0x2234,	0x2642,	0x2640,	0x00B0,	0x2032,	0x2033,	0x2103,	0xFF04,
	0x00A4,	0xFFE0,	0xFFE1,	0x2030,	0x00A7,	0x2116,	0x2606,	0x2605,
	0x25CB,	0x25CF,	0x25CE,	0x25C7,	0x25C6,	0x25A1,	0x25A0,	0x25B3,
	0x25B2,	0x203B,	0x2192,	0x2190,	0x2191,	0x2193,	0x3013,
	/* Skip: GB 0xA240..0xA27E, 0xA280..0xA2A0 (UDA 3) */
	/* GB 0xA3A1..0xA3FE */
		0x2170,	0x2171,	0x2172,	0x2173,	0x2174,	0x2175,	0x2176,
	0x2177,	0x2178,	0x2179,	0xE766,	0xE767,	0xE768,	0xE769,	0xE76A,
	0xE76B,	0x2488,	0x2489,	0x248A,	0x248B,	0x248C,	0x248D,	0x248E,
	0x248F,	0x2490,	0x2491,	0x2492,	0x2493,	0x2494,	0x2495,	0x2496,
	0x2497,	0x2498,	0x2499,	0x249A,	0x249B,	0x2474,	0x2475,	0x2476,
	0x2477,	0x2478,	0x2479,	0x247A,	0x247B,	0x247C,	0x247D,	0x247E,
	0x247F,	0x2480,	0x2481,	0x2482,	0x2483,	0x2484,	0x2485,	0x2486,
	0x2487,	0x2460,	0x2461,	0x2462,	0x2463,	0x2464,	0x2465,	0x2466,
	0x2467,	0x2468,	0x2469,	0x20AC,	0xE76D,	0x3220,	0x3221,	0x3222,
	0x3223,	0x3224,	0x3225,	0x3226,	0x3227,	0x3228,	0x3229,	0xE76E,
	0xE76F,	0x2160,	0x2161,	0x2162,	0x2163,	0x2164,	0x2165,	0x2166,
	0x2167,	0x2168,	0x2169,	0x216A,	0x216B,	0xE770,	0xE771,
	/* Skip: GB 0xA340..0xA37E, 0xA380..0xA3A0 (UDA 3) */
	/* GB 0xA4A1..0xA4FE */
		0xFF01,	0xFF02,	0xFF03,	0xFFE5,	0xFF05,	0xFF06,	0xFF07,
	0xFF08,	0xFF09,	0xFF0A,	0xFF0B,	0xFF0C,	0xFF0D,	0xFF0E,	0xFF0F,
	0xFF10,	0xFF11,	0xFF12,	0xFF13,	0xFF14,	0xFF15,	0xFF16,	0xFF17,
	0xFF18,	0xFF19,	0xFF1A,	0xFF1B,	0xFF1C,	0xFF1D,	0xFF1E,	0xFF1F,
	0xFF20,	0xFF21,	0xFF22,	0xFF23,	0xFF24,	0xFF25,	0xFF26,	0xFF27,
	0xFF28,	0xFF29,	0xFF2A,	0xFF2B,	0xFF2C,	0xFF2D,	0xFF2E,	0xFF2F,
	0xFF30,	0xFF31,	0xFF32,	0xFF33,	0xFF34,	0xFF35,	0xFF36,	0xFF37,
	0xFF38,	0xFF39,	0xFF3A,	0xFF3B,	0xFF3C,	0xFF3D,	0xFF3E,	0xFF3F,
	0xFF40,	0xFF41,	0xFF42,	0xFF43,	0xFF44,	0xFF45,	0xFF46,	0xFF47,
	0xFF48,	0xFF49,	0xFF4A,	0xFF4B,	0xFF4C,	0xFF4D,	0xFF4E,	0xFF4F,
	0xFF50,	0xFF51,	0xFF52,	0xFF53,	0xFF54,	0xFF55,	0xFF56,	0xFF57,
	0xFF58,	0xFF59,	0xFF5A,	0xFF5B,	0xFF5C,	0xFF5D,	0xFFE3,
	/* Skip: GB 0xA440..0xA47E, 0xA480..0xA4A0 (UDA 3) */
	/* GB 0xA5A1..0xA5FE */
		0x3041,	0x3042,	0x3043,	0x3044,	0x3045,	0x3046,	0x3047,
	0x3048,	0x3049,	0x304A,	0x304B,	0x304C,	0x304D,	0x304E,	0x304F,
	0x3050,	0x3051,	0x3052,	0x3053,	0x3054,	0x3055,	0x3056,	0x3057,
	0x3058,	0x3059,	0x305A,	0x305B,	0x305C,	0x305D,	0x305E,	0x305F,
	0x3060,	0x3061,	0x3062,	0x3063,	0x3064,	0x3065,	0x3066,	0x3067,
	0x3068,	0x3069,	0x306A,	0x306B,	0x306C,	0x306D,	0x306E,	0x306F,
	0x3070,	0x3071,	0x3072,	0x3073,	0x3074,	0x3075,	0x3076,	0x3077,
	0x3078,	0x3079,	0x307A,	0x307B,	0x307C,	0x307D,	0x307E,	0x307F,
	0x3080,	0x3081,	0x3082,	0x3083,	0x3084,	0x3085,	0x3086,	0x3087,
	0x3088,	0x3089,	0x308A,	0x308B,	0x308C,	0x308D,	0x308E,	0x308F,
	0x3090,	0x3091,	0x3092,	0x3093,	0xE772,	0xE773,	0xE774,	0xE775,
	0xE776,	0xE777,	0xE778,	0xE779,	0xE77A,	0xE77B,	0xE77C,
	/* Skip: GB 0xA540..0xA57E, 0xA580..0xA5A0 (UDA 3) */
	/* GB 0xA6A1..0xA6FE */
		0x30A1,	0x30A2,	0x30A3,	0x30A4,	0x30A5,	0x30A6,	0x30A7,
	0x30A8,	0x30A9,	0x30AA,	0x30AB,	0x30AC,	0x30AD,	0x30AE,	0x30AF,
	0x30B0,	0x30B1,	0x30B2,	0x30B3,	0x30B4,	0x30B5,	0x30B6,	0x30B7,
	0x30B8,	0x30B9,	0x30BA,	0x30BB,	0x30BC,	0x30BD,	0x30BE,	0x30BF,
	0x30C0,	0x30C1,	0x30C2,	0x30C3,	0x30C4,	0x30C5,	0x30C6,	0x30C7,
	0x30C8,	0x30C9,	0x30CA,	0x30CB,	0x30CC,	0x30CD,	0x30CE,	0x30CF,
	0x30D0,	0x30D1,	0x30D2,	0x30D3,	0x30D4,	0x30D5,	0x30D6,	0x30D7,
	0x30D8,	0x30D9,	0x30DA,	0x30DB,	0x30DC,	0x30DD,	0x30DE,	0x30DF,
	0x30E0,	0x30E1,	0x30E2,	0x30E3,	0x30E4,	0x30E5,	0x30E6,	0x30E7,
	0x30E8,	0x30E9,	0x30EA,	0x30EB,	0x30EC,	0x30ED,	0x30EE,	0x30EF,
	0x30F0,	0x30F1,	0x30F2,	0x30F3,	0x30F4,	0x30F5,	0x30F6,	0xE77D,
	0xE77E,	0xE77F,	0xE780,	0xE781,	0xE782,	0xE783,	0xE784,
	/* Skip: GB 0xA640..0xA67E, 0xA680..0xA6A0 (UDA 3) */
	/* GB 0xA7A1..0xA7FE */
		0x0391,	0x0392,	0x0393,	0x0394,	0x0395,	0x0396,	0x0397,
	0x0398,	0x0399,	0x039A,	0x039B,	0x039C,	0x039D,	0x039E,	0x039F,
	0x03A0,	0x03A1,	0x03A3,	0x03A4,	0x03A5,	0x03A6,	0x03A7,	0x03A8,
	0x03A9,	0xE785,	0xE786,	0xE787,	0xE788,	0xE789,	0xE78A,	0xE78B,
	0xE78C,	0x03B1,	0x03B2,	0x03B3,	0x03B4,	0x03B5,	0x03B6,	0x03B7,
	0x03B8,	0x03B9,	0x03BA,	0x03BB,	0x03BC,	0x03BD,	0x03BE,	0x03BF,
	0x03C0,	0x03C1,	0x03C3,	0x03C4,	0x03C5,	0x03C6,	0x03C7,	0x03C8,
	0x03C9,	0xE78D,	0xE78E,	0xE78F,	0xE790,	0xE791,	0xE792,	0xE793,
	0xFE35,	0xFE36,	0xFE39,	0xFE3A,	0xFE3F,	0xFE40,	0xFE3D,	0xFE3E,
	0xFE41,	0xFE42,	0xFE43,	0xFE44,	0xE794,	0xE795,	0xFE3B,	0xFE3C,
	0xFE37,	0xFE38,	0xFE31,	0xE796,	0xFE33,	0xFE34,	0xE797,	0xE798,
	0xE799,	0xE79A,	0xE79B,	0xE79C,	0xE79D,	0xE79E,	0xE79F,
	/* Skip: GB 0xA740..0xA77E, 0xA780..0xA7A0 (UDA 3) */
	/* GB 0xA8A1..0xA8FE */
		0x0410,	0x0411,	0x0412,	0x0413,	0x0414,	0x0415,	0x0401,
	0x0416,	0x0417,	0x0418,	0x0419,	0x041A,	0x041B,	0x041C,	0x041D,
	0x041E,	0x041F,	0x0420,	0x0421,	0x0422,	0x0423,	0x0424,	0x0425,
	0x0426,	0x0427,	0x0428,	0x0429,	0x042A,	0x042B,	0x042C,	0x042D,
	0x042E,	0x042F,	0xE7A0,	0xE7A1,	0xE7A2,	0xE7A3,	0xE7A4,	0xE7A5,
	0xE7A6,	0xE7A7,	0xE7A8,	0xE7A9,	0xE7AA,	0xE7AB,	0xE7AC,	0xE7AD,
	0xE7AE,	0x0430,	0x0431,	0x0432,	0x0433,	0x0434,	0x0435,	0x0451,
	0x0436,	0x0437,	0x0438,	0x0439,	0x043A,	0x043B,	0x043C,	0x043D,
	0x043E,	0x043F,	0x0440,	0x0441,	0x0442,	0x0443,	0x0444,	0x0445,
	0x0446,	0x0447,	0x0448,	0x0449,	0x044A,	0x044B,	0x044C,	0x044D,
	0x044E,	0x044F,	0xE7AF,	0xE7B0,	0xE7B1,	0xE7B2,	0xE7B3,	0xE7B4,
	0xE7B5,	0xE7B6,	0xE7B7,	0xE7B8,	0xE7B9,	0xE7BA,	0xE7BB,
	/* GB 0xA840..0xA87E */
	0x02CA,	0x02CB,	0x02D9,	0x2013,	0x2015,	0x2025,	0x2035,	0x2105,
	0x2109,	0x2196,	0x2197,	0x2198,	0x2199,	0x2215,	0x221F,	0x2223,
	0x2252,	0x2266,	0x2267,	0x22BF,	0x2550,	0x2551,	0x2552,	0x2553,
	0x2554,	0x2555,	0x2556,	0x2557,	0x2558,	0x2559,	0x255A,	0x255B,
	0x255C,	0x255D,	0x255E,	0x255F,	0x2560,	0x2561,	0x2562,	0x2563,
	0x2564,	0x2565,	0x2566,	0x2567,	0x2568,	0x2569,	0x256A,	0x256B,
	0x256C,	0x256D,	0x256E,	0x256F,	0x2570,	0x2571,	0x2572,	0x2573,
	0x2581,	0x2582,	0x2583,	0x2584,	0x2585,	0x2586,	0x2587,
	/* GB 0xA880..0xA8FE */
	0x2588,	0x2589,	0x258A,	0x258B,	0x258C,	0x258D,	0x258E,	0x258F,
	0x2593,	0x2594,	0x2595,	0x25BC,	0x25BD,	0x25E2,	0x25E3,	0x25E4,
	0x25E5,	0x2609,	0x2295,	0x3012,	0x301D,	0x301E,	0xE7BC,	0xE7BD,
	0xE7BE,	0xE7BF,	0xE7C0,	0xE7C1,	0xE7C2,	0xE7C3,	0xE7C4,	0xE7C5,
	0xE7C6,	0x0101,	0x00E1,	0x01CE,	0x00E0,	0x0113,	0x00E9,	0x011B,
	0x00E8,	0x012B,	0x00ED,	0x01D0,	0x00EC,	0x014D,	0x00F3,	0x01D2,
	0x00F2,	0x016B,	0x00FA,	0x01D4,	0x00F9,	0x01D6,	0x01D8,	0x01DA,
	0x01DC,	0x00FC,	0x00EA,	0x0251,	0xE7C7,	0x0144,	0x0148,	0x01F9,
	0x0261,	0xE7C9,	0xE7CA,	0xE7CB,	0xE7CC,	0x3105,	0x3106,	0x3107,
	0x3108,	0x3109,	0x310A,	0x310B,	0x310C,	0x310D,	0x310E,	0x310F,
	0x3110,	0x3111,	0x3112,	0x3113,	0x3114,	0x3115,	0x3116,	0x3117,
	0x3118,	0x3119,	0x311A,	0x311B,	0x311C,	0x311D,	0x311E,	0x311F,
	0x3120,	0x3121,	0x3122,	0x3123,	0x3124,	0x3125,	0x3126,	0x3127,
	0x3128,	0x3129,	0xE7CD,	0xE7CE,	0xE7CF,	0xE7D0,	0xE7D1,	0xE7D2,
	0xE7D3,	0xE7D4,	0xE7D5,	0xE7D6,	0xE7D7,	0xE7D8,	0xE7D9,	0xE7DA,
	0xE7DB,	0xE7DC,	0xE7DD,	0xE7DE,	0xE7DF,	0xE7E0,	0xE7E1,
	/* GB 0xA940..0xA97E */
	0x3021,	0x3022,	0x3023,	0x3024,	0x3025,	0x3026,	0x3027,	0x3028,
	0x3029,	0x32A3,	0x338E,	0x338F,	0x339C,	0x339D,	0x339E,	0x33A1,
	0x33C4,	0x33CE,	0x33D1,	0x33D2,	0x33D5,	0xFE30,	0xFFE2,	0xFFE4,
	0xE7E2,	0x2121,	0x3231,	0xE7E3,	0x2010,	0xE7E4,	0xE7E5,	0xE7E6,
	0x30FC,	0x309B,	0x309C,	0x30FD,	0x30FE,	0x3006,	0x309D,	0x309E,
	0xFE49,	0xFE4A,	0xFE4B,	0xFE4C,	0xFE4D,	0xFE4E,	0xFE4F,	0xFE50,
	0xFE51,	0xFE52,	0xFE54,	0xFE55,	0xFE56,	0xFE57,	0xFE59,	0xFE5A,
	0xFE5B,	0xFE5C,	0xFE5D,	0xFE5E,	0xFE5F,	0xFE60,	0xFE61,
	/* GB 0xA980..0xA9FE */
	0xFE62,	0xFE63,	0xFE64,	0xFE65,	0xFE66,	0xFE68,	0xFE69,	0xFE6A,
	0xFE6B,	0x303E,	0x2FF0,	0x2FF1,	0x2FF2,	0x2FF3,	0x2FF4,	0x2FF5,
	0x2FF6,	0x2FF7,	0x2FF8,	0x2FF9,	0x2FFA,	0x2FFB,	0x3007,	0xE7F4,
	0xE7F5,	0xE7F6,	0xE7F7,	0xE7F8,	0xE7F9,	0xE7FA,	0xE7FB,	0xE7FC,
	0xE7FD,	0xE7FE,	0xE7FF,	0xE800,	0x2500,	0x2501,	0x2502,	0x2503,
	0x2504,	0x2505,	0x2506,	0x2507,	0x2508,	0x2509,	0x250A,	0x250B,
	0x250C,	0x250D,	0x250E,	0x250F,	0x2510,	0x2511,	0x2512,	0x2513,
	0x2514,	0x2515,	0x2516,	0x2517,	0x2518,	0x2519,	0x251A,	0x251B,
	0x251C,	0x251D,	0x251E,	0x251F,	0x2520,	0x2521,	0x2522,	0x2523,
	0x2524,	0x2525,	0x2526,	0x2527,	0x2528,	0x2529,	0x252A,	0x252B,
	0x252C,	0x252D,	0x252E,	0x252F,	0x2530,	0x2531,	0x2532,	0x2533,
	0x2534,	0x2535,	0x2536,	0x2537,	0x2538,	0x2539,	0x253A,	0x253B,
	0x253C,	0x253D,	0x253E,	0x253F,	0x2540,	0x2541,	0x2542,	0x2543,
	0x2544,	0x2545,	0x2546,	0x2547,	0x2548,	0x2549,	0x254A,	0x254B,
	0xE801,	0xE802,	0xE803,	0xE804,	0xE805,	0xE806,	0xE807,	0xE808,
	0xE809,	0xE80A,	0xE80B,	0xE80C,	0xE80D,	0xE80E,	0xE80F,
	/* GB 0xAA40..0xAA7E */
	0x72DC,	0x72DD,	0x72DF,	0x72E2,	0x72E3,	0x72E4,	0x72E5,	0x72E6,
	0x72E7,	0x72EA,	0x72EB,	0x72F5,	0x72F6,	0x72F9,	0x72FD,	0x72FE,
	0x72FF,	0x7300,	0x7302,	0x7304,	0x7305,	0x7306,	0x7307,	0x7308,
	0x7309,	0x730B,	0x730C,	0x730D,	0x730F,	0x7310,	0x7311,	0x7312,
	0x7314,	0x7318,	0x7319,	0x731A,	0x731F,	0x7320,	0x7323,	0x7324,
	0x7326,	0x7327,	0x7328,	0x732D,	0x732F,	0x7330,	0x7332,	0x7333,
	0x7335,	0x7336,	0x733A,	0x733B,	0x733C,	0x733D,	0x7340,	0x7341,
	0x7342,	0x7343,	0x7344,	0x7345,	0x7346,	0x7347,	0x7348,
	/* GB 0xAA80..0xAAA0 */
	0x7349,	0x734A,	0x734B,	0x734C,	0x734E,	0x734F,	0x7351,	0x7353,
	0x7354,	0x7355,	0x7356,	0x7358,	0x7359,	0x735A,	0x735B,	0x735C,
	0x735D,	0x735E,	0x735F,	0x7361,	0x7362,	0x7363,	0x7364,	0x7365,
	0x7366,	0x7367,	0x7368,	0x7369,	0x736A,	0x736B,	0x736E,	0x7370,
	0x7371,			/* Skip: GB 0xAAA1..0xAAFE (UDA 1) */
	/* GB 0xAB40..0xAB7E */
	0x7372,	0x7373,	0x7374,	0x7375,	0x7376,	0x7377,	0x7378,	0x7379,
	0x737A,	0x737B,	0x737C,	0x737D,	0x737F,	0x7380,	0x7381,	0x7382,
	0x7383,	0x7385,	0x7386,	0x7388,	0x738A,	0x738C,	0x738D,	0x738F,
	0x7390,	0x7392,	0x7393,	0x7394,	0x7395,	0x7397,	0x7398,	0x7399,
	0x739A,	0x739C,	0x739D,	0x739E,	0x73A0,	0x73A1,	0x73A3,	0x73A4,
	0x73A5,	0x73A6,	0x73A7,	0x73A8,	0x73AA,	0x73AC,	0x73AD,	0x73B1,
	0x73B4,	0x73B5,	0x73B6,	0x73B8,	0x73B9,	0x73BC,	0x73BD,	0x73BE,
	0x73BF,	0x73C1,	0x73C3,	0x73C4,	0x73C5,	0x73C6,	0x73C7,
	/* GB 0xAB80..0xABA0 */
	0x73CB,	0x73CC,	0x73CE,	0x73D2,	0x73D3,	0x73D4,	0x73D5,	0x73D6,
	0x73D7,	0x73D8,	0x73DA,	0x73DB,	0x73DC,	0x73DD,	0x73DF,	0x73E1,
	0x73E2,	0x73E3,	0x73E4,	0x73E6,	0x73E8,	0x73EA,	0x73EB,	0x73EC,
	0x73EE,	0x73EF,	0x73F0,	0x73F1,	0x73F3,	0x73F4,	0x73F5,	0x73F6,
	0x73F7,			/* Skip: GB 0xABA1..0xABFE (UDA 1) */
	/* GB 0xAC40..0xAC7E */
	0x73F8,	0x73F9,	0x73FA,	0x73FB,	0x73FC,	0x73FD,	0x73FE,	0x73FF,
	0x7400,	0x7401,	0x7402,	0x7404,	0x7407,	0x7408,	0x740B,	0x740C,
	0x740D,	0x740E,	0x7411,	0x7412,	0x7413,	0x7414,	0x7415,	0x7416,
	0x7417,	0x7418,	0x7419,	0x741C,	0x741D,	0x741E,	0x741F,	0x7420,
	0x7421,	0x7423,	0x7424,	0x7427,	0x7429,	0x742B,	0x742D,	0x742F,
	0x7431,	0x7432,	0x7437,	0x7438,	0x7439,	0x743A,	0x743B,	0x743D,
	0x743E,	0x743F,	0x7440,	0x7442,	0x7443,	0x7444,	0x7445,	0x7446,
	0x7447,	0x7448,	0x7449,	0x744A,	0x744B,	0x744C,	0x744D,
	/* GB 0xAC80..0xACA0 */
	0x744E,	0x744F,	0x7450,	0x7451,	0x7452,	0x7453,	0x7454,	0x7456,
	0x7458,	0x745D,	0x7460,	0x7461,	0x7462,	0x7463,	0x7464,	0x7465,
	0x7466,	0x7467,	0x7468,	0x7469,	0x746A,	0x746B,	0x746C,	0x746E,
	0x746F,	0x7471,	0x7472,	0x7473,	0x7474,	0x7475,	0x7478,	0x7479,
	0x747A,			/* Skip: GB 0xACA1..0xACFE (UDA 1) */
	/* GB 0xAD40..0xAD7E */
	0x747B,	0x747C,	0x747D,	0x747F,	0x7482,	0x7484,	0x7485,	0x7486,
	0x7488,	0x7489,	0x748A,	0x748C,	0x748D,	0x748F,	0x7491,	0x7492,
	0x7493,	0x7494,	0x7495,	0x7496,	0x7497,	0x7498,	0x7499,	0x749A,
	0x749B,	0x749D,	0x749F,	0x74A0,	0x74A1,	0x74A2,	0x74A3,	0x74A4,
	0x74A5,	0x74A6,	0x74AA,	0x74AB,	0x74AC,	0x74AD,	0x74AE,	0x74AF,
	0x74B0,	0x74B1,	0x74B2,	0x74B3,	0x74B4,	0x74B5,	0x74B6,	0x74B7,
	0x74B8,	0x74B9,	0x74BB,	0x74BC,	0x74BD,	0x74BE,	0x74BF,	0x74C0,
	0x74C1,	0x74C2,	0x74C3,	0x74C4,	0x74C5,	0x74C6,	0x74C7,
	/* GB 0xAD80..0xADA0 */
	0x74C8,	0x74C9,	0x74CA,	0x74CB,	0x74CC,	0x74CD,	0x74CE,	0x74CF,
	0x74D0,	0x74D1,	0x74D3,	0x74D4,	0x74D5,	0x74D6,	0x74D7,	0x74D8,
	0x74D9,	0x74DA,	0x74DB,	0x74DD,	0x74DF,	0x74E1,	0x74E5,	0x74E7,
	0x74E8,	0x74E9,	0x74EA,	0x74EB,	0x74EC,	0x74ED,	0x74F0,	0x74F1,
	0x74F2,			/* Skip: GB 0xADA1..0xADFE (UDA 1) */
	/* GB 0xAE40..0xAE7E */
	0x74F3,	0x74F5,	0x74F8,	0x74F9,	0x74FA,	0x74FB,	0x74FC,	0x74FD,
	0x74FE,	0x7500,	0x7501,	0x7502,	0x7503,	0x7505,	0x7506,	0x7507,
	0x7508,	0x7509,	0x750A,	0x750B,	0x750C,	0x750E,	0x7510,	0x7512,
	0x7514,	0x7515,	0x7516,	0x7517,	0x751B,	0x751D,	0x751E,	0x7520,
	0x7521,	0x7522,	0x7523,	0x7524,	0x7526,	0x7527,	0x752A,	0x752E,
	0x7534,	0x7536,	0x7539,	0x753C,	0x753D,	0x753F,	0x7541,	0x7542,
	0x7543,	0x7544,	0x7546,	0x7547,	0x7549,	0x754A,	0x754D,	0x7550,
	0x7551,	0x7552,	0x7553,	0x7555,	0x7556,	0x7557,	0x7558,
	/* GB 0xAE80..0xAEA0 */
	0x755D,	0x755E,	0x755F,	0x7560,	0x7561,	0x7562,	0x7563,	0x7564,
	0x7567,	0x7568,	0x7569,	0x756B,	0x756C,	0x756D,	0x756E,	0x756F,
	0x7570,	0x7571,	0x7573,	0x7575,	0x7576,	0x7577,	0x757A,	0x757B,
	0x757C,	0x757D,	0x757E,	0x7580,	0x7581,	0x7582,	0x7584,	0x7585,
	0x7587,			/* Skip: GB 0xAEA1..0xAEFE (UDA 1) */
	/* GB 0xAF40..0xAF7E */
	0x7588,	0x7589,	0x758A,	0x758C,	0x758D,	0x758E,	0x7590,	0x7593,
	0x7595,	0x7598,	0x759B,	0x759C,	0x759E,	0x75A2,	0x75A6,	0x75A7,
	0x75A8,	0x75A9,	0x75AA,	0x75AD,	0x75B6,	0x75B7,	0x75BA,	0x75BB,
	0x75BF,	0x75C0,	0x75C1,	0x75C6,	0x75CB,	0x75CC,	0x75CE,	0x75CF,
	0x75D0,	0x75D1,	0x75D3,	0x75D7,	0x75D9,	0x75DA,	0x75DC,	0x75DD,
	0x75DF,	0x75E0,	0x75E1,	0x75E5,	0x75E9,	0x75EC,	0x75ED,	0x75EE,
	0x75EF,	0x75F2,	0x75F3,	0x75F5,	0x75F6,	0x75F7,	0x75F8,	0x75FA,
	0x75FB,	0x75FD,	0x75FE,	0x7602,	0x7604,	0x7606,	0x7607,
	/* GB 0xAF80..0xAFA0 */
	0x7608,	0x7609,	0x760B,	0x760D,	0x760E,	0x760F,	0x7611,	0x7612,
	0x7613,	0x7614,	0x7616,	0x761A,	0x761C,	0x761D,	0x761E,	0x7621,
	0x7623,	0x7627,	0x7628,	0x762C,	0x762E,	0x762F,	0x7631,	0x7632,
	0x7636,	0x7637,	0x7639,	0x763A,	0x763B,	0x763D,	0x7641,	0x7642,
	0x7644,			/* Skip: GB 0xAFA1..0xAFFE (UDA 1) */
	/* GB 0xB040..0xB07E */
	0x7645,	0x7646,	0x7647,	0x7648,	0x7649,	0x764A,	0x764B,	0x764E,
	0x764F,	0x7650,	0x7651,	0x7652,	0x7653,	0x7655,	0x7657,	0x7658,
	0x7659,	0x765A,	0x765B,	0x765D,	0x765F,	0x7660,	0x7661,	0x7662,
	0x7664,	0x7665,	0x7666,	0x7667,	0x7668,	0x7669,	0x766A,	0x766C,
	0x766D,	0x766E,	0x7670,	0x7671,	0x7672,	0x7673,	0x7674,	0x7675,
	0x7676,	0x7677,	0x7679,	0x767A,	0x767C,	0x767F,	0x7680,	0x7681,
	0x7683,	0x7685,	0x7689,	0x768A,	0x768C,	0x768D,	0x768F,	0x7690,
	0x7692,	0x7694,	0x7695,	0x7697,	0x7698,	0x769A,	0x769B,
	/* GB 0xB080..0xB0FE */
	0x769C,	0x769D,	0x769E,	0x769F,	0x76A0,	0x76A1,	0x76A2,	0x76A3,
	0x76A5,	0x76A6,	0x76A7,	0x76A8,	0x76A9,	0x76AA,	0x76AB,	0x76AC,
	0x76AD,	0x76AF,	0x76B0,	0x76B3,	0x76B5,	0x76B6,	0x76B7,	0x76B8,
	0x76B9,	0x76BA,	0x76BB,	0x76BC,	0x76BD,	0x76BE,	0x76C0,	0x76C1,
	0x76C3,	0x554A,	0x963F,	0x57C3,	0x6328,	0x54CE,	0x5509,	0x54C0,
	0x7691,	0x764C,	0x853C,	0x77EE,	0x827E,	0x788D,	0x7231,	0x9698,
	0x978D,	0x6C28,	0x5B89,	0x4FFA,	0x6309,	0x6697,	0x5CB8,	0x80FA,
	0x6848,	0x80AE,	0x6602,	0x76CE,	0x51F9,	0x6556,	0x71AC,	0x7FF1,
	0x8884,	0x50B2,	0x5965,	0x61CA,	0x6FB3,	0x82AD,	0x634C,	0x6252,
	0x53ED,	0x5427,	0x7B06,	0x516B,	0x75A4,	0x5DF4,	0x62D4,	0x8DCB,
	0x9776,	0x628A,	0x8019,	0x575D,	0x9738,	0x7F62,	0x7238,	0x767D,
	0x67CF,	0x767E,	0x6446,	0x4F70,	0x8D25,	0x62DC,	0x7A17,	0x6591,
	0x73ED,	0x642C,	0x6273,	0x822C,	0x9881,	0x677F,	0x7248,	0x626E,
	0x62CC,	0x4F34,	0x74E3,	0x534A,	0x529E,	0x7ECA,	0x90A6,	0x5E2E,
	0x6886,	0x699C,	0x8180,	0x7ED1,	0x68D2,	0x78C5,	0x868C,	0x9551,
	0x508D,	0x8C24,	0x82DE,	0x80DE,	0x5305,	0x8912,	0x5265,
	/* GB 0xB140..0xB17E */
	0x76C4,	0x76C7,	0x76C9,	0x76CB,	0x76CC,	0x76D3,	0x76D5,	0x76D9,
	0x76DA,	0x76DC,	0x76DD,	0x76DE,	0x76E0,	0x76E1,	0x76E2,	0x76E3,
	0x76E4,	0x76E6,	0x76E7,	0x76E8,	0x76E9,	0x76EA,	0x76EB,	0x76EC,
	0x76ED,	0x76F0,	0x76F3,	0x76F5,	0x76F6,	0x76F7,	0x76FA,	0x76FB,
	0x76FD,	0x76FF,	0x7700,	0x7702,	0x7703,	0x7705,	0x7706,	0x770A,
	0x770C,	0x770E,	0x770F,	0x7710,	0x7711,	0x7712,	0x7713,	0x7714,
	0x7715,	0x7716,	0x7717,	0x7718,	0x771B,	0x771C,	0x771D,	0x771E,
	0x7721,	0x7723,	0x7724,	0x7725,	0x7727,	0x772A,	0x772B,
	/* GB 0xB180..0xB1FE */
	0x772C,	0x772E,	0x7730,	0x7731,	0x7732,	0x7733,	0x7734,	0x7739,
	0x773B,	0x773D,	0x773E,	0x773F,	0x7742,	0x7744,	0x7745,	0x7746,
	0x7748,	0x7749,	0x774A,	0x774B,	0x774C,	0x774D,	0x774E,	0x774F,
	0x7752,	0x7753,	0x7754,	0x7755,	0x7756,	0x7757,	0x7758,	0x7759,
	0x775C,	0x8584,	0x96F9,	0x4FDD,	0x5821,	0x9971,	0x5B9D,	0x62B1,
	0x62A5,	0x66B4,	0x8C79,	0x9C8D,	0x7206,	0x676F,	0x7891,	0x60B2,
	0x5351,	0x5317,	0x8F88,	0x80CC,	0x8D1D,	0x94A1,	0x500D,	0x72C8,
	0x5907,	0x60EB,	0x7119,	0x88AB,	0x5954,	0x82EF,	0x672C,	0x7B28,
	0x5D29,	0x7EF7,	0x752D,	0x6CF5,	0x8E66,	0x8FF8,	0x903C,	0x9F3B,
	0x6BD4,	0x9119,	0x7B14,	0x5F7C,	0x78A7,	0x84D6,	0x853D,	0x6BD5,
	0x6BD9,	0x6BD6,	0x5E01,	0x5E87,	0x75F9,	0x95ED,	0x655D,	0x5F0A,
	0x5FC5,	0x8F9F,	0x58C1,	0x81C2,	0x907F,	0x965B,	0x97AD,	0x8FB9,
	0x7F16,	0x8D2C,	0x6241,	0x4FBF,	0x53D8,	0x535E,	0x8FA8,	0x8FA9,
	0x8FAB,	0x904D,	0x6807,	0x5F6A,	0x8198,	0x8868,	0x9CD6,	0x618B,
	0x522B,	0x762A,	0x5F6C,	0x658C,	0x6FD2,	0x6EE8,	0x5BBE,	0x6448,
	0x5175,	0x51B0,	0x67C4,	0x4E19,	0x79C9,	0x997C,	0x70B3,
	/* GB 0xB240..0xB27E */
	0x775D,	0x775E,	0x775F,	0x7760,	0x7764,	0x7767,	0x7769,	0x776A,
	0x776D,	0x776E,	0x776F,	0x7770,	0x7771,	0x7772,	0x7773,	0x7774,
	0x7775,	0x7776,	0x7777,	0x7778,	0x777A,	0x777B,	0x777C,	0x7781,
	0x7782,	0x7783,	0x7786,	0x7787,	0x7788,	0x7789,	0x778A,	0x778B,
	0x778F,	0x7790,	0x7793,	0x7794,	0x7795,	0x7796,	0x7797,	0x7798,
	0x7799,	0x779A,	0x779B,	0x779C,	0x779D,	0x779E,	0x77A1,	0x77A3,
	0x77A4,	0x77A6,	0x77A8,	0x77AB,	0x77AD,	0x77AE,	0x77AF,	0x77B1,
	0x77B2,	0x77B4,	0x77B6,	0x77B7,	0x77B8,	0x77B9,	0x77BA,
	/* GB 0xB280..0xB2FE */
	0x77BC,	0x77BE,	0x77C0,	0x77C1,	0x77C2,	0x77C3,	0x77C4,	0x77C5,
	0x77C6,	0x77C7,	0x77C8,	0x77C9,	0x77CA,	0x77CB,	0x77CC,	0x77CE,
	0x77CF,	0x77D0,	0x77D1,	0x77D2,	0x77D3,	0x77D4,	0x77D5,	0x77D6,
	0x77D8,	0x77D9,	0x77DA,	0x77DD,	0x77DE,	0x77DF,	0x77E0,	0x77E1,
	0x77E4,	0x75C5,	0x5E76,	0x73BB,	0x83E0,	0x64AD,	0x62E8,	0x94B5,
	0x6CE2,	0x535A,	0x52C3,	0x640F,	0x94C2,	0x7B94,	0x4F2F,	0x5E1B,
	0x8236,	0x8116,	0x818A,	0x6E24,	0x6CCA,	0x9A73,	0x6355,	0x535C,
	0x54FA,	0x8865,	0x57E0,	0x4E0D,	0x5E03,	0x6B65,	0x7C3F,	0x90E8,
	0x6016,	0x64E6,	0x731C,	0x88C1,	0x6750,	0x624D,	0x8D22,	0x776C,
	0x8E29,	0x91C7,	0x5F69,	0x83DC,	0x8521,	0x9910,	0x53C2,	0x8695,
	0x6B8B,	0x60ED,	0x60E8,	0x707F,	0x82CD,	0x8231,	0x4ED3,	0x6CA7,
	0x85CF,	0x64CD,	0x7CD9,	0x69FD,	0x66F9,	0x8349,	0x5395,	0x7B56,
	0x4FA7,	0x518C,	0x6D4B,	0x5C42,	0x8E6D,	0x63D2,	0x53C9,	0x832C,
	0x8336,	0x67E5,	0x78B4,	0x643D,	0x5BDF,	0x5C94,	0x5DEE,	0x8BE7,
	0x62C6,	0x67F4,	0x8C7A,	0x6400,	0x63BA,	0x8749,	0x998B,	0x8C17,
	0x7F20,	0x94F2,	0x4EA7,	0x9610,	0x98A4,	0x660C,	0x7316,
	/* GB 0xB340..0xB37E */
	0x77E6,	0x77E8,	0x77EA,	0x77EF,	0x77F0,	0x77F1,	0x77F2,	0x77F4,
	0x77F5,	0x77F7,	0x77F9,	0x77FA,	0x77FB,	0x77FC,	0x7803,	0x7804,
	0x7805,	0x7806,	0x7807,	0x7808,	0x780A,	0x780B,	0x780E,	0x780F,
	0x7810,	0x7813,	0x7815,	0x7819,	0x781B,	0x781E,	0x7820,	0x7821,
	0x7822,	0x7824,	0x7828,	0x782A,	0x782B,	0x782E,	0x782F,	0x7831,
	0x7832,	0x7833,	0x7835,	0x7836,	0x783D,	0x783F,	0x7841,	0x7842,
	0x7843,	0x7844,	0x7846,	0x7848,	0x7849,	0x784A,	0x784B,	0x784D,
	0x784F,	0x7851,	0x7853,	0x7854,	0x7858,	0x7859,	0x785A,
	/* GB 0xB380..0xB3FE */
	0x785B,	0x785C,	0x785E,	0x785F,	0x7860,	0x7861,	0x7862,	0x7863,
	0x7864,	0x7865,	0x7866,	0x7867,	0x7868,	0x7869,	0x786F,	0x7870,
	0x7871,	0x7872,	0x7873,	0x7874,	0x7875,	0x7876,	0x7878,	0x7879,
	0x787A,	0x787B,	0x787D,	0x787E,	0x787F,	0x7880,	0x7881,	0x7882,
	0x7883,	0x573A,	0x5C1D,	0x5E38,	0x957F,	0x507F,	0x80A0,	0x5382,
	0x655E,	0x7545,	0x5531,	0x5021,	0x8D85,	0x6284,	0x949E,	0x671D,
	0x5632,	0x6F6E,	0x5DE2,	0x5435,	0x7092,	0x8F66,	0x626F,	0x64A4,
	0x63A3,	0x5F7B,	0x6F88,	0x90F4,	0x81E3,	0x8FB0,	0x5C18,	0x6668,
	0x5FF1,	0x6C89,	0x9648,	0x8D81,	0x886C,	0x6491,	0x79F0,	0x57CE,
	0x6A59,	0x6210,	0x5448,	0x4E58,	0x7A0B,	0x60E9,	0x6F84,	0x8BDA,
	0x627F,	0x901E,	0x9A8B,	0x79E4,	0x5403,	0x75F4,	0x6301,	0x5319,
	0x6C60,	0x8FDF,	0x5F1B,	0x9A70,	0x803B,	0x9F7F,	0x4F88,	0x5C3A,
	0x8D64,	0x7FC5,	0x65A5,	0x70BD,	0x5145,	0x51B2,	0x866B,	0x5D07,
	0x5BA0,	0x62BD,	0x916C,	0x7574,	0x8E0C,	0x7A20,	0x6101,	0x7B79,
	0x4EC7,	0x7EF8,	0x7785,	0x4E11,	0x81ED,	0x521D,	0x51FA,	0x6A71,
	0x53A8,	0x8E87,	0x9504,	0x96CF,	0x6EC1,	0x9664,	0x695A,
	/* GB 0xB440..0xB47E */
	0x7884,	0x7885,	0x7886,	0x7888,	0x788A,	0x788B,	0x788F,	0x7890,
	0x7892,	0x7894,	0x7895,	0x7896,	0x7899,	0x789D,	0x789E,	0x78A0,
	0x78A2,	0x78A4,	0x78A6,	0x78A8,	0x78A9,	0x78AA,	0x78AB,	0x78AC,
	0x78AD,	0x78AE,	0x78AF,	0x78B5,	0x78B6,	0x78B7,	0x78B8,	0x78BA,
	0x78BB,	0x78BC,	0x78BD,	0x78BF,	0x78C0,	0x78C2,	0x78C3,	0x78C4,
	0x78C6,	0x78C7,	0x78C8,	0x78CC,	0x78CD,	0x78CE,	0x78CF,	0x78D1,
	0x78D2,	0x78D3,	0x78D6,	0x78D7,	0x78D8,	0x78DA,	0x78DB,	0x78DC,
	0x78DD,	0x78DE,	0x78DF,	0x78E0,	0x78E1,	0x78E2,	0x78E3,
	/* GB 0xB480..0xB4FE */
	0x78E4,	0x78E5,	0x78E6,	0x78E7,	0x78E9,	0x78EA,	0x78EB,	0x78ED,
	0x78EE,	0x78EF,	0x78F0,	0x78F1,	0x78F3,	0x78F5,	0x78F6,	0x78F8,
	0x78F9,	0x78FB,	0x78FC,	0x78FD,	0x78FE,	0x78FF,	0x7900,	0x7902,
	0x7903,	0x7904,	0x7906,	0x7907,	0x7908,	0x7909,	0x790A,	0x790B,
	0x790C,	0x7840,	0x50A8,	0x77D7,	0x6410,	0x89E6,	0x5904,	0x63E3,
	0x5DDD,	0x7A7F,	0x693D,	0x4F20,	0x8239,	0x5598,	0x4E32,	0x75AE,
	0x7A97,	0x5E62,	0x5E8A,	0x95EF,	0x521B,	0x5439,	0x708A,	0x6376,
	0x9524,	0x5782,	0x6625,	0x693F,	0x9187,	0x5507,	0x6DF3,	0x7EAF,
	0x8822,	0x6233,	0x7EF0,	0x75B5,	0x8328,	0x78C1,	0x96CC,	0x8F9E,
	0x6148,	0x74F7,	0x8BCD,	0x6B64,	0x523A,	0x8D50,	0x6B21,	0x806A,
	0x8471,	0x56F1,	0x5306,	0x4ECE,	0x4E1B,	0x51D1,	0x7C97,	0x918B,
	0x7C07,	0x4FC3,	0x8E7F,	0x7BE1,	0x7A9C,	0x6467,	0x5D14,	0x50AC,
	0x8106,	0x7601,	0x7CB9,	0x6DEC,	0x7FE0,	0x6751,	0x5B58,	0x5BF8,
	0x78CB,	0x64AE,	0x6413,	0x63AA,	0x632B,	0x9519,	0x642D,	0x8FBE,
	0x7B54,	0x7629,	0x6253,	0x5927,	0x5446,	0x6B79,	0x50A3,	0x6234,
	0x5E26,	0x6B86,	0x4EE3,	0x8D37,	0x888B,	0x5F85,	0x902E,
	/* GB 0xB540..0xB57E */
	0x790D,	0x790E,	0x790F,	0x7910,	0x7911,	0x7912,	0x7914,	0x7915,
	0x7916,	0x7917,	0x7918,	0x7919,	0x791A,	0x791B,	0x791C,	0x791D,
	0x791F,	0x7920,	0x7921,	0x7922,	0x7923,	0x7925,	0x7926,	0x7927,
	0x7928,	0x7929,	0x792A,	0x792B,	0x792C,	0x792D,	0x792E,	0x792F,
	0x7930,	0x7931,	0x7932,	0x7933,	0x7935,	0x7936,	0x7937,	0x7938,
	0x7939,	0x793D,	0x793F,	0x7942,	0x7943,	0x7944,	0x7945,	0x7947,
	0x794A,	0x794B,	0x794C,	0x794D,	0x794E,	0x794F,	0x7950,	0x7951,
	0x7952,	0x7954,	0x7955,	0x7958,	0x7959,	0x7961,	0x7963,
	/* GB 0xB580..0xB5FE */
	0x7964,	0x7966,	0x7969,	0x796A,	0x796B,	0x796C,	0x796E,	0x7970,
	0x7971,	0x7972,	0x7973,	0x7974,	0x7975,	0x7976,	0x7979,	0x797B,
	0x797C,	0x797D,	0x797E,	0x797F,	0x7982,	0x7983,	0x7986,	0x7987,
	0x7988,	0x7989,	0x798B,	0x798C,	0x798D,	0x798E,	0x7990,	0x7991,
	0x7992,	0x6020,	0x803D,	0x62C5,	0x4E39,	0x5355,	0x90F8,	0x63B8,
	0x80C6,	0x65E6,	0x6C2E,	0x4F46,	0x60EE,	0x6DE1,	0x8BDE,	0x5F39,
	0x86CB,	0x5F53,	0x6321,	0x515A,	0x8361,	0x6863,	0x5200,	0x6363,
	0x8E48,	0x5012,	0x5C9B,	0x7977,	0x5BFC,	0x5230,	0x7A3B,	0x60BC,
	0x9053,	0x76D7,	0x5FB7,	0x5F97,	0x7684,	0x8E6C,	0x706F,	0x767B,
	0x7B49,	0x77AA,	0x51F3,	0x9093,	0x5824,	0x4F4E,	0x6EF4,	0x8FEA,
	0x654C,	0x7B1B,	0x72C4,	0x6DA4,	0x7FDF,	0x5AE1,	0x62B5,	0x5E95,
	0x5730,	0x8482,	0x7B2C,	0x5E1D,	0x5F1F,	0x9012,	0x7F14,	0x98A0,
	0x6382,	0x6EC7,	0x7898,	0x70B9,	0x5178,	0x975B,	0x57AB,	0x7535,
	0x4F43,	0x7538,	0x5E97,	0x60E6,	0x5960,	0x6DC0,	0x6BBF,	0x7889,
	0x53FC,	0x96D5,	0x51CB,	0x5201,	0x6389,	0x540A,	0x9493,	0x8C03,
	0x8DCC,	0x7239,	0x789F,	0x8776,	0x8FED,	0x8C0D,	0x53E0,
	/* GB 0xB640..0xB67E */
	0x7993,	0x7994,	0x7995,	0x7996,	0x7997,	0x7998,	0x7999,	0x799B,
	0x799C,	0x799D,	0x799E,	0x799F,	0x79A0,	0x79A1,	0x79A2,	0x79A3,
	0x79A4,	0x79A5,	0x79A6,	0x79A8,	0x79A9,	0x79AA,	0x79AB,	0x79AC,
	0x79AD,	0x79AE,	0x79AF,	0x79B0,	0x79B1,	0x79B2,	0x79B4,	0x79B5,
	0x79B6,	0x79B7,	0x79B8,	0x79BC,	0x79BF,	0x79C2,	0x79C4,	0x79C5,
	0x79C7,	0x79C8,	0x79CA,	0x79CC,	0x79CE,	0x79CF,	0x79D0,	0x79D3,
	0x79D4,	0x79D6,	0x79D7,	0x79D9,	0x79DA,	0x79DB,	0x79DC,	0x79DD,
	0x79DE,	0x79E0,	0x79E1,	0x79E2,	0x79E5,	0x79E8,	0x79EA,
	/* GB 0xB680..0xB6FE */
	0x79EC,	0x79EE,	0x79F1,	0x79F2,	0x79F3,	0x79F4,	0x79F5,	0x79F6,
	0x79F7,	0x79F9,	0x79FA,	0x79FC,	0x79FE,	0x79FF,	0x7A01,	0x7A04,
	0x7A05,	0x7A07,	0x7A08,	0x7A09,	0x7A0A,	0x7A0C,	0x7A0F,	0x7A10,
	0x7A11,	0x7A12,	0x7A13,	0x7A15,	0x7A16,	0x7A18,	0x7A19,	0x7A1B,
	0x7A1C,	0x4E01,	0x76EF,	0x53EE,	0x9489,	0x9876,	0x9F0E,	0x952D,
	0x5B9A,	0x8BA2,	0x4E22,	0x4E1C,	0x51AC,	0x8463,	0x61C2,	0x52A8,
	0x680B,	0x4F97,	0x606B,	0x51BB,	0x6D1E,	0x515C,	0x6296,	0x6597,
	0x9661,	0x8C46,	0x9017,	0x75D8,	0x90FD,	0x7763,	0x6BD2,	0x728A,
	0x72EC,	0x8BFB,	0x5835,	0x7779,	0x8D4C,	0x675C,	0x9540,	0x809A,
	0x5EA6,	0x6E21,	0x5992,	0x7AEF,	0x77ED,	0x953B,	0x6BB5,	0x65AD,
	0x7F0E,	0x5806,	0x5151,	0x961F,	0x5BF9,	0x58A9,	0x5428,	0x8E72,
	0x6566,	0x987F,	0x56E4,	0x949D,	0x76FE,	0x9041,	0x6387,	0x54C6,
	0x591A,	0x593A,	0x579B,	0x8EB2,	0x6735,	0x8DFA,	0x8235,	0x5241,
	0x60F0,	0x5815,	0x86FE,	0x5CE8,	0x9E45,	0x4FC4,	0x989D,	0x8BB9,
	0x5A25,	0x6076,	0x5384,	0x627C,	0x904F,	0x9102,	0x997F,	0x6069,
	0x800C,	0x513F,	0x8033,	0x5C14,	0x9975,	0x6D31,	0x4E8C,
	/* GB 0xB740..0xB77E */
	0x7A1D,	0x7A1F,	0x7A21,	0x7A22,	0x7A24,	0x7A25,	0x7A26,	0x7A27,
	0x7A28,	0x7A29,	0x7A2A,	0x7A2B,	0x7A2C,	0x7A2D,	0x7A2E,	0x7A2F,
	0x7A30,	0x7A31,	0x7A32,	0x7A34,	0x7A35,	0x7A36,	0x7A38,	0x7A3A,
	0x7A3E,	0x7A40,	0x7A41,	0x7A42,	0x7A43,	0x7A44,	0x7A45,	0x7A47,
	0x7A48,	0x7A49,	0x7A4A,	0x7A4B,	0x7A4C,	0x7A4D,	0x7A4E,	0x7A4F,
	0x7A50,	0x7A52,	0x7A53,	0x7A54,	0x7A55,	0x7A56,	0x7A58,	0x7A59,
	0x7A5A,	0x7A5B,	0x7A5C,	0x7A5D,	0x7A5E,	0x7A5F,	0x7A60,	0x7A61,
	0x7A62,	0x7A63,	0x7A64,	0x7A65,	0x7A66,	0x7A67,	0x7A68,
	/* GB 0xB780..0xB7FE */
	0x7A69,	0x7A6A,	0x7A6B,	0x7A6C,	0x7A6D,	0x7A6E,	0x7A6F,	0x7A71,
	0x7A72,	0x7A73,	0x7A75,	0x7A7B,	0x7A7C,	0x7A7D,	0x7A7E,	0x7A82,
	0x7A85,	0x7A87,	0x7A89,	0x7A8A,	0x7A8B,	0x7A8C,	0x7A8E,	0x7A8F,
	0x7A90,	0x7A93,	0x7A94,	0x7A99,	0x7A9A,	0x7A9B,	0x7A9E,	0x7AA1,
	0x7AA2,	0x8D30,	0x53D1,	0x7F5A,	0x7B4F,	0x4F10,	0x4E4F,	0x9600,
	0x6CD5,	0x73D0,	0x85E9,	0x5E06,	0x756A,	0x7FFB,	0x6A0A,	0x77FE,
	0x9492,	0x7E41,	0x51E1,	0x70E6,	0x53CD,	0x8FD4,	0x8303,	0x8D29,
	0x72AF,	0x996D,	0x6CDB,	0x574A,	0x82B3,	0x65B9,	0x80AA,	0x623F,
	0x9632,	0x59A8,	0x4EFF,	0x8BBF,	0x7EBA,	0x653E,	0x83F2,	0x975E,
	0x5561,	0x98DE,	0x80A5,	0x532A,	0x8BFD,	0x5420,	0x80BA,	0x5E9F,
	0x6CB8,	0x8D39,	0x82AC,	0x915A,	0x5429,	0x6C1B,	0x5206,	0x7EB7,
	0x575F,	0x711A,	0x6C7E,	0x7C89,	0x594B,	0x4EFD,	0x5FFF,	0x6124,
	0x7CAA,	0x4E30,	0x5C01,	0x67AB,	0x8702,	0x5CF0,	0x950B,	0x98CE,
	0x75AF,	0x70FD,	0x9022,	0x51AF,	0x7F1D,	0x8BBD,	0x5949,	0x51E4,
	0x4F5B,	0x5426,	0x592B,	0x6577,	0x80A4,	0x5B75,	0x6276,	0x62C2,
	0x8F90,	0x5E45,	0x6C1F,	0x7B26,	0x4F0F,	0x4FD8,	0x670D,
	/* GB 0xB840..0xB87E */
	0x7AA3,	0x7AA4,	0x7AA7,	0x7AA9,	0x7AAA,	0x7AAB,	0x7AAE,	0x7AAF,
	0x7AB0,	0x7AB1,	0x7AB2,	0x7AB4,	0x7AB5,	0x7AB6,	0x7AB7,	0x7AB8,
	0x7AB9,	0x7ABA,	0x7ABB,	0x7ABC,	0x7ABD,	0x7ABE,	0x7AC0,	0x7AC1,
	0x7AC2,	0x7AC3,	0x7AC4,	0x7AC5,	0x7AC6,	0x7AC7,	0x7AC8,	0x7AC9,
	0x7ACA,	0x7ACC,	0x7ACD,	0x7ACE,	0x7ACF,	0x7AD0,	0x7AD1,	0x7AD2,
	0x7AD3,	0x7AD4,	0x7AD5,	0x7AD7,	0x7AD8,	0x7ADA,	0x7ADB,	0x7ADC,
	0x7ADD,	0x7AE1,	0x7AE2,	0x7AE4,	0x7AE7,	0x7AE8,	0x7AE9,	0x7AEA,
	0x7AEB,	0x7AEC,	0x7AEE,	0x7AF0,	0x7AF1,	0x7AF2,	0x7AF3,
	/* GB 0xB880..0xB8FE */
	0x7AF4,	0x7AF5,	0x7AF6,	0x7AF7,	0x7AF8,	0x7AFB,	0x7AFC,	0x7AFE,
	0x7B00,	0x7B01,	0x7B02,	0x7B05,	0x7B07,	0x7B09,	0x7B0C,	0x7B0D,
	0x7B0E,	0x7B10,	0x7B12,	0x7B13,	0x7B16,	0x7B17,	0x7B18,	0x7B1A,
	0x7B1C,	0x7B1D,	0x7B1F,	0x7B21,	0x7B22,	0x7B23,	0x7B27,	0x7B29,
	0x7B2D,	0x6D6E,	0x6DAA,	0x798F,	0x88B1,	0x5F17,	0x752B,	0x629A,
	0x8F85,	0x4FEF,	0x91DC,	0x65A7,	0x812F,	0x8151,	0x5E9C,	0x8150,
	0x8D74,	0x526F,	0x8986,	0x8D4B,	0x590D,	0x5085,	0x4ED8,	0x961C,
	0x7236,	0x8179,	0x8D1F,	0x5BCC,	0x8BA3,	0x9644,	0x5987,	0x7F1A,
	0x5490,	0x5676,	0x560E,	0x8BE5,	0x6539,	0x6982,	0x9499,	0x76D6,
	0x6E89,	0x5E72,	0x7518,	0x6746,	0x67D1,	0x7AFF,	0x809D,	0x8D76,
	0x611F,	0x79C6,	0x6562,	0x8D63,	0x5188,	0x521A,	0x94A2,	0x7F38,
	0x809B,	0x7EB2,	0x5C97,	0x6E2F,	0x6760,	0x7BD9,	0x768B,	0x9AD8,
	0x818F,	0x7F94,	0x7CD5,	0x641E,	0x9550,	0x7A3F,	0x544A,	0x54E5,
	0x6B4C,	0x6401,	0x6208,	0x9E3D,	0x80F3,	0x7599,	0x5272,	0x9769,
	0x845B,	0x683C,	0x86E4,	0x9601,	0x9694,	0x94EC,	0x4E2A,	0x5404,
	0x7ED9,	0x6839,	0x8DDF,	0x8015,	0x66F4,	0x5E9A,	0x7FB9,
	/* GB 0xB940..0xB97E */
	0x7B2F,	0x7B30,	0x7B32,	0x7B34,	0x7B35,	0x7B36,	0x7B37,	0x7B39,
	0x7B3B,	0x7B3D,	0x7B3F,	0x7B40,	0x7B41,	0x7B42,	0x7B43,	0x7B44,
	0x7B46,	0x7B48,	0x7B4A,	0x7B4D,	0x7B4E,	0x7B53,	0x7B55,	0x7B57,
	0x7B59,	0x7B5C,	0x7B5E,	0x7B5F,	0x7B61,	0x7B63,	0x7B64,	0x7B65,
	0x7B66,	0x7B67,	0x7B68,	0x7B69,	0x7B6A,	0x7B6B,	0x7B6C,	0x7B6D,
	0x7B6F,	0x7B70,	0x7B73,	0x7B74,	0x7B76,	0x7B78,	0x7B7A,	0x7B7C,
	0x7B7D,	0x7B7F,	0x7B81,	0x7B82,	0x7B83,	0x7B84,	0x7B86,	0x7B87,
	0x7B88,	0x7B89,	0x7B8A,	0x7B8B,	0x7B8C,	0x7B8E,	0x7B8F,
	/* GB 0xB980..0xB9FE */
	0x7B91,	0x7B92,	0x7B93,	0x7B96,	0x7B98,	0x7B99,	0x7B9A,	0x7B9B,
	0x7B9E,	0x7B9F,	0x7BA0,	0x7BA3,	0x7BA4,	0x7BA5,	0x7BAE,	0x7BAF,
	0x7BB0,	0x7BB2,	0x7BB3,	0x7BB5,	0x7BB6,	0x7BB7,	0x7BB9,	0x7BBA,
	0x7BBB,	0x7BBC,	0x7BBD,	0x7BBE,	0x7BBF,	0x7BC0,	0x7BC2,	0x7BC3,
	0x7BC4,	0x57C2,	0x803F,	0x6897,	0x5DE5,	0x653B,	0x529F,	0x606D,
	0x9F9A,	0x4F9B,	0x8EAC,	0x516C,	0x5BAB,	0x5F13,	0x5DE9,	0x6C5E,
	0x62F1,	0x8D21,	0x5171,	0x94A9,	0x52FE,	0x6C9F,	0x82DF,	0x72D7,
	0x57A2,	0x6784,	0x8D2D,	0x591F,	0x8F9C,	0x83C7,	0x5495,	0x7B8D,
	0x4F30,	0x6CBD,	0x5B64,	0x59D1,	0x9F13,	0x53E4,	0x86CA,	0x9AA8,
	0x8C37,	0x80A1,	0x6545,	0x987E,	0x56FA,	0x96C7,	0x522E,	0x74DC,
	0x5250,	0x5BE1,	0x6302,	0x8902,	0x4E56,	0x62D0,	0x602A,	0x68FA,
	0x5173,	0x5B98,	0x51A0,	0x89C2,	0x7BA1,	0x9986,	0x7F50,	0x60EF,
	0x704C,	0x8D2F,	0x5149,	0x5E7F,	0x901B,	0x7470,	0x89C4,	0x572D,
	0x7845,	0x5F52,	0x9F9F,	0x95FA,	0x8F68,	0x9B3C,	0x8BE1,	0x7678,
	0x6842,	0x67DC,	0x8DEA,	0x8D35,	0x523D,	0x8F8A,	0x6EDA,	0x68CD,
	0x9505,	0x90ED,	0x56FD,	0x679C,	0x88F9,	0x8FC7,	0x54C8,
	/* GB 0xBA40..0xBA7E */
	0x7BC5,	0x7BC8,	0x7BC9,	0x7BCA,	0x7BCB,	0x7BCD,	0x7BCE,	0x7BCF,
	0x7BD0,	0x7BD2,	0x7BD4,	0x7BD5,	0x7BD6,	0x7BD7,	0x7BD8,	0x7BDB,
	0x7BDC,	0x7BDE,	0x7BDF,	0x7BE0,	0x7BE2,	0x7BE3,	0x7BE4,	0x7BE7,
	0x7BE8,	0x7BE9,	0x7BEB,	0x7BEC,	0x7BED,	0x7BEF,	0x7BF0,	0x7BF2,
	0x7BF3,	0x7BF4,	0x7BF5,	0x7BF6,	0x7BF8,	0x7BF9,	0x7BFA,	0x7BFB,
	0x7BFD,	0x7BFF,	0x7C00,	0x7C01,	0x7C02,	0x7C03,	0x7C04,	0x7C05,
	0x7C06,	0x7C08,	0x7C09,	0x7C0A,	0x7C0D,	0x7C0E,	0x7C10,	0x7C11,
	0x7C12,	0x7C13,	0x7C14,	0x7C15,	0x7C17,	0x7C18,	0x7C19,
	/* GB 0xBA80..0xBAFE */
	0x7C1A,	0x7C1B,	0x7C1C,	0x7C1D,	0x7C1E,	0x7C20,	0x7C21,	0x7C22,
	0x7C23,	0x7C24,	0x7C25,	0x7C28,	0x7C29,	0x7C2B,	0x7C2C,	0x7C2D,
	0x7C2E,	0x7C2F,	0x7C30,	0x7C31,	0x7C32,	0x7C33,	0x7C34,	0x7C35,
	0x7C36,	0x7C37,	0x7C39,	0x7C3A,	0x7C3B,	0x7C3C,	0x7C3D,	0x7C3E,
	0x7C42,	0x9AB8,	0x5B69,	0x6D77,	0x6C26,	0x4EA5,	0x5BB3,	0x9A87,
	0x9163,	0x61A8,	0x90AF,	0x97E9,	0x542B,	0x6DB5,	0x5BD2,	0x51FD,
	0x558A,	0x7F55,	0x7FF0,	0x64BC,	0x634D,	0x65F1,	0x61BE,	0x608D,
	0x710A,	0x6C57,	0x6C49,	0x592F,	0x676D,	0x822A,	0x58D5,	0x568E,
	0x8C6A,	0x6BEB,	0x90DD,	0x597D,	0x8017,	0x53F7,	0x6D69,	0x5475,
	0x559D,	0x8377,	0x83CF,	0x6838,	0x79BE,	0x548C,	0x4F55,	0x5408,
	0x76D2,	0x8C89,	0x9602,	0x6CB3,	0x6DB8,	0x8D6B,	0x8910,	0x9E64,
	0x8D3A,	0x563F,	0x9ED1,	0x75D5,	0x5F88,	0x72E0,	0x6068,	0x54FC,
	0x4EA8,	0x6A2A,	0x8861,	0x6052,	0x8F70,	0x54C4,	0x70D8,	0x8679,
	0x9E3F,	0x6D2A,	0x5B8F,	0x5F18,	0x7EA2,	0x5589,	0x4FAF,	0x7334,
	0x543C,	0x539A,	0x5019,	0x540E,	0x547C,	0x4E4E,	0x5FFD,	0x745A,
	0x58F6,	0x846B,	0x80E1,	0x8774,	0x72D0,	0x7CCA,	0x6E56,
	/* GB 0xBB40..0xBB7E */
	0x7C43,	0x7C44,	0x7C45,	0x7C46,	0x7C47,	0x7C48,	0x7C49,	0x7C4A,
	0x7C4B,	0x7C4C,	0x7C4E,	0x7C4F,	0x7C50,	0x7C51,	0x7C52,	0x7C53,
	0x7C54,	0x7C55,	0x7C56,	0x7C57,	0x7C58,	0x7C59,	0x7C5A,	0x7C5B,
	0x7C5C,	0x7C5D,	0x7C5E,	0x7C5F,	0x7C60,	0x7C61,	0x7C62,	0x7C63,
	0x7C64,	0x7C65,	0x7C66,	0x7C67,	0x7C68,	0x7C69,	0x7C6A,	0x7C6B,
	0x7C6C,	0x7C6D,	0x7C6E,	0x7C6F,	0x7C70,	0x7C71,	0x7C72,	0x7C75,
	0x7C76,	0x7C77,	0x7C78,	0x7C79,	0x7C7A,	0x7C7E,	0x7C7F,	0x7C80,
	0x7C81,	0x7C82,	0x7C83,	0x7C84,	0x7C85,	0x7C86,	0x7C87,
	/* GB 0xBB80..0xBBFE */
	0x7C88,	0x7C8A,	0x7C8B,	0x7C8C,	0x7C8D,	0x7C8E,	0x7C8F,	0x7C90,
	0x7C93,	0x7C94,	0x7C96,	0x7C99,	0x7C9A,	0x7C9B,	0x7CA0,	0x7CA1,
	0x7CA3,	0x7CA6,	0x7CA7,	0x7CA8,	0x7CA9,	0x7CAB,	0x7CAC,	0x7CAD,
	0x7CAF,	0x7CB0,	0x7CB4,	0x7CB5,	0x7CB6,	0x7CB7,	0x7CB8,	0x7CBA,
	0x7CBB,	0x5F27,	0x864E,	0x552C,	0x62A4,	0x4E92,	0x6CAA,	0x6237,
	0x82B1,	0x54D7,	0x534E,	0x733E,	0x6ED1,	0x753B,	0x5212,	0x5316,
	0x8BDD,	0x69D0,	0x5F8A,	0x6000,	0x6DEE,	0x574F,	0x6B22,	0x73AF,
	0x6853,	0x8FD8,	0x7F13,	0x6362,	0x60A3,	0x5524,	0x75EA,	0x8C62,
	0x7115,	0x6DA3,	0x5BA6,	0x5E7B,	0x8352,	0x614C,	0x9EC4,	0x78FA,
	0x8757,	0x7C27,	0x7687,	0x51F0,	0x60F6,	0x714C,	0x6643,	0x5E4C,
	0x604D,	0x8C0E,	0x7070,	0x6325,	0x8F89,	0x5FBD,	0x6062,	0x86D4,
	0x56DE,	0x6BC1,	0x6094,	0x6167,	0x5349,	0x60E0,	0x6666,	0x8D3F,
	0x79FD,	0x4F1A,	0x70E9,	0x6C47,	0x8BB3,	0x8BF2,	0x7ED8,	0x8364,
	0x660F,	0x5A5A,	0x9B42,	0x6D51,	0x6DF7,	0x8C41,	0x6D3B,	0x4F19,
	0x706B,	0x83B7,	0x6216,	0x60D1,	0x970D,	0x8D27,	0x7978,	0x51FB,
	0x573E,	0x57FA,	0x673A,	0x7578,	0x7A3D,	0x79EF,	0x7B95,
	/* GB 0xBC40..0xBC7E */
	0x7CBF,	0x7CC0,	0x7CC2,	0x7CC3,	0x7CC4,	0x7CC6,	0x7CC9,	0x7CCB,
	0x7CCE,	0x7CCF,	0x7CD0,	0x7CD1,	0x7CD2,	0x7CD3,	0x7CD4,	0x7CD8,
	0x7CDA,	0x7CDB,	0x7CDD,	0x7CDE,	0x7CE1,	0x7CE2,	0x7CE3,	0x7CE4,
	0x7CE5,	0x7CE6,	0x7CE7,	0x7CE9,	0x7CEA,	0x7CEB,	0x7CEC,	0x7CED,
	0x7CEE,	0x7CF0,	0x7CF1,	0x7CF2,	0x7CF3,	0x7CF4,	0x7CF5,	0x7CF6,
	0x7CF7,	0x7CF9,	0x7CFA,	0x7CFC,	0x7CFD,	0x7CFE,	0x7CFF,	0x7D00,
	0x7D01,	0x7D02,	0x7D03,	0x7D04,	0x7D05,	0x7D06,	0x7D07,	0x7D08,
	0x7D09,	0x7D0B,	0x7D0C,	0x7D0D,	0x7D0E,	0x7D0F,	0x7D10,
	/* GB 0xBC80..0xBCFE */
	0x7D11,	0x7D12,	0x7D13,	0x7D14,	0x7D15,	0x7D16,	0x7D17,	0x7D18,
	0x7D19,	0x7D1A,	0x7D1B,	0x7D1C,	0x7D1D,	0x7D1E,	0x7D1F,	0x7D21,
	0x7D23,	0x7D24,	0x7D25,	0x7D26,	0x7D28,	0x7D29,	0x7D2A,	0x7D2C,
	0x7D2D,	0x7D2E,	0x7D30,	0x7D31,	0x7D32,	0x7D33,	0x7D34,	0x7D35,
	0x7D36,	0x808C,	0x9965,	0x8FF9,	0x6FC0,	0x8BA5,	0x9E21,	0x59EC,
	0x7EE9,	0x7F09,	0x5409,	0x6781,	0x68D8,	0x8F91,	0x7C4D,	0x96C6,
	0x53CA,	0x6025,	0x75BE,	0x6C72,	0x5373,	0x5AC9,	0x7EA7,	0x6324,
	0x51E0,	0x810A,	0x5DF1,	0x84DF,	0x6280,	0x5180,	0x5B63,	0x4F0E,
	0x796D,	0x5242,	0x60B8,	0x6D4E,	0x5BC4,	0x5BC2,	0x8BA1,	0x8BB0,
	0x65E2,	0x5FCC,	0x9645,	0x5993,	0x7EE7,	0x7EAA,	0x5609,	0x67B7,
	0x5939,	0x4F73,	0x5BB6,	0x52A0,	0x835A,	0x988A,	0x8D3E,	0x7532,
	0x94BE,	0x5047,	0x7A3C,	0x4EF7,	0x67B6,	0x9A7E,	0x5AC1,	0x6B7C,
	0x76D1,	0x575A,	0x5C16,	0x7B3A,	0x95F4,	0x714E,	0x517C,	0x80A9,
	0x8270,	0x5978,	0x7F04,	0x8327,	0x68C0,	0x67EC,	0x78B1,	0x7877,
	0x62E3,	0x6361,	0x7B80,	0x4FED,	0x526A,	0x51CF,	0x8350,	0x69DB,
	0x9274,	0x8DF5,	0x8D31,	0x89C1,	0x952E,	0x7BAD,	0x4EF6,
	/* GB 0xBD40..0xBD7E */
	0x7D37,	0x7D38,	0x7D39,	0x7D3A,	0x7D3B,	0x7D3C,	0x7D3D,	0x7D3E,
	0x7D3F,	0x7D40,	0x7D41,	0x7D42,	0x7D43,	0x7D44,	0x7D45,	0x7D46,
	0x7D47,	0x7D48,	0x7D49,	0x7D4A,	0x7D4B,	0x7D4C,	0x7D4D,	0x7D4E,
	0x7D4F,	0x7D50,	0x7D51,	0x7D52,	0x7D53,	0x7D54,	0x7D55,	0x7D56,
	0x7D57,	0x7D58,	0x7D59,	0x7D5A,	0x7D5B,	0x7D5C,	0x7D5D,	0x7D5E,
	0x7D5F,	0x7D60,	0x7D61,	0x7D62,	0x7D63,	0x7D64,	0x7D65,	0x7D66,
	0x7D67,	0x7D68,	0x7D69,	0x7D6A,	0x7D6B,	0x7D6C,	0x7D6D,	0x7D6F,
	0x7D70,	0x7D71,	0x7D72,	0x7D73,	0x7D74,	0x7D75,	0x7D76,
	/* GB 0xBD80..0xBDFE */
	0x7D78,	0x7D79,	0x7D7A,	0x7D7B,	0x7D7C,	0x7D7D,	0x7D7E,	0x7D7F,
	0x7D80,	0x7D81,	0x7D82,	0x7D83,	0x7D84,	0x7D85,	0x7D86,	0x7D87,
	0x7D88,	0x7D89,	0x7D8A,	0x7D8B,	0x7D8C,	0x7D8D,	0x7D8E,	0x7D8F,
	0x7D90,	0x7D91,	0x7D92,	0x7D93,	0x7D94,	0x7D95,	0x7D96,	0x7D97,
	0x7D98,	0x5065,	0x8230,	0x5251,	0x996F,	0x6E10,	0x6E85,	0x6DA7,
	0x5EFA,	0x50F5,	0x59DC,	0x5C06,	0x6D46,	0x6C5F,	0x7586,	0x848B,
	0x6868,	0x5956,	0x8BB2,	0x5320,	0x9171,	0x964D,	0x8549,	0x6912,
	0x7901,	0x7126,	0x80F6,	0x4EA4,	0x90CA,	0x6D47,	0x9A84,	0x5A07,
	0x56BC,	0x6405,	0x94F0,	0x77EB,	0x4FA5,	0x811A,	0x72E1,	0x89D2,
	0x997A,	0x7F34,	0x7EDE,	0x527F,	0x6559,	0x9175,	0x8F7F,	0x8F83,
	0x53EB,	0x7A96,	0x63ED,	0x63A5,	0x7686,	0x79F8,	0x8857,	0x9636,
	0x622A,	0x52AB,	0x8282,	0x6854,	0x6770,	0x6377,	0x776B,	0x7AED,
	0x6D01,	0x7ED3,	0x89E3,	0x59D0,	0x6212,	0x85C9,	0x82A5,	0x754C,
	0x501F,	0x4ECB,	0x75A5,	0x8BEB,	0x5C4A,	0x5DFE,	0x7B4B,	0x65A4,
	0x91D1,	0x4ECA,	0x6D25,	0x895F,	0x7D27,	0x9526,	0x4EC5,	0x8C28,
	0x8FDB,	0x9773,	0x664B,	0x7981,	0x8FD1,	0x70EC,	0x6D78,
	/* GB 0xBE40..0xBE7E */
	0x7D99,	0x7D9A,	0x7D9B,	0x7D9C,	0x7D9D,	0x7D9E,	0x7D9F,	0x7DA0,
	0x7DA1,	0x7DA2,	0x7DA3,	0x7DA4,	0x7DA5,	0x7DA7,	0x7DA8,	0x7DA9,
	0x7DAA,	0x7DAB,	0x7DAC,	0x7DAD,	0x7DAF,	0x7DB0,	0x7DB1,	0x7DB2,
	0x7DB3,	0x7DB4,	0x7DB5,	0x7DB6,	0x7DB7,	0x7DB8,	0x7DB9,	0x7DBA,
	0x7DBB,	0x7DBC,	0x7DBD,	0x7DBE,	0x7DBF,	0x7DC0,	0x7DC1,	0x7DC2,
	0x7DC3,	0x7DC4,	0x7DC5,	0x7DC6,	0x7DC7,	0x7DC8,	0x7DC9,	0x7DCA,
	0x7DCB,	0x7DCC,	0x7DCD,	0x7DCE,	0x7DCF,	0x7DD0,	0x7DD1,	0x7DD2,
	0x7DD3,	0x7DD4,	0x7DD5,	0x7DD6,	0x7DD7,	0x7DD8,	0x7DD9,
	/* GB 0xBE80..0xBEFE */
	0x7DDA,	0x7DDB,	0x7DDC,	0x7DDD,	0x7DDE,	0x7DDF,	0x7DE0,	0x7DE1,
	0x7DE2,	0x7DE3,	0x7DE4,	0x7DE5,	0x7DE6,	0x7DE7,	0x7DE8,	0x7DE9,
	0x7DEA,	0x7DEB,	0x7DEC,	0x7DED,	0x7DEE,	0x7DEF,	0x7DF0,	0x7DF1,
	0x7DF2,	0x7DF3,	0x7DF4,	0x7DF5,	0x7DF6,	0x7DF7,	0x7DF8,	0x7DF9,
	0x7DFA,	0x5C3D,	0x52B2,	0x8346,	0x5162,	0x830E,	0x775B,	0x6676,
	0x9CB8,	0x4EAC,	0x60CA,	0x7CBE,	0x7CB3,	0x7ECF,	0x4E95,	0x8B66,
	0x666F,	0x9888,	0x9759,	0x5883,	0x656C,	0x955C,	0x5F84,	0x75C9,
	0x9756,	0x7ADF,	0x7ADE,	0x51C0,	0x70AF,	0x7A98,	0x63EA,	0x7A76,
	0x7EA0,	0x7396,	0x97ED,	0x4E45,	0x7078,	0x4E5D,	0x9152,	0x53A9,
	0x6551,	0x65E7,	0x81FC,	0x8205,	0x548E,	0x5C31,	0x759A,	0x97A0,
	0x62D8,	0x72D9,	0x75BD,	0x5C45,	0x9A79,	0x83CA,	0x5C40,	0x5480,
	0x77E9,	0x4E3E,	0x6CAE,	0x805A,	0x62D2,	0x636E,	0x5DE8,	0x5177,
	0x8DDD,	0x8E1E,	0x952F,	0x4FF1,	0x53E5,	0x60E7,	0x70AC,	0x5267,
	0x6350,	0x9E43,	0x5A1F,	0x5026,	0x7737,	0x5377,	0x7EE2,	0x6485,
	0x652B,	0x6289,	0x6398,	0x5014,	0x7235,	0x89C9,	0x51B3,	0x8BC0,
	0x7EDD,	0x5747,	0x83CC,	0x94A7,	0x519B,	0x541B,	0x5CFB,
	/* GB 0xBF40..0xBF7E */
	0x7DFB,	0x7DFC,	0x7DFD,	0x7DFE,	0x7DFF,	0x7E00,	0x7E01,	0x7E02,
	0x7E03,	0x7E04,	0x7E05,	0x7E06,	0x7E07,	0x7E08,	0x7E09,	0x7E0A,
	0x7E0B,	0x7E0C,	0x7E0D,	0x7E0E,	0x7E0F,	0x7E10,	0x7E11,	0x7E12,
	0x7E13,	0x7E14,	0x7E15,	0x7E16,	0x7E17,	0x7E18,	0x7E19,	0x7E1A,
	0x7E1B,	0x7E1C,	0x7E1D,	0x7E1E,	0x7E1F,	0x7E20,	0x7E21,	0x7E22,
	0x7E23,	0x7E24,	0x7E25,	0x7E26,	0x7E27,	0x7E28,	0x7E29,	0x7E2A,
	0x7E2B,	0x7E2C,	0x7E2D,	0x7E2E,	0x7E2F,	0x7E30,	0x7E31,	0x7E32,
	0x7E33,	0x7E34,	0x7E35,	0x7E36,	0x7E37,	0x7E38,	0x7E39,
	/* GB 0xBF80..0xBFFE */
	0x7E3A,	0x7E3C,	0x7E3D,	0x7E3E,	0x7E3F,	0x7E40,	0x7E42,	0x7E43,
	0x7E44,	0x7E45,	0x7E46,	0x7E48,	0x7E49,	0x7E4A,	0x7E4B,	0x7E4C,
	0x7E4D,	0x7E4E,	0x7E4F,	0x7E50,	0x7E51,	0x7E52,	0x7E53,	0x7E54,
	0x7E55,	0x7E56,	0x7E57,	0x7E58,	0x7E59,	0x7E5A,	0x7E5B,	0x7E5C,
	0x7E5D,	0x4FCA,	0x7AE3,	0x6D5A,	0x90E1,	0x9A8F,	0x5580,	0x5496,
	0x5361,	0x54AF,	0x5F00,	0x63E9,	0x6977,	0x51EF,	0x6168,	0x520A,
	0x582A,	0x52D8,	0x574E,	0x780D,	0x770B,	0x5EB7,	0x6177,	0x7CE0,
	0x625B,	0x6297,	0x4EA2,	0x7095,	0x8003,	0x62F7,	0x70E4,	0x9760,
	0x5777,	0x82DB,	0x67EF,	0x68F5,	0x78D5,	0x9897,	0x79D1,	0x58F3,
	0x54B3,	0x53EF,	0x6E34,	0x514B,	0x523B,	0x5BA2,	0x8BFE,	0x80AF,
	0x5543,	0x57A6,	0x6073,	0x5751,	0x542D,	0x7A7A,	0x6050,	0x5B54,
	0x63A7,	0x62A0,	0x53E3,	0x6263,	0x5BC7,	0x67AF,	0x54ED,	0x7A9F,
	0x82E6,	0x9177,	0x5E93,	0x88E4,	0x5938,	0x57AE,	0x630E,	0x8DE8,
	0x80EF,	0x5757,	0x7B77,	0x4FA9,	0x5FEB,	0x5BBD,	0x6B3E,	0x5321,
	0x7B50,	0x72C2,	0x6846,	0x77FF,	0x7736,	0x65F7,	0x51B5,	0x4E8F,
	0x76D4,	0x5CBF,	0x7AA5,	0x8475,	0x594E,	0x9B41,	0x5080,
	/* GB 0xC040..0xC07E */
	0x7E5E,	0x7E5F,	0x7E60,	0x7E61,	0x7E62,	0x7E63,	0x7E64,	0x7E65,
	0x7E66,	0x7E67,	0x7E68,	0x7E69,	0x7E6A,	0x7E6B,	0x7E6C,	0x7E6D,
	0x7E6E,	0x7E6F,	0x7E70,	0x7E71,	0x7E72,	0x7E73,	0x7E74,	0x7E75,
	0x7E76,	0x7E77,	0x7E78,	0x7E79,	0x7E7A,	0x7E7B,	0x7E7C,	0x7E7D,
	0x7E7E,	0x7E7F,	0x7E80,	0x7E81,	0x7E83,	0x7E84,	0x7E85,	0x7E86,
	0x7E87,	0x7E88,	0x7E89,	0x7E8A,	0x7E8B,	0x7E8C,	0x7E8D,	0x7E8E,
	0x7E8F,	0x7E90,	0x7E91,	0x7E92,	0x7E93,	0x7E94,	0x7E95,	0x7E96,
	0x7E97,	0x7E98,	0x7E99,	0x7E9A,	0x7E9C,	0x7E9D,	0x7E9E,
	/* GB 0xC080..0xC0FE */
	0x7EAE,	0x7EB4,	0x7EBB,	0x7EBC,	0x7ED6,	0x7EE4,	0x7EEC,	0x7EF9,
	0x7F0A,	0x7F10,	0x7F1E,	0x7F37,	0x7F39,	0x7F3B,	0x7F3C,	0x7F3D,
	0x7F3E,	0x7F3F,	0x7F40,	0x7F41,	0x7F43,	0x7F46,	0x7F47,	0x7F48,
	0x7F49,	0x7F4A,	0x7F4B,	0x7F4C,	0x7F4D,	0x7F4E,	0x7F4F,	0x7F52,
	0x7F53,	0x9988,	0x6127,	0x6E83,	0x5764,	0x6606,	0x6346,	0x56F0,
	0x62EC,	0x6269,	0x5ED3,	0x9614,	0x5783,	0x62C9,	0x5587,	0x8721,
	0x814A,	0x8FA3,	0x5566,	0x83B1,	0x6765,	0x8D56,	0x84DD,	0x5A6A,
	0x680F,	0x62E6,	0x7BEE,	0x9611,	0x5170,	0x6F9C,	0x8C30,	0x63FD,
	0x89C8,	0x61D2,	0x7F06,	0x70C2,	0x6EE5,	0x7405,	0x6994,	0x72FC,
	0x5ECA,	0x90CE,	0x6717,	0x6D6A,	0x635E,	0x52B3,	0x7262,	0x8001,
	0x4F6C,	0x59E5,	0x916A,	0x70D9,	0x6D9D,	0x52D2,	0x4E50,	0x96F7,
	0x956D,	0x857E,	0x78CA,	0x7D2F,	0x5121,	0x5792,	0x64C2,	0x808B,
	0x7C7B,	0x6CEA,	0x68F1,	0x695E,	0x51B7,	0x5398,	0x68A8,	0x7281,
	0x9ECE,	0x7BF1,	0x72F8,	0x79BB,	0x6F13,	0x7406,	0x674E,	0x91CC,
	0x9CA4,	0x793C,	0x8389,	0x8354,	0x540F,	0x6817,	0x4E3D,	0x5389,
	0x52B1,	0x783E,	0x5386,	0x5229,	0x5088,	0x4F8B,	0x4FD0,
	/* GB 0xC140..0xC17E */
	0x7F56,	0x7F59,	0x7F5B,	0x7F5C,	0x7F5D,	0x7F5E,	0x7F60,	0x7F63,
	0x7F64,	0x7F65,	0x7F66,	0x7F67,	0x7F6B,	0x7F6C,	0x7F6D,	0x7F6F,
	0x7F70,	0x7F73,	0x7F75,	0x7F76,	0x7F77,	0x7F78,	0x7F7A,	0x7F7B,
	0x7F7C,	0x7F7D,	0x7F7F,	0x7F80,	0x7F82,	0x7F83,	0x7F84,	0x7F85,
	0x7F86,	0x7F87,	0x7F88,	0x7F89,	0x7F8B,	0x7F8D,	0x7F8F,	0x7F90,
	0x7F91,	0x7F92,	0x7F93,	0x7F95,	0x7F96,	0x7F97,	0x7F98,	0x7F99,
	0x7F9B,	0x7F9C,	0x7FA0,	0x7FA2,	0x7FA3,	0x7FA5,	0x7FA6,	0x7FA8,
	0x7FA9,	0x7FAA,	0x7FAB,	0x7FAC,	0x7FAD,	0x7FAE,	0x7FB1,
	/* GB 0xC180..0xC1FE */
	0x7FB3,	0x7FB4,	0x7FB5,	0x7FB6,	0x7FB7,	0x7FBA,	0x7FBB,	0x7FBE,
	0x7FC0,	0x7FC2,	0x7FC3,	0x7FC4,	0x7FC6,	0x7FC7,	0x7FC8,	0x7FC9,
	0x7FCB,	0x7FCD,	0x7FCF,	0x7FD0,	0x7FD1,	0x7FD2,	0x7FD3,	0x7FD6,
	0x7FD7,	0x7FD9,	0x7FDA,	0x7FDB,	0x7FDC,	0x7FDD,	0x7FDE,	0x7FE2,
	0x7FE3,	0x75E2,	0x7ACB,	0x7C92,	0x6CA5,	0x96B6,	0x529B,	0x7483,
	0x54E9,	0x4FE9,	0x8054,	0x83B2,	0x8FDE,	0x9570,	0x5EC9,	0x601C,
	0x6D9F,	0x5E18,	0x655B,	0x8138,	0x94FE,	0x604B,	0x70BC,	0x7EC3,
	0x7CAE,	0x51C9,	0x6881,	0x7CB1,	0x826F,	0x4E24,	0x8F86,	0x91CF,
	0x667E,	0x4EAE,	0x8C05,	0x64A9,	0x804A,	0x50DA,	0x7597,	0x71CE,
	0x5BE5,	0x8FBD,	0x6F66,	0x4E86,	0x6482,	0x9563,	0x5ED6,	0x6599,
	0x5217,	0x88C2,	0x70C8,	0x52A3,	0x730E,	0x7433,	0x6797,	0x78F7,
	0x9716,	0x4E34,	0x90BB,	0x9CDE,	0x6DCB,	0x51DB,	0x8D41,	0x541D,
	0x62CE,	0x73B2,	0x83F1,	0x96F6,	0x9F84,	0x94C3,	0x4F36,	0x7F9A,
	0x51CC,	0x7075,	0x9675,	0x5CAD,	0x9886,	0x53E6,	0x4EE4,	0x6E9C,
	0x7409,	0x69B4,	0x786B,	0x998F,	0x7559,	0x5218,	0x7624,	0x6D41,
	0x67F3,	0x516D,	0x9F99,	0x804B,	0x5499,	0x7B3C,	0x7ABF,
	/* GB 0xC240..0xC27E */
	0x7FE4,	0x7FE7,	0x7FE8,	0x7FEA,	0x7FEB,	0x7FEC,	0x7FED,	0x7FEF,
	0x7FF2,	0x7FF4,	0x7FF5,	0x7FF6,	0x7FF7,	0x7FF8,	0x7FF9,	0x7FFA,
	0x7FFD,	0x7FFE,	0x7FFF,	0x8002,	0x8007,	0x8008,	0x8009,	0x800A,
	0x800E,	0x800F,	0x8011,	0x8013,	0x801A,	0x801B,	0x801D,	0x801E,
	0x801F,	0x8021,	0x8023,	0x8024,	0x802B,	0x802C,	0x802D,	0x802E,
	0x802F,	0x8030,	0x8032,	0x8034,	0x8039,	0x803A,	0x803C,	0x803E,
	0x8040,	0x8041,	0x8044,	0x8045,	0x8047,	0x8048,	0x8049,	0x804E,
	0x804F,	0x8050,	0x8051,	0x8053,	0x8055,	0x8056,	0x8057,
	/* GB 0xC280..0xC2FE */
	0x8059,	0x805B,	0x805C,	0x805D,	0x805E,	0x805F,	0x8060,	0x8061,
	0x8062,	0x8063,	0x8064,	0x8065,	0x8066,	0x8067,	0x8068,	0x806B,
	0x806C,	0x806D,	0x806E,	0x806F,	0x8070,	0x8072,	0x8073,	0x8074,
	0x8075,	0x8076,	0x8077,	0x8078,	0x8079,	0x807A,	0x807B,	0x807C,
	0x807D,	0x9686,	0x5784,	0x62E2,	0x9647,	0x697C,	0x5A04,	0x6402,
	0x7BD3,	0x6F0F,	0x964B,	0x82A6,	0x5362,	0x9885,	0x5E90,	0x7089,
	0x63B3,	0x5364,	0x864F,	0x9C81,	0x9E93,	0x788C,	0x9732,	0x8DEF,
	0x8D42,	0x9E7F,	0x6F5E,	0x7984,	0x5F55,	0x9646,	0x622E,	0x9A74,
	0x5415,	0x94DD,	0x4FA3,	0x65C5,	0x5C65,	0x5C61,	0x7F15,	0x8651,
	0x6C2F,	0x5F8B,	0x7387,	0x6EE4,	0x7EFF,	0x5CE6,	0x631B,	0x5B6A,
	0x6EE6,	0x5375,	0x4E71,	0x63A0,	0x7565,	0x62A1,	0x8F6E,	0x4F26,
	0x4ED1,	0x6CA6,	0x7EB6,	0x8BBA,	0x841D,	0x87BA,	0x7F57,	0x903B,
	0x9523,	0x7BA9,	0x9AA1,	0x88F8,	0x843D,	0x6D1B,	0x9A86,	0x7EDC,
	0x5988,	0x9EBB,	0x739B,	0x7801,	0x8682,	0x9A6C,	0x9A82,	0x561B,
	0x5417,	0x57CB,	0x4E70,	0x9EA6,	0x5356,	0x8FC8,	0x8109,	0x7792,
	0x9992,	0x86EE,	0x6EE1,	0x8513,	0x66FC,	0x6162,	0x6F2B,
	/* GB 0xC340..0xC37E */
	0x807E,	0x8081,	0x8082,	0x8085,	0x8088,	0x808A,	0x808D,	0x808E,
	0x808F,	0x8090,	0x8091,	0x8092,	0x8094,	0x8095,	0x8097,	0x8099,
	0x809E,	0x80A3,	0x80A6,	0x80A7,	0x80A8,	0x80AC,	0x80B0,	0x80B3,
	0x80B5,	0x80B6,	0x80B8,	0x80B9,	0x80BB,	0x80C5,	0x80C7,	0x80C8,
	0x80C9,	0x80CA,	0x80CB,	0x80CF,	0x80D0,	0x80D1,	0x80D2,	0x80D3,
	0x80D4,	0x80D5,	0x80D8,	0x80DF,	0x80E0,	0x80E2,	0x80E3,	0x80E6,
	0x80EE,	0x80F5,	0x80F7,	0x80F9,	0x80FB,	0x80FE,	0x80FF,	0x8100,
	0x8101,	0x8103,	0x8104,	0x8105,	0x8107,	0x8108,	0x810B,
	/* GB 0xC380..0xC3FE */
	0x810C,	0x8115,	0x8117,	0x8119,	0x811B,	0x811C,	0x811D,	0x811F,
	0x8120,	0x8121,	0x8122,	0x8123,	0x8124,	0x8125,	0x8126,	0x8127,
	0x8128,	0x8129,	0x812A,	0x812B,	0x812D,	0x812E,	0x8130,	0x8133,
	0x8134,	0x8135,	0x8137,	0x8139,	0x813A,	0x813B,	0x813C,	0x813D,
	0x813F,	0x8C29,	0x8292,	0x832B,	0x76F2,	0x6C13,	0x5FD9,	0x83BD,
	0x732B,	0x8305,	0x951A,	0x6BDB,	0x77DB,	0x94C6,	0x536F,	0x8302,
	0x5192,	0x5E3D,	0x8C8C,	0x8D38,	0x4E48,	0x73AB,	0x679A,	0x6885,
	0x9176,	0x9709,	0x7164,	0x6CA1,	0x7709,	0x5A92,	0x9541,	0x6BCF,
	0x7F8E,	0x6627,	0x5BD0,	0x59B9,	0x5A9A,	0x95E8,	0x95F7,	0x4EEC,
	0x840C,	0x8499,	0x6AAC,	0x76DF,	0x9530,	0x731B,	0x68A6,	0x5B5F,
	0x772F,	0x919A,	0x9761,	0x7CDC,	0x8FF7,	0x8C1C,	0x5F25,	0x7C73,
	0x79D8,	0x89C5,	0x6CCC,	0x871C,	0x5BC6,	0x5E42,	0x68C9,	0x7720,
	0x7EF5,	0x5195,	0x514D,	0x52C9,	0x5A29,	0x7F05,	0x9762,	0x82D7,
	0x63CF,	0x7784,	0x85D0,	0x79D2,	0x6E3A,	0x5E99,	0x5999,	0x8511,
	0x706D,	0x6C11,	0x62BF,	0x76BF,	0x654F,	0x60AF,	0x95FD,	0x660E,
	0x879F,	0x9E23,	0x94ED,	0x540D,	0x547D,	0x8C2C,	0x6478,
	/* GB 0xC440..0xC47E */
	0x8140,	0x8141,	0x8142,	0x8143,	0x8144,	0x8145,	0x8147,	0x8149,
	0x814D,	0x814E,	0x814F,	0x8152,	0x8156,	0x8157,	0x8158,	0x815B,
	0x815C,	0x815D,	0x815E,	0x815F,	0x8161,	0x8162,	0x8163,	0x8164,
	0x8166,	0x8168,	0x816A,	0x816B,	0x816C,	0x816F,	0x8172,	0x8173,
	0x8175,	0x8176,	0x8177,	0x8178,	0x8181,	0x8183,	0x8184,	0x8185,
	0x8186,	0x8187,	0x8189,	0x818B,	0x818C,	0x818D,	0x818E,	0x8190,
	0x8192,	0x8193,	0x8194,	0x8195,	0x8196,	0x8197,	0x8199,	0x819A,
	0x819E,	0x819F,	0x81A0,	0x81A1,	0x81A2,	0x81A4,	0x81A5,
	/* GB 0xC480..0xC4FE */
	0x81A7,	0x81A9,	0x81AB,	0x81AC,	0x81AD,	0x81AE,	0x81AF,	0x81B0,
	0x81B1,	0x81B2,	0x81B4,	0x81B5,	0x81B6,	0x81B7,	0x81B8,	0x81B9,
	0x81BC,	0x81BD,	0x81BE,	0x81BF,	0x81C4,	0x81C5,	0x81C7,	0x81C8,
	0x81C9,	0x81CB,	0x81CD,	0x81CE,	0x81CF,	0x81D0,	0x81D1,	0x81D2,
	0x81D3,	0x6479,	0x8611,	0x6A21,	0x819C,	0x78E8,	0x6469,	0x9B54,
	0x62B9,	0x672B,	0x83AB,	0x58A8,	0x9ED8,	0x6CAB,	0x6F20,	0x5BDE,
	0x964C,	0x8C0B,	0x725F,	0x67D0,	0x62C7,	0x7261,	0x4EA9,	0x59C6,
	0x6BCD,	0x5893,	0x66AE,	0x5E55,	0x52DF,	0x6155,	0x6728,	0x76EE,
	0x7766,	0x7267,	0x7A46,	0x62FF,	0x54EA,	0x5450,	0x94A0,	0x90A3,
	0x5A1C,	0x7EB3,	0x6C16,	0x4E43,	0x5976,	0x8010,	0x5948,	0x5357,
	0x7537,	0x96BE,	0x56CA,	0x6320,	0x8111,	0x607C,	0x95F9,	0x6DD6,
	0x5462,	0x9981,	0x5185,	0x5AE9,	0x80FD,	0x59AE,	0x9713,	0x502A,
	0x6CE5,	0x5C3C,	0x62DF,	0x4F60,	0x533F,	0x817B,	0x9006,	0x6EBA,
	0x852B,	0x62C8,	0x5E74,	0x78BE,	0x64B5,	0x637B,	0x5FF5,	0x5A18,
	0x917F,	0x9E1F,	0x5C3F,	0x634F,	0x8042,	0x5B7D,	0x556E,	0x954A,
	0x954D,	0x6D85,	0x60A8,	0x67E0,	0x72DE,	0x51DD,	0x5B81,
	/* GB 0xC540..0xC57E */
	0x81D4,	0x81D5,	0x81D6,	0x81D7,	0x81D8,	0x81D9,	0x81DA,	0x81DB,
	0x81DC,	0x81DD,	0x81DE,	0x81DF,	0x81E0,	0x81E1,	0x81E2,	0x81E4,
	0x81E5,	0x81E6,	0x81E8,	0x81E9,	0x81EB,	0x81EE,	0x81EF,	0x81F0,
	0x81F1,	0x81F2,	0x81F5,	0x81F6,	0x81F7,	0x81F8,	0x81F9,	0x81FA,
	0x81FD,	0x81FF,	0x8203,	0x8207,	0x8208,	0x8209,	0x820A,	0x820B,
	0x820E,	0x820F,	0x8211,	0x8213,	0x8215,	0x8216,	0x8217,	0x8218,
	0x8219,	0x821A,	0x821D,	0x8220,	0x8224,	0x8225,	0x8226,	0x8227,
	0x8229,	0x822E,	0x8232,	0x823A,	0x823C,	0x823D,	0x823F,
	/* GB 0xC580..0xC5FE */
	0x8240,	0x8241,	0x8242,	0x8243,	0x8245,	0x8246,	0x8248,	0x824A,
	0x824C,	0x824D,	0x824E,	0x8250,	0x8251,	0x8252,	0x8253,	0x8254,
	0x8255,	0x8256,	0x8257,	0x8259,	0x825B,	0x825C,	0x825D,	0x825E,
	0x8260,	0x8261,	0x8262,	0x8263,	0x8264,	0x8265,	0x8266,	0x8267,
	0x8269,	0x62E7,	0x6CDE,	0x725B,	0x626D,	0x94AE,	0x7EBD,	0x8113,
	0x6D53,	0x519C,	0x5F04,	0x5974,	0x52AA,	0x6012,	0x5973,	0x6696,
	0x8650,	0x759F,	0x632A,	0x61E6,	0x7CEF,	0x8BFA,	0x54E6,	0x6B27,
	0x9E25,	0x6BB4,	0x85D5,	0x5455,	0x5076,	0x6CA4,	0x556A,	0x8DB4,
	0x722C,	0x5E15,	0x6015,	0x7436,	0x62CD,	0x6392,	0x724C,	0x5F98,
	0x6E43,	0x6D3E,	0x6500,	0x6F58,	0x76D8,	0x78D0,	0x76FC,	0x7554,
	0x5224,	0x53DB,	0x4E53,	0x5E9E,	0x65C1,	0x802A,	0x80D6,	0x629B,
	0x5486,	0x5228,	0x70AE,	0x888D,	0x8DD1,	0x6CE1,	0x5478,	0x80DA,
	0x57F9,	0x88F4,	0x8D54,	0x966A,	0x914D,	0x4F69,	0x6C9B,	0x55B7,
	0x76C6,	0x7830,	0x62A8,	0x70F9,	0x6F8E,	0x5F6D,	0x84EC,	0x68DA,
	0x787C,	0x7BF7,	0x81A8,	0x670B,	0x9E4F,	0x6367,	0x78B0,	0x576F,
	0x7812,	0x9739,	0x6279,	0x62AB,	0x5288,	0x7435,	0x6BD7,
	/* GB 0xC640..0xC67E */
	0x826A,	0x826B,	0x826C,	0x826D,	0x8271,	0x8275,	0x8276,	0x8277,
	0x8278,	0x827B,	0x827C,	0x8280,	0x8281,	0x8283,	0x8285,	0x8286,
	0x8287,	0x8289,	0x828C,	0x8290,	0x8293,	0x8294,	0x8295,	0x8296,
	0x829A,	0x829B,	0x829E,	0x82A0,	0x82A2,	0x82A3,	0x82A7,	0x82B2,
	0x82B5,	0x82B6,	0x82BA,	0x82BB,	0x82BC,	0x82BF,	0x82C0,	0x82C2,
	0x82C3,	0x82C5,	0x82C6,	0x82C9,	0x82D0,	0x82D6,	0x82D9,	0x82DA,
	0x82DD,	0x82E2,	0x82E7,	0x82E8,	0x82E9,	0x82EA,	0x82EC,	0x82ED,
	0x82EE,	0x82F0,	0x82F2,	0x82F3,	0x82F5,	0x82F6,	0x82F8,
	/* GB 0xC680..0xC6FE */
	0x82FA,	0x82FC,	0x82FD,	0x82FE,	0x82FF,	0x8300,	0x830A,	0x830B,
	0x830D,	0x8310,	0x8312,	0x8313,	0x8316,	0x8318,	0x8319,	0x831D,
	0x831E,	0x831F,	0x8320,	0x8321,	0x8322,	0x8323,	0x8324,	0x8325,
	0x8326,	0x8329,	0x832A,	0x832E,	0x8330,	0x8332,	0x8337,	0x833B,
	0x833D,	0x5564,	0x813E,	0x75B2,	0x76AE,	0x5339,	0x75DE,	0x50FB,
	0x5C41,	0x8B6C,	0x7BC7,	0x504F,	0x7247,	0x9A97,	0x98D8,	0x6F02,
	0x74E2,	0x7968,	0x6487,	0x77A5,	0x62FC,	0x9891,	0x8D2B,	0x54C1,
	0x8058,	0x4E52,	0x576A,	0x82F9,	0x840D,	0x5E73,	0x51ED,	0x74F6,
	0x8BC4,	0x5C4F,	0x5761,	0x6CFC,	0x9887,	0x5A46,	0x7834,	0x9B44,
	0x8FEB,	0x7C95,	0x5256,	0x6251,	0x94FA,	0x4EC6,	0x8386,	0x8461,
	0x83E9,	0x84B2,	0x57D4,	0x6734,	0x5703,	0x666E,	0x6D66,	0x8C31,
	0x66DD,	0x7011,	0x671F,	0x6B3A,	0x6816,	0x621A,	0x59BB,	0x4E03,
	0x51C4,	0x6F06,	0x67D2,	0x6C8F,	0x5176,	0x68CB,	0x5947,	0x6B67,
	0x7566,	0x5D0E,	0x8110,	0x9F50,	0x65D7,	0x7948,	0x7941,	0x9A91,
	0x8D77,	0x5C82,	0x4E5E,	0x4F01,	0x542F,	0x5951,	0x780C,	0x5668,
	0x6C14,	0x8FC4,	0x5F03,	0x6C7D,	0x6CE3,	0x8BAB,	0x6390,
	/* GB 0xC740..0xC77E */
	0x833E,	0x833F,	0x8341,	0x8342,	0x8344,	0x8345,	0x8348,	0x834A,
	0x834B,	0x834C,	0x834D,	0x834E,	0x8353,	0x8355,	0x8356,	0x8357,
	0x8358,	0x8359,	0x835D,	0x8362,	0x8370,	0x8371,	0x8372,	0x8373,
	0x8374,	0x8375,	0x8376,	0x8379,	0x837A,	0x837E,	0x837F,	0x8380,
	0x8381,	0x8382,	0x8383,	0x8384,	0x8387,	0x8388,	0x838A,	0x838B,
	0x838C,	0x838D,	0x838F,	0x8390,	0x8391,	0x8394,	0x8395,	0x8396,
	0x8397,	0x8399,	0x839A,	0x839D,	0x839F,	0x83A1,	0x83A2,	0x83A3,
	0x83A4,	0x83A5,	0x83A6,	0x83A7,	0x83AC,	0x83AD,	0x83AE,
	/* GB 0xC780..0xC7FE */
	0x83AF,	0x83B5,	0x83BB,	0x83BE,	0x83BF,	0x83C2,	0x83C3,	0x83C4,
	0x83C6,	0x83C8,	0x83C9,	0x83CB,	0x83CD,	0x83CE,	0x83D0,	0x83D1,
	0x83D2,	0x83D3,	0x83D5,	0x83D7,	0x83D9,	0x83DA,	0x83DB,	0x83DE,
	0x83E2,	0x83E3,	0x83E4,	0x83E6,	0x83E7,	0x83E8,	0x83EB,	0x83EC,
	0x83ED,	0x6070,	0x6D3D,	0x7275,	0x6266,	0x948E,	0x94C5,	0x5343,
	0x8FC1,	0x7B7E,	0x4EDF,	0x8C26,	0x4E7E,	0x9ED4,	0x94B1,	0x94B3,
	0x524D,	0x6F5C,	0x9063,	0x6D45,	0x8C34,	0x5811,	0x5D4C,	0x6B20,
	0x6B49,	0x67AA,	0x545B,	0x8154,	0x7F8C,	0x5899,	0x8537,	0x5F3A,
	0x62A2,	0x6A47,	0x9539,	0x6572,	0x6084,	0x6865,	0x77A7,	0x4E54,
	0x4FA8,	0x5DE7,	0x9798,	0x64AC,	0x7FD8,	0x5CED,	0x4FCF,	0x7A8D,
	0x5207,	0x8304,	0x4E14,	0x602F,	0x7A83,	0x94A6,	0x4FB5,	0x4EB2,
	0x79E6,	0x7434,	0x52E4,	0x82B9,	0x64D2,	0x79BD,	0x5BDD,	0x6C81,
	0x9752,	0x8F7B,	0x6C22,	0x503E,	0x537F,	0x6E05,	0x64CE,	0x6674,
	0x6C30,	0x60C5,	0x9877,	0x8BF7,	0x5E86,	0x743C,	0x7A77,	0x79CB,
	0x4E18,	0x90B1,	0x7403,	0x6C42,	0x56DA,	0x914B,	0x6CC5,	0x8D8B,
	0x533A,	0x86C6,	0x66F2,	0x8EAF,	0x5C48,	0x9A71,	0x6E20,
	/* GB 0xC840..0xC87E */
	0x83EE,	0x83EF,	0x83F3,	0x83F4,	0x83F5,	0x83F6,	0x83F7,	0x83FA,
	0x83FB,	0x83FC,	0x83FE,	0x83FF,	0x8400,	0x8402,	0x8405,	0x8407,
	0x8408,	0x8409,	0x840A,	0x8410,	0x8412,	0x8413,	0x8414,	0x8415,
	0x8416,	0x8417,	0x8419,	0x841A,	0x841B,	0x841E,	0x841F,	0x8420,
	0x8421,	0x8422,	0x8423,	0x8429,	0x842A,	0x842B,	0x842C,	0x842D,
	0x842E,	0x842F,	0x8430,	0x8432,	0x8433,	0x8434,	0x8435,	0x8436,
	0x8437,	0x8439,	0x843A,	0x843B,	0x843E,	0x843F,	0x8440,	0x8441,
	0x8442,	0x8443,	0x8444,	0x8445,	0x8447,	0x8448,	0x8449,
	/* GB 0xC880..0xC8FE */
	0x844A,	0x844B,	0x844C,	0x844D,	0x844E,	0x844F,	0x8450,	0x8452,
	0x8453,	0x8454,	0x8455,	0x8456,	0x8458,	0x845D,	0x845E,	0x845F,
	0x8460,	0x8462,	0x8464,	0x8465,	0x8466,	0x8467,	0x8468,	0x846A,
	0x846E,	0x846F,	0x8470,	0x8472,	0x8474,	0x8477,	0x8479,	0x847B,
	0x847C,	0x53D6,	0x5A36,	0x9F8B,	0x8DA3,	0x53BB,	0x5708,	0x98A7,
	0x6743,	0x919B,	0x6CC9,	0x5168,	0x75CA,	0x62F3,	0x72AC,	0x5238,
	0x529D,	0x7F3A,	0x7094,	0x7638,	0x5374,	0x9E4A,	0x69B7,	0x786E,
	0x96C0,	0x88D9,	0x7FA4,	0x7136,	0x71C3,	0x5189,	0x67D3,	0x74E4,
	0x58E4,	0x6518,	0x56B7,	0x8BA9,	0x9976,	0x6270,	0x7ED5,	0x60F9,
	0x70ED,	0x58EC,	0x4EC1,	0x4EBA,	0x5FCD,	0x97E7,	0x4EFB,	0x8BA4,
	0x5203,	0x598A,	0x7EAB,	0x6254,	0x4ECD,	0x65E5,	0x620E,	0x8338,
	0x84C9,	0x8363,	0x878D,	0x7194,	0x6EB6,	0x5BB9,	0x7ED2,	0x5197,
	0x63C9,	0x67D4,	0x8089,	0x8339,	0x8815,	0x5112,	0x5B7A,	0x5982,
	0x8FB1,	0x4E73,	0x6C5D,	0x5165,	0x8925,	0x8F6F,	0x962E,	0x854A,
	0x745E,	0x9510,	0x95F0,	0x6DA6,	0x82E5,	0x5F31,	0x6492,	0x6D12,
	0x8428,	0x816E,	0x9CC3,	0x585E,	0x8D5B,	0x4E09,	0x53C1,
	/* GB 0xC940..0xC97E */
	0x847D,	0x847E,	0x847F,	0x8480,	0x8481,	0x8483,	0x8484,	0x8485,
	0x8486,	0x848A,	0x848D,	0x848F,	0x8490,	0x8491,	0x8492,	0x8493,
	0x8494,	0x8495,	0x8496,	0x8498,	0x849A,	0x849B,	0x849D,	0x849E,
	0x849F,	0x84A0,	0x84A2,	0x84A3,	0x84A4,	0x84A5,	0x84A6,	0x84A7,
	0x84A8,	0x84A9,	0x84AA,	0x84AB,	0x84AC,	0x84AD,	0x84AE,	0x84B0,
	0x84B1,	0x84B3,	0x84B5,	0x84B6,	0x84B7,	0x84BB,	0x84BC,	0x84BE,
	0x84C0,	0x84C2,	0x84C3,	0x84C5,	0x84C6,	0x84C7,	0x84C8,	0x84CB,
	0x84CC,	0x84CE,	0x84CF,	0x84D2,	0x84D4,	0x84D5,	0x84D7,
	/* GB 0xC980..0xC9FE */
	0x84D8,	0x84D9,	0x84DA,	0x84DB,	0x84DC,	0x84DE,	0x84E1,	0x84E2,
	0x84E4,	0x84E7,	0x84E8,	0x84E9,	0x84EA,	0x84EB,	0x84ED,	0x84EE,
	0x84EF,	0x84F1,	0x84F2,	0x84F3,	0x84F4,	0x84F5,	0x84F6,	0x84F7,
	0x84F8,	0x84F9,	0x84FA,	0x84FB,	0x84FD,	0x84FE,	0x8500,	0x8501,
	0x8502,	0x4F1E,	0x6563,	0x6851,	0x55D3,	0x4E27,	0x6414,	0x9A9A,
	0x626B,	0x5AC2,	0x745F,	0x8272,	0x6DA9,	0x68EE,	0x50E7,	0x838E,
	0x7802,	0x6740,	0x5239,	0x6C99,	0x7EB1,	0x50BB,	0x5565,	0x715E,
	0x7B5B,	0x6652,	0x73CA,	0x82EB,	0x6749,	0x5C71,	0x5220,	0x717D,
	0x886B,	0x95EA,	0x9655,	0x64C5,	0x8D61,	0x81B3,	0x5584,	0x6C55,
	0x6247,	0x7F2E,	0x5892,	0x4F24,	0x5546,	0x8D4F,	0x664C,	0x4E0A,
	0x5C1A,	0x88F3,	0x68A2,	0x634E,	0x7A0D,	0x70E7,	0x828D,	0x52FA,
	0x97F6,	0x5C11,	0x54E8,	0x90B5,	0x7ECD,	0x5962,	0x8D4A,	0x86C7,
	0x820C,	0x820D,	0x8D66,	0x6444,	0x5C04,	0x6151,	0x6D89,	0x793E,
	0x8BBE,	0x7837,	0x7533,	0x547B,	0x4F38,	0x8EAB,	0x6DF1,	0x5A20,
	0x7EC5,	0x795E,	0x6C88,	0x5BA1,	0x5A76,	0x751A,	0x80BE,	0x614E,
	0x6E17,	0x58F0,	0x751F,	0x7525,	0x7272,	0x5347,	0x7EF3,
	/* GB 0xCA40..0xCA7E */
	0x8503,	0x8504,	0x8505,	0x8506,	0x8507,	0x8508,	0x8509,	0x850A,
	0x850B,	0x850D,	0x850E,	0x850F,	0x8510,	0x8512,	0x8514,	0x8515,
	0x8516,	0x8518,	0x8519,	0x851B,	0x851C,	0x851D,	0x851E,	0x8520,
	0x8522,	0x8523,	0x8524,	0x8525,	0x8526,	0x8527,	0x8528,	0x8529,
	0x852A,	0x852D,	0x852E,	0x852F,	0x8530,	0x8531,	0x8532,	0x8533,
	0x8534,	0x8535,	0x8536,	0x853E,	0x853F,	0x8540,	0x8541,	0x8542,
	0x8544,	0x8545,	0x8546,	0x8547,	0x854B,	0x854C,	0x854D,	0x854E,
	0x854F,	0x8550,	0x8551,	0x8552,	0x8553,	0x8554,	0x8555,
	/* GB 0xCA80..0xCAFE */
	0x8557,	0x8558,	0x855A,	0x855B,	0x855C,	0x855D,	0x855F,	0x8560,
	0x8561,	0x8562,	0x8563,	0x8565,	0x8566,	0x8567,	0x8569,	0x856A,
	0x856B,	0x856C,	0x856D,	0x856E,	0x856F,	0x8570,	0x8571,	0x8573,
	0x8575,	0x8576,	0x8577,	0x8578,	0x857C,	0x857D,	0x857F,	0x8580,
	0x8581,	0x7701,	0x76DB,	0x5269,	0x80DC,	0x5723,	0x5E08,	0x5931,
	0x72EE,	0x65BD,	0x6E7F,	0x8BD7,	0x5C38,	0x8671,	0x5341,	0x77F3,
	0x62FE,	0x65F6,	0x4EC0,	0x98DF,	0x8680,	0x5B9E,	0x8BC6,	0x53F2,
	0x77E2,	0x4F7F,	0x5C4E,	0x9A76,	0x59CB,	0x5F0F,	0x793A,	0x58EB,
	0x4E16,	0x67FF,	0x4E8B,	0x62ED,	0x8A93,	0x901D,	0x52BF,	0x662F,
	0x55DC,	0x566C,	0x9002,	0x4ED5,	0x4F8D,	0x91CA,	0x9970,	0x6C0F,
	0x5E02,	0x6043,	0x5BA4,	0x89C6,	0x8BD5,	0x6536,	0x624B,	0x9996,
	0x5B88,	0x5BFF,	0x6388,	0x552E,	0x53D7,	0x7626,	0x517D,	0x852C,
	0x67A2,	0x68B3,	0x6B8A,	0x6292,	0x8F93,	0x53D4,	0x8212,	0x6DD1,
	0x758F,	0x4E66,	0x8D4E,	0x5B70,	0x719F,	0x85AF,	0x6691,	0x66D9,
	0x7F72,	0x8700,	0x9ECD,	0x9F20,	0x5C5E,	0x672F,	0x8FF0,	0x6811,
	0x675F,	0x620D,	0x7AD6,	0x5885,	0x5EB6,	0x6570,	0x6F31,
	/* GB 0xCB40..0xCB7E */
	0x8582,	0x8583,	0x8586,	0x8588,	0x8589,	0x858A,	0x858B,	0x858C,
	0x858D,	0x858E,	0x8590,	0x8591,	0x8592,	0x8593,	0x8594,	0x8595,
	0x8596,	0x8597,	0x8598,	0x8599,	0x859A,	0x859D,	0x859E,	0x859F,
	0x85A0,	0x85A1,	0x85A2,	0x85A3,	0x85A5,	0x85A6,	0x85A7,	0x85A9,
	0x85AB,	0x85AC,	0x85AD,	0x85B1,	0x85B2,	0x85B3,	0x85B4,	0x85B5,
	0x85B6,	0x85B8,	0x85BA,	0x85BB,	0x85BC,	0x85BD,	0x85BE,	0x85BF,
	0x85C0,	0x85C2,	0x85C3,	0x85C4,	0x85C5,	0x85C6,	0x85C7,	0x85C8,
	0x85CA,	0x85CB,	0x85CC,	0x85CD,	0x85CE,	0x85D1,	0x85D2,
	/* GB 0xCB80..0xCBFE */
	0x85D4,	0x85D6,	0x85D7,	0x85D8,	0x85D9,	0x85DA,	0x85DB,	0x85DD,
	0x85DE,	0x85DF,	0x85E0,	0x85E1,	0x85E2,	0x85E3,	0x85E5,	0x85E6,
	0x85E7,	0x85E8,	0x85EA,	0x85EB,	0x85EC,	0x85ED,	0x85EE,	0x85EF,
	0x85F0,	0x85F1,	0x85F2,	0x85F3,	0x85F4,	0x85F5,	0x85F6,	0x85F7,
	0x85F8,	0x6055,	0x5237,	0x800D,	0x6454,	0x8870,	0x7529,	0x5E05,
	0x6813,	0x62F4,	0x971C,	0x53CC,	0x723D,	0x8C01,	0x6C34,	0x7761,
	0x7A0E,	0x542E,	0x77AC,	0x987A,	0x821C,	0x8BF4,	0x7855,	0x6714,
	0x70C1,	0x65AF,	0x6495,	0x5636,	0x601D,	0x79C1,	0x53F8,	0x4E1D,
	0x6B7B,	0x8086,	0x5BFA,	0x55E3,	0x56DB,	0x4F3A,	0x4F3C,	0x9972,
	0x5DF3,	0x677E,	0x8038,	0x6002,	0x9882,	0x9001,	0x5B8B,	0x8BBC,
	0x8BF5,	0x641C,	0x8258,	0x64DE,	0x55FD,	0x82CF,	0x9165,	0x4FD7,
	0x7D20,	0x901F,	0x7C9F,	0x50F3,	0x5851,	0x6EAF,	0x5BBF,	0x8BC9,
	0x8083,	0x9178,	0x849C,	0x7B97,	0x867D,	0x968B,	0x968F,	0x7EE5,
	0x9AD3,	0x788E,	0x5C81,	0x7A57,	0x9042,	0x96A7,	0x795F,	0x5B59,
	0x635F,	0x7B0B,	0x84D1,	0x68AD,	0x5506,	0x7F29,	0x7410,	0x7D22,
	0x9501,	0x6240,	0x584C,	0x4ED6,	0x5B83,	0x5979,	0x5854,
	/* GB 0xCC40..0xCC7E */
	0x85F9,	0x85FA,	0x85FC,	0x85FD,	0x85FE,	0x8600,	0x8601,	0x8602,
	0x8603,	0x8604,	0x8606,	0x8607,	0x8608,	0x8609,	0x860A,	0x860B,
	0x860C,	0x860D,	0x860E,	0x860F,	0x8610,	0x8612,	0x8613,	0x8614,
	0x8615,	0x8617,	0x8618,	0x8619,	0x861A,	0x861B,	0x861C,	0x861D,
	0x861E,	0x861F,	0x8620,	0x8621,	0x8622,	0x8623,	0x8624,	0x8625,
	0x8626,	0x8628,	0x862A,	0x862B,	0x862C,	0x862D,	0x862E,	0x862F,
	0x8630,	0x8631,	0x8632,	0x8633,	0x8634,	0x8635,	0x8636,	0x8637,
	0x8639,	0x863A,	0x863B,	0x863D,	0x863E,	0x863F,	0x8640,
	/* GB 0xCC80..0xCCFE */
	0x8641,	0x8642,	0x8643,	0x8644,	0x8645,	0x8646,	0x8647,	0x8648,
	0x8649,	0x864A,	0x864B,	0x864C,	0x8652,	0x8653,	0x8655,	0x8656,
	0x8657,	0x8658,	0x8659,	0x865B,	0x865C,	0x865D,	0x865F,	0x8660,
	0x8661,	0x8663,	0x8664,	0x8665,	0x8666,	0x8667,	0x8668,	0x8669,
	0x866A,	0x736D,	0x631E,	0x8E4B,	0x8E0F,	0x80CE,	0x82D4,	0x62AC,
	0x53F0,	0x6CF0,	0x915E,	0x592A,	0x6001,	0x6C70,	0x574D,	0x644A,
	0x8D2A,	0x762B,	0x6EE9,	0x575B,	0x6A80,	0x75F0,	0x6F6D,	0x8C2D,
	0x8C08,	0x5766,	0x6BEF,	0x8892,	0x78B3,	0x63A2,	0x53F9,	0x70AD,
	0x6C64,	0x5858,	0x642A,	0x5802,	0x68E0,	0x819B,	0x5510,	0x7CD6,
	0x5018,	0x8EBA,	0x6DCC,	0x8D9F,	0x70EB,	0x638F,	0x6D9B,	0x6ED4,
	0x7EE6,	0x8404,	0x6843,	0x9003,	0x6DD8,	0x9676,	0x8BA8,	0x5957,
	0x7279,	0x85E4,	0x817E,	0x75BC,	0x8A8A,	0x68AF,	0x5254,	0x8E22,
	0x9511,	0x63D0,	0x9898,	0x8E44,	0x557C,	0x4F53,	0x66FF,	0x568F,
	0x60D5,	0x6D95,	0x5243,	0x5C49,	0x5929,	0x6DFB,	0x586B,	0x7530,
	0x751C,	0x606C,	0x8214,	0x8146,	0x6311,	0x6761,	0x8FE2,	0x773A,
	0x8DF3,	0x8D34,	0x94C1,	0x5E16,	0x5385,	0x542C,	0x70C3,
	/* GB 0xCD40..0xCD7E */
	0x866D,	0x866F,	0x8670,	0x8672,	0x8673,	0x8674,	0x8675,	0x8676,
	0x8677,	0x8678,	0x8683,	0x8684,	0x8685,	0x8686,	0x8687,	0x8688,
	0x8689,	0x868E,	0x868F,	0x8690,	0x8691,	0x8692,	0x8694,	0x8696,
	0x8697,	0x8698,	0x8699,	0x869A,	0x869B,	0x869E,	0x869F,	0x86A0,
	0x86A1,	0x86A2,	0x86A5,	0x86A6,	0x86AB,	0x86AD,	0x86AE,	0x86B2,
	0x86B3,	0x86B7,	0x86B8,	0x86B9,	0x86BB,	0x86BC,	0x86BD,	0x86BE,
	0x86BF,	0x86C1,	0x86C2,	0x86C3,	0x86C5,	0x86C8,	0x86CC,	0x86CD,
	0x86D2,	0x86D3,	0x86D5,	0x86D6,	0x86D7,	0x86DA,	0x86DC,
	/* GB 0xCD80..0xCDFE */
	0x86DD,	0x86E0,	0x86E1,	0x86E2,	0x86E3,	0x86E5,	0x86E6,	0x86E7,
	0x86E8,	0x86EA,	0x86EB,	0x86EC,	0x86EF,	0x86F5,	0x86F6,	0x86F7,
	0x86FA,	0x86FB,	0x86FC,	0x86FD,	0x86FF,	0x8701,	0x8704,	0x8705,
	0x8706,	0x870B,	0x870C,	0x870E,	0x870F,	0x8710,	0x8711,	0x8714,
	0x8716,	0x6C40,	0x5EF7,	0x505C,	0x4EAD,	0x5EAD,	0x633A,	0x8247,
	0x901A,	0x6850,	0x916E,	0x77B3,	0x540C,	0x94DC,	0x5F64,	0x7AE5,
	0x6876,	0x6345,	0x7B52,	0x7EDF,	0x75DB,	0x5077,	0x6295,	0x5934,
	0x900F,	0x51F8,	0x79C3,	0x7A81,	0x56FE,	0x5F92,	0x9014,	0x6D82,
	0x5C60,	0x571F,	0x5410,	0x5154,	0x6E4D,	0x56E2,	0x63A8,	0x9893,
	0x817F,	0x8715,	0x892A,	0x9000,	0x541E,	0x5C6F,	0x81C0,	0x62D6,
	0x6258,	0x8131,	0x9E35,	0x9640,	0x9A6E,	0x9A7C,	0x692D,	0x59A5,
	0x62D3,	0x553E,	0x6316,	0x54C7,	0x86D9,	0x6D3C,	0x5A03,	0x74E6,
	0x889C,	0x6B6A,	0x5916,	0x8C4C,	0x5F2F,	0x6E7E,	0x73A9,	0x987D,
	0x4E38,	0x70F7,	0x5B8C,	0x7897,	0x633D,	0x665A,	0x7696,	0x60CB,
	0x5B9B,	0x5A49,	0x4E07,	0x8155,	0x6C6A,	0x738B,	0x4EA1,	0x6789,
	0x7F51,	0x5F80,	0x65FA,	0x671B,	0x5FD8,	0x5984,	0x5A01,
	/* GB 0xCE40..0xCE7E */
	0x8719,	0x871B,	0x871D,	0x871F,	0x8720,	0x8724,	0x8726,	0x8727,
	0x8728,	0x872A,	0x872B,	0x872C,	0x872D,	0x872F,	0x8730,	0x8732,
	0x8733,	0x8735,	0x8736,	0x8738,	0x8739,	0x873A,	0x873C,	0x873D,
	0x8740,	0x8741,	0x8742,	0x8743,	0x8744,	0x8745,	0x8746,	0x874A,
	0x874B,	0x874D,	0x874F,	0x8750,	0x8751,	0x8752,	0x8754,	0x8755,
	0x8756,	0x8758,	0x875A,	0x875B,	0x875C,	0x875D,	0x875E,	0x875F,
	0x8761,	0x8762,	0x8766,	0x8767,	0x8768,	0x8769,	0x876A,	0x876B,
	0x876C,	0x876D,	0x876F,	0x8771,	0x8772,	0x8773,	0x8775,
	/* GB 0xCE80..0xCEFE */
	0x8777,	0x8778,	0x8779,	0x877A,	0x877F,	0x8780,	0x8781,	0x8784,
	0x8786,	0x8787,	0x8789,	0x878A,	0x878C,	0x878E,	0x878F,	0x8790,
	0x8791,	0x8792,	0x8794,	0x8795,	0x8796,	0x8798,	0x8799,	0x879A,
	0x879B,	0x879C,	0x879D,	0x879E,	0x87A0,	0x87A1,	0x87A2,	0x87A3,
	0x87A4,	0x5DCD,	0x5FAE,	0x5371,	0x97E6,	0x8FDD,	0x6845,	0x56F4,
	0x552F,	0x60DF,	0x4E3A,	0x6F4D,	0x7EF4,	0x82C7,	0x840E,	0x59D4,
	0x4F1F,	0x4F2A,	0x5C3E,	0x7EAC,	0x672A,	0x851A,	0x5473,	0x754F,
	0x80C3,	0x5582,	0x9B4F,	0x4F4D,	0x6E2D,	0x8C13,	0x5C09,	0x6170,
	0x536B,	0x761F,	0x6E29,	0x868A,	0x6587,	0x95FB,	0x7EB9,	0x543B,
	0x7A33,	0x7D0A,	0x95EE,	0x55E1,	0x7FC1,	0x74EE,	0x631D,	0x8717,
	0x6DA1,	0x7A9D,	0x6211,	0x65A1,	0x5367,	0x63E1,	0x6C83,	0x5DEB,
	0x545C,	0x94A8,	0x4E4C,	0x6C61,	0x8BEC,	0x5C4B,	0x65E0,	0x829C,
	0x68A7,	0x543E,	0x5434,	0x6BCB,	0x6B66,	0x4E94,	0x6342,	0x5348,
	0x821E,	0x4F0D,	0x4FAE,	0x575E,	0x620A,	0x96FE,	0x6664,	0x7269,
	0x52FF,	0x52A1,	0x609F,	0x8BEF,	0x6614,	0x7199,	0x6790,	0x897F,
	0x7852,	0x77FD,	0x6670,	0x563B,	0x5438,	0x9521,	0x727A,
	/* GB 0xCF40..0xCF7E */
	0x87A5,	0x87A6,	0x87A7,	0x87A9,	0x87AA,	0x87AE,	0x87B0,	0x87B1,
	0x87B2,	0x87B4,	0x87B6,	0x87B7,	0x87B8,	0x87B9,	0x87BB,	0x87BC,
	0x87BE,	0x87BF,	0x87C1,	0x87C2,	0x87C3,	0x87C4,	0x87C5,	0x87C7,
	0x87C8,	0x87C9,	0x87CC,	0x87CD,	0x87CE,	0x87CF,	0x87D0,	0x87D4,
	0x87D5,	0x87D6,	0x87D7,	0x87D8,	0x87D9,	0x87DA,	0x87DC,	0x87DD,
	0x87DE,	0x87DF,	0x87E1,	0x87E2,	0x87E3,	0x87E4,	0x87E6,	0x87E7,
	0x87E8,	0x87E9,	0x87EB,	0x87EC,	0x87ED,	0x87EF,	0x87F0,	0x87F1,
	0x87F2,	0x87F3,	0x87F4,	0x87F5,	0x87F6,	0x87F7,	0x87F8,
	/* GB 0xCF80..0xCFFE */
	0x87FA,	0x87FB,	0x87FC,	0x87FD,	0x87FF,	0x8800,	0x8801,	0x8802,
	0x8804,	0x8805,	0x8806,	0x8807,	0x8808,	0x8809,	0x880B,	0x880C,
	0x880D,	0x880E,	0x880F,	0x8810,	0x8811,	0x8812,	0x8814,	0x8817,
	0x8818,	0x8819,	0x881A,	0x881C,	0x881D,	0x881E,	0x881F,	0x8820,
	0x8823,	0x7A00,	0x606F,	0x5E0C,	0x6089,	0x819D,	0x5915,	0x60DC,
	0x7184,	0x70EF,	0x6EAA,	0x6C50,	0x7280,	0x6A84,	0x88AD,	0x5E2D,
	0x4E60,	0x5AB3,	0x559C,	0x94E3,	0x6D17,	0x7CFB,	0x9699,	0x620F,
	0x7EC6,	0x778E,	0x867E,	0x5323,	0x971E,	0x8F96,	0x6687,	0x5CE1,
	0x4FA0,	0x72ED,	0x4E0B,	0x53A6,	0x590F,	0x5413,	0x6380,	0x9528,
	0x5148,	0x4ED9,	0x9C9C,	0x7EA4,	0x54B8,	0x8D24,	0x8854,	0x8237,
	0x95F2,	0x6D8E,	0x5F26,	0x5ACC,	0x663E,	0x9669,	0x73B0,	0x732E,
	0x53BF,	0x817A,	0x9985,	0x7FA1,	0x5BAA,	0x9677,	0x9650,	0x7EBF,
	0x76F8,	0x53A2,	0x9576,	0x9999,	0x7BB1,	0x8944,	0x6E58,	0x4E61,
	0x7FD4,	0x7965,	0x8BE6,	0x60F3,	0x54CD,	0x4EAB,	0x9879,	0x5DF7,
	0x6A61,	0x50CF,	0x5411,	0x8C61,	0x8427,	0x785D,	0x9704,	0x524A,
	0x54EE,	0x56A3,	0x9500,	0x6D88,	0x5BB5,	0x6DC6,	0x6653,
	/* GB 0xD040..0xD07E */
	0x8824,	0x8825,	0x8826,	0x8827,	0x8828,	0x8829,	0x882A,	0x882B,
	0x882C,	0x882D,	0x882E,	0x882F,	0x8830,	0x8831,	0x8833,	0x8834,
	0x8835,	0x8836,	0x8837,	0x8838,	0x883A,	0x883B,	0x883D,	0x883E,
	0x883F,	0x8841,	0x8842,	0x8843,	0x8846,	0x8847,	0x8848,	0x8849,
	0x884A,	0x884B,	0x884E,	0x884F,	0x8850,	0x8851,	0x8852,	0x8853,
	0x8855,	0x8856,	0x8858,	0x885A,	0x885B,	0x885C,	0x885D,	0x885E,
	0x885F,	0x8860,	0x8866,	0x8867,	0x886A,	0x886D,	0x886F,	0x8871,
	0x8873,	0x8874,	0x8875,	0x8876,	0x8878,	0x8879,	0x887A,
	/* GB 0xD080..0xD0FE */
	0x887B,	0x887C,	0x8880,	0x8883,	0x8886,	0x8887,	0x8889,	0x888A,
	0x888C,	0x888E,	0x888F,	0x8890,	0x8891,	0x8893,	0x8894,	0x8895,
	0x8897,	0x8898,	0x8899,	0x889A,	0x889B,	0x889D,	0x889E,	0x889F,
	0x88A0,	0x88A1,	0x88A3,	0x88A5,	0x88A6,	0x88A7,	0x88A8,	0x88A9,
	0x88AA,	0x5C0F,	0x5B5D,	0x6821,	0x8096,	0x5578,	0x7B11,	0x6548,
	0x6954,	0x4E9B,	0x6B47,	0x874E,	0x978B,	0x534F,	0x631F,	0x643A,
	0x90AA,	0x659C,	0x80C1,	0x8C10,	0x5199,	0x68B0,	0x5378,	0x87F9,
	0x61C8,	0x6CC4,	0x6CFB,	0x8C22,	0x5C51,	0x85AA,	0x82AF,	0x950C,
	0x6B23,	0x8F9B,	0x65B0,	0x5FFB,	0x5FC3,	0x4FE1,	0x8845,	0x661F,
	0x8165,	0x7329,	0x60FA,	0x5174,	0x5211,	0x578B,	0x5F62,	0x90A2,
	0x884C,	0x9192,	0x5E78,	0x674F,	0x6027,	0x59D3,	0x5144,	0x51F6,
	0x80F8,	0x5308,	0x6C79,	0x96C4,	0x718A,	0x4F11,	0x4FEE,	0x7F9E,
	0x673D,	0x55C5,	0x9508,	0x79C0,	0x8896,	0x7EE3,	0x589F,	0x620C,
	0x9700,	0x865A,	0x5618,	0x987B,	0x5F90,	0x8BB8,	0x84C4,	0x9157,
	0x53D9,	0x65ED,	0x5E8F,	0x755C,	0x6064,	0x7D6E,	0x5A7F,	0x7EEA,
	0x7EED,	0x8F69,	0x55A7,	0x5BA3,	0x60AC,	0x65CB,	0x7384,
	/* GB 0xD140..0xD17E */
	0x88AC,	0x88AE,	0x88AF,	0x88B0,	0x88B2,	0x88B3,	0x88B4,	0x88B5,
	0x88B6,	0x88B8,	0x88B9,	0x88BA,	0x88BB,	0x88BD,	0x88BE,	0x88BF,
	0x88C0,	0x88C3,	0x88C4,	0x88C7,	0x88C8,	0x88CA,	0x88CB,	0x88CC,
	0x88CD,	0x88CF,	0x88D0,	0x88D1,	0x88D3,	0x88D6,	0x88D7,	0x88DA,
	0x88DB,	0x88DC,	0x88DD,	0x88DE,	0x88E0,	0x88E1,	0x88E6,	0x88E7,
	0x88E9,	0x88EA,	0x88EB,	0x88EC,	0x88ED,	0x88EE,	0x88EF,	0x88F2,
	0x88F5,	0x88F6,	0x88F7,	0x88FA,	0x88FB,	0x88FD,	0x88FF,	0x8900,
	0x8901,	0x8903,	0x8904,	0x8905,	0x8906,	0x8907,	0x8908,
	/* GB 0xD180..0xD1FE */
	0x8909,	0x890B,	0x890C,	0x890D,	0x890E,	0x890F,	0x8911,	0x8914,
	0x8915,	0x8916,	0x8917,	0x8918,	0x891C,	0x891D,	0x891E,	0x891F,
	0x8920,	0x8922,	0x8923,	0x8924,	0x8926,	0x8927,	0x8928,	0x8929,
	0x892C,	0x892D,	0x892E,	0x892F,	0x8931,	0x8932,	0x8933,	0x8935,
	0x8937,	0x9009,	0x7663,	0x7729,	0x7EDA,	0x9774,	0x859B,	0x5B66,
	0x7A74,	0x96EA,	0x8840,	0x52CB,	0x718F,	0x5FAA,	0x65EC,	0x8BE2,
	0x5BFB,	0x9A6F,	0x5DE1,	0x6B89,	0x6C5B,	0x8BAD,	0x8BAF,	0x900A,
	0x8FC5,	0x538B,	0x62BC,	0x9E26,	0x9E2D,	0x5440,	0x4E2B,	0x82BD,
	0x7259,	0x869C,	0x5D16,	0x8859,	0x6DAF,	0x96C5,	0x54D1,	0x4E9A,
	0x8BB6,	0x7109,	0x54BD,	0x9609,	0x70DF,	0x6DF9,	0x76D0,	0x4E25,
	0x7814,	0x8712,	0x5CA9,	0x5EF6,	0x8A00,	0x989C,	0x960E,	0x708E,
	0x6CBF,	0x5944,	0x63A9,	0x773C,	0x884D,	0x6F14,	0x8273,	0x5830,
	0x71D5,	0x538C,	0x781A,	0x96C1,	0x5501,	0x5F66,	0x7130,	0x5BB4,
	0x8C1A,	0x9A8C,	0x6B83,	0x592E,	0x9E2F,	0x79E7,	0x6768,	0x626C,
	0x4F6F,	0x75A1,	0x7F8A,	0x6D0B,	0x9633,	0x6C27,	0x4EF0,	0x75D2,
	0x517B,	0x6837,	0x6F3E,	0x9080,	0x8170,	0x5996,	0x7476,
	/* GB 0xD240..0xD27E */
	0x8938,	0x8939,	0x893A,	0x893B,	0x893C,	0x893D,	0x893E,	0x893F,
	0x8940,	0x8942,	0x8943,	0x8945,	0x8946,	0x8947,	0x8948,	0x8949,
	0x894A,	0x894B,	0x894C,	0x894D,	0x894E,	0x894F,	0x8950,	0x8951,
	0x8952,	0x8953,	0x8954,	0x8955,	0x8956,	0x8957,	0x8958,	0x8959,
	0x895A,	0x895B,	0x895C,	0x895D,	0x8960,	0x8961,	0x8962,	0x8963,
	0x8964,	0x8965,	0x8967,	0x8968,	0x8969,	0x896A,	0x896B,	0x896C,
	0x896D,	0x896E,	0x896F,	0x8970,	0x8971,	0x8972,	0x8973,	0x8974,
	0x8975,	0x8976,	0x8977,	0x8978,	0x8979,	0x897A,	0x897C,
	/* GB 0xD280..0xD2FE */
	0x897D,	0x897E,	0x8980,	0x8982,	0x8984,	0x8985,	0x8987,	0x8988,
	0x8989,	0x898A,	0x898B,	0x898C,	0x898D,	0x898E,	0x898F,	0x8990,
	0x8991,	0x8992,	0x8993,	0x8994,	0x8995,	0x8996,	0x8997,	0x8998,
	0x8999,	0x899A,	0x899B,	0x899C,	0x899D,	0x899E,	0x899F,	0x89A0,
	0x89A1,	0x6447,	0x5C27,	0x9065,	0x7A91,	0x8C23,	0x59DA,	0x54AC,
	0x8200,	0x836F,	0x8981,	0x8000,	0x6930,	0x564E,	0x8036,	0x7237,
	0x91CE,	0x51B6,	0x4E5F,	0x9875,	0x6396,	0x4E1A,	0x53F6,	0x66F3,
	0x814B,	0x591C,	0x6DB2,	0x4E00,	0x58F9,	0x533B,	0x63D6,	0x94F1,
	0x4F9D,	0x4F0A,	0x8863,	0x9890,	0x5937,	0x9057,	0x79FB,	0x4EEA,
	0x80F0,	0x7591,	0x6C82,	0x5B9C,	0x59E8,	0x5F5D,	0x6905,	0x8681,
	0x501A,	0x5DF2,	0x4E59,	0x77E3,	0x4EE5,	0x827A,	0x6291,	0x6613,
	0x9091,	0x5C79,	0x4EBF,	0x5F79,	0x81C6,	0x9038,	0x8084,	0x75AB,
	0x4EA6,	0x88D4,	0x610F,	0x6BC5,	0x5FC6,	0x4E49,	0x76CA,	0x6EA2,
	0x8BE3,	0x8BAE,	0x8C0A,	0x8BD1,	0x5F02,	0x7FFC,	0x7FCC,	0x7ECE,
	0x8335,	0x836B,	0x56E0,	0x6BB7,	0x97F3,	0x9634,	0x59FB,	0x541F,
	0x94F6,	0x6DEB,	0x5BC5,	0x996E,	0x5C39,	0x5F15,	0x9690,
	/* GB 0xD340..0xD37E */
	0x89A2,	0x89A3,	0x89A4,	0x89A5,	0x89A6,	0x89A7,	0x89A8,	0x89A9,
	0x89AA,	0x89AB,	0x89AC,	0x89AD,	0x89AE,	0x89AF,	0x89B0,	0x89B1,
	0x89B2,	0x89B3,	0x89B4,	0x89B5,	0x89B6,	0x89B7,	0x89B8,	0x89B9,
	0x89BA,	0x89BB,	0x89BC,	0x89BD,	0x89BE,	0x89BF,	0x89C0,	0x89C3,
	0x89CD,	0x89D3,	0x89D4,	0x89D5,	0x89D7,	0x89D8,	0x89D9,	0x89DB,
	0x89DD,	0x89DF,	0x89E0,	0x89E1,	0x89E2,	0x89E4,	0x89E7,	0x89E8,
	0x89E9,	0x89EA,	0x89EC,	0x89ED,	0x89EE,	0x89F0,	0x89F1,	0x89F2,
	0x89F4,	0x89F5,	0x89F6,	0x89F7,	0x89F8,	0x89F9,	0x89FA,
	/* GB 0xD380..0xD3FE */
	0x89FB,	0x89FC,	0x89FD,	0x89FE,	0x89FF,	0x8A01,	0x8A02,	0x8A03,
	0x8A04,	0x8A05,	0x8A06,	0x8A08,	0x8A09,	0x8A0A,	0x8A0B,	0x8A0C,
	0x8A0D,	0x8A0E,	0x8A0F,	0x8A10,	0x8A11,	0x8A12,	0x8A13,	0x8A14,
	0x8A15,	0x8A16,	0x8A17,	0x8A18,	0x8A19,	0x8A1A,	0x8A1B,	0x8A1C,
	0x8A1D,	0x5370,	0x82F1,	0x6A31,	0x5A74,	0x9E70,	0x5E94,	0x7F28,
	0x83B9,	0x8424,	0x8425,	0x8367,	0x8747,	0x8FCE,	0x8D62,	0x76C8,
	0x5F71,	0x9896,	0x786C,	0x6620,	0x54DF,	0x62E5,	0x4F63,	0x81C3,
	0x75C8,	0x5EB8,	0x96CD,	0x8E0A,	0x86F9,	0x548F,	0x6CF3,	0x6D8C,
	0x6C38,	0x607F,	0x52C7,	0x7528,	0x5E7D,	0x4F18,	0x60A0,	0x5FE7,
	0x5C24,	0x7531,	0x90AE,	0x94C0,	0x72B9,	0x6CB9,	0x6E38,	0x9149,
	0x6709,	0x53CB,	0x53F3,	0x4F51,	0x91C9,	0x8BF1,	0x53C8,	0x5E7C,
	0x8FC2,	0x6DE4,	0x4E8E,	0x76C2,	0x6986,	0x865E,	0x611A,	0x8206,
	0x4F59,	0x4FDE,	0x903E,	0x9C7C,	0x6109,	0x6E1D,	0x6E14,	0x9685,
	0x4E88,	0x5A31,	0x96E8,	0x4E0E,	0x5C7F,	0x79B9,	0x5B87,	0x8BED,
	0x7FBD,	0x7389,	0x57DF,	0x828B,	0x90C1,	0x5401,	0x9047,	0x55BB,
	0x5CEA,	0x5FA1,	0x6108,	0x6B32,	0x72F1,	0x80B2,	0x8A89,
	/* GB 0xD440..0xD47E */
	0x8A1E,	0x8A1F,	0x8A20,	0x8A21,	0x8A22,	0x8A23,	0x8A24,	0x8A25,
	0x8A26,	0x8A27,	0x8A28,	0x8A29,	0x8A2A,	0x8A2B,	0x8A2C,	0x8A2D,
	0x8A2E,	0x8A2F,	0x8A30,	0x8A31,	0x8A32,	0x8A33,	0x8A34,	0x8A35,
	0x8A36,	0x8A37,	0x8A38,	0x8A39,	0x8A3A,	0x8A3B,	0x8A3C,	0x8A3D,
	0x8A3F,	0x8A40,	0x8A41,	0x8A42,	0x8A43,	0x8A44,	0x8A45,	0x8A46,
	0x8A47,	0x8A49,	0x8A4A,	0x8A4B,	0x8A4C,	0x8A4D,	0x8A4E,	0x8A4F,
	0x8A50,	0x8A51,	0x8A52,	0x8A53,	0x8A54,	0x8A55,	0x8A56,	0x8A57,
	0x8A58,	0x8A59,	0x8A5A,	0x8A5B,	0x8A5C,	0x8A5D,	0x8A5E,
	/* GB 0xD480..0xD4FE */
	0x8A5F,	0x8A60,	0x8A61,	0x8A62,	0x8A63,	0x8A64,	0x8A65,	0x8A66,
	0x8A67,	0x8A68,	0x8A69,	0x8A6A,	0x8A6B,	0x8A6C,	0x8A6D,	0x8A6E,
	0x8A6F,	0x8A70,	0x8A71,	0x8A72,	0x8A73,	0x8A74,	0x8A75,	0x8A76,
	0x8A77,	0x8A78,	0x8A7A,	0x8A7B,	0x8A7C,	0x8A7D,	0x8A7E,	0x8A7F,
	0x8A80,	0x6D74,	0x5BD3,	0x88D5,	0x9884,	0x8C6B,	0x9A6D,	0x9E33,
	0x6E0A,	0x51A4,	0x5143,	0x57A3,	0x8881,	0x539F,	0x63F4,	0x8F95,
	0x56ED,	0x5458,	0x5706,	0x733F,	0x6E90,	0x7F18,	0x8FDC,	0x82D1,
	0x613F,	0x6028,	0x9662,	0x66F0,	0x7EA6,	0x8D8A,	0x8DC3,	0x94A5,
	0x5CB3,	0x7CA4,	0x6708,	0x60A6,	0x9605,	0x8018,	0x4E91,	0x90E7,
	0x5300,	0x9668,	0x5141,	0x8FD0,	0x8574,	0x915D,	0x6655,	0x97F5,
	0x5B55,	0x531D,	0x7838,	0x6742,	0x683D,	0x54C9,	0x707E,	0x5BB0,
	0x8F7D,	0x518D,	0x5728,	0x54B1,	0x6512,	0x6682,	0x8D5E,	0x8D43,
	0x810F,	0x846C,	0x906D,	0x7CDF,	0x51FF,	0x85FB,	0x67A3,	0x65E9,
	0x6FA1,	0x86A4,	0x8E81,	0x566A,	0x9020,	0x7682,	0x7076,	0x71E5,
	0x8D23,	0x62E9,	0x5219,	0x6CFD,	0x8D3C,	0x600E,	0x589E,	0x618E,
	0x66FE,	0x8D60,	0x624E,	0x55B3,	0x6E23,	0x672D,	0x8F67,
	/* GB 0xD540..0xD57E */
	0x8A81,	0x8A82,	0x8A83,	0x8A84,	0x8A85,	0x8A86,	0x8A87,	0x8A88,
	0x8A8B,	0x8A8C,	0x8A8D,	0x8A8E,	0x8A8F,	0x8A90,	0x8A91,	0x8A92,
	0x8A94,	0x8A95,	0x8A96,	0x8A97,	0x8A98,	0x8A99,	0x8A9A,	0x8A9B,
	0x8A9C,	0x8A9D,	0x8A9E,	0x8A9F,	0x8AA0,	0x8AA1,	0x8AA2,	0x8AA3,
	0x8AA4,	0x8AA5,	0x8AA6,	0x8AA7,	0x8AA8,	0x8AA9,	0x8AAA,	0x8AAB,
	0x8AAC,	0x8AAD,	0x8AAE,	0x8AAF,	0x8AB0,	0x8AB1,	0x8AB2,	0x8AB3,
	0x8AB4,	0x8AB5,	0x8AB6,	0x8AB7,	0x8AB8,	0x8AB9,	0x8ABA,	0x8ABB,
	0x8ABC,	0x8ABD,	0x8ABE,	0x8ABF,	0x8AC0,	0x8AC1,	0x8AC2,
	/* GB 0xD580..0xD5FE */
	0x8AC3,	0x8AC4,	0x8AC5,	0x8AC6,	0x8AC7,	0x8AC8,	0x8AC9,	0x8ACA,
	0x8ACB,	0x8ACC,	0x8ACD,	0x8ACE,	0x8ACF,	0x8AD0,	0x8AD1,	0x8AD2,
	0x8AD3,	0x8AD4,	0x8AD5,	0x8AD6,	0x8AD7,	0x8AD8,	0x8AD9,	0x8ADA,
	0x8ADB,	0x8ADC,	0x8ADD,	0x8ADE,	0x8ADF,	0x8AE0,	0x8AE1,	0x8AE2,
	0x8AE3,	0x94E1,	0x95F8,	0x7728,	0x6805,	0x69A8,	0x548B,	0x4E4D,
	0x70B8,	0x8BC8,	0x6458,	0x658B,	0x5B85,	0x7A84,	0x503A,	0x5BE8,
	0x77BB,	0x6BE1,	0x8A79,	0x7C98,	0x6CBE,	0x76CF,	0x65A9,	0x8F97,
	0x5D2D,	0x5C55,	0x8638,	0x6808,	0x5360,	0x6218,	0x7AD9,	0x6E5B,
	0x7EFD,	0x6A1F,	0x7AE0,	0x5F70,	0x6F33,	0x5F20,	0x638C,	0x6DA8,
	0x6756,	0x4E08,	0x5E10,	0x8D26,	0x4ED7,	0x80C0,	0x7634,	0x969C,
	0x62DB,	0x662D,	0x627E,	0x6CBC,	0x8D75,	0x7167,	0x7F69,	0x5146,
	0x8087,	0x53EC,	0x906E,	0x6298,	0x54F2,	0x86F0,	0x8F99,	0x8005,
	0x9517,	0x8517,	0x8FD9,	0x6D59,	0x73CD,	0x659F,	0x771F,	0x7504,
	0x7827,	0x81FB,	0x8D1E,	0x9488,	0x4FA6,	0x6795,	0x75B9,	0x8BCA,
	0x9707,	0x632F,	0x9547,	0x9635,	0x84B8,	0x6323,	0x7741,	0x5F81,
	0x72F0,	0x4E89,	0x6014,	0x6574,	0x62EF,	0x6B63,	0x653F,
	/* GB 0xD640..0xD67E */
	0x8AE4,	0x8AE5,	0x8AE6,	0x8AE7,	0x8AE8,	0x8AE9,	0x8AEA,	0x8AEB,
	0x8AEC,	0x8AED,	0x8AEE,	0x8AEF,	0x8AF0,	0x8AF1,	0x8AF2,	0x8AF3,
	0x8AF4,	0x8AF5,	0x8AF6,	0x8AF7,	0x8AF8,	0x8AF9,	0x8AFA,	0x8AFB,
	0x8AFC,	0x8AFD,	0x8AFE,	0x8AFF,	0x8B00,	0x8B01,	0x8B02,	0x8B03,
	0x8B04,	0x8B05,	0x8B06,	0x8B08,	0x8B09,	0x8B0A,	0x8B0B,	0x8B0C,
	0x8B0D,	0x8B0E,	0x8B0F,	0x8B10,	0x8B11,	0x8B12,	0x8B13,	0x8B14,
	0x8B15,	0x8B16,	0x8B17,	0x8B18,	0x8B19,	0x8B1A,	0x8B1B,	0x8B1C,
	0x8B1D,	0x8B1E,	0x8B1F,	0x8B20,	0x8B21,	0x8B22,	0x8B23,
	/* GB 0xD680..0xD6FE */
	0x8B24,	0x8B25,	0x8B27,	0x8B28,	0x8B29,	0x8B2A,	0x8B2B,	0x8B2C,
	0x8B2D,	0x8B2E,	0x8B2F,	0x8B30,	0x8B31,	0x8B32,	0x8B33,	0x8B34,
	0x8B35,	0x8B36,	0x8B37,	0x8B38,	0x8B39,	0x8B3A,	0x8B3B,	0x8B3C,
	0x8B3D,	0x8B3E,	0x8B3F,	0x8B40,	0x8B41,	0x8B42,	0x8B43,	0x8B44,
	0x8B45,	0x5E27,	0x75C7,	0x90D1,	0x8BC1,	0x829D,	0x679D,	0x652F,
	0x5431,	0x8718,	0x77E5,	0x80A2,	0x8102,	0x6C41,	0x4E4B,	0x7EC7,
	0x804C,	0x76F4,	0x690D,	0x6B96,	0x6267,	0x503C,	0x4F84,	0x5740,
	0x6307,	0x6B62,	0x8DBE,	0x53EA,	0x65E8,	0x7EB8,	0x5FD7,	0x631A,
	0x63B7,	0x81F3,	0x81F4,	0x7F6E,	0x5E1C,	0x5CD9,	0x5236,	0x667A,
	0x79E9,	0x7A1A,	0x8D28,	0x7099,	0x75D4,	0x6EDE,	0x6CBB,	0x7A92,
	0x4E2D,	0x76C5,	0x5FE0,	0x949F,	0x8877,	0x7EC8,	0x79CD,	0x80BF,
	0x91CD,	0x4EF2,	0x4F17,	0x821F,	0x5468,	0x5DDE,	0x6D32,	0x8BCC,
	0x7CA5,	0x8F74,	0x8098,	0x5E1A,	0x5492,	0x76B1,	0x5B99,	0x663C,
	0x9AA4,	0x73E0,	0x682A,	0x86DB,	0x6731,	0x732A,	0x8BF8,	0x8BDB,
	0x9010,	0x7AF9,	0x70DB,	0x716E,	0x62C4,	0x77A9,	0x5631,	0x4E3B,
	0x8457,	0x67F1,	0x52A9,	0x86C0,	0x8D2E,	0x94F8,	0x7B51,
	/* GB 0xD740..0xD77E */
	0x8B46,	0x8B47,	0x8B48,	0x8B49,	0x8B4A,	0x8B4B,	0x8B4C,	0x8B4D,
	0x8B4E,	0x8B4F,	0x8B50,	0x8B51,	0x8B52,	0x8B53,	0x8B54,	0x8B55,
	0x8B56,	0x8B57,	0x8B58,	0x8B59,	0x8B5A,	0x8B5B,	0x8B5C,	0x8B5D,
	0x8B5E,	0x8B5F,	0x8B60,	0x8B61,	0x8B62,	0x8B63,	0x8B64,	0x8B65,
	0x8B67,	0x8B68,	0x8B69,	0x8B6A,	0x8B6B,	0x8B6D,	0x8B6E,	0x8B6F,
	0x8B70,	0x8B71,	0x8B72,	0x8B73,	0x8B74,	0x8B75,	0x8B76,	0x8B77,
	0x8B78,	0x8B79,	0x8B7A,	0x8B7B,	0x8B7C,	0x8B7D,	0x8B7E,	0x8B7F,
	0x8B80,	0x8B81,	0x8B82,	0x8B83,	0x8B84,	0x8B85,	0x8B86,
	/* GB 0xD780..0xD7FE */
	0x8B87,	0x8B88,	0x8B89,	0x8B8A,	0x8B8B,	0x8B8C,	0x8B8D,	0x8B8E,
	0x8B8F,	0x8B90,	0x8B91,	0x8B92,	0x8B93,	0x8B94,	0x8B95,	0x8B96,
	0x8B97,	0x8B98,	0x8B99,	0x8B9A,	0x8B9B,	0x8B9C,	0x8B9D,	0x8B9E,
	0x8B9F,	0x8BAC,	0x8BB1,	0x8BBB,	0x8BC7,	0x8BD0,	0x8BEA,	0x8C09,
	0x8C1E,	0x4F4F,	0x6CE8,	0x795D,	0x9A7B,	0x6293,	0x722A,	0x62FD,
	0x4E13,	0x7816,	0x8F6C,	0x64B0,	0x8D5A,	0x7BC6,	0x6869,	0x5E84,
	0x88C5,	0x5986,	0x649E,	0x58EE,	0x72B6,	0x690E,	0x9525,	0x8FFD,
	0x8D58,	0x5760,	0x7F00,	0x8C06,	0x51C6,	0x6349,	0x62D9,	0x5353,
	0x684C,	0x7422,	0x8301,	0x914C,	0x5544,	0x7740,	0x707C,	0x6D4A,
	0x5179,	0x54A8,	0x8D44,	0x59FF,	0x6ECB,	0x6DC4,	0x5B5C,	0x7D2B,
	0x4ED4,	0x7C7D,	0x6ED3,	0x5B50,	0x81EA,	0x6E0D,	0x5B57,	0x9B03,
	0x68D5,	0x8E2A,	0x5B97,	0x7EFC,	0x603B,	0x7EB5,	0x90B9,	0x8D70,
	0x594F,	0x63CD,	0x79DF,	0x8DB3,	0x5352,	0x65CF,	0x7956,	0x8BC5,
	0x963B,	0x7EC4,	0x94BB,	0x7E82,	0x5634,	0x9189,	0x6700,	0x7F6A,
	0x5C0A,	0x9075,	0x6628,	0x5DE6,	0x4F50,	0x67DE,	0x505A,	0x4F5C,
	0x5750,	0x5EA7,	0xE810,	0xE811,	0xE812,	0xE813,	0xE814,
	/* GB 0xD840..0xD87E */
	0x8C38,	0x8C39,	0x8C3A,	0x8C3B,	0x8C3C,	0x8C3D,	0x8C3E,	0x8C3F,
	0x8C40,	0x8C42,	0x8C43,	0x8C44,	0x8C45,	0x8C48,	0x8C4A,	0x8C4B,
	0x8C4D,	0x8C4E,	0x8C4F,	0x8C50,	0x8C51,	0x8C52,	0x8C53,	0x8C54,
	0x8C56,	0x8C57,	0x8C58,	0x8C59,	0x8C5B,	0x8C5C,	0x8C5D,	0x8C5E,
	0x8C5F,	0x8C60,	0x8C63,	0x8C64,	0x8C65,	0x8C66,	0x8C67,	0x8C68,
	0x8C69,	0x8C6C,	0x8C6D,	0x8C6E,	0x8C6F,	0x8C70,	0x8C71,	0x8C72,
	0x8C74,	0x8C75,	0x8C76,	0x8C77,	0x8C7B,	0x8C7C,	0x8C7D,	0x8C7E,
	0x8C7F,	0x8C80,	0x8C81,	0x8C83,	0x8C84,	0x8C86,	0x8C87,
	/* GB 0xD880..0xD8FE */
	0x8C88,	0x8C8B,	0x8C8D,	0x8C8E,	0x8C8F,	0x8C90,	0x8C91,	0x8C92,
	0x8C93,	0x8C95,	0x8C96,	0x8C97,	0x8C99,	0x8C9A,	0x8C9B,	0x8C9C,
	0x8C9D,	0x8C9E,	0x8C9F,	0x8CA0,	0x8CA1,	0x8CA2,	0x8CA3,	0x8CA4,
	0x8CA5,	0x8CA6,	0x8CA7,	0x8CA8,	0x8CA9,	0x8CAA,	0x8CAB,	0x8CAC,
	0x8CAD,	0x4E8D,	0x4E0C,	0x5140,	0x4E10,	0x5EFF,	0x5345,	0x4E15,
	0x4E98,	0x4E1E,	0x9B32,	0x5B6C,	0x5669,	0x4E28,	0x79BA,	0x4E3F,
	0x5315,	0x4E47,	0x592D,	0x723B,	0x536E,	0x6C10,	0x56DF,	0x80E4,
	0x9997,	0x6BD3,	0x777E,	0x9F17,	0x4E36,	0x4E9F,	0x9F10,	0x4E5C,
	0x4E69,	0x4E93,	0x8288,	0x5B5B,	0x556C,	0x560F,	0x4EC4,	0x538D,
	0x539D,	0x53A3,	0x53A5,	0x53AE,	0x9765,	0x8D5D,	0x531A,	0x53F5,
	0x5326,	0x532E,	0x533E,	0x8D5C,	0x5366,	0x5363,	0x5202,	0x5208,
	0x520E,	0x522D,	0x5233,	0x523F,	0x5240,	0x524C,	0x525E,	0x5261,
	0x525C,	0x84AF,	0x527D,	0x5282,	0x5281,	0x5290,	0x5293,	0x5182,
	0x7F54,	0x4EBB,	0x4EC3,	0x4EC9,	0x4EC2,	0x4EE8,	0x4EE1,	0x4EEB,
	0x4EDE,	0x4F1B,	0x4EF3,	0x4F22,	0x4F64,	0x4EF5,	0x4F25,	0x4F27,
	0x4F09,	0x4F2B,	0x4F5E,	0x4F67,	0x6538,	0x4F5A,	0x4F5D,
	/* GB 0xD940..0xD97E */
	0x8CAE,	0x8CAF,	0x8CB0,	0x8CB1,	0x8CB2,	0x8CB3,	0x8CB4,	0x8CB5,
	0x8CB6,	0x8CB7,	0x8CB8,	0x8CB9,	0x8CBA,	0x8CBB,	0x8CBC,	0x8CBD,
	0x8CBE,	0x8CBF,	0x8CC0,	0x8CC1,	0x8CC2,	0x8CC3,	0x8CC4,	0x8CC5,
	0x8CC6,	0x8CC7,	0x8CC8,	0x8CC9,	0x8CCA,	0x8CCB,	0x8CCC,	0x8CCD,
	0x8CCE,	0x8CCF,	0x8CD0,	0x8CD1,	0x8CD2,	0x8CD3,	0x8CD4,	0x8CD5,
	0x8CD6,	0x8CD7,	0x8CD8,	0x8CD9,	0x8CDA,	0x8CDB,	0x8CDC,	0x8CDD,
	0x8CDE,	0x8CDF,	0x8CE0,	0x8CE1,	0x8CE2,	0x8CE3,	0x8CE4,	0x8CE5,
	0x8CE6,	0x8CE7,	0x8CE8,	0x8CE9,	0x8CEA,	0x8CEB,	0x8CEC,
	/* GB 0xD980..0xD9FE */
	0x8CED,	0x8CEE,	0x8CEF,	0x8CF0,	0x8CF1,	0x8CF2,	0x8CF3,	0x8CF4,
	0x8CF5,	0x8CF6,	0x8CF7,	0x8CF8,	0x8CF9,	0x8CFA,	0x8CFB,	0x8CFC,
	0x8CFD,	0x8CFE,	0x8CFF,	0x8D00,	0x8D01,	0x8D02,	0x8D03,	0x8D04,
	0x8D05,	0x8D06,	0x8D07,	0x8D08,	0x8D09,	0x8D0A,	0x8D0B,	0x8D0C,
	0x8D0D,	0x4F5F,	0x4F57,	0x4F32,	0x4F3D,	0x4F76,	0x4F74,	0x4F91,
	0x4F89,	0x4F83,	0x4F8F,	0x4F7E,	0x4F7B,	0x4FAA,	0x4F7C,	0x4FAC,
	0x4F94,	0x4FE6,	0x4FE8,	0x4FEA,	0x4FC5,	0x4FDA,	0x4FE3,	0x4FDC,
	0x4FD1,	0x4FDF,	0x4FF8,	0x5029,	0x504C,	0x4FF3,	0x502C,	0x500F,
	0x502E,	0x502D,	0x4FFE,	0x501C,	0x500C,	0x5025,	0x5028,	0x507E,
	0x5043,	0x5055,	0x5048,	0x504E,	0x506C,	0x507B,	0x50A5,	0x50A7,
	0x50A9,	0x50BA,	0x50D6,	0x5106,	0x50ED,	0x50EC,	0x50E6,	0x50EE,
	0x5107,	0x510B,	0x4EDD,	0x6C3D,	0x4F58,	0x4F65,	0x4FCE,	0x9FA0,
	0x6C46,	0x7C74,	0x516E,	0x5DFD,	0x9EC9,	0x9998,	0x5181,	0x5914,
	0x52F9,	0x530D,	0x8A07,	0x5310,	0x51EB,	0x5919,	0x5155,	0x4EA0,
	0x5156,	0x4EB3,	0x886E,	0x88A4,	0x4EB5,	0x8114,	0x88D2,	0x7980,
	0x5B34,	0x8803,	0x7FB8,	0x51AB,	0x51B1,	0x51BD,	0x51BC,
	/* GB 0xDA40..0xDA7E */
	0x8D0E,	0x8D0F,	0x8D10,	0x8D11,	0x8D12,	0x8D13,	0x8D14,	0x8D15,
	0x8D16,	0x8D17,	0x8D18,	0x8D19,	0x8D1A,	0x8D1B,	0x8D1C,	0x8D20,
	0x8D51,	0x8D52,	0x8D57,	0x8D5F,	0x8D65,	0x8D68,	0x8D69,	0x8D6A,
	0x8D6C,	0x8D6E,	0x8D6F,	0x8D71,	0x8D72,	0x8D78,	0x8D79,	0x8D7A,
	0x8D7B,	0x8D7C,	0x8D7D,	0x8D7E,	0x8D7F,	0x8D80,	0x8D82,	0x8D83,
	0x8D86,	0x8D87,	0x8D88,	0x8D89,	0x8D8C,	0x8D8D,	0x8D8E,	0x8D8F,
	0x8D90,	0x8D92,	0x8D93,	0x8D95,	0x8D96,	0x8D97,	0x8D98,	0x8D99,
	0x8D9A,	0x8D9B,	0x8D9C,	0x8D9D,	0x8D9E,	0x8DA0,	0x8DA1,
	/* GB 0xDA80..0xDAFE */
	0x8DA2,	0x8DA4,	0x8DA5,	0x8DA6,	0x8DA7,	0x8DA8,	0x8DA9,	0x8DAA,
	0x8DAB,	0x8DAC,	0x8DAD,	0x8DAE,	0x8DAF,	0x8DB0,	0x8DB2,	0x8DB6,
	0x8DB7,	0x8DB9,	0x8DBB,	0x8DBD,	0x8DC0,	0x8DC1,	0x8DC2,	0x8DC5,
	0x8DC7,	0x8DC8,	0x8DC9,	0x8DCA,	0x8DCD,	0x8DD0,	0x8DD2,	0x8DD3,
	0x8DD4,	0x51C7,	0x5196,	0x51A2,	0x51A5,	0x8BA0,	0x8BA6,	0x8BA7,
	0x8BAA,	0x8BB4,	0x8BB5,	0x8BB7,	0x8BC2,	0x8BC3,	0x8BCB,	0x8BCF,
	0x8BCE,	0x8BD2,	0x8BD3,	0x8BD4,	0x8BD6,	0x8BD8,	0x8BD9,	0x8BDC,
	0x8BDF,	0x8BE0,	0x8BE4,	0x8BE8,	0x8BE9,	0x8BEE,	0x8BF0,	0x8BF3,
	0x8BF6,	0x8BF9,	0x8BFC,	0x8BFF,	0x8C00,	0x8C02,	0x8C04,	0x8C07,
	0x8C0C,	0x8C0F,	0x8C11,	0x8C12,	0x8C14,	0x8C15,	0x8C16,	0x8C19,
	0x8C1B,	0x8C18,	0x8C1D,	0x8C1F,	0x8C20,	0x8C21,	0x8C25,	0x8C27,
	0x8C2A,	0x8C2B,	0x8C2E,	0x8C2F,	0x8C32,	0x8C33,	0x8C35,	0x8C36,
	0x5369,	0x537A,	0x961D,	0x9622,	0x9621,	0x9631,	0x962A,	0x963D,
	0x963C,	0x9642,	0x9649,	0x9654,	0x965F,	0x9667,	0x966C,	0x9672,
	0x9674,	0x9688,	0x968D,	0x9697,	0x96B0,	0x9097,	0x909B,	0x909D,
	0x9099,	0x90AC,	0x90A1,	0x90B4,	0x90B3,	0x90B6,	0x90BA,
	/* GB 0xDB40..0xDB7E */
	0x8DD5,	0x8DD8,	0x8DD9,	0x8DDC,	0x8DE0,	0x8DE1,	0x8DE2,	0x8DE5,
	0x8DE6,	0x8DE7,	0x8DE9,	0x8DED,	0x8DEE,	0x8DF0,	0x8DF1,	0x8DF2,
	0x8DF4,	0x8DF6,	0x8DFC,	0x8DFE,	0x8DFF,	0x8E00,	0x8E01,	0x8E02,
	0x8E03,	0x8E04,	0x8E06,	0x8E07,	0x8E08,	0x8E0B,	0x8E0D,	0x8E0E,
	0x8E10,	0x8E11,	0x8E12,	0x8E13,	0x8E15,	0x8E16,	0x8E17,	0x8E18,
	0x8E19,	0x8E1A,	0x8E1B,	0x8E1C,	0x8E20,	0x8E21,	0x8E24,	0x8E25,
	0x8E26,	0x8E27,	0x8E28,	0x8E2B,	0x8E2D,	0x8E30,	0x8E32,	0x8E33,
	0x8E34,	0x8E36,	0x8E37,	0x8E38,	0x8E3B,	0x8E3C,	0x8E3E,
	/* GB 0xDB80..0xDBFE */
	0x8E3F,	0x8E43,	0x8E45,	0x8E46,	0x8E4C,	0x8E4D,	0x8E4E,	0x8E4F,
	0x8E50,	0x8E53,	0x8E54,	0x8E55,	0x8E56,	0x8E57,	0x8E58,	0x8E5A,
	0x8E5B,	0x8E5C,	0x8E5D,	0x8E5E,	0x8E5F,	0x8E60,	0x8E61,	0x8E62,
	0x8E63,	0x8E64,	0x8E65,	0x8E67,	0x8E68,	0x8E6A,	0x8E6B,	0x8E6E,
	0x8E71,	0x90B8,	0x90B0,	0x90CF,	0x90C5,	0x90BE,	0x90D0,	0x90C4,
	0x90C7,	0x90D3,	0x90E6,	0x90E2,	0x90DC,	0x90D7,	0x90DB,	0x90EB,
	0x90EF,	0x90FE,	0x9104,	0x9122,	0x911E,	0x9123,	0x9131,	0x912F,
	0x9139,	0x9143,	0x9146,	0x520D,	0x5942,	0x52A2,	0x52AC,	0x52AD,
	0x52BE,	0x54FF,	0x52D0,	0x52D6,	0x52F0,	0x53DF,	0x71EE,	0x77CD,
	0x5EF4,	0x51F5,	0x51FC,	0x9B2F,	0x53B6,	0x5F01,	0x755A,	0x5DEF,
	0x574C,	0x57A9,	0x57A1,	0x587E,	0x58BC,	0x58C5,	0x58D1,	0x5729,
	0x572C,	0x572A,	0x5733,	0x5739,	0x572E,	0x572F,	0x575C,	0x573B,
	0x5742,	0x5769,	0x5785,	0x576B,	0x5786,	0x577C,	0x577B,	0x5768,
	0x576D,	0x5776,	0x5773,	0x57AD,	0x57A4,	0x578C,	0x57B2,	0x57CF,
	0x57A7,	0x57B4,	0x5793,	0x57A0,	0x57D5,	0x57D8,	0x57DA,	0x57D9,
	0x57D2,	0x57B8,	0x57F4,	0x57EF,	0x57F8,	0x57E4,	0x57DD,
	/* GB 0xDC40..0xDC7E */
	0x8E73,	0x8E75,	0x8E77,	0x8E78,	0x8E79,	0x8E7A,	0x8E7B,	0x8E7D,
	0x8E7E,	0x8E80,	0x8E82,	0x8E83,	0x8E84,	0x8E86,	0x8E88,	0x8E89,
	0x8E8A,	0x8E8B,	0x8E8C,	0x8E8D,	0x8E8E,	0x8E91,	0x8E92,	0x8E93,
	0x8E95,	0x8E96,	0x8E97,	0x8E98,	0x8E99,	0x8E9A,	0x8E9B,	0x8E9D,
	0x8E9F,	0x8EA0,	0x8EA1,	0x8EA2,	0x8EA3,	0x8EA4,	0x8EA5,	0x8EA6,
	0x8EA7,	0x8EA8,	0x8EA9,	0x8EAA,	0x8EAD,	0x8EAE,	0x8EB0,	0x8EB1,
	0x8EB3,	0x8EB4,	0x8EB5,	0x8EB6,	0x8EB7,	0x8EB8,	0x8EB9,	0x8EBB,
	0x8EBC,	0x8EBD,	0x8EBE,	0x8EBF,	0x8EC0,	0x8EC1,	0x8EC2,
	/* GB 0xDC80..0xDCFE */
	0x8EC3,	0x8EC4,	0x8EC5,	0x8EC6,	0x8EC7,	0x8EC8,	0x8EC9,	0x8ECA,
	0x8ECB,	0x8ECC,	0x8ECD,	0x8ECF,	0x8ED0,	0x8ED1,	0x8ED2,	0x8ED3,
	0x8ED4,	0x8ED5,	0x8ED6,	0x8ED7,	0x8ED8,	0x8ED9,	0x8EDA,	0x8EDB,
	0x8EDC,	0x8EDD,	0x8EDE,	0x8EDF,	0x8EE0,	0x8EE1,	0x8EE2,	0x8EE3,
	0x8EE4,	0x580B,	0x580D,	0x57FD,	0x57ED,	0x5800,	0x581E,	0x5819,
	0x5844,	0x5820,	0x5865,	0x586C,	0x5881,	0x5889,	0x589A,	0x5880,
	0x99A8,	0x9F19,	0x61FF,	0x8279,	0x827D,	0x827F,	0x828F,	0x828A,
	0x82A8,	0x8284,	0x828E,	0x8291,	0x8297,	0x8299,	0x82AB,	0x82B8,
	0x82BE,	0x82B0,	0x82C8,	0x82CA,	0x82E3,	0x8298,	0x82B7,	0x82AE,
	0x82CB,	0x82CC,	0x82C1,	0x82A9,	0x82B4,	0x82A1,	0x82AA,	0x829F,
	0x82C4,	0x82CE,	0x82A4,	0x82E1,	0x8309,	0x82F7,	0x82E4,	0x830F,
	0x8307,	0x82DC,	0x82F4,	0x82D2,	0x82D8,	0x830C,	0x82FB,	0x82D3,
	0x8311,	0x831A,	0x8306,	0x8314,	0x8315,	0x82E0,	0x82D5,	0x831C,
	0x8351,	0x835B,	0x835C,	0x8308,	0x8392,	0x833C,	0x8334,	0x8331,
	0x839B,	0x835E,	0x832F,	0x834F,	0x8347,	0x8343,	0x835F,	0x8340,
	0x8317,	0x8360,	0x832D,	0x833A,	0x8333,	0x8366,	0x8365,
	/* GB 0xDD40..0xDD7E */
	0x8EE5,	0x8EE6,	0x8EE7,	0x8EE8,	0x8EE9,	0x8EEA,	0x8EEB,	0x8EEC,
	0x8EED,	0x8EEE,	0x8EEF,	0x8EF0,	0x8EF1,	0x8EF2,	0x8EF3,	0x8EF4,
	0x8EF5,	0x8EF6,	0x8EF7,	0x8EF8,	0x8EF9,	0x8EFA,	0x8EFB,	0x8EFC,
	0x8EFD,	0x8EFE,	0x8EFF,	0x8F00,	0x8F01,	0x8F02,	0x8F03,	0x8F04,
	0x8F05,	0x8F06,	0x8F07,	0x8F08,	0x8F09,	0x8F0A,	0x8F0B,	0x8F0C,
	0x8F0D,	0x8F0E,	0x8F0F,	0x8F10,	0x8F11,	0x8F12,	0x8F13,	0x8F14,
	0x8F15,	0x8F16,	0x8F17,	0x8F18,	0x8F19,	0x8F1A,	0x8F1B,	0x8F1C,
	0x8F1D,	0x8F1E,	0x8F1F,	0x8F20,	0x8F21,	0x8F22,	0x8F23,
	/* GB 0xDD80..0xDDFE */
	0x8F24,	0x8F25,	0x8F26,	0x8F27,	0x8F28,	0x8F29,	0x8F2A,	0x8F2B,
	0x8F2C,	0x8F2D,	0x8F2E,	0x8F2F,	0x8F30,	0x8F31,	0x8F32,	0x8F33,
	0x8F34,	0x8F35,	0x8F36,	0x8F37,	0x8F38,	0x8F39,	0x8F3A,	0x8F3B,
	0x8F3C,	0x8F3D,	0x8F3E,	0x8F3F,	0x8F40,	0x8F41,	0x8F42,	0x8F43,
	0x8F44,	0x8368,	0x831B,	0x8369,	0x836C,	0x836A,	0x836D,	0x836E,
	0x83B0,	0x8378,	0x83B3,	0x83B4,	0x83A0,	0x83AA,	0x8393,	0x839C,
	0x8385,	0x837C,	0x83B6,	0x83A9,	0x837D,	0x83B8,	0x837B,	0x8398,
	0x839E,	0x83A8,	0x83BA,	0x83BC,	0x83C1,	0x8401,	0x83E5,	0x83D8,
	0x5807,	0x8418,	0x840B,	0x83DD,	0x83FD,	0x83D6,	0x841C,	0x8438,
	0x8411,	0x8406,	0x83D4,	0x83DF,	0x840F,	0x8403,	0x83F8,	0x83F9,
	0x83EA,	0x83C5,	0x83C0,	0x8426,	0x83F0,	0x83E1,	0x845C,	0x8451,
	0x845A,	0x8459,	0x8473,	0x8487,	0x8488,	0x847A,	0x8489,	0x8478,
	0x843C,	0x8446,	0x8469,	0x8476,	0x848C,	0x848E,	0x8431,	0x846D,
	0x84C1,	0x84CD,	0x84D0,	0x84E6,	0x84BD,	0x84D3,	0x84CA,	0x84BF,
	0x84BA,	0x84E0,	0x84A1,	0x84B9,	0x84B4,	0x8497,	0x84E5,	0x84E3,
	0x850C,	0x750D,	0x8538,	0x84F0,	0x8539,	0x851F,	0x853A,
	/* GB 0xDE40..0xDE7E */
	0x8F45,	0x8F46,	0x8F47,	0x8F48,	0x8F49,	0x8F4A,	0x8F4B,	0x8F4C,
	0x8F4D,	0x8F4E,	0x8F4F,	0x8F50,	0x8F51,	0x8F52,	0x8F53,	0x8F54,
	0x8F55,	0x8F56,	0x8F57,	0x8F58,	0x8F59,	0x8F5A,	0x8F5B,	0x8F5C,
	0x8F5D,	0x8F5E,	0x8F5F,	0x8F60,	0x8F61,	0x8F62,	0x8F63,	0x8F64,
	0x8F65,	0x8F6A,	0x8F80,	0x8F8C,	0x8F92,	0x8F9D,	0x8FA0,	0x8FA1,
	0x8FA2,	0x8FA4,	0x8FA5,	0x8FA6,	0x8FA7,	0x8FAA,	0x8FAC,	0x8FAD,
	0x8FAE,	0x8FAF,	0x8FB2,	0x8FB3,	0x8FB4,	0x8FB5,	0x8FB7,	0x8FB8,
	0x8FBA,	0x8FBB,	0x8FBC,	0x8FBF,	0x8FC0,	0x8FC3,	0x8FC6,
	/* GB 0xDE80..0xDEFE */
	0x8FC9,	0x8FCA,	0x8FCB,	0x8FCC,	0x8FCD,	0x8FCF,	0x8FD2,	0x8FD6,
	0x8FD7,	0x8FDA,	0x8FE0,	0x8FE1,	0x8FE3,	0x8FE7,	0x8FEC,	0x8FEF,
	0x8FF1,	0x8FF2,	0x8FF4,	0x8FF5,	0x8FF6,	0x8FFA,	0x8FFB,	0x8FFC,
	0x8FFE,	0x8FFF,	0x9007,	0x9008,	0x900C,	0x900E,	0x9013,	0x9015,
	0x9018,	0x8556,	0x853B,	0x84FF,	0x84FC,	0x8559,	0x8548,	0x8568,
	0x8564,	0x855E,	0x857A,	0x77A2,	0x8543,	0x8572,	0x857B,	0x85A4,
	0x85A8,	0x8587,	0x858F,	0x8579,	0x85AE,	0x859C,	0x8585,	0x85B9,
	0x85B7,	0x85B0,	0x85D3,	0x85C1,	0x85DC,	0x85FF,	0x8627,	0x8605,
	0x8629,	0x8616,	0x863C,	0x5EFE,	0x5F08,	0x593C,	0x5941,	0x8037,
	0x5955,	0x595A,	0x5958,	0x530F,	0x5C22,	0x5C25,	0x5C2C,	0x5C34,
	0x624C,	0x626A,	0x629F,	0x62BB,	0x62CA,	0x62DA,	0x62D7,	0x62EE,
	0x6322,	0x62F6,	0x6339,	0x634B,	0x6343,	0x63AD,	0x63F6,	0x6371,
	0x637A,	0x638E,	0x63B4,	0x636D,	0x63AC,	0x638A,	0x6369,	0x63AE,
	0x63BC,	0x63F2,	0x63F8,	0x63E0,	0x63FF,	0x63C4,	0x63DE,	0x63CE,
	0x6452,	0x63C6,	0x63BE,	0x6445,	0x6441,	0x640B,	0x641B,	0x6420,
	0x640C,	0x6426,	0x6421,	0x645E,	0x6484,	0x646D,	0x6496,
	/* GB 0xDF40..0xDF7E */
	0x9019,	0x901C,	0x9023,	0x9024,	0x9025,	0x9027,	0x9028,	0x9029,
	0x902A,	0x902B,	0x902C,	0x9030,	0x9031,	0x9032,	0x9033,	0x9034,
	0x9037,	0x9039,	0x903A,	0x903D,	0x903F,	0x9040,	0x9043,	0x9045,
	0x9046,	0x9048,	0x9049,	0x904A,	0x904B,	0x904C,	0x904E,	0x9054,
	0x9055,	0x9056,	0x9059,	0x905A,	0x905C,	0x905D,	0x905E,	0x905F,
	0x9060,	0x9061,	0x9064,	0x9066,	0x9067,	0x9069,	0x906A,	0x906B,
	0x906C,	0x906F,	0x9070,	0x9071,	0x9072,	0x9073,	0x9076,	0x9077,
	0x9078,	0x9079,	0x907A,	0x907B,	0x907C,	0x907E,	0x9081,
	/* GB 0xDF80..0xDFFE */
	0x9084,	0x9085,	0x9086,	0x9087,	0x9089,	0x908A,	0x908C,	0x908D,
	0x908E,	0x908F,	0x9090,	0x9092,	0x9094,	0x9096,	0x9098,	0x909A,
	0x909C,	0x909E,	0x909F,	0x90A0,	0x90A4,	0x90A5,	0x90A7,	0x90A8,
	0x90A9,	0x90AB,	0x90AD,	0x90B2,	0x90B7,	0x90BC,	0x90BD,	0x90BF,
	0x90C0,	0x647A,	0x64B7,	0x64B8,	0x6499,	0x64BA,	0x64C0,	0x64D0,
	0x64D7,	0x64E4,	0x64E2,	0x6509,	0x6525,	0x652E,	0x5F0B,	0x5FD2,
	0x7519,	0x5F11,	0x535F,	0x53F1,	0x53FD,	0x53E9,	0x53E8,	0x53FB,
	0x5412,	0x5416,	0x5406,	0x544B,	0x5452,	0x5453,	0x5454,	0x5456,
	0x5443,	0x5421,	0x5457,	0x5459,	0x5423,	0x5432,	0x5482,	0x5494,
	0x5477,	0x5471,	0x5464,	0x549A,	0x549B,	0x5484,	0x5476,	0x5466,
	0x549D,	0x54D0,	0x54AD,	0x54C2,	0x54B4,	0x54D2,	0x54A7,	0x54A6,
	0x54D3,	0x54D4,	0x5472,	0x54A3,	0x54D5,	0x54BB,	0x54BF,	0x54CC,
	0x54D9,	0x54DA,	0x54DC,	0x54A9,	0x54AA,	0x54A4,	0x54DD,	0x54CF,
	0x54DE,	0x551B,	0x54E7,	0x5520,	0x54FD,	0x5514,	0x54F3,	0x5522,
	0x5523,	0x550F,	0x5511,	0x5527,	0x552A,	0x5567,	0x558F,	0x55B5,
	0x5549,	0x556D,	0x5541,	0x5555,	0x553F,	0x5550,	0x553C,
	/* GB 0xE040..0xE07E */
	0x90C2,	0x90C3,	0x90C6,	0x90C8,	0x90C9,	0x90CB,	0x90CC,	0x90CD,
	0x90D2,	0x90D4,	0x90D5,	0x90D6,	0x90D8,	0x90D9,	0x90DA,	0x90DE,
	0x90DF,	0x90E0,	0x90E3,	0x90E4,	0x90E5,	0x90E9,	0x90EA,	0x90EC,
	0x90EE,	0x90F0,	0x90F1,	0x90F2,	0x90F3,	0x90F5,	0x90F6,	0x90F7,
	0x90F9,	0x90FA,	0x90FB,	0x90FC,	0x90FF,	0x9100,	0x9101,	0x9103,
	0x9105,	0x9106,	0x9107,	0x9108,	0x9109,	0x910A,	0x910B,	0x910C,
	0x910D,	0x910E,	0x910F,	0x9110,	0x9111,	0x9112,	0x9113,	0x9114,
	0x9115,	0x9116,	0x9117,	0x9118,	0x911A,	0x911B,	0x911C,
	/* GB 0xE080..0xE0FE */
	0x911D,	0x911F,	0x9120,	0x9121,	0x9124,	0x9125,	0x9126,	0x9127,
	0x9128,	0x9129,	0x912A,	0x912B,	0x912C,	0x912D,	0x912E,	0x9130,
	0x9132,	0x9133,	0x9134,	0x9135,	0x9136,	0x9137,	0x9138,	0x913A,
	0x913B,	0x913C,	0x913D,	0x913E,	0x913F,	0x9140,	0x9141,	0x9142,
	0x9144,	0x5537,	0x5556,	0x5575,	0x5576,	0x5577,	0x5533,	0x5530,
	0x555C,	0x558B,	0x55D2,	0x5583,	0x55B1,	0x55B9,	0x5588,	0x5581,
	0x559F,	0x557E,	0x55D6,	0x5591,	0x557B,	0x55DF,	0x55BD,	0x55BE,
	0x5594,	0x5599,	0x55EA,	0x55F7,	0x55C9,	0x561F,	0x55D1,	0x55EB,
	0x55EC,	0x55D4,	0x55E6,	0x55DD,	0x55C4,	0x55EF,	0x55E5,	0x55F2,
	0x55F3,	0x55CC,	0x55CD,	0x55E8,	0x55F5,	0x55E4,	0x8F94,	0x561E,
	0x5608,	0x560C,	0x5601,	0x5624,	0x5623,	0x55FE,	0x5600,	0x5627,
	0x562D,	0x5658,	0x5639,	0x5657,	0x562C,	0x564D,	0x5662,	0x5659,
	0x565C,	0x564C,	0x5654,	0x5686,	0x5664,	0x5671,	0x566B,	0x567B,
	0x567C,	0x5685,	0x5693,	0x56AF,	0x56D4,	0x56D7,	0x56DD,	0x56E1,
	0x56F5,	0x56EB,	0x56F9,	0x56FF,	0x5704,	0x570A,	0x5709,	0x571C,
	0x5E0F,	0x5E19,	0x5E14,	0x5E11,	0x5E31,	0x5E3B,	0x5E3C,
	/* GB 0xE140..0xE17E */
	0x9145,	0x9147,	0x9148,	0x9151,	0x9153,	0x9154,	0x9155,	0x9156,
	0x9158,	0x9159,	0x915B,	0x915C,	0x915F,	0x9160,	0x9166,	0x9167,
	0x9168,	0x916B,	0x916D,	0x9173,	0x917A,	0x917B,	0x917C,	0x9180,
	0x9181,	0x9182,	0x9183,	0x9184,	0x9186,	0x9188,	0x918A,	0x918E,
	0x918F,	0x9193,	0x9194,	0x9195,	0x9196,	0x9197,	0x9198,	0x9199,
	0x919C,	0x919D,	0x919E,	0x919F,	0x91A0,	0x91A1,	0x91A4,	0x91A5,
	0x91A6,	0x91A7,	0x91A8,	0x91A9,	0x91AB,	0x91AC,	0x91B0,	0x91B1,
	0x91B2,	0x91B3,	0x91B6,	0x91B7,	0x91B8,	0x91B9,	0x91BB,
	/* GB 0xE180..0xE1FE */
	0x91BC,	0x91BD,	0x91BE,	0x91BF,	0x91C0,	0x91C1,	0x91C2,	0x91C3,
	0x91C4,	0x91C5,	0x91C6,	0x91C8,	0x91CB,	0x91D0,	0x91D2,	0x91D3,
	0x91D4,	0x91D5,	0x91D6,	0x91D7,	0x91D8,	0x91D9,	0x91DA,	0x91DB,
	0x91DD,	0x91DE,	0x91DF,	0x91E0,	0x91E1,	0x91E2,	0x91E3,	0x91E4,
	0x91E5,	0x5E37,	0x5E44,	0x5E54,	0x5E5B,	0x5E5E,	0x5E61,	0x5C8C,
	0x5C7A,	0x5C8D,	0x5C90,	0x5C96,	0x5C88,	0x5C98,	0x5C99,	0x5C91,
	0x5C9A,	0x5C9C,	0x5CB5,	0x5CA2,	0x5CBD,	0x5CAC,	0x5CAB,	0x5CB1,
	0x5CA3,	0x5CC1,	0x5CB7,	0x5CC4,	0x5CD2,	0x5CE4,	0x5CCB,	0x5CE5,
	0x5D02,	0x5D03,	0x5D27,	0x5D26,	0x5D2E,	0x5D24,	0x5D1E,	0x5D06,
	0x5D1B,	0x5D58,	0x5D3E,	0x5D34,	0x5D3D,	0x5D6C,	0x5D5B,	0x5D6F,
	0x5D5D,	0x5D6B,	0x5D4B,	0x5D4A,	0x5D69,	0x5D74,	0x5D82,	0x5D99,
	0x5D9D,	0x8C73,	0x5DB7,	0x5DC5,	0x5F73,	0x5F77,	0x5F82,	0x5F87,
	0x5F89,	0x5F8C,	0x5F95,	0x5F99,	0x5F9C,	0x5FA8,	0x5FAD,	0x5FB5,
	0x5FBC,	0x8862,	0x5F61,	0x72AD,	0x72B0,	0x72B4,	0x72B7,	0x72B8,
	0x72C3,	0x72C1,	0x72CE,	0x72CD,	0x72D2,	0x72E8,	0x72EF,	0x72E9,
	0x72F2,	0x72F4,	0x72F7,	0x7301,	0x72F3,	0x7303,	0x72FA,
	/* GB 0xE240..0xE27E */
	0x91E6,	0x91E7,	0x91E8,	0x91E9,	0x91EA,	0x91EB,	0x91EC,	0x91ED,
	0x91EE,	0x91EF,	0x91F0,	0x91F1,	0x91F2,	0x91F3,	0x91F4,	0x91F5,
	0x91F6,	0x91F7,	0x91F8,	0x91F9,	0x91FA,	0x91FB,	0x91FC,	0x91FD,
	0x91FE,	0x91FF,	0x9200,	0x9201,	0x9202,	0x9203,	0x9204,	0x9205,
	0x9206,	0x9207,	0x9208,	0x9209,	0x920A,	0x920B,	0x920C,	0x920D,
	0x920E,	0x920F,	0x9210,	0x9211,	0x9212,	0x9213,	0x9214,	0x9215,
	0x9216,	0x9217,	0x9218,	0x9219,	0x921A,	0x921B,	0x921C,	0x921D,
	0x921E,	0x921F,	0x9220,	0x9221,	0x9222,	0x9223,	0x9224,
	/* GB 0xE280..0xE2FE */
	0x9225,	0x9226,	0x9227,	0x9228,	0x9229,	0x922A,	0x922B,	0x922C,
	0x922D,	0x922E,	0x922F,	0x9230,	0x9231,	0x9232,	0x9233,	0x9234,
	0x9235,	0x9236,	0x9237,	0x9238,	0x9239,	0x923A,	0x923B,	0x923C,
	0x923D,	0x923E,	0x923F,	0x9240,	0x9241,	0x9242,	0x9243,	0x9244,
	0x9245,	0x72FB,	0x7317,	0x7313,	0x7321,	0x730A,	0x731E,	0x731D,
	0x7315,	0x7322,	0x7339,	0x7325,	0x732C,	0x7338,	0x7331,	0x7350,
	0x734D,	0x7357,	0x7360,	0x736C,	0x736F,	0x737E,	0x821B,	0x5925,
	0x98E7,	0x5924,	0x5902,	0x9963,	0x9967,	0x9968,	0x9969,	0x996A,
	0x996B,	0x996C,	0x9974,	0x9977,	0x997D,	0x9980,	0x9984,	0x9987,
	0x998A,	0x998D,	0x9990,	0x9991,	0x9993,	0x9994,	0x9995,	0x5E80,
	0x5E91,	0x5E8B,	0x5E96,	0x5EA5,	0x5EA0,	0x5EB9,	0x5EB5,	0x5EBE,
	0x5EB3,	0x8D53,	0x5ED2,	0x5ED1,	0x5EDB,	0x5EE8,	0x5EEA,	0x81BA,
	0x5FC4,	0x5FC9,	0x5FD6,	0x5FCF,	0x6003,	0x5FEE,	0x6004,	0x5FE1,
	0x5FE4,	0x5FFE,	0x6005,	0x6006,	0x5FEA,	0x5FED,	0x5FF8,	0x6019,
	0x6035,	0x6026,	0x601B,	0x600F,	0x600D,	0x6029,	0x602B,	0x600A,
	0x603F,	0x6021,	0x6078,	0x6079,	0x607B,	0x607A,	0x6042,
	/* GB 0xE340..0xE37E */
	0x9246,	0x9247,	0x9248,	0x9249,	0x924A,	0x924B,	0x924C,	0x924D,
	0x924E,	0x924F,	0x9250,	0x9251,	0x9252,	0x9253,	0x9254,	0x9255,
	0x9256,	0x9257,	0x9258,	0x9259,	0x925A,	0x925B,	0x925C,	0x925D,
	0x925E,	0x925F,	0x9260,	0x9261,	0x9262,	0x9263,	0x9264,	0x9265,
	0x9266,	0x9267,	0x9268,	0x9269,	0x926A,	0x926B,	0x926C,	0x926D,
	0x926E,	0x926F,	0x9270,	0x9271,	0x9272,	0x9273,	0x9275,	0x9276,
	0x9277,	0x9278,	0x9279,	0x927A,	0x927B,	0x927C,	0x927D,	0x927E,
	0x927F,	0x9280,	0x9281,	0x9282,	0x9283,	0x9284,	0x9285,
	/* GB 0xE380..0xE3FE */
	0x9286,	0x9287,	0x9288,	0x9289,	0x928A,	0x928B,	0x928C,	0x928D,
	0x928F,	0x9290,	0x9291,	0x9292,	0x9293,	0x9294,	0x9295,	0x9296,
	0x9297,	0x9298,	0x9299,	0x929A,	0x929B,	0x929C,	0x929D,	0x929E,
	0x929F,	0x92A0,	0x92A1,	0x92A2,	0x92A3,	0x92A4,	0x92A5,	0x92A6,
	0x92A7,	0x606A,	0x607D,	0x6096,	0x609A,	0x60AD,	0x609D,	0x6083,
	0x6092,	0x608C,	0x609B,	0x60EC,	0x60BB,	0x60B1,	0x60DD,	0x60D8,
	0x60C6,	0x60DA,	0x60B4,	0x6120,	0x6126,	0x6115,	0x6123,	0x60F4,
	0x6100,	0x610E,	0x612B,	0x614A,	0x6175,	0x61AC,	0x6194,	0x61A7,
	0x61B7,	0x61D4,	0x61F5,	0x5FDD,	0x96B3,	0x95E9,	0x95EB,	0x95F1,
	0x95F3,	0x95F5,	0x95F6,	0x95FC,	0x95FE,	0x9603,	0x9604,	0x9606,
	0x9608,	0x960A,	0x960B,	0x960C,	0x960D,	0x960F,	0x9612,	0x9615,
	0x9616,	0x9617,	0x9619,	0x961A,	0x4E2C,	0x723F,	0x6215,	0x6C35,
	0x6C54,	0x6C5C,	0x6C4A,	0x6CA3,	0x6C85,	0x6C90,	0x6C94,	0x6C8C,
	0x6C68,	0x6C69,	0x6C74,	0x6C76,	0x6C86,	0x6CA9,	0x6CD0,	0x6CD4,
	0x6CAD,	0x6CF7,	0x6CF8,	0x6CF1,	0x6CD7,	0x6CB2,	0x6CE0,	0x6CD6,
	0x6CFA,	0x6CEB,	0x6CEE,	0x6CB1,	0x6CD3,	0x6CEF,	0x6CFE,
	/* GB 0xE440..0xE47E */
	0x92A8,	0x92A9,	0x92AA,	0x92AB,	0x92AC,	0x92AD,	0x92AF,	0x92B0,
	0x92B1,	0x92B2,	0x92B3,	0x92B4,	0x92B5,	0x92B6,	0x92B7,	0x92B8,
	0x92B9,	0x92BA,	0x92BB,	0x92BC,	0x92BD,	0x92BE,	0x92BF,	0x92C0,
	0x92C1,	0x92C2,	0x92C3,	0x92C4,	0x92C5,	0x92C6,	0x92C7,	0x92C9,
	0x92CA,	0x92CB,	0x92CC,	0x92CD,	0x92CE,	0x92CF,	0x92D0,	0x92D1,
	0x92D2,	0x92D3,	0x92D4,	0x92D5,	0x92D6,	0x92D7,	0x92D8,	0x92D9,
	0x92DA,	0x92DB,	0x92DC,	0x92DD,	0x92DE,	0x92DF,	0x92E0,	0x92E1,
	0x92E2,	0x92E3,	0x92E4,	0x92E5,	0x92E6,	0x92E7,	0x92E8,
	/* GB 0xE480..0xE4FE */
	0x92E9,	0x92EA,	0x92EB,	0x92EC,	0x92ED,	0x92EE,	0x92EF,	0x92F0,
	0x92F1,	0x92F2,	0x92F3,	0x92F4,	0x92F5,	0x92F6,	0x92F7,	0x92F8,
	0x92F9,	0x92FA,	0x92FB,	0x92FC,	0x92FD,	0x92FE,	0x92FF,	0x9300,
	0x9301,	0x9302,	0x9303,	0x9304,	0x9305,	0x9306,	0x9307,	0x9308,
	0x9309,	0x6D39,	0x6D27,	0x6D0C,	0x6D43,	0x6D48,	0x6D07,	0x6D04,
	0x6D19,	0x6D0E,	0x6D2B,	0x6D4D,	0x6D2E,	0x6D35,	0x6D1A,	0x6D4F,
	0x6D52,	0x6D54,	0x6D33,	0x6D91,	0x6D6F,	0x6D9E,	0x6DA0,	0x6D5E,
	0x6D93,	0x6D94,	0x6D5C,	0x6D60,	0x6D7C,	0x6D63,	0x6E1A,	0x6DC7,
	0x6DC5,	0x6DDE,	0x6E0E,	0x6DBF,	0x6DE0,	0x6E11,	0x6DE6,	0x6DDD,
	0x6DD9,	0x6E16,	0x6DAB,	0x6E0C,	0x6DAE,	0x6E2B,	0x6E6E,	0x6E4E,
	0x6E6B,	0x6EB2,	0x6E5F,	0x6E86,	0x6E53,	0x6E54,	0x6E32,	0x6E25,
	0x6E44,	0x6EDF,	0x6EB1,	0x6E98,	0x6EE0,	0x6F2D,	0x6EE2,	0x6EA5,
	0x6EA7,	0x6EBD,	0x6EBB,	0x6EB7,	0x6ED7,	0x6EB4,	0x6ECF,	0x6E8F,
	0x6EC2,	0x6E9F,	0x6F62,	0x6F46,	0x6F47,	0x6F24,	0x6F15,	0x6EF9,
	0x6F2F,	0x6F36,	0x6F4B,	0x6F74,	0x6F2A,	0x6F09,	0x6F29,	0x6F89,
	0x6F8D,	0x6F8C,	0x6F78,	0x6F72,	0x6F7C,	0x6F7A,	0x6FD1,
	/* GB 0xE540..0xE57E */
	0x930A,	0x930B,	0x930C,	0x930D,	0x930E,	0x930F,	0x9310,	0x9311,
	0x9312,	0x9313,	0x9314,	0x9315,	0x9316,	0x9317,	0x9318,	0x9319,
	0x931A,	0x931B,	0x931C,	0x931D,	0x931E,	0x931F,	0x9320,	0x9321,
	0x9322,	0x9323,	0x9324,	0x9325,	0x9326,	0x9327,	0x9328,	0x9329,
	0x932A,	0x932B,	0x932C,	0x932D,	0x932E,	0x932F,	0x9330,	0x9331,
	0x9332,	0x9333,	0x9334,	0x9335,	0x9336,	0x9337,	0x9338,	0x9339,
	0x933A,	0x933B,	0x933C,	0x933D,	0x933F,	0x9340,	0x9341,	0x9342,
	0x9343,	0x9344,	0x9345,	0x9346,	0x9347,	0x9348,	0x9349,
	/* GB 0xE580..0xE5FE */
	0x934A,	0x934B,	0x934C,	0x934D,	0x934E,	0x934F,	0x9350,	0x9351,
	0x9352,	0x9353,	0x9354,	0x9355,	0x9356,	0x9357,	0x9358,	0x9359,
	0x935A,	0x935B,	0x935C,	0x935D,	0x935E,	0x935F,	0x9360,	0x9361,
	0x9362,	0x9363,	0x9364,	0x9365,	0x9366,	0x9367,	0x9368,	0x9369,
	0x936B,	0x6FC9,	0x6FA7,	0x6FB9,	0x6FB6,	0x6FC2,	0x6FE1,	0x6FEE,
	0x6FDE,	0x6FE0,	0x6FEF,	0x701A,	0x7023,	0x701B,	0x7039,	0x7035,
	0x704F,	0x705E,	0x5B80,	0x5B84,	0x5B95,	0x5B93,	0x5BA5,	0x5BB8,
	0x752F,	0x9A9E,	0x6434,	0x5BE4,	0x5BEE,	0x8930,	0x5BF0,	0x8E47,
	0x8B07,	0x8FB6,	0x8FD3,	0x8FD5,	0x8FE5,	0x8FEE,	0x8FE4,	0x8FE9,
	0x8FE6,	0x8FF3,	0x8FE8,	0x9005,	0x9004,	0x900B,	0x9026,	0x9011,
	0x900D,	0x9016,	0x9021,	0x9035,	0x9036,	0x902D,	0x902F,	0x9044,
	0x9051,	0x9052,	0x9050,	0x9068,	0x9058,	0x9062,	0x905B,	0x66B9,
	0x9074,	0x907D,	0x9082,	0x9088,	0x9083,	0x908B,	0x5F50,	0x5F57,
	0x5F56,	0x5F58,	0x5C3B,	0x54AB,	0x5C50,	0x5C59,	0x5B71,	0x5C63,
	0x5C66,	0x7FBC,	0x5F2A,	0x5F29,	0x5F2D,	0x8274,	0x5F3C,	0x9B3B,
	0x5C6E,	0x5981,	0x5983,	0x598D,	0x59A9,	0x59AA,	0x59A3,
	/* GB 0xE640..0xE67E */
	0x936C,	0x936D,	0x936E,	0x936F,	0x9370,	0x9371,	0x9372,	0x9373,
	0x9374,	0x9375,	0x9376,	0x9377,	0x9378,	0x9379,	0x937A,	0x937B,
	0x937C,	0x937D,	0x937E,	0x937F,	0x9380,	0x9381,	0x9382,	0x9383,
	0x9384,	0x9385,	0x9386,	0x9387,	0x9388,	0x9389,	0x938A,	0x938B,
	0x938C,	0x938D,	0x938E,	0x9390,	0x9391,	0x9392,	0x9393,	0x9394,
	0x9395,	0x9396,	0x9397,	0x9398,	0x9399,	0x939A,	0x939B,	0x939C,
	0x939D,	0x939E,	0x939F,	0x93A0,	0x93A1,	0x93A2,	0x93A3,	0x93A4,
	0x93A5,	0x93A6,	0x93A7,	0x93A8,	0x93A9,	0x93AA,	0x93AB,
	/* GB 0xE680..0xE6FE */
	0x93AC,	0x93AD,	0x93AE,	0x93AF,	0x93B0,	0x93B1,	0x93B2,	0x93B3,
	0x93B4,	0x93B5,	0x93B6,	0x93B7,	0x93B8,	0x93B9,	0x93BA,	0x93BB,
	0x93BC,	0x93BD,	0x93BE,	0x93BF,	0x93C0,	0x93C1,	0x93C2,	0x93C3,
	0x93C4,	0x93C5,	0x93C6,	0x93C7,	0x93C8,	0x93C9,	0x93CB,	0x93CC,
	0x93CD,	0x5997,	0x59CA,	0x59AB,	0x599E,	0x59A4,	0x59D2,	0x59B2,
	0x59AF,	0x59D7,	0x59BE,	0x5A05,	0x5A06,	0x59DD,	0x5A08,	0x59E3,
	0x59D8,	0x59F9,	0x5A0C,	0x5A09,	0x5A32,	0x5A34,	0x5A11,	0x5A23,
	0x5A13,	0x5A40,	0x5A67,	0x5A4A,	0x5A55,	0x5A3C,	0x5A62,	0x5A75,
	0x80EC,	0x5AAA,	0x5A9B,	0x5A77,	0x5A7A,	0x5ABE,	0x5AEB,	0x5AB2,
	0x5AD2,	0x5AD4,	0x5AB8,	0x5AE0,	0x5AE3,	0x5AF1,	0x5AD6,	0x5AE6,
	0x5AD8,	0x5ADC,	0x5B09,	0x5B17,	0x5B16,	0x5B32,	0x5B37,	0x5B40,
	0x5C15,	0x5C1C,	0x5B5A,	0x5B65,	0x5B73,	0x5B51,	0x5B53,	0x5B62,
	0x9A75,	0x9A77,	0x9A78,	0x9A7A,	0x9A7F,	0x9A7D,	0x9A80,	0x9A81,
	0x9A85,	0x9A88,	0x9A8A,	0x9A90,	0x9A92,	0x9A93,	0x9A96,	0x9A98,
	0x9A9B,	0x9A9C,	0x9A9D,	0x9A9F,	0x9AA0,	0x9AA2,	0x9AA3,	0x9AA5,
	0x9AA7,	0x7E9F,	0x7EA1,	0x7EA3,	0x7EA5,	0x7EA8,	0x7EA9,
	/* GB 0xE740..0xE77E */
	0x93CE,	0x93CF,	0x93D0,	0x93D1,	0x93D2,	0x93D3,	0x93D4,	0x93D5,
	0x93D7,	0x93D8,	0x93D9,	0x93DA,	0x93DB,	0x93DC,	0x93DD,	0x93DE,
	0x93DF,	0x93E0,	0x93E1,	0x93E2,	0x93E3,	0x93E4,	0x93E5,	0x93E6,
	0x93E7,	0x93E8,	0x93E9,	0x93EA,	0x93EB,	0x93EC,	0x93ED,	0x93EE,
	0x93EF,	0x93F0,	0x93F1,	0x93F2,	0x93F3,	0x93F4,	0x93F5,	0x93F6,
	0x93F7,	0x93F8,	0x93F9,	0x93FA,	0x93FB,	0x93FC,	0x93FD,	0x93FE,
	0x93FF,	0x9400,	0x9401,	0x9402,	0x9403,	0x9404,	0x9405,	0x9406,
	0x9407,	0x9408,	0x9409,	0x940A,	0x940B,	0x940C,	0x940D,
	/* GB 0xE780..0xE7FE */
	0x940E,	0x940F,	0x9410,	0x9411,	0x9412,	0x9413,	0x9414,	0x9415,
	0x9416,	0x9417,	0x9418,	0x9419,	0x941A,	0x941B,	0x941C,	0x941D,
	0x941E,	0x941F,	0x9420,	0x9421,	0x9422,	0x9423,	0x9424,	0x9425,
	0x9426,	0x9427,	0x9428,	0x9429,	0x942A,	0x942B,	0x942C,	0x942D,
	0x942E,	0x7EAD,	0x7EB0,	0x7EBE,	0x7EC0,	0x7EC1,	0x7EC2,	0x7EC9,
	0x7ECB,	0x7ECC,	0x7ED0,	0x7ED4,	0x7ED7,	0x7EDB,	0x7EE0,	0x7EE1,
	0x7EE8,	0x7EEB,	0x7EEE,	0x7EEF,	0x7EF1,	0x7EF2,	0x7F0D,	0x7EF6,
	0x7EFA,	0x7EFB,	0x7EFE,	0x7F01,	0x7F02,	0x7F03,	0x7F07,	0x7F08,
	0x7F0B,	0x7F0C,	0x7F0F,	0x7F11,	0x7F12,	0x7F17,	0x7F19,	0x7F1C,
	0x7F1B,	0x7F1F,	0x7F21,	0x7F22,	0x7F23,	0x7F24,	0x7F25,	0x7F26,
	0x7F27,	0x7F2A,	0x7F2B,	0x7F2C,	0x7F2D,	0x7F2F,	0x7F30,	0x7F31,
	0x7F32,	0x7F33,	0x7F35,	0x5E7A,	0x757F,	0x5DDB,	0x753E,	0x9095,
	0x738E,	0x7391,	0x73AE,	0x73A2,	0x739F,	0x73CF,	0x73C2,	0x73D1,
	0x73B7,	0x73B3,	0x73C0,	0x73C9,	0x73C8,	0x73E5,	0x73D9,	0x987C,
	0x740A,	0x73E9,	0x73E7,	0x73DE,	0x73BA,	0x73F2,	0x740F,	0x742A,
	0x745B,	0x7426,	0x7425,	0x7428,	0x7430,	0x742E,	0x742C,
	/* GB 0xE840..0xE87E */
	0x942F,	0x9430,	0x9431,	0x9432,	0x9433,	0x9434,	0x9435,	0x9436,
	0x9437,	0x9438,	0x9439,	0x943A,	0x943B,	0x943C,	0x943D,	0x943F,
	0x9440,	0x9441,	0x9442,	0x9443,	0x9444,	0x9445,	0x9446,	0x9447,
	0x9448,	0x9449,	0x944A,	0x944B,	0x944C,	0x944D,	0x944E,	0x944F,
	0x9450,	0x9451,	0x9452,	0x9453,	0x9454,	0x9455,	0x9456,	0x9457,
	0x9458,	0x9459,	0x945A,	0x945B,	0x945C,	0x945D,	0x945E,	0x945F,
	0x9460,	0x9461,	0x9462,	0x9463,	0x9464,	0x9465,	0x9466,	0x9467,
	0x9468,	0x9469,	0x946A,	0x946C,	0x946D,	0x946E,	0x946F,
	/* GB 0xE880..0xE8FE */
	0x9470,	0x9471,	0x9472,	0x9473,	0x9474,	0x9475,	0x9476,	0x9477,
	0x9478,	0x9479,	0x947A,	0x947B,	0x947C,	0x947D,	0x947E,	0x947F,
	0x9480,	0x9481,	0x9482,	0x9483,	0x9484,	0x9491,	0x9496,	0x9498,
	0x94C7,	0x94CF,	0x94D3,	0x94D4,	0x94DA,	0x94E6,	0x94FB,	0x951C,
	0x9520,	0x741B,	0x741A,	0x7441,	0x745C,	0x7457,	0x7455,	0x7459,
	0x7477,	0x746D,	0x747E,	0x749C,	0x748E,	0x7480,	0x7481,	0x7487,
	0x748B,	0x749E,	0x74A8,	0x74A9,	0x7490,	0x74A7,	0x74D2,	0x74BA,
	0x97EA,	0x97EB,	0x97EC,	0x674C,	0x6753,	0x675E,	0x6748,	0x6769,
	0x67A5,	0x6787,	0x676A,	0x6773,	0x6798,	0x67A7,	0x6775,	0x67A8,
	0x679E,	0x67AD,	0x678B,	0x6777,	0x677C,	0x67F0,	0x6809,	0x67D8,
	0x680A,	0x67E9,	0x67B0,	0x680C,	0x67D9,	0x67B5,	0x67DA,	0x67B3,
	0x67DD,	0x6800,	0x67C3,	0x67B8,	0x67E2,	0x680E,	0x67C1,	0x67FD,
	0x6832,	0x6833,	0x6860,	0x6861,	0x684E,	0x6862,	0x6844,	0x6864,
	0x6883,	0x681D,	0x6855,	0x6866,	0x6841,	0x6867,	0x6840,	0x683E,
	0x684A,	0x6849,	0x6829,	0x68B5,	0x688F,	0x6874,	0x6877,	0x6893,
	0x686B,	0x68C2,	0x696E,	0x68FC,	0x691F,	0x6920,	0x68F9,
	/* GB 0xE940..0xE97E */
	0x9527,	0x9533,	0x953D,	0x9543,	0x9548,	0x954B,	0x9555,	0x955A,
	0x9560,	0x956E,	0x9574,	0x9575,	0x9577,	0x9578,	0x9579,	0x957A,
	0x957B,	0x957C,	0x957D,	0x957E,	0x9580,	0x9581,	0x9582,	0x9583,
	0x9584,	0x9585,	0x9586,	0x9587,	0x9588,	0x9589,	0x958A,	0x958B,
	0x958C,	0x958D,	0x958E,	0x958F,	0x9590,	0x9591,	0x9592,	0x9593,
	0x9594,	0x9595,	0x9596,	0x9597,	0x9598,	0x9599,	0x959A,	0x959B,
	0x959C,	0x959D,	0x959E,	0x959F,	0x95A0,	0x95A1,	0x95A2,	0x95A3,
	0x95A4,	0x95A5,	0x95A6,	0x95A7,	0x95A8,	0x95A9,	0x95AA,
	/* GB 0xE980..0xE9FE */
	0x95AB,	0x95AC,	0x95AD,	0x95AE,	0x95AF,	0x95B0,	0x95B1,	0x95B2,
	0x95B3,	0x95B4,	0x95B5,	0x95B6,	0x95B7,	0x95B8,	0x95B9,	0x95BA,
	0x95BB,	0x95BC,	0x95BD,	0x95BE,	0x95BF,	0x95C0,	0x95C1,	0x95C2,
	0x95C3,	0x95C4,	0x95C5,	0x95C6,	0x95C7,	0x95C8,	0x95C9,	0x95CA,
	0x95CB,	0x6924,	0x68F0,	0x690B,	0x6901,	0x6957,	0x68E3,	0x6910,
	0x6971,	0x6939,	0x6960,	0x6942,	0x695D,	0x6984,	0x696B,	0x6980,
	0x6998,	0x6978,	0x6934,	0x69CC,	0x6987,	0x6988,	0x69CE,	0x6989,
	0x6966,	0x6963,	0x6979,	0x699B,	0x69A7,	0x69BB,	0x69AB,	0x69AD,
	0x69D4,	0x69B1,	0x69C1,	0x69CA,	0x69DF,	0x6995,	0x69E0,	0x698D,
	0x69FF,	0x6A2F,	0x69ED,	0x6A17,	0x6A18,	0x6A65,	0x69F2,	0x6A44,
	0x6A3E,	0x6AA0,	0x6A50,	0x6A5B,	0x6A35,	0x6A8E,	0x6A79,	0x6A3D,
	0x6A28,	0x6A58,	0x6A7C,	0x6A91,	0x6A90,	0x6AA9,	0x6A97,	0x6AAB,
	0x7337,	0x7352,	0x6B81,	0x6B82,	0x6B87,	0x6B84,	0x6B92,	0x6B93,
	0x6B8D,	0x6B9A,	0x6B9B,	0x6BA1,	0x6BAA,	0x8F6B,	0x8F6D,	0x8F71,
	0x8F72,	0x8F73,	0x8F75,	0x8F76,	0x8F78,	0x8F77,	0x8F79,	0x8F7A,
	0x8F7C,	0x8F7E,	0x8F81,	0x8F82,	0x8F84,	0x8F87,	0x8F8B,
	/* GB 0xEA40..0xEA7E */
	0x95CC,	0x95CD,	0x95CE,	0x95CF,	0x95D0,	0x95D1,	0x95D2,	0x95D3,
	0x95D4,	0x95D5,	0x95D6,	0x95D7,	0x95D8,	0x95D9,	0x95DA,	0x95DB,
	0x95DC,	0x95DD,	0x95DE,	0x95DF,	0x95E0,	0x95E1,	0x95E2,	0x95E3,
	0x95E4,	0x95E5,	0x95E6,	0x95E7,	0x95EC,	0x95FF,	0x9607,	0x9613,
	0x9618,	0x961B,	0x961E,	0x9620,	0x9623,	0x9624,	0x9625,	0x9626,
	0x9627,	0x9628,	0x9629,	0x962B,	0x962C,	0x962D,	0x962F,	0x9630,
	0x9637,	0x9638,	0x9639,	0x963A,	0x963E,	0x9641,	0x9643,	0x964A,
	0x964E,	0x964F,	0x9651,	0x9652,	0x9653,	0x9656,	0x9657,
	/* GB 0xEA80..0xEAFE */
	0x9658,	0x9659,	0x965A,	0x965C,	0x965D,	0x965E,	0x9660,	0x9663,
	0x9665,	0x9666,	0x966B,	0x966D,	0x966E,	0x966F,	0x9670,	0x9671,
	0x9673,	0x9678,	0x9679,	0x967A,	0x967B,	0x967C,	0x967D,	0x967E,
	0x967F,	0x9680,	0x9681,	0x9682,	0x9683,	0x9684,	0x9687,	0x9689,
	0x968A,	0x8F8D,	0x8F8E,	0x8F8F,	0x8F98,	0x8F9A,	0x8ECE,	0x620B,
	0x6217,	0x621B,	0x621F,	0x6222,	0x6221,	0x6225,	0x6224,	0x622C,
	0x81E7,	0x74EF,	0x74F4,	0x74FF,	0x750F,	0x7511,	0x7513,	0x6534,
	0x65EE,	0x65EF,	0x65F0,	0x660A,	0x6619,	0x6772,	0x6603,	0x6615,
	0x6600,	0x7085,	0x66F7,	0x661D,	0x6634,	0x6631,	0x6636,	0x6635,
	0x8006,	0x665F,	0x6654,	0x6641,	0x664F,	0x6656,	0x6661,	0x6657,
	0x6677,	0x6684,	0x668C,	0x66A7,	0x669D,	0x66BE,	0x66DB,	0x66DC,
	0x66E6,	0x66E9,	0x8D32,	0x8D33,	0x8D36,	0x8D3B,	0x8D3D,	0x8D40,
	0x8D45,	0x8D46,	0x8D48,	0x8D49,	0x8D47,	0x8D4D,	0x8D55,	0x8D59,
	0x89C7,	0x89CA,	0x89CB,	0x89CC,	0x89CE,	0x89CF,	0x89D0,	0x89D1,
	0x726E,	0x729F,	0x725D,	0x7266,	0x726F,	0x727E,	0x727F,	0x7284,
	0x728B,	0x728D,	0x728F,	0x7292,	0x6308,	0x6332,	0x63B0,
	/* GB 0xEB40..0xEB7E */
	0x968C,	0x968E,	0x9691,	0x9692,	0x9693,	0x9695,	0x9696,	0x969A,
	0x969B,	0x969D,	0x969E,	0x969F,	0x96A0,	0x96A1,	0x96A2,	0x96A3,
	0x96A4,	0x96A5,	0x96A6,	0x96A8,	0x96A9,	0x96AA,	0x96AB,	0x96AC,
	0x96AD,	0x96AE,	0x96AF,	0x96B1,	0x96B2,	0x96B4,	0x96B5,	0x96B7,
	0x96B8,	0x96BA,	0x96BB,	0x96BF,	0x96C2,	0x96C3,	0x96C8,	0x96CA,
	0x96CB,	0x96D0,	0x96D1,	0x96D3,	0x96D4,	0x96D6,	0x96D7,	0x96D8,
	0x96D9,	0x96DA,	0x96DB,	0x96DC,	0x96DD,	0x96DE,	0x96DF,	0x96E1,
	0x96E2,	0x96E3,	0x96E4,	0x96E5,	0x96E6,	0x96E7,	0x96EB,
	/* GB 0xEB80..0xEBFE */
	0x96EC,	0x96ED,	0x96EE,	0x96F0,	0x96F1,	0x96F2,	0x96F4,	0x96F5,
	0x96F8,	0x96FA,	0x96FB,	0x96FC,	0x96FD,	0x96FF,	0x9702,	0x9703,
	0x9705,	0x970A,	0x970B,	0x970C,	0x9710,	0x9711,	0x9712,	0x9714,
	0x9715,	0x9717,	0x9718,	0x9719,	0x971A,	0x971B,	0x971D,	0x971F,
	0x9720,	0x643F,	0x64D8,	0x8004,	0x6BEA,	0x6BF3,	0x6BFD,	0x6BF5,
	0x6BF9,	0x6C05,	0x6C07,	0x6C06,	0x6C0D,	0x6C15,	0x6C18,	0x6C19,
	0x6C1A,	0x6C21,	0x6C29,	0x6C24,	0x6C2A,	0x6C32,	0x6535,	0x6555,
	0x656B,	0x724D,	0x7252,	0x7256,	0x7230,	0x8662,	0x5216,	0x809F,
	0x809C,	0x8093,	0x80BC,	0x670A,	0x80BD,	0x80B1,	0x80AB,	0x80AD,
	0x80B4,	0x80B7,	0x80E7,	0x80E8,	0x80E9,	0x80EA,	0x80DB,	0x80C2,
	0x80C4,	0x80D9,	0x80CD,	0x80D7,	0x6710,	0x80DD,	0x80EB,	0x80F1,
	0x80F4,	0x80ED,	0x810D,	0x810E,	0x80F2,	0x80FC,	0x6715,	0x8112,
	0x8C5A,	0x8136,	0x811E,	0x812C,	0x8118,	0x8132,	0x8148,	0x814C,
	0x8153,	0x8174,	0x8159,	0x815A,	0x8171,	0x8160,	0x8169,	0x817C,
	0x817D,	0x816D,	0x8167,	0x584D,	0x5AB5,	0x8188,	0x8182,	0x8191,
	0x6ED5,	0x81A3,	0x81AA,	0x81CC,	0x6726,	0x81CA,	0x81BB,
	/* GB 0xEC40..0xEC7E */
	0x9721,	0x9722,	0x9723,	0x9724,	0x9725,	0x9726,	0x9727,	0x9728,
	0x9729,	0x972B,	0x972C,	0x972E,	0x972F,	0x9731,	0x9733,	0x9734,
	0x9735,	0x9736,	0x9737,	0x973A,	0x973B,	0x973C,	0x973D,	0x973F,
	0x9740,	0x9741,	0x9742,	0x9743,	0x9744,	0x9745,	0x9746,	0x9747,
	0x9748,	0x9749,	0x974A,	0x974B,	0x974C,	0x974D,	0x974E,	0x974F,
	0x9750,	0x9751,	0x9754,	0x9755,	0x9757,	0x9758,	0x975A,	0x975C,
	0x975D,	0x975F,	0x9763,	0x9764,	0x9766,	0x9767,	0x9768,	0x976A,
	0x976B,	0x976C,	0x976D,	0x976E,	0x976F,	0x9770,	0x9771,
	/* GB 0xEC80..0xECFE */
	0x9772,	0x9775,	0x9777,	0x9778,	0x9779,	0x977A,	0x977B,	0x977D,
	0x977E,	0x977F,	0x9780,	0x9781,	0x9782,	0x9783,	0x9784,	0x9786,
	0x9787,	0x9788,	0x9789,	0x978A,	0x978C,	0x978E,	0x978F,	0x9790,
	0x9793,	0x9795,	0x9796,	0x9797,	0x9799,	0x979A,	0x979B,	0x979C,
	0x979D,	0x81C1,	0x81A6,	0x6B24,	0x6B37,	0x6B39,	0x6B43,	0x6B46,
	0x6B59,	0x98D1,	0x98D2,	0x98D3,	0x98D5,	0x98D9,	0x98DA,	0x6BB3,
	0x5F40,	0x6BC2,	0x89F3,	0x6590,	0x9F51,	0x6593,	0x65BC,	0x65C6,
	0x65C4,	0x65C3,	0x65CC,	0x65CE,	0x65D2,	0x65D6,	0x7080,	0x709C,
	0x7096,	0x709D,	0x70BB,	0x70C0,	0x70B7,	0x70AB,	0x70B1,	0x70E8,
	0x70CA,	0x7110,	0x7113,	0x7116,	0x712F,	0x7131,	0x7173,	0x715C,
	0x7168,	0x7145,	0x7172,	0x714A,	0x7178,	0x717A,	0x7198,	0x71B3,
	0x71B5,	0x71A8,	0x71A0,	0x71E0,	0x71D4,	0x71E7,	0x71F9,	0x721D,
	0x7228,	0x706C,	0x7118,	0x7166,	0x71B9,	0x623E,	0x623D,	0x6243,
	0x6248,	0x6249,	0x793B,	0x7940,	0x7946,	0x7949,	0x795B,	0x795C,
	0x7953,	0x795A,	0x7962,	0x7957,	0x7960,	0x796F,	0x7967,	0x797A,
	0x7985,	0x798A,	0x799A,	0x79A7,	0x79B3,	0x5FD1,	0x5FD0,
	/* GB 0xED40..0xED7E */
	0x979E,	0x979F,	0x97A1,	0x97A2,	0x97A4,	0x97A5,	0x97A6,	0x97A7,
	0x97A8,	0x97A9,	0x97AA,	0x97AC,	0x97AE,	0x97B0,	0x97B1,	0x97B3,
	0x97B5,	0x97B6,	0x97B7,	0x97B8,	0x97B9,	0x97BA,	0x97BB,	0x97BC,
	0x97BD,	0x97BE,	0x97BF,	0x97C0,	0x97C1,	0x97C2,	0x97C3,	0x97C4,
	0x97C5,	0x97C6,	0x97C7,	0x97C8,	0x97C9,	0x97CA,	0x97CB,	0x97CC,
	0x97CD,	0x97CE,	0x97CF,	0x97D0,	0x97D1,	0x97D2,	0x97D3,	0x97D4,
	0x97D5,	0x97D6,	0x97D7,	0x97D8,	0x97D9,	0x97DA,	0x97DB,	0x97DC,
	0x97DD,	0x97DE,	0x97DF,	0x97E0,	0x97E1,	0x97E2,	0x97E3,
	/* GB 0xED80..0xEDFE */
	0x97E4,	0x97E5,	0x97E8,	0x97EE,	0x97EF,	0x97F0,	0x97F1,	0x97F2,
	0x97F4,	0x97F7,	0x97F8,	0x97F9,	0x97FA,	0x97FB,	0x97FC,	0x97FD,
	0x97FE,	0x97FF,	0x9800,	0x9801,	0x9802,	0x9803,	0x9804,	0x9805,
	0x9806,	0x9807,	0x9808,	0x9809,	0x980A,	0x980B,	0x980C,	0x980D,
	0x980E,	0x603C,	0x605D,	0x605A,	0x6067,	0x6041,	0x6059,	0x6063,
	0x60AB,	0x6106,	0x610D,	0x615D,	0x61A9,	0x619D,	0x61CB,	0x61D1,
	0x6206,	0x8080,	0x807F,	0x6C93,	0x6CF6,	0x6DFC,	0x77F6,	0x77F8,
	0x7800,	0x7809,	0x7817,	0x7818,	0x7811,	0x65AB,	0x782D,	0x781C,
	0x781D,	0x7839,	0x783A,	0x783B,	0x781F,	0x783C,	0x7825,	0x782C,
	0x7823,	0x7829,	0x784E,	0x786D,	0x7856,	0x7857,	0x7826,	0x7850,
	0x7847,	0x784C,	0x786A,	0x789B,	0x7893,	0x789A,	0x7887,	0x789C,
	0x78A1,	0x78A3,	0x78B2,	0x78B9,	0x78A5,	0x78D4,	0x78D9,	0x78C9,
	0x78EC,	0x78F2,	0x7905,	0x78F4,	0x7913,	0x7924,	0x791E,	0x7934,
	0x9F9B,	0x9EF9,	0x9EFB,	0x9EFC,	0x76F1,	0x7704,	0x770D,	0x76F9,
	0x7707,	0x7708,	0x771A,	0x7722,	0x7719,	0x772D,	0x7726,	0x7735,
	0x7738,	0x7750,	0x7751,	0x7747,	0x7743,	0x775A,	0x7768,
	/* GB 0xEE40..0xEE7E */
	0x980F,	0x9810,	0x9811,	0x9812,	0x9813,	0x9814,	0x9815,	0x9816,
	0x9817,	0x9818,	0x9819,	0x981A,	0x981B,	0x981C,	0x981D,	0x981E,
	0x981F,	0x9820,	0x9821,	0x9822,	0x9823,	0x9824,	0x9825,	0x9826,
	0x9827,	0x9828,	0x9829,	0x982A,	0x982B,	0x982C,	0x982D,	0x982E,
	0x982F,	0x9830,	0x9831,	0x9832,	0x9833,	0x9834,	0x9835,	0x9836,
	0x9837,	0x9838,	0x9839,	0x983A,	0x983B,	0x983C,	0x983D,	0x983E,
	0x983F,	0x9840,	0x9841,	0x9842,	0x9843,	0x9844,	0x9845,	0x9846,
	0x9847,	0x9848,	0x9849,	0x984A,	0x984B,	0x984C,	0x984D,
	/* GB 0xEE80..0xEEFE */
	0x984E,	0x984F,	0x9850,	0x9851,	0x9852,	0x9853,	0x9854,	0x9855,
	0x9856,	0x9857,	0x9858,	0x9859,	0x985A,	0x985B,	0x985C,	0x985D,
	0x985E,	0x985F,	0x9860,	0x9861,	0x9862,	0x9863,	0x9864,	0x9865,
	0x9866,	0x9867,	0x9868,	0x9869,	0x986A,	0x986B,	0x986C,	0x986D,
	0x986E,	0x7762,	0x7765,	0x777F,	0x778D,	0x777D,	0x7780,	0x778C,
	0x7791,	0x779F,	0x77A0,	0x77B0,	0x77B5,	0x77BD,	0x753A,	0x7540,
	0x754E,	0x754B,	0x7548,	0x755B,	0x7572,	0x7579,	0x7583,	0x7F58,
	0x7F61,	0x7F5F,	0x8A48,	0x7F68,	0x7F74,	0x7F71,	0x7F79,	0x7F81,
	0x7F7E,	0x76CD,	0x76E5,	0x8832,	0x9485,	0x9486,	0x9487,	0x948B,
	0x948A,	0x948C,	0x948D,	0x948F,	0x9490,	0x9494,	0x9497,	0x9495,
	0x949A,	0x949B,	0x949C,	0x94A3,	0x94A4,	0x94AB,	0x94AA,	0x94AD,
	0x94AC,	0x94AF,	0x94B0,	0x94B2,	0x94B4,	0x94B6,	0x94B7,	0x94B8,
	0x94B9,	0x94BA,	0x94BC,	0x94BD,	0x94BF,	0x94C4,	0x94C8,	0x94C9,
	0x94CA,	0x94CB,	0x94CC,	0x94CD,	0x94CE,	0x94D0,	0x94D1,	0x94D2,
	0x94D5,	0x94D6,	0x94D7,	0x94D9,	0x94D8,	0x94DB,	0x94DE,	0x94DF,
	0x94E0,	0x94E2,	0x94E4,	0x94E5,	0x94E7,	0x94E8,	0x94EA,
	/* GB 0xEF40..0xEF7E */
	0x986F,	0x9870,	0x9871,	0x9872,	0x9873,	0x9874,	0x988B,	0x988E,
	0x9892,	0x9895,	0x9899,	0x98A3,	0x98A8,	0x98A9,	0x98AA,	0x98AB,
	0x98AC,	0x98AD,	0x98AE,	0x98AF,	0x98B0,	0x98B1,	0x98B2,	0x98B3,
	0x98B4,	0x98B5,	0x98B6,	0x98B7,	0x98B8,	0x98B9,	0x98BA,	0x98BB,
	0x98BC,	0x98BD,	0x98BE,	0x98BF,	0x98C0,	0x98C1,	0x98C2,	0x98C3,
	0x98C4,	0x98C5,	0x98C6,	0x98C7,	0x98C8,	0x98C9,	0x98CA,	0x98CB,
	0x98CC,	0x98CD,	0x98CF,	0x98D0,	0x98D4,	0x98D6,	0x98D7,	0x98DB,
	0x98DC,	0x98DD,	0x98E0,	0x98E1,	0x98E2,	0x98E3,	0x98E4,
	/* GB 0xEF80..0xEFFE */
	0x98E5,	0x98E6,	0x98E9,	0x98EA,	0x98EB,	0x98EC,	0x98ED,	0x98EE,
	0x98EF,	0x98F0,	0x98F1,	0x98F2,	0x98F3,	0x98F4,	0x98F5,	0x98F6,
	0x98F7,	0x98F8,	0x98F9,	0x98FA,	0x98FB,	0x98FC,	0x98FD,	0x98FE,
	0x98FF,	0x9900,	0x9901,	0x9902,	0x9903,	0x9904,	0x9905,	0x9906,
	0x9907,	0x94E9,	0x94EB,	0x94EE,	0x94EF,	0x94F3,	0x94F4,	0x94F5,
	0x94F7,	0x94F9,	0x94FC,	0x94FD,	0x94FF,	0x9503,	0x9502,	0x9506,
	0x9507,	0x9509,	0x950A,	0x950D,	0x950E,	0x950F,	0x9512,	0x9513,
	0x9514,	0x9515,	0x9516,	0x9518,	0x951B,	0x951D,	0x951E,	0x951F,
	0x9522,	0x952A,	0x952B,	0x9529,	0x952C,	0x9531,	0x9532,	0x9534,
	0x9536,	0x9537,	0x9538,	0x953C,	0x953E,	0x953F,	0x9542,	0x9535,
	0x9544,	0x9545,	0x9546,	0x9549,	0x954C,	0x954E,	0x954F,	0x9552,
	0x9553,	0x9554,	0x9556,	0x9557,	0x9558,	0x9559,	0x955B,	0x955E,
	0x955F,	0x955D,	0x9561,	0x9562,	0x9564,	0x9565,	0x9566,	0x9567,
	0x9568,	0x9569,	0x956A,	0x956B,	0x956C,	0x956F,	0x9571,	0x9572,
	0x9573,	0x953A,	0x77E7,	0x77EC,	0x96C9,	0x79D5,	0x79ED,	0x79E3,
	0x79EB,	0x7A06,	0x5D47,	0x7A03,	0x7A02,	0x7A1E,	0x7A14,
	/* GB 0xF040..0xF07E */
	0x9908,	0x9909,	0x990A,	0x990B,	0x990C,	0x990E,	0x990F,	0x9911,
	0x9912,	0x9913,	0x9914,	0x9915,	0x9916,	0x9917,	0x9918,	0x9919,
	0x991A,	0x991B,	0x991C,	0x991D,	0x991E,	0x991F,	0x9920,	0x9921,
	0x9922,	0x9923,	0x9924,	0x9925,	0x9926,	0x9927,	0x9928,	0x9929,
	0x992A,	0x992B,	0x992C,	0x992D,	0x992F,	0x9930,	0x9931,	0x9932,
	0x9933,	0x9934,	0x9935,	0x9936,	0x9937,	0x9938,	0x9939,	0x993A,
	0x993B,	0x993C,	0x993D,	0x993E,	0x993F,	0x9940,	0x9941,	0x9942,
	0x9943,	0x9944,	0x9945,	0x9946,	0x9947,	0x9948,	0x9949,
	/* GB 0xF080..0xF0FE */
	0x994A,	0x994B,	0x994C,	0x994D,	0x994E,	0x994F,	0x9950,	0x9951,
	0x9952,	0x9953,	0x9956,	0x9957,	0x9958,	0x9959,	0x995A,	0x995B,
	0x995C,	0x995D,	0x995E,	0x995F,	0x9960,	0x9961,	0x9962,	0x9964,
	0x9966,	0x9973,	0x9978,	0x9979,	0x997B,	0x997E,	0x9982,	0x9983,
	0x9989,	0x7A39,	0x7A37,	0x7A51,	0x9ECF,	0x99A5,	0x7A70,	0x7688,
	0x768E,	0x7693,	0x7699,	0x76A4,	0x74DE,	0x74E0,	0x752C,	0x9E20,
	0x9E22,	0x9E28,	0x9E29,	0x9E2A,	0x9E2B,	0x9E2C,	0x9E32,	0x9E31,
	0x9E36,	0x9E38,	0x9E37,	0x9E39,	0x9E3A,	0x9E3E,	0x9E41,	0x9E42,
	0x9E44,	0x9E46,	0x9E47,	0x9E48,	0x9E49,	0x9E4B,	0x9E4C,	0x9E4E,
	0x9E51,	0x9E55,	0x9E57,	0x9E5A,	0x9E5B,	0x9E5C,	0x9E5E,	0x9E63,
	0x9E66,	0x9E67,	0x9E68,	0x9E69,	0x9E6A,	0x9E6B,	0x9E6C,	0x9E71,
	0x9E6D,	0x9E73,	0x7592,	0x7594,	0x7596,	0x75A0,	0x759D,	0x75AC,
	0x75A3,	0x75B3,	0x75B4,	0x75B8,	0x75C4,	0x75B1,	0x75B0,	0x75C3,
	0x75C2,	0x75D6,	0x75CD,	0x75E3,	0x75E8,	0x75E6,	0x75E4,	0x75EB,
	0x75E7,	0x7603,	0x75F1,	0x75FC,	0x75FF,	0x7610,	0x7600,	0x7605,
	0x760C,	0x7617,	0x760A,	0x7625,	0x7618,	0x7615,	0x7619,
	/* GB 0xF140..0xF17E */
	0x998C,	0x998E,	0x999A,	0x999B,	0x999C,	0x999D,	0x999E,	0x999F,
	0x99A0,	0x99A1,	0x99A2,	0x99A3,	0x99A4,	0x99A6,	0x99A7,	0x99A9,
	0x99AA,	0x99AB,	0x99AC,	0x99AD,	0x99AE,	0x99AF,	0x99B0,	0x99B1,
	0x99B2,	0x99B3,	0x99B4,	0x99B5,	0x99B6,	0x99B7,	0x99B8,	0x99B9,
	0x99BA,	0x99BB,	0x99BC,	0x99BD,	0x99BE,	0x99BF,	0x99C0,	0x99C1,
	0x99C2,	0x99C3,	0x99C4,	0x99C5,	0x99C6,	0x99C7,	0x99C8,	0x99C9,
	0x99CA,	0x99CB,	0x99CC,	0x99CD,	0x99CE,	0x99CF,	0x99D0,	0x99D1,
	0x99D2,	0x99D3,	0x99D4,	0x99D5,	0x99D6,	0x99D7,	0x99D8,
	/* GB 0xF180..0xF1FE */
	0x99D9,	0x99DA,	0x99DB,	0x99DC,	0x99DD,	0x99DE,	0x99DF,	0x99E0,
	0x99E1,	0x99E2,	0x99E3,	0x99E4,	0x99E5,	0x99E6,	0x99E7,	0x99E8,
	0x99E9,	0x99EA,	0x99EB,	0x99EC,	0x99ED,	0x99EE,	0x99EF,	0x99F0,
	0x99F1,	0x99F2,	0x99F3,	0x99F4,	0x99F5,	0x99F6,	0x99F7,	0x99F8,
	0x99F9,	0x761B,	0x763C,	0x7622,	0x7620,	0x7640,	0x762D,	0x7630,
	0x763F,	0x7635,	0x7643,	0x763E,	0x7633,	0x764D,	0x765E,	0x7654,
	0x765C,	0x7656,	0x766B,	0x766F,	0x7FCA,	0x7AE6,	0x7A78,	0x7A79,
	0x7A80,	0x7A86,	0x7A88,	0x7A95,	0x7AA6,	0x7AA0,	0x7AAC,	0x7AA8,
	0x7AAD,	0x7AB3,	0x8864,	0x8869,	0x8872,	0x887D,	0x887F,	0x8882,
	0x88A2,	0x88C6,	0x88B7,	0x88BC,	0x88C9,	0x88E2,	0x88CE,	0x88E3,
	0x88E5,	0x88F1,	0x891A,	0x88FC,	0x88E8,	0x88FE,	0x88F0,	0x8921,
	0x8919,	0x8913,	0x891B,	0x890A,	0x8934,	0x892B,	0x8936,	0x8941,
	0x8966,	0x897B,	0x758B,	0x80E5,	0x76B2,	0x76B4,	0x77DC,	0x8012,
	0x8014,	0x8016,	0x801C,	0x8020,	0x8022,	0x8025,	0x8026,	0x8027,
	0x8029,	0x8028,	0x8031,	0x800B,	0x8035,	0x8043,	0x8046,	0x804D,
	0x8052,	0x8069,	0x8071,	0x8983,	0x9878,	0x9880,	0x9883,
	/* GB 0xF240..0xF27E */
	0x99FA,	0x99FB,	0x99FC,	0x99FD,	0x99FE,	0x99FF,	0x9A00,	0x9A01,
	0x9A02,	0x9A03,	0x9A04,	0x9A05,	0x9A06,	0x9A07,	0x9A08,	0x9A09,
	0x9A0A,	0x9A0B,	0x9A0C,	0x9A0D,	0x9A0E,	0x9A0F,	0x9A10,	0x9A11,
	0x9A12,	0x9A13,	0x9A14,	0x9A15,	0x9A16,	0x9A17,	0x9A18,	0x9A19,
	0x9A1A,	0x9A1B,	0x9A1C,	0x9A1D,	0x9A1E,	0x9A1F,	0x9A20,	0x9A21,
	0x9A22,	0x9A23,	0x9A24,	0x9A25,	0x9A26,	0x9A27,	0x9A28,	0x9A29,
	0x9A2A,	0x9A2B,	0x9A2C,	0x9A2D,	0x9A2E,	0x9A2F,	0x9A30,	0x9A31,
	0x9A32,	0x9A33,	0x9A34,	0x9A35,	0x9A36,	0x9A37,	0x9A38,
	/* GB 0xF280..0xF2FE */
	0x9A39,	0x9A3A,	0x9A3B,	0x9A3C,	0x9A3D,	0x9A3E,	0x9A3F,	0x9A40,
	0x9A41,	0x9A42,	0x9A43,	0x9A44,	0x9A45,	0x9A46,	0x9A47,	0x9A48,
	0x9A49,	0x9A4A,	0x9A4B,	0x9A4C,	0x9A4D,	0x9A4E,	0x9A4F,	0x9A50,
	0x9A51,	0x9A52,	0x9A53,	0x9A54,	0x9A55,	0x9A56,	0x9A57,	0x9A58,
	0x9A59,	0x9889,	0x988C,	0x988D,	0x988F,	0x9894,	0x989A,	0x989B,
	0x989E,	0x989F,	0x98A1,	0x98A2,	0x98A5,	0x98A6,	0x864D,	0x8654,
	0x866C,	0x866E,	0x867F,	0x867A,	0x867C,	0x867B,	0x86A8,	0x868D,
	0x868B,	0x86AC,	0x869D,	0x86A7,	0x86A3,	0x86AA,	0x8693,	0x86A9,
	0x86B6,	0x86C4,	0x86B5,	0x86CE,	0x86B0,	0x86BA,	0x86B1,	0x86AF,
	0x86C9,	0x86CF,	0x86B4,	0x86E9,	0x86F1,	0x86F2,	0x86ED,	0x86F3,
	0x86D0,	0x8713,	0x86DE,	0x86F4,	0x86DF,	0x86D8,	0x86D1,	0x8703,
	0x8707,	0x86F8,	0x8708,	0x870A,	0x870D,	0x8709,	0x8723,	0x873B,
	0x871E,	0x8725,	0x872E,	0x871A,	0x873E,	0x8748,	0x8734,	0x8731,
	0x8729,	0x8737,	0x873F,	0x8782,	0x8722,	0x877D,	0x877E,	0x877B,
	0x8760,	0x8770,	0x874C,	0x876E,	0x878B,	0x8753,	0x8763,	0x877C,
	0x8764,	0x8759,	0x8765,	0x8793,	0x87AF,	0x87A8,	0x87D2,
	/* GB 0xF340..0xF37E */
	0x9A5A,	0x9A5B,	0x9A5C,	0x9A5D,	0x9A5E,	0x9A5F,	0x9A60,	0x9A61,
	0x9A62,	0x9A63,	0x9A64,	0x9A65,	0x9A66,	0x9A67,	0x9A68,	0x9A69,
	0x9A6A,	0x9A6B,	0x9A72,	0x9A83,	0x9A89,	0x9A8D,	0x9A8E,	0x9A94,
	0x9A95,	0x9A99,	0x9AA6,	0x9AA9,	0x9AAA,	0x9AAB,	0x9AAC,	0x9AAD,
	0x9AAE,	0x9AAF,	0x9AB2,	0x9AB3,	0x9AB4,	0x9AB5,	0x9AB9,	0x9ABB,
	0x9ABD,	0x9ABE,	0x9ABF,	0x9AC3,	0x9AC4,	0x9AC6,	0x9AC7,	0x9AC8,
	0x9AC9,	0x9ACA,	0x9ACD,	0x9ACE,	0x9ACF,	0x9AD0,	0x9AD2,	0x9AD4,
	0x9AD5,	0x9AD6,	0x9AD7,	0x9AD9,	0x9ADA,	0x9ADB,	0x9ADC,
	/* GB 0xF380..0xF3FE */
	0x9ADD,	0x9ADE,	0x9AE0,	0x9AE2,	0x9AE3,	0x9AE4,	0x9AE5,	0x9AE7,
	0x9AE8,	0x9AE9,	0x9AEA,	0x9AEC,	0x9AEE,	0x9AF0,	0x9AF1,	0x9AF2,
	0x9AF3,	0x9AF4,	0x9AF5,	0x9AF6,	0x9AF7,	0x9AF8,	0x9AFA,	0x9AFC,
	0x9AFD,	0x9AFE,	0x9AFF,	0x9B00,	0x9B01,	0x9B02,	0x9B04,	0x9B05,
	0x9B06,	0x87C6,	0x8788,	0x8785,	0x87AD,	0x8797,	0x8783,	0x87AB,
	0x87E5,	0x87AC,	0x87B5,	0x87B3,	0x87CB,	0x87D3,	0x87BD,	0x87D1,
	0x87C0,	0x87CA,	0x87DB,	0x87EA,	0x87E0,	0x87EE,	0x8816,	0x8813,
	0x87FE,	0x880A,	0x881B,	0x8821,	0x8839,	0x883C,	0x7F36,	0x7F42,
	0x7F44,	0x7F45,	0x8210,	0x7AFA,	0x7AFD,	0x7B08,	0x7B03,	0x7B04,
	0x7B15,	0x7B0A,	0x7B2B,	0x7B0F,	0x7B47,	0x7B38,	0x7B2A,	0x7B19,
	0x7B2E,	0x7B31,	0x7B20,	0x7B25,	0x7B24,	0x7B33,	0x7B3E,	0x7B1E,
	0x7B58,	0x7B5A,	0x7B45,	0x7B75,	0x7B4C,	0x7B5D,	0x7B60,	0x7B6E,
	0x7B7B,	0x7B62,	0x7B72,	0x7B71,	0x7B90,	0x7BA6,	0x7BA7,	0x7BB8,
	0x7BAC,	0x7B9D,	0x7BA8,	0x7B85,	0x7BAA,	0x7B9C,	0x7BA2,	0x7BAB,
	0x7BB4,	0x7BD1,	0x7BC1,	0x7BCC,	0x7BDD,	0x7BDA,	0x7BE5,	0x7BE6,
	0x7BEA,	0x7C0C,	0x7BFE,	0x7BFC,	0x7C0F,	0x7C16,	0x7C0B,
	/* GB 0xF440..0xF47E */
	0x9B07,	0x9B09,	0x9B0A,	0x9B0B,	0x9B0C,	0x9B0D,	0x9B0E,	0x9B10,
	0x9B11,	0x9B12,	0x9B14,	0x9B15,	0x9B16,	0x9B17,	0x9B18,	0x9B19,
	0x9B1A,	0x9B1B,	0x9B1C,	0x9B1D,	0x9B1E,	0x9B20,	0x9B21,	0x9B22,
	0x9B24,	0x9B25,	0x9B26,	0x9B27,	0x9B28,	0x9B29,	0x9B2A,	0x9B2B,
	0x9B2C,	0x9B2D,	0x9B2E,	0x9B30,	0x9B31,	0x9B33,	0x9B34,	0x9B35,
	0x9B36,	0x9B37,	0x9B38,	0x9B39,	0x9B3A,	0x9B3D,	0x9B3E,	0x9B3F,
	0x9B40,	0x9B46,	0x9B4A,	0x9B4B,	0x9B4C,	0x9B4E,	0x9B50,	0x9B52,
	0x9B53,	0x9B55,	0x9B56,	0x9B57,	0x9B58,	0x9B59,	0x9B5A,
	/* GB 0xF480..0xF4FE */
	0x9B5B,	0x9B5C,	0x9B5D,	0x9B5E,	0x9B5F,	0x9B60,	0x9B61,	0x9B62,
	0x9B63,	0x9B64,	0x9B65,	0x9B66,	0x9B67,	0x9B68,	0x9B69,	0x9B6A,
	0x9B6B,	0x9B6C,	0x9B6D,	0x9B6E,	0x9B6F,	0x9B70,	0x9B71,	0x9B72,
	0x9B73,	0x9B74,	0x9B75,	0x9B76,	0x9B77,	0x9B78,	0x9B79,	0x9B7A,
	0x9B7B,	0x7C1F,	0x7C2A,	0x7C26,	0x7C38,	0x7C41,	0x7C40,	0x81FE,
	0x8201,	0x8202,	0x8204,	0x81EC,	0x8844,	0x8221,	0x8222,	0x8223,
	0x822D,	0x822F,	0x8228,	0x822B,	0x8238,	0x823B,	0x8233,	0x8234,
	0x823E,	0x8244,	0x8249,	0x824B,	0x824F,	0x825A,	0x825F,	0x8268,
	0x887E,	0x8885,	0x8888,	0x88D8,	0x88DF,	0x895E,	0x7F9D,	0x7F9F,
	0x7FA7,	0x7FAF,	0x7FB0,	0x7FB2,	0x7C7C,	0x6549,	0x7C91,	0x7C9D,
	0x7C9C,	0x7C9E,	0x7CA2,	0x7CB2,	0x7CBC,	0x7CBD,	0x7CC1,	0x7CC7,
	0x7CCC,	0x7CCD,	0x7CC8,	0x7CC5,	0x7CD7,	0x7CE8,	0x826E,	0x66A8,
	0x7FBF,	0x7FCE,	0x7FD5,	0x7FE5,	0x7FE1,	0x7FE6,	0x7FE9,	0x7FEE,
	0x7FF3,	0x7CF8,	0x7D77,	0x7DA6,	0x7DAE,	0x7E47,	0x7E9B,	0x9EB8,
	0x9EB4,	0x8D73,	0x8D84,	0x8D94,	0x8D91,	0x8DB1,	0x8D67,	0x8D6D,
	0x8C47,	0x8C49,	0x914A,	0x9150,	0x914E,	0x914F,	0x9164,
	/* GB 0xF540..0xF57E */
	0x9B7C,	0x9B7D,	0x9B7E,	0x9B7F,	0x9B80,	0x9B81,	0x9B82,	0x9B83,
	0x9B84,	0x9B85,	0x9B86,	0x9B87,	0x9B88,	0x9B89,	0x9B8A,	0x9B8B,
	0x9B8C,	0x9B8D,	0x9B8E,	0x9B8F,	0x9B90,	0x9B91,	0x9B92,	0x9B93,
	0x9B94,	0x9B95,	0x9B96,	0x9B97,	0x9B98,	0x9B99,	0x9B9A,	0x9B9B,
	0x9B9C,	0x9B9D,	0x9B9E,	0x9B9F,	0x9BA0,	0x9BA1,	0x9BA2,	0x9BA3,
	0x9BA4,	0x9BA5,	0x9BA6,	0x9BA7,	0x9BA8,	0x9BA9,	0x9BAA,	0x9BAB,
	0x9BAC,	0x9BAD,	0x9BAE,	0x9BAF,	0x9BB0,	0x9BB1,	0x9BB2,	0x9BB3,
	0x9BB4,	0x9BB5,	0x9BB6,	0x9BB7,	0x9BB8,	0x9BB9,	0x9BBA,
	/* GB 0xF580..0xF5FE */
	0x9BBB,	0x9BBC,	0x9BBD,	0x9BBE,	0x9BBF,	0x9BC0,	0x9BC1,	0x9BC2,
	0x9BC3,	0x9BC4,	0x9BC5,	0x9BC6,	0x9BC7,	0x9BC8,	0x9BC9,	0x9BCA,
	0x9BCB,	0x9BCC,	0x9BCD,	0x9BCE,	0x9BCF,	0x9BD0,	0x9BD1,	0x9BD2,
	0x9BD3,	0x9BD4,	0x9BD5,	0x9BD6,	0x9BD7,	0x9BD8,	0x9BD9,	0x9BDA,
	0x9BDB,	0x9162,	0x9161,	0x9170,	0x9169,	0x916F,	0x917D,	0x917E,
	0x9172,	0x9174,	0x9179,	0x918C,	0x9185,	0x9190,	0x918D,	0x9191,
	0x91A2,	0x91A3,	0x91AA,	0x91AD,	0x91AE,	0x91AF,	0x91B5,	0x91B4,
	0x91BA,	0x8C55,	0x9E7E,	0x8DB8,	0x8DEB,	0x8E05,	0x8E59,	0x8E69,
	0x8DB5,	0x8DBF,	0x8DBC,	0x8DBA,	0x8DC4,	0x8DD6,	0x8DD7,	0x8DDA,
	0x8DDE,	0x8DCE,	0x8DCF,	0x8DDB,	0x8DC6,	0x8DEC,	0x8DF7,	0x8DF8,
	0x8DE3,	0x8DF9,	0x8DFB,	0x8DE4,	0x8E09,	0x8DFD,	0x8E14,	0x8E1D,
	0x8E1F,	0x8E2C,	0x8E2E,	0x8E23,	0x8E2F,	0x8E3A,	0x8E40,	0x8E39,
	0x8E35,	0x8E3D,	0x8E31,	0x8E49,	0x8E41,	0x8E42,	0x8E51,	0x8E52,
	0x8E4A,	0x8E70,	0x8E76,	0x8E7C,	0x8E6F,	0x8E74,	0x8E85,	0x8E8F,
	0x8E94,	0x8E90,	0x8E9C,	0x8E9E,	0x8C78,	0x8C82,	0x8C8A,	0x8C85,
	0x8C98,	0x8C94,	0x659B,	0x89D6,	0x89DE,	0x89DA,	0x89DC,
	/* GB 0xF640..0xF67E */
	0x9BDC,	0x9BDD,	0x9BDE,	0x9BDF,	0x9BE0,	0x9BE1,	0x9BE2,	0x9BE3,
	0x9BE4,	0x9BE5,	0x9BE6,	0x9BE7,	0x9BE8,	0x9BE9,	0x9BEA,	0x9BEB,
	0x9BEC,	0x9BED,	0x9BEE,	0x9BEF,	0x9BF0,	0x9BF1,	0x9BF2,	0x9BF3,
	0x9BF4,	0x9BF5,	0x9BF6,	0x9BF7,	0x9BF8,	0x9BF9,	0x9BFA,	0x9BFB,
	0x9BFC,	0x9BFD,	0x9BFE,	0x9BFF,	0x9C00,	0x9C01,	0x9C02,	0x9C03,
	0x9C04,	0x9C05,	0x9C06,	0x9C07,	0x9C08,	0x9C09,	0x9C0A,	0x9C0B,
	0x9C0C,	0x9C0D,	0x9C0E,	0x9C0F,	0x9C10,	0x9C11,	0x9C12,	0x9C13,
	0x9C14,	0x9C15,	0x9C16,	0x9C17,	0x9C18,	0x9C19,	0x9C1A,
	/* GB 0xF680..0xF6FE */
	0x9C1B,	0x9C1C,	0x9C1D,	0x9C1E,	0x9C1F,	0x9C20,	0x9C21,	0x9C22,
	0x9C23,	0x9C24,	0x9C25,	0x9C26,	0x9C27,	0x9C28,	0x9C29,	0x9C2A,
	0x9C2B,	0x9C2C,	0x9C2D,	0x9C2E,	0x9C2F,	0x9C30,	0x9C31,	0x9C32,
	0x9C33,	0x9C34,	0x9C35,	0x9C36,	0x9C37,	0x9C38,	0x9C39,	0x9C3A,
	0x9C3B,	0x89E5,	0x89EB,	0x89EF,	0x8A3E,	0x8B26,	0x9753,	0x96E9,
	0x96F3,	0x96EF,	0x9706,	0x9701,	0x9708,	0x970F,	0x970E,	0x972A,
	0x972D,	0x9730,	0x973E,	0x9F80,	0x9F83,	0x9F85,	0x9F86,	0x9F87,
	0x9F88,	0x9F89,	0x9F8A,	0x9F8C,	0x9EFE,	0x9F0B,	0x9F0D,	0x96B9,
	0x96BC,	0x96BD,	0x96CE,	0x96D2,	0x77BF,	0x96E0,	0x928E,	0x92AE,
	0x92C8,	0x933E,	0x936A,	0x93CA,	0x938F,	0x943E,	0x946B,	0x9C7F,
	0x9C82,	0x9C85,	0x9C86,	0x9C87,	0x9C88,	0x7A23,	0x9C8B,	0x9C8E,
	0x9C90,	0x9C91,	0x9C92,	0x9C94,	0x9C95,	0x9C9A,	0x9C9B,	0x9C9E,
	0x9C9F,	0x9CA0,	0x9CA1,	0x9CA2,	0x9CA3,	0x9CA5,	0x9CA6,	0x9CA7,
	0x9CA8,	0x9CA9,	0x9CAB,	0x9CAD,	0x9CAE,	0x9CB0,	0x9CB1,	0x9CB2,
	0x9CB3,	0x9CB4,	0x9CB5,	0x9CB6,	0x9CB7,	0x9CBA,	0x9CBB,	0x9CBC,
	0x9CBD,	0x9CC4,	0x9CC5,	0x9CC6,	0x9CC7,	0x9CCA,	0x9CCB,
	/* GB 0xF740..0xF77E */
	0x9C3C,	0x9C3D,	0x9C3E,	0x9C3F,	0x9C40,	0x9C41,	0x9C42,	0x9C43,
	0x9C44,	0x9C45,	0x9C46,	0x9C47,	0x9C48,	0x9C49,	0x9C4A,	0x9C4B,
	0x9C4C,	0x9C4D,	0x9C4E,	0x9C4F,	0x9C50,	0x9C51,	0x9C52,	0x9C53,
	0x9C54,	0x9C55,	0x9C56,	0x9C57,	0x9C58,	0x9C59,	0x9C5A,	0x9C5B,
	0x9C5C,	0x9C5D,	0x9C5E,	0x9C5F,	0x9C60,	0x9C61,	0x9C62,	0x9C63,
	0x9C64,	0x9C65,	0x9C66,	0x9C67,	0x9C68,	0x9C69,	0x9C6A,	0x9C6B,
	0x9C6C,	0x9C6D,	0x9C6E,	0x9C6F,	0x9C70,	0x9C71,	0x9C72,	0x9C73,
	0x9C74,	0x9C75,	0x9C76,	0x9C77,	0x9C78,	0x9C79,	0x9C7A,
	/* GB 0xF780..0xF7FE */
	0x9C7B,	0x9C7D,	0x9C7E,	0x9C80,	0x9C83,	0x9C84,	0x9C89,	0x9C8A,
	0x9C8C,	0x9C8F,	0x9C93,	0x9C96,	0x9C97,	0x9C98,	0x9C99,	0x9C9D,
	0x9CAA,	0x9CAC,	0x9CAF,	0x9CB9,	0x9CBE,	0x9CBF,	0x9CC0,	0x9CC1,
	0x9CC2,	0x9CC8,	0x9CC9,	0x9CD1,	0x9CD2,	0x9CDA,	0x9CDB,	0x9CE0,
	0x9CE1,	0x9CCC,	0x9CCD,	0x9CCE,	0x9CCF,	0x9CD0,	0x9CD3,	0x9CD4,
	0x9CD5,	0x9CD7,	0x9CD8,	0x9CD9,	0x9CDC,	0x9CDD,	0x9CDF,	0x9CE2,
	0x977C,	0x9785,	0x9791,	0x9792,	0x9794,	0x97AF,	0x97AB,	0x97A3,
	0x97B2,	0x97B4,	0x9AB1,	0x9AB0,	0x9AB7,	0x9E58,	0x9AB6,	0x9ABA,
	0x9ABC,	0x9AC1,	0x9AC0,	0x9AC5,	0x9AC2,	0x9ACB,	0x9ACC,	0x9AD1,
	0x9B45,	0x9B43,	0x9B47,	0x9B49,	0x9B48,	0x9B4D,	0x9B51,	0x98E8,
	0x990D,	0x992E,	0x9955,	0x9954,	0x9ADF,	0x9AE1,	0x9AE6,	0x9AEF,
	0x9AEB,	0x9AFB,	0x9AED,	0x9AF9,	0x9B08,	0x9B0F,	0x9B13,	0x9B1F,
	0x9B23,	0x9EBD,	0x9EBE,	0x7E3B,	0x9E82,	0x9E87,	0x9E88,	0x9E8B,
	0x9E92,	0x93D6,	0x9E9D,	0x9E9F,	0x9EDB,	0x9EDC,	0x9EDD,	0x9EE0,
	0x9EDF,	0x9EE2,	0x9EE9,	0x9EE7,	0x9EE5,	0x9EEA,	0x9EEF,	0x9F22,
	0x9F2C,	0x9F2F,	0x9F39,	0x9F37,	0x9F3D,	0x9F3E,	0x9F44,
	/* GB 0xF840..0xF87E */
	0x9CE3,	0x9CE4,	0x9CE5,	0x9CE6,	0x9CE7,	0x9CE8,	0x9CE9,	0x9CEA,
	0x9CEB,	0x9CEC,	0x9CED,	0x9CEE,	0x9CEF,	0x9CF0,	0x9CF1,	0x9CF2,
	0x9CF3,	0x9CF4,	0x9CF5,	0x9CF6,	0x9CF7,	0x9CF8,	0x9CF9,	0x9CFA,
	0x9CFB,	0x9CFC,	0x9CFD,	0x9CFE,	0x9CFF,	0x9D00,	0x9D01,	0x9D02,
	0x9D03,	0x9D04,	0x9D05,	0x9D06,	0x9D07,	0x9D08,	0x9D09,	0x9D0A,
	0x9D0B,	0x9D0C,	0x9D0D,	0x9D0E,	0x9D0F,	0x9D10,	0x9D11,	0x9D12,
	0x9D13,	0x9D14,	0x9D15,	0x9D16,	0x9D17,	0x9D18,	0x9D19,	0x9D1A,
	0x9D1B,	0x9D1C,	0x9D1D,	0x9D1E,	0x9D1F,	0x9D20,	0x9D21,
	/* GB 0xF880..0xF8A0 */
	0x9D22,	0x9D23,	0x9D24,	0x9D25,	0x9D26,	0x9D27,	0x9D28,	0x9D29,
	0x9D2A,	0x9D2B,	0x9D2C,	0x9D2D,	0x9D2E,	0x9D2F,	0x9D30,	0x9D31,
	0x9D32,	0x9D33,	0x9D34,	0x9D35,	0x9D36,	0x9D37,	0x9D38,	0x9D39,
	0x9D3A,	0x9D3B,	0x9D3C,	0x9D3D,	0x9D3E,	0x9D3F,	0x9D40,	0x9D41,
	0x9D42,			/* Skip: GB 0xF8A1..0xF8FE (UDA 2) */
	/* GB 0xF940..0xF97E */
	0x9D43,	0x9D44,	0x9D45,	0x9D46,	0x9D47,	0x9D48,	0x9D49,	0x9D4A,
	0x9D4B,	0x9D4C,	0x9D4D,	0x9D4E,	0x9D4F,	0x9D50,	0x9D51,	0x9D52,
	0x9D53,	0x9D54,	0x9D55,	0x9D56,	0x9D57,	0x9D58,	0x9D59,	0x9D5A,
	0x9D5B,	0x9D5C,	0x9D5D,	0x9D5E,	0x9D5F,	0x9D60,	0x9D61,	0x9D62,
	0x9D63,	0x9D64,	0x9D65,	0x9D66,	0x9D67,	0x9D68,	0x9D69,	0x9D6A,
	0x9D6B,	0x9D6C,	0x9D6D,	0x9D6E,	0x9D6F,	0x9D70,	0x9D71,	0x9D72,
	0x9D73,	0x9D74,	0x9D75,	0x9D76,	0x9D77,	0x9D78,	0x9D79,	0x9D7A,
	0x9D7B,	0x9D7C,	0x9D7D,	0x9D7E,	0x9D7F,	0x9D80,	0x9D81,
	/* GB 0xF980..0xF9A0 */
	0x9D82,	0x9D83,	0x9D84,	0x9D85,	0x9D86,	0x9D87,	0x9D88,	0x9D89,
	0x9D8A,	0x9D8B,	0x9D8C,	0x9D8D,	0x9D8E,	0x9D8F,	0x9D90,	0x9D91,
	0x9D92,	0x9D93,	0x9D94,	0x9D95,	0x9D96,	0x9D97,	0x9D98,	0x9D99,
	0x9D9A,	0x9D9B,	0x9D9C,	0x9D9D,	0x9D9E,	0x9D9F,	0x9DA0,	0x9DA1,
	0x9DA2,			/* Skip: GB 0xF9A1..0xF9FE (UDA 2) */
	/* GB 0xFA40..0xFA7E */
	0x9DA3,	0x9DA4,	0x9DA5,	0x9DA6,	0x9DA7,	0x9DA8,	0x9DA9,	0x9DAA,
	0x9DAB,	0x9DAC,	0x9DAD,	0x9DAE,	0x9DAF,	0x9DB0,	0x9DB1,	0x9DB2,
	0x9DB3,	0x9DB4,	0x9DB5,	0x9DB6,	0x9DB7,	0x9DB8,	0x9DB9,	0x9DBA,
	0x9DBB,	0x9DBC,	0x9DBD,	0x9DBE,	0x9DBF,	0x9DC0,	0x9DC1,	0x9DC2,
	0x9DC3,	0x9DC4,	0x9DC5,	0x9DC6,	0x9DC7,	0x9DC8,	0x9DC9,	0x9DCA,
	0x9DCB,	0x9DCC,	0x9DCD,	0x9DCE,	0x9DCF,	0x9DD0,	0x9DD1,	0x9DD2,
	0x9DD3,	0x9DD4,	0x9DD5,	0x9DD6,	0x9DD7,	0x9DD8,	0x9DD9,	0x9DDA,
	0x9DDB,	0x9DDC,	0x9DDD,	0x9DDE,	0x9DDF,	0x9DE0,	0x9DE1,
	/* GB 0xFA80..0xFAA0 */
	0x9DE2,	0x9DE3,	0x9DE4,	0x9DE5,	0x9DE6,	0x9DE7,	0x9DE8,	0x9DE9,
	0x9DEA,	0x9DEB,	0x9DEC,	0x9DED,	0x9DEE,	0x9DEF,	0x9DF0,	0x9DF1,
	0x9DF2,	0x9DF3,	0x9DF4,	0x9DF5,	0x9DF6,	0x9DF7,	0x9DF8,	0x9DF9,
	0x9DFA,	0x9DFB,	0x9DFC,	0x9DFD,	0x9DFE,	0x9DFF,	0x9E00,	0x9E01,
	0x9E02,			/* Skip: GB 0xFAA1..0xFAFE (UDA 2) */
	/* GB 0xFB40..0xFB7E */
	0x9E03,	0x9E04,	0x9E05,	0x9E06,	0x9E07,	0x9E08,	0x9E09,	0x9E0A,
	0x9E0B,	0x9E0C,	0x9E0D,	0x9E0E,	0x9E0F,	0x9E10,	0x9E11,	0x9E12,
	0x9E13,	0x9E14,	0x9E15,	0x9E16,	0x9E17,	0x9E18,	0x9E19,	0x9E1A,
	0x9E1B,	0x9E1C,	0x9E1D,	0x9E1E,	0x9E24,	0x9E27,	0x9E2E,	0x9E30,
	0x9E34,	0x9E3B,	0x9E3C,	0x9E40,	0x9E4D,	0x9E50,	0x9E52,	0x9E53,
	0x9E54,	0x9E56,	0x9E59,	0x9E5D,	0x9E5F,	0x9E60,	0x9E61,	0x9E62,
	0x9E65,	0x9E6E,	0x9E6F,	0x9E72,	0x9E74,	0x9E75,	0x9E76,	0x9E77,
	0x9E78,	0x9E79,	0x9E7A,	0x9E7B,	0x9E7C,	0x9E7D,	0x9E80,
	/* GB 0xFB80..0xFBA0 */
	0x9E81,	0x9E83,	0x9E84,	0x9E85,	0x9E86,	0x9E89,	0x9E8A,	0x9E8C,
	0x9E8D,	0x9E8E,	0x9E8F,	0x9E90,	0x9E91,	0x9E94,	0x9E95,	0x9E96,
	0x9E97,	0x9E98,	0x9E99,	0x9E9A,	0x9E9B,	0x9E9C,	0x9E9E,	0x9EA0,
	0x9EA1,	0x9EA2,	0x9EA3,	0x9EA4,	0x9EA5,	0x9EA7,	0x9EA8,	0x9EA9,
	0x9EAA,			/* Skip: GB 0xFBA1..0xFBFE (UDA 2) */
	/* GB 0xFC40..0xFC7E */
	0x9EAB,	0x9EAC,	0x9EAD,	0x9EAE,	0x9EAF,	0x9EB0,	0x9EB1,	0x9EB2,
	0x9EB3,	0x9EB5,	0x9EB6,	0x9EB7,	0x9EB9,	0x9EBA,	0x9EBC,	0x9EBF,
	0x9EC0,	0x9EC1,	0x9EC2,	0x9EC3,	0x9EC5,	0x9EC6,	0x9EC7,	0x9EC8,
	0x9ECA,	0x9ECB,	0x9ECC,	0x9ED0,	0x9ED2,	0x9ED3,	0x9ED5,	0x9ED6,
	0x9ED7,	0x9ED9,	0x9EDA,	0x9EDE,	0x9EE1,	0x9EE3,	0x9EE4,	0x9EE6,
	0x9EE8,	0x9EEB,	0x9EEC,	0x9EED,	0x9EEE,	0x9EF0,	0x9EF1,	0x9EF2,
	0x9EF3,	0x9EF4,	0x9EF5,	0x9EF6,	0x9EF7,	0x9EF8,	0x9EFA,	0x9EFD,
	0x9EFF,	0x9F00,	0x9F01,	0x9F02,	0x9F03,	0x9F04,	0x9F05,
	/* GB 0xFC80..0xFCA0 */
	0x9F06,	0x9F07,	0x9F08,	0x9F09,	0x9F0A,	0x9F0C,	0x9F0F,	0x9F11,
	0x9F12,	0x9F14,	0x9F15,	0x9F16,	0x9F18,	0x9F1A,	0x9F1B,	0x9F1C,
	0x9F1D,	0x9F1E,	0x9F1F,	0x9F21,	0x9F23,	0x9F24,	0x9F25,	0x9F26,
	0x9F27,	0x9F28,	0x9F29,	0x9F2A,	0x9F2B,	0x9F2D,	0x9F2E,	0x9F30,
	0x9F31,			/* Skip: GB 0xFCA1..0xFCFE (UDA 2) */
	/* GB 0xFD40..0xFD7E */
	0x9F32,	0x9F33,	0x9F34,	0x9F35,	0x9F36,	0x9F38,	0x9F3A,	0x9F3C,
	0x9F3F,	0x9F40,	0x9F41,	0x9F42,	0x9F43,	0x9F45,	0x9F46,	0x9F47,
	0x9F48,	0x9F49,	0x9F4A,	0x9F4B,	0x9F4C,	0x9F4D,	0x9F4E,	0x9F4F,
	0x9F52,	0x9F53,	0x9F54,	0x9F55,	0x9F56,	0x9F57,	0x9F58,	0x9F59,
	0x9F5A,	0x9F5B,	0x9F5C,	0x9F5D,	0x9F5E,	0x9F5F,	0x9F60,	0x9F61,
	0x9F62,	0x9F63,	0x9F64,	0x9F65,	0x9F66,	0x9F67,	0x9F68,	0x9F69,
	0x9F6A,	0x9F6B,	0x9F6C,	0x9F6D,	0x9F6E,	0x9F6F,	0x9F70,	0x9F71,
	0x9F72,	0x9F73,	0x9F74,	0x9F75,	0x9F76,	0x9F77,	0x9F78,
	/* GB 0xFD80..0xFDA0 */
	0x9F79,	0x9F7A,	0x9F7B,	0x9F7C,	0x9F7D,	0x9F7E,	0x9F81,	0x9F82,
	0x9F8D,	0x9F8E,	0x9F8F,	0x9F90,	0x9F91,	0x9F92,	0x9F93,	0x9F94,
	0x9F95,	0x9F96,	0x9F97,	0x9F98,	0x9F9C,	0x9F9D,	0x9F9E,	0x9FA1,
	0x9FA2,	0x9FA3,	0x9FA4,	0x9FA5,	0xF92C,	0xF979,	0xF995,	0xF9E7,
	0xF9F1,			/* Skip: GB 0xFDA1..0xFDFE (UDA 2) */
	/* GB 0xFE40..0xFE7E */
	0xFA0C,	0xFA0D,	0xFA0E,	0xFA0F,	0xFA11,	0xFA13,	0xFA14,	0xFA18,
	0xFA1F,	0xFA20,	0xFA21,	0xFA23,	0xFA24,	0xFA27,	0xFA28,	0xFA29,
	0x2E81,	0xE816,	0xE817,	0xE818,	0x2E84,	0x3473,	0x3447,	0x2E88,
	0x2E8B,	0xE81E,	0x359E,	0x361A,	0x360E,	0x2E8C,	0x2E97,	0x396E,
	0x3918,	0xE826,	0x39CF,	0x39DF,	0x3A73,	0x39D0,	0xE82B,	0xE82C,
	0x3B4E,	0x3C6E,	0x3CE0,	0x2EA7,	0xE831,	0xE832,	0x2EAA,	0x4056,
	0x415F,	0x2EAE,	0x4337,	0x2EB3,	0x2EB6,	0x2EB7,	0xE83B,	0x43B1,
	0x43AC,	0x2EBB,	0x43DD,	0x44D6,	0x4661,	0x464C,	0xE843,
	/* GB 0xFE80..0xFEA0 */
	0x4723,	0x4729,	0x477C,	0x478D,	0x2ECA,	0x4947,	0x497A,	0x497D,
	0x4982,	0x4983,	0x4985,	0x4986,	0x499F,	0x499B,	0x49B7,	0x49B6,
	0xE854,	0xE855,	0x4CA3,	0x4C9F,	0x4CA0,	0x4CA1,	0x4C77,	0x4CA2,
	0x4D13,	0x4D14,	0x4D15,	0x4D16,	0x4D17,	0x4D18,	0x4D19,	0x4DAE,
	0xE864,			/* Skip: GB 0xFEA1..0xFEFE (UDA 2) */
};

static const uint16_t __gb18030_4byte_to_ucs[6793] = {
  /* Contiguous area: GB+81 30 81 30 .. GB+81 30 D2 39 */
  /* GB+81 30 81 30 */	0x0080,	0x0081,	0x0082,	0x0083,	0x0084,
  /* GB+81 30 81 35 */	0x0085,	0x0086,	0x0087,	0x0088,	0x0089,
  /* GB+81 30 82 30 */	0x008A,	0x008B,	0x008C,	0x008D,	0x008E,
  /* GB+81 30 82 35 */	0x008F,	0x0090,	0x0091,	0x0092,	0x0093,
  /* GB+81 30 83 30 */	0x0094,	0x0095,	0x0096,	0x0097,	0x0098,
  /* GB+81 30 83 35 */	0x0099,	0x009A,	0x009B,	0x009C,	0x009D,
  /* GB+81 30 84 30 */	0x009E,	0x009F,	0x00A0,	0x00A1,	0x00A2,
  /* GB+81 30 84 35 */	0x00A3,	0x00A5,	0x00A6,	0x00A9,	0x00AA,
  /* GB+81 30 85 30 */	0x00AB,	0x00AC,	0x00AD,	0x00AE,	0x00AF,
  /* GB+81 30 85 35 */	0x00B2,	0x00B3,	0x00B4,	0x00B5,	0x00B6,
  /* GB+81 30 86 30 */	0x00B8,	0x00B9,	0x00BA,	0x00BB,	0x00BC,
  /* GB+81 30 86 35 */	0x00BD,	0x00BE,	0x00BF,	0x00C0,	0x00C1,
  /* GB+81 30 87 30 */	0x00C2,	0x00C3,	0x00C4,	0x00C5,	0x00C6,
  /* GB+81 30 87 35 */	0x00C7,	0x00C8,	0x00C9,	0x00CA,	0x00CB,
  /* GB+81 30 88 30 */	0x00CC,	0x00CD,	0x00CE,	0x00CF,	0x00D0,
  /* GB+81 30 88 35 */	0x00D1,	0x00D2,	0x00D3,	0x00D4,	0x00D5,
  /* GB+81 30 89 30 */	0x00D6,	0x00D8,	0x00D9,	0x00DA,	0x00DB,
  /* GB+81 30 89 35 */	0x00DC,	0x00DD,	0x00DE,	0x00DF,	0x00E2,
  /* GB+81 30 8A 30 */	0x00E3,	0x00E4,	0x00E5,	0x00E6,	0x00E7,
  /* GB+81 30 8A 35 */	0x00EB,	0x00EE,	0x00EF,	0x00F0,	0x00F1,
  /* GB+81 30 8B 30 */	0x00F4,	0x00F5,	0x00F6,	0x00F8,	0x00FB,
  /* GB+81 30 8B 35 */	0x00FD,	0x00FE,	0x00FF,	0x0100,	0x0102,
  /* GB+81 30 8C 30 */	0x0103,	0x0104,	0x0105,	0x0106,	0x0107,
  /* GB+81 30 8C 35 */	0x0108,	0x0109,	0x010A,	0x010B,	0x010C,
  /* GB+81 30 8D 30 */	0x010D,	0x010E,	0x010F,	0x0110,	0x0111,
  /* GB+81 30 8D 35 */	0x0112,	0x0114,	0x0115,	0x0116,	0x0117,
  /* GB+81 30 8E 30 */	0x0118,	0x0119,	0x011A,	0x011C,	0x011D,
  /* GB+81 30 8E 35 */	0x011E,	0x011F,	0x0120,	0x0121,	0x0122,
  /* GB+81 30 8F 30 */	0x0123,	0x0124,	0x0125,	0x0126,	0x0127,
  /* GB+81 30 8F 35 */	0x0128,	0x0129,	0x012A,	0x012C,	0x012D,
  /* GB+81 30 90 30 */	0x012E,	0x012F,	0x0130,	0x0131,	0x0132,
  /* GB+81 30 90 35 */	0x0133,	0x0134,	0x0135,	0x0136,	0x0137,
  /* GB+81 30 91 30 */	0x0138,	0x0139,	0x013A,	0x013B,	0x013C,
  /* GB+81 30 91 35 */	0x013D,	0x013E,	0x013F,	0x0140,	0x0141,
  /* GB+81 30 92 30 */	0x0142,	0x0143,	0x0145,	0x0146,	0x0147,
  /* GB+81 30 92 35 */	0x0149,	0x014A,	0x014B,	0x014C,	0x014E,
  /* GB+81 30 93 30 */	0x014F,	0x0150,	0x0151,	0x0152,	0x0153,
  /* GB+81 30 93 35 */	0x0154,	0x0155,	0x0156,	0x0157,	0x0158,
  /* GB+81 30 94 30 */	0x0159,	0x015A,	0x015B,	0x015C,	0x015D,
  /* GB+81 30 94 35 */	0x015E,	0x015F,	0x0160,	0x0161,	0x0162,
  /* GB+81 30 95 30 */	0x0163,	0x0164,	0x0165,	0x0166,	0x0167,
  /* GB+81 30 95 35 */	0x0168,	0x0169,	0x016A,	0x016C,	0x016D,
  /* GB+81 30 96 30 */	0x016E,	0x016F,	0x0170,	0x0171,	0x0172,
  /* GB+81 30 96 35 */	0x0173,	0x0174,	0x0175,	0x0176,	0x0177,
  /* GB+81 30 97 30 */	0x0178,	0x0179,	0x017A,	0x017B,	0x017C,
  /* GB+81 30 97 35 */	0x017D,	0x017E,	0x017F,	0x0180,	0x0181,
  /* GB+81 30 98 30 */	0x0182,	0x0183,	0x0184,	0x0185,	0x0186,
  /* GB+81 30 98 35 */	0x0187,	0x0188,	0x0189,	0x018A,	0x018B,
  /* GB+81 30 99 30 */	0x018C,	0x018D,	0x018E,	0x018F,	0x0190,
  /* GB+81 30 99 35 */	0x0191,	0x0192,	0x0193,	0x0194,	0x0195,
  /* GB+81 30 9A 30 */	0x0196,	0x0197,	0x0198,	0x0199,	0x019A,
  /* GB+81 30 9A 35 */	0x019B,	0x019C,	0x019D,	0x019E,	0x019F,
  /* GB+81 30 9B 30 */	0x01A0,	0x01A1,	0x01A2,	0x01A3,	0x01A4,
  /* GB+81 30 9B 35 */	0x01A5,	0x01A6,	0x01A7,	0x01A8,	0x01A9,
  /* GB+81 30 9C 30 */	0x01AA,	0x01AB,	0x01AC,	0x01AD,	0x01AE,
  /* GB+81 30 9C 35 */	0x01AF,	0x01B0,	0x01B1,	0x01B2,	0x01B3,
  /* GB+81 30 9D 30 */	0x01B4,	0x01B5,	0x01B6,	0x01B7,	0x01B8,
  /* GB+81 30 9D 35 */	0x01B9,	0x01BA,	0x01BB,	0x01BC,	0x01BD,
  /* GB+81 30 9E 30 */	0x01BE,	0x01BF,	0x01C0,	0x01C1,	0x01C2,
  /* GB+81 30 9E 35 */	0x01C3,	0x01C4,	0x01C5,	0x01C6,	0x01C7,
  /* GB+81 30 9F 30 */	0x01C8,	0x01C9,	0x01CA,	0x01CB,	0x01CC,
  /* GB+81 30 9F 35 */	0x01CD,	0x01CF,	0x01D1,	0x01D3,	0x01D5,
  /* GB+81 30 A0 30 */	0x01D7,	0x01D9,	0x01DB,	0x01DD,	0x01DE,
  /* GB+81 30 A0 35 */	0x01DF,	0x01E0,	0x01E1,	0x01E2,	0x01E3,
  /* GB+81 30 A1 30 */	0x01E4,	0x01E5,	0x01E6,	0x01E7,	0x01E8,
  /* GB+81 30 A1 35 */	0x01E9,	0x01EA,	0x01EB,	0x01EC,	0x01ED,
  /* GB+81 30 A2 30 */	0x01EE,	0x01EF,	0x01F0,	0x01F1,	0x01F2,
  /* GB+81 30 A2 35 */	0x01F3,	0x01F4,	0x01F5,	0x01F6,	0x01F7,
  /* GB+81 30 A3 30 */	0x01F8,	0x01FA,	0x01FB,	0x01FC,	0x01FD,
  /* GB+81 30 A3 35 */	0x01FE,	0x01FF,	0x0200,	0x0201,	0x0202,
  /* GB+81 30 A4 30 */	0x0203,	0x0204,	0x0205,	0x0206,	0x0207,
  /* GB+81 30 A4 35 */	0x0208,	0x0209,	0x020A,	0x020B,	0x020C,
  /* GB+81 30 A5 30 */	0x020D,	0x020E,	0x020F,	0x0210,	0x0211,
  /* GB+81 30 A5 35 */	0x0212,	0x0213,	0x0214,	0x0215,	0x0216,
  /* GB+81 30 A6 30 */	0x0217,	0x0218,	0x0219,	0x021A,	0x021B,
  /* GB+81 30 A6 35 */	0x021C,	0x021D,	0x021E,	0x021F,	0x0220,
  /* GB+81 30 A7 30 */	0x0221,	0x0222,	0x0223,	0x0224,	0x0225,
  /* GB+81 30 A7 35 */	0x0226,	0x0227,	0x0228,	0x0229,	0x022A,
  /* GB+81 30 A8 30 */	0x022B,	0x022C,	0x022D,	0x022E,	0x022F,
  /* GB+81 30 A8 35 */	0x0230,	0x0231,	0x0232,	0x0233,	0x0234,
  /* GB+81 30 A9 30 */	0x0235,	0x0236,	0x0237,	0x0238,	0x0239,
  /* GB+81 30 A9 35 */	0x023A,	0x023B,	0x023C,	0x023D,	0x023E,
  /* GB+81 30 AA 30 */	0x023F,	0x0240,	0x0241,	0x0242,	0x0243,
  /* GB+81 30 AA 35 */	0x0244,	0x0245,	0x0246,	0x0247,	0x0248,
  /* GB+81 30 AB 30 */	0x0249,	0x024A,	0x024B,	0x024C,	0x024D,
  /* GB+81 30 AB 35 */	0x024E,	0x024F,	0x0250,	0x0252,	0x0253,
  /* GB+81 30 AC 30 */	0x0254,	0x0255,	0x0256,	0x0257,	0x0258,
  /* GB+81 30 AC 35 */	0x0259,	0x025A,	0x025B,	0x025C,	0x025D,
  /* GB+81 30 AD 30 */	0x025E,	0x025F,	0x0260,	0x0262,	0x0263,
  /* GB+81 30 AD 35 */	0x0264,	0x0265,	0x0266,	0x0267,	0x0268,
  /* GB+81 30 AE 30 */	0x0269,	0x026A,	0x026B,	0x026C,	0x026D,
  /* GB+81 30 AE 35 */	0x026E,	0x026F,	0x0270,	0x0271,	0x0272,
  /* GB+81 30 AF 30 */	0x0273,	0x0274,	0x0275,	0x0276,	0x0277,
  /* GB+81 30 AF 35 */	0x0278,	0x0279,	0x027A,	0x027B,	0x027C,
  /* GB+81 30 B0 30 */	0x027D,	0x027E,	0x027F,	0x0280,	0x0281,
  /* GB+81 30 B0 35 */	0x0282,	0x0283,	0x0284,	0x0285,	0x0286,
  /* GB+81 30 B1 30 */	0x0287,	0x0288,	0x0289,	0x028A,	0x028B,
  /* GB+81 30 B1 35 */	0x028C,	0x028D,	0x028E,	0x028F,	0x0290,
  /* GB+81 30 B2 30 */	0x0291,	0x0292,	0x0293,	0x0294,	0x0295,
  /* GB+81 30 B2 35 */	0x0296,	0x0297,	0x0298,	0x0299,	0x029A,
  /* GB+81 30 B3 30 */	0x029B,	0x029C,	0x029D,	0x029E,	0x029F,
  /* GB+81 30 B3 35 */	0x02A0,	0x02A1,	0x02A2,	0x02A3,	0x02A4,
  /* GB+81 30 B4 30 */	0x02A5,	0x02A6,	0x02A7,	0x02A8,	0x02A9,
  /* GB+81 30 B4 35 */	0x02AA,	0x02AB,	0x02AC,	0x02AD,	0x02AE,
  /* GB+81 30 B5 30 */	0x02AF,	0x02B0,	0x02B1,	0x02B2,	0x02B3,
  /* GB+81 30 B5 35 */	0x02B4,	0x02B5,	0x02B6,	0x02B7,	0x02B8,
  /* GB+81 30 B6 30 */	0x02B9,	0x02BA,	0x02BB,	0x02BC,	0x02BD,
  /* GB+81 30 B6 35 */	0x02BE,	0x02BF,	0x02C0,	0x02C1,	0x02C2,
  /* GB+81 30 B7 30 */	0x02C3,	0x02C4,	0x02C5,	0x02C6,	0x02C8,
  /* GB+81 30 B7 35 */	0x02CC,	0x02CD,	0x02CE,	0x02CF,	0x02D0,
  /* GB+81 30 B8 30 */	0x02D1,	0x02D2,	0x02D3,	0x02D4,	0x02D5,
  /* GB+81 30 B8 35 */	0x02D6,	0x02D7,	0x02D8,	0x02DA,	0x02DB,
  /* GB+81 30 B9 30 */	0x02DC,	0x02DD,	0x02DE,	0x02DF,	0x02E0,
  /* GB+81 30 B9 35 */	0x02E1,	0x02E2,	0x02E3,	0x02E4,	0x02E5,
  /* GB+81 30 BA 30 */	0x02E6,	0x02E7,	0x02E8,	0x02E9,	0x02EA,
  /* GB+81 30 BA 35 */	0x02EB,	0x02EC,	0x02ED,	0x02EE,	0x02EF,
  /* GB+81 30 BB 30 */	0x02F0,	0x02F1,	0x02F2,	0x02F3,	0x02F4,
  /* GB+81 30 BB 35 */	0x02F5,	0x02F6,	0x02F7,	0x02F8,	0x02F9,
  /* GB+81 30 BC 30 */	0x02FA,	0x02FB,	0x02FC,	0x02FD,	0x02FE,
  /* GB+81 30 BC 35 */	0x02FF,	0x0300,	0x0301,	0x0302,	0x0303,
  /* GB+81 30 BD 30 */	0x0304,	0x0305,	0x0306,	0x0307,	0x0308,
  /* GB+81 30 BD 35 */	0x0309,	0x030A,	0x030B,	0x030C,	0x030D,
  /* GB+81 30 BE 30 */	0x030E,	0x030F,	0x0310,	0x0311,	0x0312,
  /* GB+81 30 BE 35 */	0x0313,	0x0314,	0x0315,	0x0316,	0x0317,
  /* GB+81 30 BF 30 */	0x0318,	0x0319,	0x031A,	0x031B,	0x031C,
  /* GB+81 30 BF 35 */	0x031D,	0x031E,	0x031F,	0x0320,	0x0321,
  /* GB+81 30 C0 30 */	0x0322,	0x0323,	0x0324,	0x0325,	0x0326,
  /* GB+81 30 C0 35 */	0x0327,	0x0328,	0x0329,	0x032A,	0x032B,
  /* GB+81 30 C1 30 */	0x032C,	0x032D,	0x032E,	0x032F,	0x0330,
  /* GB+81 30 C1 35 */	0x0331,	0x0332,	0x0333,	0x0334,	0x0335,
  /* GB+81 30 C2 30 */	0x0336,	0x0337,	0x0338,	0x0339,	0x033A,
  /* GB+81 30 C2 35 */	0x033B,	0x033C,	0x033D,	0x033E,	0x033F,
  /* GB+81 30 C3 30 */	0x0340,	0x0341,	0x0342,	0x0343,	0x0344,
  /* GB+81 30 C3 35 */	0x0345,	0x0346,	0x0347,	0x0348,	0x0349,
  /* GB+81 30 C4 30 */	0x034A,	0x034B,	0x034C,	0x034D,	0x034E,
  /* GB+81 30 C4 35 */	0x034F,	0x0350,	0x0351,	0x0352,	0x0353,
  /* GB+81 30 C5 30 */	0x0354,	0x0355,	0x0356,	0x0357,	0x0358,
  /* GB+81 30 C5 35 */	0x0359,	0x035A,	0x035B,	0x035C,	0x035D,
  /* GB+81 30 C6 30 */	0x035E,	0x035F,	0x0360,	0x0361,	0x0362,
  /* GB+81 30 C6 35 */	0x0363,	0x0364,	0x0365,	0x0366,	0x0367,
  /* GB+81 30 C7 30 */	0x0368,	0x0369,	0x036A,	0x036B,	0x036C,
  /* GB+81 30 C7 35 */	0x036D,	0x036E,	0x036F,	0x0370,	0x0371,
  /* GB+81 30 C8 30 */	0x0372,	0x0373,	0x0374,	0x0375,	0x0376,
  /* GB+81 30 C8 35 */	0x0377,	0x0378,	0x0379,	0x037A,	0x037B,
  /* GB+81 30 C9 30 */	0x037C,	0x037D,	0x037E,	0x037F,	0x0380,
  /* GB+81 30 C9 35 */	0x0381,	0x0382,	0x0383,	0x0384,	0x0385,
  /* GB+81 30 CA 30 */	0x0386,	0x0387,	0x0388,	0x0389,	0x038A,
  /* GB+81 30 CA 35 */	0x038B,	0x038C,	0x038D,	0x038E,	0x038F,
  /* GB+81 30 CB 30 */	0x0390,	0x03A2,	0x03AA,	0x03AB,	0x03AC,
  /* GB+81 30 CB 35 */	0x03AD,	0x03AE,	0x03AF,	0x03B0,	0x03C2,
  /* GB+81 30 CC 30 */	0x03CA,	0x03CB,	0x03CC,	0x03CD,	0x03CE,
  /* GB+81 30 CC 35 */	0x03CF,	0x03D0,	0x03D1,	0x03D2,	0x03D3,
  /* GB+81 30 CD 30 */	0x03D4,	0x03D5,	0x03D6,	0x03D7,	0x03D8,
  /* GB+81 30 CD 35 */	0x03D9,	0x03DA,	0x03DB,	0x03DC,	0x03DD,
  /* GB+81 30 CE 30 */	0x03DE,	0x03DF,	0x03E0,	0x03E1,	0x03E2,
  /* GB+81 30 CE 35 */	0x03E3,	0x03E4,	0x03E5,	0x03E6,	0x03E7,
  /* GB+81 30 CF 30 */	0x03E8,	0x03E9,	0x03EA,	0x03EB,	0x03EC,
  /* GB+81 30 CF 35 */	0x03ED,	0x03EE,	0x03EF,	0x03F0,	0x03F1,
  /* GB+81 30 D0 30 */	0x03F2,	0x03F3,	0x03F4,	0x03F5,	0x03F6,
  /* GB+81 30 D0 35 */	0x03F7,	0x03F8,	0x03F9,	0x03FA,	0x03FB,
  /* GB+81 30 D1 30 */	0x03FC,	0x03FD,	0x03FE,	0x03FF,	0x0400,
  /* GB+81 30 D1 35 */	0x0402,	0x0403,	0x0404,	0x0405,	0x0406,
  /* GB+81 30 D2 30 */	0x0407,	0x0408,	0x0409,	0x040A,	0x040B,
  /* GB+81 30 D2 35 */	0x040C,	0x040D,	0x040E,	0x040F,	0x0450,
  /* Contiguous area: GB+81 36 A5 32 .. GB+81 37 A8 38 */
  /* GB+81 36 A5 32 */			0x2011,	0x2012,	0x2017,
  /* GB+81 36 A5 35 */	0x201A,	0x201B,	0x201E,	0x201F,	0x2020,
  /* GB+81 36 A6 30 */	0x2021,	0x2022,	0x2023,	0x2024,	0x2027,
  /* GB+81 36 A6 35 */	0x2028,	0x2029,	0x202A,	0x202B,	0x202C,
  /* GB+81 36 A7 30 */	0x202D,	0x202E,	0x202F,	0x2031,	0x2034,
  /* GB+81 36 A7 35 */	0x2036,	0x2037,	0x2038,	0x2039,	0x203A,
  /* GB+81 36 A8 30 */	0x203C,	0x203D,	0x203E,	0x203F,	0x2040,
  /* GB+81 36 A8 35 */	0x2041,	0x2042,	0x2043,	0x2044,	0x2045,
  /* GB+81 36 A9 30 */	0x2046,	0x2047,	0x2048,	0x2049,	0x204A,
  /* GB+81 36 A9 35 */	0x204B,	0x204C,	0x204D,	0x204E,	0x204F,
  /* GB+81 36 AA 30 */	0x2050,	0x2051,	0x2052,	0x2053,	0x2054,
  /* GB+81 36 AA 35 */	0x2055,	0x2056,	0x2057,	0x2058,	0x2059,
  /* GB+81 36 AB 30 */	0x205A,	0x205B,	0x205C,	0x205D,	0x205E,
  /* GB+81 36 AB 35 */	0x205F,	0x2060,	0x2061,	0x2062,	0x2063,
  /* GB+81 36 AC 30 */	0x2064,	0x2065,	0x2066,	0x2067,	0x2068,
  /* GB+81 36 AC 35 */	0x2069,	0x206A,	0x206B,	0x206C,	0x206D,
  /* GB+81 36 AD 30 */	0x206E,	0x206F,	0x2070,	0x2071,	0x2072,
  /* GB+81 36 AD 35 */	0x2073,	0x2074,	0x2075,	0x2076,	0x2077,
  /* GB+81 36 AE 30 */	0x2078,	0x2079,	0x207A,	0x207B,	0x207C,
  /* GB+81 36 AE 35 */	0x207D,	0x207E,	0x207F,	0x2080,	0x2081,
  /* GB+81 36 AF 30 */	0x2082,	0x2083,	0x2084,	0x2085,	0x2086,
  /* GB+81 36 AF 35 */	0x2087,	0x2088,	0x2089,	0x208A,	0x208B,
  /* GB+81 36 B0 30 */	0x208C,	0x208D,	0x208E,	0x208F,	0x2090,
  /* GB+81 36 B0 35 */	0x2091,	0x2092,	0x2093,	0x2094,	0x2095,
  /* GB+81 36 B1 30 */	0x2096,	0x2097,	0x2098,	0x2099,	0x209A,
  /* GB+81 36 B1 35 */	0x209B,	0x209C,	0x209D,	0x209E,	0x209F,
  /* GB+81 36 B2 30 */	0x20A0,	0x20A1,	0x20A2,	0x20A3,	0x20A4,
  /* GB+81 36 B2 35 */	0x20A5,	0x20A6,	0x20A7,	0x20A8,	0x20A9,
  /* GB+81 36 B3 30 */	0x20AA,	0x20AB,	0x20AD,	0x20AE,	0x20AF,
  /* GB+81 36 B3 35 */	0x20B0,	0x20B1,	0x20B2,	0x20B3,	0x20B4,
  /* GB+81 36 B4 30 */	0x20B5,	0x20B6,	0x20B7,	0x20B8,	0x20B9,
  /* GB+81 36 B4 35 */	0x20BA,	0x20BB,	0x20BC,	0x20BD,	0x20BE,
  /* GB+81 36 B5 30 */	0x20BF,	0x20C0,	0x20C1,	0x20C2,	0x20C3,
  /* GB+81 36 B5 35 */	0x20C4,	0x20C5,	0x20C6,	0x20C7,	0x20C8,
  /* GB+81 36 B6 30 */	0x20C9,	0x20CA,	0x20CB,	0x20CC,	0x20CD,
  /* GB+81 36 B6 35 */	0x20CE,	0x20CF,	0x20D0,	0x20D1,	0x20D2,
  /* GB+81 36 B7 30 */	0x20D3,	0x20D4,	0x20D5,	0x20D6,	0x20D7,
  /* GB+81 36 B7 35 */	0x20D8,	0x20D9,	0x20DA,	0x20DB,	0x20DC,
  /* GB+81 36 B8 30 */	0x20DD,	0x20DE,	0x20DF,	0x20E0,	0x20E1,
  /* GB+81 36 B8 35 */	0x20E2,	0x20E3,	0x20E4,	0x20E5,	0x20E6,
  /* GB+81 36 B9 30 */	0x20E7,	0x20E8,	0x20E9,	0x20EA,	0x20EB,
  /* GB+81 36 B9 35 */	0x20EC,	0x20ED,	0x20EE,	0x20EF,	0x20F0,
  /* GB+81 36 BA 30 */	0x20F1,	0x20F2,	0x20F3,	0x20F4,	0x20F5,
  /* GB+81 36 BA 35 */	0x20F6,	0x20F7,	0x20F8,	0x20F9,	0x20FA,
  /* GB+81 36 BB 30 */	0x20FB,	0x20FC,	0x20FD,	0x20FE,	0x20FF,
  /* GB+81 36 BB 35 */	0x2100,	0x2101,	0x2102,	0x2104,	0x2106,
  /* GB+81 36 BC 30 */	0x2107,	0x2108,	0x210A,	0x210B,	0x210C,
  /* GB+81 36 BC 35 */	0x210D,	0x210E,	0x210F,	0x2110,	0x2111,
  /* GB+81 36 BD 30 */	0x2112,	0x2113,	0x2114,	0x2115,	0x2117,
  /* GB+81 36 BD 35 */	0x2118,	0x2119,	0x211A,	0x211B,	0x211C,
  /* GB+81 36 BE 30 */	0x211D,	0x211E,	0x211F,	0x2120,	0x2122,
  /* GB+81 36 BE 35 */	0x2123,	0x2124,	0x2125,	0x2126,	0x2127,
  /* GB+81 36 BF 30 */	0x2128,	0x2129,	0x212A,	0x212B,	0x212C,
  /* GB+81 36 BF 35 */	0x212D,	0x212E,	0x212F,	0x2130,	0x2131,
  /* GB+81 36 C0 30 */	0x2132,	0x2133,	0x2134,	0x2135,	0x2136,
  /* GB+81 36 C0 35 */	0x2137,	0x2138,	0x2139,	0x213A,	0x213B,
  /* GB+81 36 C1 30 */	0x213C,	0x213D,	0x213E,	0x213F,	0x2140,
  /* GB+81 36 C1 35 */	0x2141,	0x2142,	0x2143,	0x2144,	0x2145,
  /* GB+81 36 C2 30 */	0x2146,	0x2147,	0x2148,	0x2149,	0x214A,
  /* GB+81 36 C2 35 */	0x214B,	0x214C,	0x214D,	0x214E,	0x214F,
  /* GB+81 36 C3 30 */	0x2150,	0x2151,	0x2152,	0x2153,	0x2154,
  /* GB+81 36 C3 35 */	0x2155,	0x2156,	0x2157,	0x2158,	0x2159,
  /* GB+81 36 C4 30 */	0x215A,	0x215B,	0x215C,	0x215D,	0x215E,
  /* GB+81 36 C4 35 */	0x215F,	0x216C,	0x216D,	0x216E,	0x216F,
  /* GB+81 36 C5 30 */	0x217A,	0x217B,	0x217C,	0x217D,	0x217E,
  /* GB+81 36 C5 35 */	0x217F,	0x2180,	0x2181,	0x2182,	0x2183,
  /* GB+81 36 C6 30 */	0x2184,	0x2185,	0x2186,	0x2187,	0x2188,
  /* GB+81 36 C6 35 */	0x2189,	0x218A,	0x218B,	0x218C,	0x218D,
  /* GB+81 36 C7 30 */	0x218E,	0x218F,	0x2194,	0x2195,	0x219A,
  /* GB+81 36 C7 35 */	0x219B,	0x219C,	0x219D,	0x219E,	0x219F,
  /* GB+81 36 C8 30 */	0x21A0,	0x21A1,	0x21A2,	0x21A3,	0x21A4,
  /* GB+81 36 C8 35 */	0x21A5,	0x21A6,	0x21A7,	0x21A8,	0x21A9,
  /* GB+81 36 C9 30 */	0x21AA,	0x21AB,	0x21AC,	0x21AD,	0x21AE,
  /* GB+81 36 C9 35 */	0x21AF,	0x21B0,	0x21B1,	0x21B2,	0x21B3,
  /* GB+81 36 CA 30 */	0x21B4,	0x21B5,	0x21B6,	0x21B7,	0x21B8,
  /* GB+81 36 CA 35 */	0x21B9,	0x21BA,	0x21BB,	0x21BC,	0x21BD,
  /* GB+81 36 CB 30 */	0x21BE,	0x21BF,	0x21C0,	0x21C1,	0x21C2,
  /* GB+81 36 CB 35 */	0x21C3,	0x21C4,	0x21C5,	0x21C6,	0x21C7,
  /* GB+81 36 CC 30 */	0x21C8,	0x21C9,	0x21CA,	0x21CB,	0x21CC,
  /* GB+81 36 CC 35 */	0x21CD,	0x21CE,	0x21CF,	0x21D0,	0x21D1,
  /* GB+81 36 CD 30 */	0x21D2,	0x21D3,	0x21D4,	0x21D5,	0x21D6,
  /* GB+81 36 CD 35 */	0x21D7,	0x21D8,	0x21D9,	0x21DA,	0x21DB,
  /* GB+81 36 CE 30 */	0x21DC,	0x21DD,	0x21DE,	0x21DF,	0x21E0,
  /* GB+81 36 CE 35 */	0x21E1,	0x21E2,	0x21E3,	0x21E4,	0x21E5,
  /* GB+81 36 CF 30 */	0x21E6,	0x21E7,	0x21E8,	0x21E9,	0x21EA,
  /* GB+81 36 CF 35 */	0x21EB,	0x21EC,	0x21ED,	0x21EE,	0x21EF,
  /* GB+81 36 D0 30 */	0x21F0,	0x21F1,	0x21F2,	0x21F3,	0x21F4,
  /* GB+81 36 D0 35 */	0x21F5,	0x21F6,	0x21F7,	0x21F8,	0x21F9,
  /* GB+81 36 D1 30 */	0x21FA,	0x21FB,	0x21FC,	0x21FD,	0x21FE,
  /* GB+81 36 D1 35 */	0x21FF,	0x2200,	0x2201,	0x2202,	0x2203,
  /* GB+81 36 D2 30 */	0x2204,	0x2205,	0x2206,	0x2207,	0x2209,
  /* GB+81 36 D2 35 */	0x220A,	0x220B,	0x220C,	0x220D,	0x220E,
  /* GB+81 36 D3 30 */	0x2210,	0x2212,	0x2213,	0x2214,	0x2216,
  /* GB+81 36 D3 35 */	0x2217,	0x2218,	0x2219,	0x221B,	0x221C,
  /* GB+81 36 D4 30 */	0x2221,	0x2222,	0x2224,	0x2226,	0x222C,
  /* GB+81 36 D4 35 */	0x222D,	0x222F,	0x2230,	0x2231,	0x2232,
  /* GB+81 36 D5 30 */	0x2233,	0x2238,	0x2239,	0x223A,	0x223B,
  /* GB+81 36 D5 35 */	0x223C,	0x223E,	0x223F,	0x2240,	0x2241,
  /* GB+81 36 D6 30 */	0x2242,	0x2243,	0x2244,	0x2245,	0x2246,
  /* GB+81 36 D6 35 */	0x2247,	0x2249,	0x224A,	0x224B,	0x224D,
  /* GB+81 36 D7 30 */	0x224E,	0x224F,	0x2250,	0x2251,	0x2253,
  /* GB+81 36 D7 35 */	0x2254,	0x2255,	0x2256,	0x2257,	0x2258,
  /* GB+81 36 D8 30 */	0x2259,	0x225A,	0x225B,	0x225C,	0x225D,
  /* GB+81 36 D8 35 */	0x225E,	0x225F,	0x2262,	0x2263,	0x2268,
  /* GB+81 36 D9 30 */	0x2269,	0x226A,	0x226B,	0x226C,	0x226D,
  /* GB+81 36 D9 35 */	0x2270,	0x2271,	0x2272,	0x2273,	0x2274,
  /* GB+81 36 DA 30 */	0x2275,	0x2276,	0x2277,	0x2278,	0x2279,
  /* GB+81 36 DA 35 */	0x227A,	0x227B,	0x227C,	0x227D,	0x227E,
  /* GB+81 36 DB 30 */	0x227F,	0x2280,	0x2281,	0x2282,	0x2283,
  /* GB+81 36 DB 35 */	0x2284,	0x2285,	0x2286,	0x2287,	0x2288,
  /* GB+81 36 DC 30 */	0x2289,	0x228A,	0x228B,	0x228C,	0x228D,
  /* GB+81 36 DC 35 */	0x228E,	0x228F,	0x2290,	0x2291,	0x2292,
  /* GB+81 36 DD 30 */	0x2293,	0x2294,	0x2296,	0x2297,	0x2298,
  /* GB+81 36 DD 35 */	0x229A,	0x229B,	0x229C,	0x229D,	0x229E,
  /* GB+81 36 DE 30 */	0x229F,	0x22A0,	0x22A1,	0x22A2,	0x22A3,
  /* GB+81 36 DE 35 */	0x22A4,	0x22A6,	0x22A7,	0x22A8,	0x22A9,
  /* GB+81 36 DF 30 */	0x22AA,	0x22AB,	0x22AC,	0x22AD,	0x22AE,
  /* GB+81 36 DF 35 */	0x22AF,	0x22B0,	0x22B1,	0x22B2,	0x22B3,
  /* GB+81 36 E0 30 */	0x22B4,	0x22B5,	0x22B6,	0x22B7,	0x22B8,
  /* GB+81 36 E0 35 */	0x22B9,	0x22BA,	0x22BB,	0x22BC,	0x22BD,
  /* GB+81 36 E1 30 */	0x22BE,	0x22C0,	0x22C1,	0x22C2,	0x22C3,
  /* GB+81 36 E1 35 */	0x22C4,	0x22C5,	0x22C6,	0x22C7,	0x22C8,
  /* GB+81 36 E2 30 */	0x22C9,	0x22CA,	0x22CB,	0x22CC,	0x22CD,
  /* GB+81 36 E2 35 */	0x22CE,	0x22CF,	0x22D0,	0x22D1,	0x22D2,
  /* GB+81 36 E3 30 */	0x22D3,	0x22D4,	0x22D5,	0x22D6,	0x22D7,
  /* GB+81 36 E3 35 */	0x22D8,	0x22D9,	0x22DA,	0x22DB,	0x22DC,
  /* GB+81 36 E4 30 */	0x22DD,	0x22DE,	0x22DF,	0x22E0,	0x22E1,
  /* GB+81 36 E4 35 */	0x22E2,	0x22E3,	0x22E4,	0x22E5,	0x22E6,
  /* GB+81 36 E5 30 */	0x22E7,	0x22E8,	0x22E9,	0x22EA,	0x22EB,
  /* GB+81 36 E5 35 */	0x22EC,	0x22ED,	0x22EE,	0x22EF,	0x22F0,
  /* GB+81 36 E6 30 */	0x22F1,	0x22F2,	0x22F3,	0x22F4,	0x22F5,
  /* GB+81 36 E6 35 */	0x22F6,	0x22F7,	0x22F8,	0x22F9,	0x22FA,
  /* GB+81 36 E7 30 */	0x22FB,	0x22FC,	0x22FD,	0x22FE,	0x22FF,
  /* GB+81 36 E7 35 */	0x2300,	0x2301,	0x2302,	0x2303,	0x2304,
  /* GB+81 36 E8 30 */	0x2305,	0x2306,	0x2307,	0x2308,	0x2309,
  /* GB+81 36 E8 35 */	0x230A,	0x230B,	0x230C,	0x230D,	0x230E,
  /* GB+81 36 E9 30 */	0x230F,	0x2310,	0x2311,	0x2313,	0x2314,
  /* GB+81 36 E9 35 */	0x2315,	0x2316,	0x2317,	0x2318,	0x2319,
  /* GB+81 36 EA 30 */	0x231A,	0x231B,	0x231C,	0x231D,	0x231E,
  /* GB+81 36 EA 35 */	0x231F,	0x2320,	0x2321,	0x2322,	0x2323,
  /* GB+81 36 EB 30 */	0x2324,	0x2325,	0x2326,	0x2327,	0x2328,
  /* GB+81 36 EB 35 */	0x2329,	0x232A,	0x232B,	0x232C,	0x232D,
  /* GB+81 36 EC 30 */	0x232E,	0x232F,	0x2330,	0x2331,	0x2332,
  /* GB+81 36 EC 35 */	0x2333,	0x2334,	0x2335,	0x2336,	0x2337,
  /* GB+81 36 ED 30 */	0x2338,	0x2339,	0x233A,	0x233B,	0x233C,
  /* GB+81 36 ED 35 */	0x233D,	0x233E,	0x233F,	0x2340,	0x2341,
  /* GB+81 36 EE 30 */	0x2342,	0x2343,	0x2344,	0x2345,	0x2346,
  /* GB+81 36 EE 35 */	0x2347,	0x2348,	0x2349,	0x234A,	0x234B,
  /* GB+81 36 EF 30 */	0x234C,	0x234D,	0x234E,	0x234F,	0x2350,
  /* GB+81 36 EF 35 */	0x2351,	0x2352,	0x2353,	0x2354,	0x2355,
  /* GB+81 36 F0 30 */	0x2356,	0x2357,	0x2358,	0x2359,	0x235A,
  /* GB+81 36 F0 35 */	0x235B,	0x235C,	0x235D,	0x235E,	0x235F,
  /* GB+81 36 F1 30 */	0x2360,	0x2361,	0x2362,	0x2363,	0x2364,
  /* GB+81 36 F1 35 */	0x2365,	0x2366,	0x2367,	0x2368,	0x2369,
  /* GB+81 36 F2 30 */	0x236A,	0x236B,	0x236C,	0x236D,	0x236E,
  /* GB+81 36 F2 35 */	0x236F,	0x2370,	0x2371,	0x2372,	0x2373,
  /* GB+81 36 F3 30 */	0x2374,	0x2375,	0x2376,	0x2377,	0x2378,
  /* GB+81 36 F3 35 */	0x2379,	0x237A,	0x237B,	0x237C,	0x237D,
  /* GB+81 36 F4 30 */	0x237E,	0x237F,	0x2380,	0x2381,	0x2382,
  /* GB+81 36 F4 35 */	0x2383,	0x2384,	0x2385,	0x2386,	0x2387,
  /* GB+81 36 F5 30 */	0x2388,	0x2389,	0x238A,	0x238B,	0x238C,
  /* GB+81 36 F5 35 */	0x238D,	0x238E,	0x238F,	0x2390,	0x2391,
  /* GB+81 36 F6 30 */	0x2392,	0x2393,	0x2394,	0x2395,	0x2396,
  /* GB+81 36 F6 35 */	0x2397,	0x2398,	0x2399,	0x239A,	0x239B,
  /* GB+81 36 F7 30 */	0x239C,	0x239D,	0x239E,	0x239F,	0x23A0,
  /* GB+81 36 F7 35 */	0x23A1,	0x23A2,	0x23A3,	0x23A4,	0x23A5,
  /* GB+81 36 F8 30 */	0x23A6,	0x23A7,	0x23A8,	0x23A9,	0x23AA,
  /* GB+81 36 F8 35 */	0x23AB,	0x23AC,	0x23AD,	0x23AE,	0x23AF,
  /* GB+81 36 F9 30 */	0x23B0,	0x23B1,	0x23B2,	0x23B3,	0x23B4,
  /* GB+81 36 F9 35 */	0x23B5,	0x23B6,	0x23B7,	0x23B8,	0x23B9,
  /* GB+81 36 FA 30 */	0x23BA,	0x23BB,	0x23BC,	0x23BD,	0x23BE,
  /* GB+81 36 FA 35 */	0x23BF,	0x23C0,	0x23C1,	0x23C2,	0x23C3,
  /* GB+81 36 FB 30 */	0x23C4,	0x23C5,	0x23C6,	0x23C7,	0x23C8,
  /* GB+81 36 FB 35 */	0x23C9,	0x23CA,	0x23CB,	0x23CC,	0x23CD,
  /* GB+81 36 FC 30 */	0x23CE,	0x23CF,	0x23D0,	0x23D1,	0x23D2,
  /* GB+81 36 FC 35 */	0x23D3,	0x23D4,	0x23D5,	0x23D6,	0x23D7,
  /* GB+81 36 FD 30 */	0x23D8,	0x23D9,	0x23DA,	0x23DB,	0x23DC,
  /* GB+81 36 FD 35 */	0x23DD,	0x23DE,	0x23DF,	0x23E0,	0x23E1,
  /* GB+81 36 FE 30 */	0x23E2,	0x23E3,	0x23E4,	0x23E5,	0x23E6,
  /* GB+81 36 FE 35 */	0x23E7,	0x23E8,	0x23E9,	0x23EA,	0x23EB,
  /* GB+81 37 81 30 */	0x23EC,	0x23ED,	0x23EE,	0x23EF,	0x23F0,
  /* GB+81 37 81 35 */	0x23F1,	0x23F2,	0x23F3,	0x23F4,	0x23F5,
  /* GB+81 37 82 30 */	0x23F6,	0x23F7,	0x23F8,	0x23F9,	0x23FA,
  /* GB+81 37 82 35 */	0x23FB,	0x23FC,	0x23FD,	0x23FE,	0x23FF,
  /* GB+81 37 83 30 */	0x2400,	0x2401,	0x2402,	0x2403,	0x2404,
  /* GB+81 37 83 35 */	0x2405,	0x2406,	0x2407,	0x2408,	0x2409,
  /* GB+81 37 84 30 */	0x240A,	0x240B,	0x240C,	0x240D,	0x240E,
  /* GB+81 37 84 35 */	0x240F,	0x2410,	0x2411,	0x2412,	0x2413,
  /* GB+81 37 85 30 */	0x2414,	0x2415,	0x2416,	0x2417,	0x2418,
  /* GB+81 37 85 35 */	0x2419,	0x241A,	0x241B,	0x241C,	0x241D,
  /* GB+81 37 86 30 */	0x241E,	0x241F,	0x2420,	0x2421,	0x2422,
  /* GB+81 37 86 35 */	0x2423,	0x2424,	0x2425,	0x2426,	0x2427,
  /* GB+81 37 87 30 */	0x2428,	0x2429,	0x242A,	0x242B,	0x242C,
  /* GB+81 37 87 35 */	0x242D,	0x242E,	0x242F,	0x2430,	0x2431,
  /* GB+81 37 88 30 */	0x2432,	0x2433,	0x2434,	0x2435,	0x2436,
  /* GB+81 37 88 35 */	0x2437,	0x2438,	0x2439,	0x243A,	0x243B,
  /* GB+81 37 89 30 */	0x243C,	0x243D,	0x243E,	0x243F,	0x2440,
  /* GB+81 37 89 35 */	0x2441,	0x2442,	0x2443,	0x2444,	0x2445,
  /* GB+81 37 8A 30 */	0x2446,	0x2447,	0x2448,	0x2449,	0x244A,
  /* GB+81 37 8A 35 */	0x244B,	0x244C,	0x244D,	0x244E,	0x244F,
  /* GB+81 37 8B 30 */	0x2450,	0x2451,	0x2452,	0x2453,	0x2454,
  /* GB+81 37 8B 35 */	0x2455,	0x2456,	0x2457,	0x2458,	0x2459,
  /* GB+81 37 8C 30 */	0x245A,	0x245B,	0x245C,	0x245D,	0x245E,
  /* GB+81 37 8C 35 */	0x245F,	0x246A,	0x246B,	0x246C,	0x246D,
  /* GB+81 37 8D 30 */	0x246E,	0x246F,	0x2470,	0x2471,	0x2472,
  /* GB+81 37 8D 35 */	0x2473,	0x249C,	0x249D,	0x249E,	0x249F,
  /* GB+81 37 8E 30 */	0x24A0,	0x24A1,	0x24A2,	0x24A3,	0x24A4,
  /* GB+81 37 8E 35 */	0x24A5,	0x24A6,	0x24A7,	0x24A8,	0x24A9,
  /* GB+81 37 8F 30 */	0x24AA,	0x24AB,	0x24AC,	0x24AD,	0x24AE,
  /* GB+81 37 8F 35 */	0x24AF,	0x24B0,	0x24B1,	0x24B2,	0x24B3,
  /* GB+81 37 90 30 */	0x24B4,	0x24B5,	0x24B6,	0x24B7,	0x24B8,
  /* GB+81 37 90 35 */	0x24B9,	0x24BA,	0x24BB,	0x24BC,	0x24BD,
  /* GB+81 37 91 30 */	0x24BE,	0x24BF,	0x24C0,	0x24C1,	0x24C2,
  /* GB+81 37 91 35 */	0x24C3,	0x24C4,	0x24C5,	0x24C6,	0x24C7,
  /* GB+81 37 92 30 */	0x24C8,	0x24C9,	0x24CA,	0x24CB,	0x24CC,
  /* GB+81 37 92 35 */	0x24CD,	0x24CE,	0x24CF,	0x24D0,	0x24D1,
  /* GB+81 37 93 30 */	0x24D2,	0x24D3,	0x24D4,	0x24D5,	0x24D6,
  /* GB+81 37 93 35 */	0x24D7,	0x24D8,	0x24D9,	0x24DA,	0x24DB,
  /* GB+81 37 94 30 */	0x24DC,	0x24DD,	0x24DE,	0x24DF,	0x24E0,
  /* GB+81 37 94 35 */	0x24E1,	0x24E2,	0x24E3,	0x24E4,	0x24E5,
  /* GB+81 37 95 30 */	0x24E6,	0x24E7,	0x24E8,	0x24E9,	0x24EA,
  /* GB+81 37 95 35 */	0x24EB,	0x24EC,	0x24ED,	0x24EE,	0x24EF,
  /* GB+81 37 96 30 */	0x24F0,	0x24F1,	0x24F2,	0x24F3,	0x24F4,
  /* GB+81 37 96 35 */	0x24F5,	0x24F6,	0x24F7,	0x24F8,	0x24F9,
  /* GB+81 37 97 30 */	0x24FA,	0x24FB,	0x24FC,	0x24FD,	0x24FE,
  /* GB+81 37 97 35 */	0x24FF,	0x254C,	0x254D,	0x254E,	0x254F,
  /* GB+81 37 98 30 */	0x2574,	0x2575,	0x2576,	0x2577,	0x2578,
  /* GB+81 37 98 35 */	0x2579,	0x257A,	0x257B,	0x257C,	0x257D,
  /* GB+81 37 99 30 */	0x257E,	0x257F,	0x2580,	0x2590,	0x2591,
  /* GB+81 37 99 35 */	0x2592,	0x2596,	0x2597,	0x2598,	0x2599,
  /* GB+81 37 9A 30 */	0x259A,	0x259B,	0x259C,	0x259D,	0x259E,
  /* GB+81 37 9A 35 */	0x259F,	0x25A2,	0x25A3,	0x25A4,	0x25A5,
  /* GB+81 37 9B 30 */	0x25A6,	0x25A7,	0x25A8,	0x25A9,	0x25AA,
  /* GB+81 37 9B 35 */	0x25AB,	0x25AC,	0x25AD,	0x25AE,	0x25AF,
  /* GB+81 37 9C 30 */	0x25B0,	0x25B1,	0x25B4,	0x25B5,	0x25B6,
  /* GB+81 37 9C 35 */	0x25B7,	0x25B8,	0x25B9,	0x25BA,	0x25BB,
  /* GB+81 37 9D 30 */	0x25BE,	0x25BF,	0x25C0,	0x25C1,	0x25C2,
  /* GB+81 37 9D 35 */	0x25C3,	0x25C4,	0x25C5,	0x25C8,	0x25C9,
  /* GB+81 37 9E 30 */	0x25CA,	0x25CC,	0x25CD,	0x25D0,	0x25D1,
  /* GB+81 37 9E 35 */	0x25D2,	0x25D3,	0x25D4,	0x25D5,	0x25D6,
  /* GB+81 37 9F 30 */	0x25D7,	0x25D8,	0x25D9,	0x25DA,	0x25DB,
  /* GB+81 37 9F 35 */	0x25DC,	0x25DD,	0x25DE,	0x25DF,	0x25E0,
  /* GB+81 37 A0 30 */	0x25E1,	0x25E6,	0x25E7,	0x25E8,	0x25E9,
  /* GB+81 37 A0 35 */	0x25EA,	0x25EB,	0x25EC,	0x25ED,	0x25EE,
  /* GB+81 37 A1 30 */	0x25EF,	0x25F0,	0x25F1,	0x25F2,	0x25F3,
  /* GB+81 37 A1 35 */	0x25F4,	0x25F5,	0x25F6,	0x25F7,	0x25F8,
  /* GB+81 37 A2 30 */	0x25F9,	0x25FA,	0x25FB,	0x25FC,	0x25FD,
  /* GB+81 37 A2 35 */	0x25FE,	0x25FF,	0x2600,	0x2601,	0x2602,
  /* GB+81 37 A3 30 */	0x2603,	0x2604,	0x2607,	0x2608,	0x260A,
  /* GB+81 37 A3 35 */	0x260B,	0x260C,	0x260D,	0x260E,	0x260F,
  /* GB+81 37 A4 30 */	0x2610,	0x2611,	0x2612,	0x2613,	0x2614,
  /* GB+81 37 A4 35 */	0x2615,	0x2616,	0x2617,	0x2618,	0x2619,
  /* GB+81 37 A5 30 */	0x261A,	0x261B,	0x261C,	0x261D,	0x261E,
  /* GB+81 37 A5 35 */	0x261F,	0x2620,	0x2621,	0x2622,	0x2623,
  /* GB+81 37 A6 30 */	0x2624,	0x2625,	0x2626,	0x2627,	0x2628,
  /* GB+81 37 A6 35 */	0x2629,	0x262A,	0x262B,	0x262C,	0x262D,
  /* GB+81 37 A7 30 */	0x262E,	0x262F,	0x2630,	0x2631,	0x2632,
  /* GB+81 37 A7 35 */	0x2633,	0x2634,	0x2635,	0x2636,	0x2637,
  /* GB+81 37 A8 30 */	0x2638,	0x2639,	0x263A,	0x263B,	0x263C,
  /* GB+81 37 A8 35 */	0x263D,	0x263E,	0x263F,	0x2641,	
  /* Contiguous area: GB+81 38 FD 39 .. GB+82 30 A6 32 */
  /* GB+81 38 FD 39 */					0x2E82,
  /* GB+81 38 FE 30 */	0x2E83,	0x2E85,	0x2E86,	0x2E87,	0x2E89,
  /* GB+81 38 FE 35 */	0x2E8A,	0x2E8D,	0x2E8E,	0x2E8F,	0x2E90,
  /* GB+81 39 81 30 */	0x2E91,	0x2E92,	0x2E93,	0x2E94,	0x2E95,
  /* GB+81 39 81 35 */	0x2E96,	0x2E98,	0x2E99,	0x2E9A,	0x2E9B,
  /* GB+81 39 82 30 */	0x2E9C,	0x2E9D,	0x2E9E,	0x2E9F,	0x2EA0,
  /* GB+81 39 82 35 */	0x2EA1,	0x2EA2,	0x2EA3,	0x2EA4,	0x2EA5,
  /* GB+81 39 83 30 */	0x2EA6,	0x2EA8,	0x2EA9,	0x2EAB,	0x2EAC,
  /* GB+81 39 83 35 */	0x2EAD,	0x2EAF,	0x2EB0,	0x2EB1,	0x2EB2,
  /* GB+81 39 84 30 */	0x2EB4,	0x2EB5,	0x2EB8,	0x2EB9,	0x2EBA,
  /* GB+81 39 84 35 */	0x2EBC,	0x2EBD,	0x2EBE,	0x2EBF,	0x2EC0,
  /* GB+81 39 85 30 */	0x2EC1,	0x2EC2,	0x2EC3,	0x2EC4,	0x2EC5,
  /* GB+81 39 85 35 */	0x2EC6,	0x2EC7,	0x2EC8,	0x2EC9,	0x2ECB,
  /* GB+81 39 86 30 */	0x2ECC,	0x2ECD,	0x2ECE,	0x2ECF,	0x2ED0,
  /* GB+81 39 86 35 */	0x2ED1,	0x2ED2,	0x2ED3,	0x2ED4,	0x2ED5,
  /* GB+81 39 87 30 */	0x2ED6,	0x2ED7,	0x2ED8,	0x2ED9,	0x2EDA,
  /* GB+81 39 87 35 */	0x2EDB,	0x2EDC,	0x2EDD,	0x2EDE,	0x2EDF,
  /* GB+81 39 88 30 */	0x2EE0,	0x2EE1,	0x2EE2,	0x2EE3,	0x2EE4,
  /* GB+81 39 88 35 */	0x2EE5,	0x2EE6,	0x2EE7,	0x2EE8,	0x2EE9,
  /* GB+81 39 89 30 */	0x2EEA,	0x2EEB,	0x2EEC,	0x2EED,	0x2EEE,
  /* GB+81 39 89 35 */	0x2EEF,	0x2EF0,	0x2EF1,	0x2EF2,	0x2EF3,
  /* GB+81 39 8A 30 */	0x2EF4,	0x2EF5,	0x2EF6,	0x2EF7,	0x2EF8,
  /* GB+81 39 8A 35 */	0x2EF9,	0x2EFA,	0x2EFB,	0x2EFC,	0x2EFD,
  /* GB+81 39 8B 30 */	0x2EFE,	0x2EFF,	0x2F00,	0x2F01,	0x2F02,
  /* GB+81 39 8B 35 */	0x2F03,	0x2F04,	0x2F05,	0x2F06,	0x2F07,
  /* GB+81 39 8C 30 */	0x2F08,	0x2F09,	0x2F0A,	0x2F0B,	0x2F0C,
  /* GB+81 39 8C 35 */	0x2F0D,	0x2F0E,	0x2F0F,	0x2F10,	0x2F11,
  /* GB+81 39 8D 30 */	0x2F12,	0x2F13,	0x2F14,	0x2F15,	0x2F16,
  /* GB+81 39 8D 35 */	0x2F17,	0x2F18,	0x2F19,	0x2F1A,	0x2F1B,
  /* GB+81 39 8E 30 */	0x2F1C,	0x2F1D,	0x2F1E,	0x2F1F,	0x2F20,
  /* GB+81 39 8E 35 */	0x2F21,	0x2F22,	0x2F23,	0x2F24,	0x2F25,
  /* GB+81 39 8F 30 */	0x2F26,	0x2F27,	0x2F28,	0x2F29,	0x2F2A,
  /* GB+81 39 8F 35 */	0x2F2B,	0x2F2C,	0x2F2D,	0x2F2E,	0x2F2F,
  /* GB+81 39 90 30 */	0x2F30,	0x2F31,	0x2F32,	0x2F33,	0x2F34,
  /* GB+81 39 90 35 */	0x2F35,	0x2F36,	0x2F37,	0x2F38,	0x2F39,
  /* GB+81 39 91 30 */	0x2F3A,	0x2F3B,	0x2F3C,	0x2F3D,	0x2F3E,
  /* GB+81 39 91 35 */	0x2F3F,	0x2F40,	0x2F41,	0x2F42,	0x2F43,
  /* GB+81 39 92 30 */	0x2F44,	0x2F45,	0x2F46,	0x2F47,	0x2F48,
  /* GB+81 39 92 35 */	0x2F49,	0x2F4A,	0x2F4B,	0x2F4C,	0x2F4D,
  /* GB+81 39 93 30 */	0x2F4E,	0x2F4F,	0x2F50,	0x2F51,	0x2F52,
  /* GB+81 39 93 35 */	0x2F53,	0x2F54,	0x2F55,	0x2F56,	0x2F57,
  /* GB+81 39 94 30 */	0x2F58,	0x2F59,	0x2F5A,	0x2F5B,	0x2F5C,
  /* GB+81 39 94 35 */	0x2F5D,	0x2F5E,	0x2F5F,	0x2F60,	0x2F61,
  /* GB+81 39 95 30 */	0x2F62,	0x2F63,	0x2F64,	0x2F65,	0x2F66,
  /* GB+81 39 95 35 */	0x2F67,	0x2F68,	0x2F69,	0x2F6A,	0x2F6B,
  /* GB+81 39 96 30 */	0x2F6C,	0x2F6D,	0x2F6E,	0x2F6F,	0x2F70,
  /* GB+81 39 96 35 */	0x2F71,	0x2F72,	0x2F73,	0x2F74,	0x2F75,
  /* GB+81 39 97 30 */	0x2F76,	0x2F77,	0x2F78,	0x2F79,	0x2F7A,
  /* GB+81 39 97 35 */	0x2F7B,	0x2F7C,	0x2F7D,	0x2F7E,	0x2F7F,
  /* GB+81 39 98 30 */	0x2F80,	0x2F81,	0x2F82,	0x2F83,	0x2F84,
  /* GB+81 39 98 35 */	0x2F85,	0x2F86,	0x2F87,	0x2F88,	0x2F89,
  /* GB+81 39 99 30 */	0x2F8A,	0x2F8B,	0x2F8C,	0x2F8D,	0x2F8E,
  /* GB+81 39 99 35 */	0x2F8F,	0x2F90,	0x2F91,	0x2F92,	0x2F93,
  /* GB+81 39 9A 30 */	0x2F94,	0x2F95,	0x2F96,	0x2F97,	0x2F98,
  /* GB+81 39 9A 35 */	0x2F99,	0x2F9A,	0x2F9B,	0x2F9C,	0x2F9D,
  /* GB+81 39 9B 30 */	0x2F9E,	0x2F9F,	0x2FA0,	0x2FA1,	0x2FA2,
  /* GB+81 39 9B 35 */	0x2FA3,	0x2FA4,	0x2FA5,	0x2FA6,	0x2FA7,
  /* GB+81 39 9C 30 */	0x2FA8,	0x2FA9,	0x2FAA,	0x2FAB,	0x2FAC,
  /* GB+81 39 9C 35 */	0x2FAD,	0x2FAE,	0x2FAF,	0x2FB0,	0x2FB1,
  /* GB+81 39 9D 30 */	0x2FB2,	0x2FB3,	0x2FB4,	0x2FB5,	0x2FB6,
  /* GB+81 39 9D 35 */	0x2FB7,	0x2FB8,	0x2FB9,	0x2FBA,	0x2FBB,
  /* GB+81 39 9E 30 */	0x2FBC,	0x2FBD,	0x2FBE,	0x2FBF,	0x2FC0,
  /* GB+81 39 9E 35 */	0x2FC1,	0x2FC2,	0x2FC3,	0x2FC4,	0x2FC5,
  /* GB+81 39 9F 30 */	0x2FC6,	0x2FC7,	0x2FC8,	0x2FC9,	0x2FCA,
  /* GB+81 39 9F 35 */	0x2FCB,	0x2FCC,	0x2FCD,	0x2FCE,	0x2FCF,
  /* GB+81 39 A0 30 */	0x2FD0,	0x2FD1,	0x2FD2,	0x2FD3,	0x2FD4,
  /* GB+81 39 A0 35 */	0x2FD5,	0x2FD6,	0x2FD7,	0x2FD8,	0x2FD9,
  /* GB+81 39 A1 30 */	0x2FDA,	0x2FDB,	0x2FDC,	0x2FDD,	0x2FDE,
  /* GB+81 39 A1 35 */	0x2FDF,	0x2FE0,	0x2FE1,	0x2FE2,	0x2FE3,
  /* GB+81 39 A2 30 */	0x2FE4,	0x2FE5,	0x2FE6,	0x2FE7,	0x2FE8,
  /* GB+81 39 A2 35 */	0x2FE9,	0x2FEA,	0x2FEB,	0x2FEC,	0x2FED,
  /* GB+81 39 A3 30 */	0x2FEE,	0x2FEF,	0x2FFC,	0x2FFD,	0x2FFE,
  /* GB+81 39 A3 35 */	0x2FFF,	0x3004,	0x3018,	0x3019,	0x301A,
  /* GB+81 39 A4 30 */	0x301B,	0x301C,	0x301F,	0x3020,	0x302A,
  /* GB+81 39 A4 35 */	0x302B,	0x302C,	0x302D,	0x302E,	0x302F,
  /* GB+81 39 A5 30 */	0x3030,	0x3031,	0x3032,	0x3033,	0x3034,
  /* GB+81 39 A5 35 */	0x3035,	0x3036,	0x3037,	0x3038,	0x3039,
  /* GB+81 39 A6 30 */	0x303A,	0x303B,	0x303C,	0x303D,	0x303F,
  /* GB+81 39 A6 35 */	0x3040,	0x3094,	0x3095,	0x3096,	0x3097,
  /* GB+81 39 A7 30 */	0x3098,	0x3099,	0x309A,	0x309F,	0x30A0,
  /* GB+81 39 A7 35 */	0x30F7,	0x30F8,	0x30F9,	0x30FA,	0x30FB,
  /* GB+81 39 A8 30 */	0x30FF,	0x3100,	0x3101,	0x3102,	0x3103,
  /* GB+81 39 A8 35 */	0x3104,	0x312A,	0x312B,	0x312C,	0x312D,
  /* GB+81 39 A9 30 */	0x312E,	0x312F,	0x3130,	0x3131,	0x3132,
  /* GB+81 39 A9 35 */	0x3133,	0x3134,	0x3135,	0x3136,	0x3137,
  /* GB+81 39 AA 30 */	0x3138,	0x3139,	0x313A,	0x313B,	0x313C,
  /* GB+81 39 AA 35 */	0x313D,	0x313E,	0x313F,	0x3140,	0x3141,
  /* GB+81 39 AB 30 */	0x3142,	0x3143,	0x3144,	0x3145,	0x3146,
  /* GB+81 39 AB 35 */	0x3147,	0x3148,	0x3149,	0x314A,	0x314B,
  /* GB+81 39 AC 30 */	0x314C,	0x314D,	0x314E,	0x314F,	0x3150,
  /* GB+81 39 AC 35 */	0x3151,	0x3152,	0x3153,	0x3154,	0x3155,
  /* GB+81 39 AD 30 */	0x3156,	0x3157,	0x3158,	0x3159,	0x315A,
  /* GB+81 39 AD 35 */	0x315B,	0x315C,	0x315D,	0x315E,	0x315F,
  /* GB+81 39 AE 30 */	0x3160,	0x3161,	0x3162,	0x3163,	0x3164,
  /* GB+81 39 AE 35 */	0x3165,	0x3166,	0x3167,	0x3168,	0x3169,
  /* GB+81 39 AF 30 */	0x316A,	0x316B,	0x316C,	0x316D,	0x316E,
  /* GB+81 39 AF 35 */	0x316F,	0x3170,	0x3171,	0x3172,	0x3173,
  /* GB+81 39 B0 30 */	0x3174,	0x3175,	0x3176,	0x3177,	0x3178,
  /* GB+81 39 B0 35 */	0x3179,	0x317A,	0x317B,	0x317C,	0x317D,
  /* GB+81 39 B1 30 */	0x317E,	0x317F,	0x3180,	0x3181,	0x3182,
  /* GB+81 39 B1 35 */	0x3183,	0x3184,	0x3185,	0x3186,	0x3187,
  /* GB+81 39 B2 30 */	0x3188,	0x3189,	0x318A,	0x318B,	0x318C,
  /* GB+81 39 B2 35 */	0x318D,	0x318E,	0x318F,	0x3190,	0x3191,
  /* GB+81 39 B3 30 */	0x3192,	0x3193,	0x3194,	0x3195,	0x3196,
  /* GB+81 39 B3 35 */	0x3197,	0x3198,	0x3199,	0x319A,	0x319B,
  /* GB+81 39 B4 30 */	0x319C,	0x319D,	0x319E,	0x319F,	0x31A0,
  /* GB+81 39 B4 35 */	0x31A1,	0x31A2,	0x31A3,	0x31A4,	0x31A5,
  /* GB+81 39 B5 30 */	0x31A6,	0x31A7,	0x31A8,	0x31A9,	0x31AA,
  /* GB+81 39 B5 35 */	0x31AB,	0x31AC,	0x31AD,	0x31AE,	0x31AF,
  /* GB+81 39 B6 30 */	0x31B0,	0x31B1,	0x31B2,	0x31B3,	0x31B4,
  /* GB+81 39 B6 35 */	0x31B5,	0x31B6,	0x31B7,	0x31B8,	0x31B9,
  /* GB+81 39 B7 30 */	0x31BA,	0x31BB,	0x31BC,	0x31BD,	0x31BE,
  /* GB+81 39 B7 35 */	0x31BF,	0x31C0,	0x31C1,	0x31C2,	0x31C3,
  /* GB+81 39 B8 30 */	0x31C4,	0x31C5,	0x31C6,	0x31C7,	0x31C8,
  /* GB+81 39 B8 35 */	0x31C9,	0x31CA,	0x31CB,	0x31CC,	0x31CD,
  /* GB+81 39 B9 30 */	0x31CE,	0x31CF,	0x31D0,	0x31D1,	0x31D2,
  /* GB+81 39 B9 35 */	0x31D3,	0x31D4,	0x31D5,	0x31D6,	0x31D7,
  /* GB+81 39 BA 30 */	0x31D8,	0x31D9,	0x31DA,	0x31DB,	0x31DC,
  /* GB+81 39 BA 35 */	0x31DD,	0x31DE,	0x31DF,	0x31E0,	0x31E1,
  /* GB+81 39 BB 30 */	0x31E2,	0x31E3,	0x31E4,	0x31E5,	0x31E6,
  /* GB+81 39 BB 35 */	0x31E7,	0x31E8,	0x31E9,	0x31EA,	0x31EB,
  /* GB+81 39 BC 30 */	0x31EC,	0x31ED,	0x31EE,	0x31EF,	0x31F0,
  /* GB+81 39 BC 35 */	0x31F1,	0x31F2,	0x31F3,	0x31F4,	0x31F5,
  /* GB+81 39 BD 30 */	0x31F6,	0x31F7,	0x31F8,	0x31F9,	0x31FA,
  /* GB+81 39 BD 35 */	0x31FB,	0x31FC,	0x31FD,	0x31FE,	0x31FF,
  /* GB+81 39 BE 30 */	0x3200,	0x3201,	0x3202,	0x3203,	0x3204,
  /* GB+81 39 BE 35 */	0x3205,	0x3206,	0x3207,	0x3208,	0x3209,
  /* GB+81 39 BF 30 */	0x320A,	0x320B,	0x320C,	0x320D,	0x320E,
  /* GB+81 39 BF 35 */	0x320F,	0x3210,	0x3211,	0x3212,	0x3213,
  /* GB+81 39 C0 30 */	0x3214,	0x3215,	0x3216,	0x3217,	0x3218,
  /* GB+81 39 C0 35 */	0x3219,	0x321A,	0x321B,	0x321C,	0x321D,
  /* GB+81 39 C1 30 */	0x321E,	0x321F,	0x322A,	0x322B,	0x322C,
  /* GB+81 39 C1 35 */	0x322D,	0x322E,	0x322F,	0x3230,	0x3232,
  /* GB+81 39 C2 30 */	0x3233,	0x3234,	0x3235,	0x3236,	0x3237,
  /* GB+81 39 C2 35 */	0x3238,	0x3239,	0x323A,	0x323B,	0x323C,
  /* GB+81 39 C3 30 */	0x323D,	0x323E,	0x323F,	0x3240,	0x3241,
  /* GB+81 39 C3 35 */	0x3242,	0x3243,	0x3244,	0x3245,	0x3246,
  /* GB+81 39 C4 30 */	0x3247,	0x3248,	0x3249,	0x324A,	0x324B,
  /* GB+81 39 C4 35 */	0x324C,	0x324D,	0x324E,	0x324F,	0x3250,
  /* GB+81 39 C5 30 */	0x3251,	0x3252,	0x3253,	0x3254,	0x3255,
  /* GB+81 39 C5 35 */	0x3256,	0x3257,	0x3258,	0x3259,	0x325A,
  /* GB+81 39 C6 30 */	0x325B,	0x325C,	0x325D,	0x325E,	0x325F,
  /* GB+81 39 C6 35 */	0x3260,	0x3261,	0x3262,	0x3263,	0x3264,
  /* GB+81 39 C7 30 */	0x3265,	0x3266,	0x3267,	0x3268,	0x3269,
  /* GB+81 39 C7 35 */	0x326A,	0x326B,	0x326C,	0x326D,	0x326E,
  /* GB+81 39 C8 30 */	0x326F,	0x3270,	0x3271,	0x3272,	0x3273,
  /* GB+81 39 C8 35 */	0x3274,	0x3275,	0x3276,	0x3277,	0x3278,
  /* GB+81 39 C9 30 */	0x3279,	0x327A,	0x327B,	0x327C,	0x327D,
  /* GB+81 39 C9 35 */	0x327E,	0x327F,	0x3280,	0x3281,	0x3282,
  /* GB+81 39 CA 30 */	0x3283,	0x3284,	0x3285,	0x3286,	0x3287,
  /* GB+81 39 CA 35 */	0x3288,	0x3289,	0x328A,	0x328B,	0x328C,
  /* GB+81 39 CB 30 */	0x328D,	0x328E,	0x328F,	0x3290,	0x3291,
  /* GB+81 39 CB 35 */	0x3292,	0x3293,	0x3294,	0x3295,	0x3296,
  /* GB+81 39 CC 30 */	0x3297,	0x3298,	0x3299,	0x329A,	0x329B,
  /* GB+81 39 CC 35 */	0x329C,	0x329D,	0x329E,	0x329F,	0x32A0,
  /* GB+81 39 CD 30 */	0x32A1,	0x32A2,	0x32A4,	0x32A5,	0x32A6,
  /* GB+81 39 CD 35 */	0x32A7,	0x32A8,	0x32A9,	0x32AA,	0x32AB,
  /* GB+81 39 CE 30 */	0x32AC,	0x32AD,	0x32AE,	0x32AF,	0x32B0,
  /* GB+81 39 CE 35 */	0x32B1,	0x32B2,	0x32B3,	0x32B4,	0x32B5,
  /* GB+81 39 CF 30 */	0x32B6,	0x32B7,	0x32B8,	0x32B9,	0x32BA,
  /* GB+81 39 CF 35 */	0x32BB,	0x32BC,	0x32BD,	0x32BE,	0x32BF,
  /* GB+81 39 D0 30 */	0x32C0,	0x32C1,	0x32C2,	0x32C3,	0x32C4,
  /* GB+81 39 D0 35 */	0x32C5,	0x32C6,	0x32C7,	0x32C8,	0x32C9,
  /* GB+81 39 D1 30 */	0x32CA,	0x32CB,	0x32CC,	0x32CD,	0x32CE,
  /* GB+81 39 D1 35 */	0x32CF,	0x32D0,	0x32D1,	0x32D2,	0x32D3,
  /* GB+81 39 D2 30 */	0x32D4,	0x32D5,	0x32D6,	0x32D7,	0x32D8,
  /* GB+81 39 D2 35 */	0x32D9,	0x32DA,	0x32DB,	0x32DC,	0x32DD,
  /* GB+81 39 D3 30 */	0x32DE,	0x32DF,	0x32E0,	0x32E1,	0x32E2,
  /* GB+81 39 D3 35 */	0x32E3,	0x32E4,	0x32E5,	0x32E6,	0x32E7,
  /* GB+81 39 D4 30 */	0x32E8,	0x32E9,	0x32EA,	0x32EB,	0x32EC,
  /* GB+81 39 D4 35 */	0x32ED,	0x32EE,	0x32EF,	0x32F0,	0x32F1,
  /* GB+81 39 D5 30 */	0x32F2,	0x32F3,	0x32F4,	0x32F5,	0x32F6,
  /* GB+81 39 D5 35 */	0x32F7,	0x32F8,	0x32F9,	0x32FA,	0x32FB,
  /* GB+81 39 D6 30 */	0x32FC,	0x32FD,	0x32FE,	0x32FF,	0x3300,
  /* GB+81 39 D6 35 */	0x3301,	0x3302,	0x3303,	0x3304,	0x3305,
  /* GB+81 39 D7 30 */	0x3306,	0x3307,	0x3308,	0x3309,	0x330A,
  /* GB+81 39 D7 35 */	0x330B,	0x330C,	0x330D,	0x330E,	0x330F,
  /* GB+81 39 D8 30 */	0x3310,	0x3311,	0x3312,	0x3313,	0x3314,
  /* GB+81 39 D8 35 */	0x3315,	0x3316,	0x3317,	0x3318,	0x3319,
  /* GB+81 39 D9 30 */	0x331A,	0x331B,	0x331C,	0x331D,	0x331E,
  /* GB+81 39 D9 35 */	0x331F,	0x3320,	0x3321,	0x3322,	0x3323,
  /* GB+81 39 DA 30 */	0x3324,	0x3325,	0x3326,	0x3327,	0x3328,
  /* GB+81 39 DA 35 */	0x3329,	0x332A,	0x332B,	0x332C,	0x332D,
  /* GB+81 39 DB 30 */	0x332E,	0x332F,	0x3330,	0x3331,	0x3332,
  /* GB+81 39 DB 35 */	0x3333,	0x3334,	0x3335,	0x3336,	0x3337,
  /* GB+81 39 DC 30 */	0x3338,	0x3339,	0x333A,	0x333B,	0x333C,
  /* GB+81 39 DC 35 */	0x333D,	0x333E,	0x333F,	0x3340,	0x3341,
  /* GB+81 39 DD 30 */	0x3342,	0x3343,	0x3344,	0x3345,	0x3346,
  /* GB+81 39 DD 35 */	0x3347,	0x3348,	0x3349,	0x334A,	0x334B,
  /* GB+81 39 DE 30 */	0x334C,	0x334D,	0x334E,	0x334F,	0x3350,
  /* GB+81 39 DE 35 */	0x3351,	0x3352,	0x3353,	0x3354,	0x3355,
  /* GB+81 39 DF 30 */	0x3356,	0x3357,	0x3358,	0x3359,	0x335A,
  /* GB+81 39 DF 35 */	0x335B,	0x335C,	0x335D,	0x335E,	0x335F,
  /* GB+81 39 E0 30 */	0x3360,	0x3361,	0x3362,	0x3363,	0x3364,
  /* GB+81 39 E0 35 */	0x3365,	0x3366,	0x3367,	0x3368,	0x3369,
  /* GB+81 39 E1 30 */	0x336A,	0x336B,	0x336C,	0x336D,	0x336E,
  /* GB+81 39 E1 35 */	0x336F,	0x3370,	0x3371,	0x3372,	0x3373,
  /* GB+81 39 E2 30 */	0x3374,	0x3375,	0x3376,	0x3377,	0x3378,
  /* GB+81 39 E2 35 */	0x3379,	0x337A,	0x337B,	0x337C,	0x337D,
  /* GB+81 39 E3 30 */	0x337E,	0x337F,	0x3380,	0x3381,	0x3382,
  /* GB+81 39 E3 35 */	0x3383,	0x3384,	0x3385,	0x3386,	0x3387,
  /* GB+81 39 E4 30 */	0x3388,	0x3389,	0x338A,	0x338B,	0x338C,
  /* GB+81 39 E4 35 */	0x338D,	0x3390,	0x3391,	0x3392,	0x3393,
  /* GB+81 39 E5 30 */	0x3394,	0x3395,	0x3396,	0x3397,	0x3398,
  /* GB+81 39 E5 35 */	0x3399,	0x339A,	0x339B,	0x339F,	0x33A0,
  /* GB+81 39 E6 30 */	0x33A2,	0x33A3,	0x33A4,	0x33A5,	0x33A6,
  /* GB+81 39 E6 35 */	0x33A7,	0x33A8,	0x33A9,	0x33AA,	0x33AB,
  /* GB+81 39 E7 30 */	0x33AC,	0x33AD,	0x33AE,	0x33AF,	0x33B0,
  /* GB+81 39 E7 35 */	0x33B1,	0x33B2,	0x33B3,	0x33B4,	0x33B5,
  /* GB+81 39 E8 30 */	0x33B6,	0x33B7,	0x33B8,	0x33B9,	0x33BA,
  /* GB+81 39 E8 35 */	0x33BB,	0x33BC,	0x33BD,	0x33BE,	0x33BF,
  /* GB+81 39 E9 30 */	0x33C0,	0x33C1,	0x33C2,	0x33C3,	0x33C5,
  /* GB+81 39 E9 35 */	0x33C6,	0x33C7,	0x33C8,	0x33C9,	0x33CA,
  /* GB+81 39 EA 30 */	0x33CB,	0x33CC,	0x33CD,	0x33CF,	0x33D0,
  /* GB+81 39 EA 35 */	0x33D3,	0x33D4,	0x33D6,	0x33D7,	0x33D8,
  /* GB+81 39 EB 30 */	0x33D9,	0x33DA,	0x33DB,	0x33DC,	0x33DD,
  /* GB+81 39 EB 35 */	0x33DE,	0x33DF,	0x33E0,	0x33E1,	0x33E2,
  /* GB+81 39 EC 30 */	0x33E3,	0x33E4,	0x33E5,	0x33E6,	0x33E7,
  /* GB+81 39 EC 35 */	0x33E8,	0x33E9,	0x33EA,	0x33EB,	0x33EC,
  /* GB+81 39 ED 30 */	0x33ED,	0x33EE,	0x33EF,	0x33F0,	0x33F1,
  /* GB+81 39 ED 35 */	0x33F2,	0x33F3,	0x33F4,	0x33F5,	0x33F6,
  /* GB+81 39 EE 30 */	0x33F7,	0x33F8,	0x33F9,	0x33FA,	0x33FB,
  /* GB+81 39 EE 35 */	0x33FC,	0x33FD,	0x33FE,	0x33FF,	0x3400,
  /* GB+81 39 EF 30 */	0x3401,	0x3402,	0x3403,	0x3404,	0x3405,
  /* GB+81 39 EF 35 */	0x3406,	0x3407,	0x3408,	0x3409,	0x340A,
  /* GB+81 39 F0 30 */	0x340B,	0x340C,	0x340D,	0x340E,	0x340F,
  /* GB+81 39 F0 35 */	0x3410,	0x3411,	0x3412,	0x3413,	0x3414,
  /* GB+81 39 F1 30 */	0x3415,	0x3416,	0x3417,	0x3418,	0x3419,
  /* GB+81 39 F1 35 */	0x341A,	0x341B,	0x341C,	0x341D,	0x341E,
  /* GB+81 39 F2 30 */	0x341F,	0x3420,	0x3421,	0x3422,	0x3423,
  /* GB+81 39 F2 35 */	0x3424,	0x3425,	0x3426,	0x3427,	0x3428,
  /* GB+81 39 F3 30 */	0x3429,	0x342A,	0x342B,	0x342C,	0x342D,
  /* GB+81 39 F3 35 */	0x342E,	0x342F,	0x3430,	0x3431,	0x3432,
  /* GB+81 39 F4 30 */	0x3433,	0x3434,	0x3435,	0x3436,	0x3437,
  /* GB+81 39 F4 35 */	0x3438,	0x3439,	0x343A,	0x343B,	0x343C,
  /* GB+81 39 F5 30 */	0x343D,	0x343E,	0x343F,	0x3440,	0x3441,
  /* GB+81 39 F5 35 */	0x3442,	0x3443,	0x3444,	0x3445,	0x3446,
  /* GB+81 39 F6 30 */	0x3448,	0x3449,	0x344A,	0x344B,	0x344C,
  /* GB+81 39 F6 35 */	0x344D,	0x344E,	0x344F,	0x3450,	0x3451,
  /* GB+81 39 F7 30 */	0x3452,	0x3453,	0x3454,	0x3455,	0x3456,
  /* GB+81 39 F7 35 */	0x3457,	0x3458,	0x3459,	0x345A,	0x345B,
  /* GB+81 39 F8 30 */	0x345C,	0x345D,	0x345E,	0x345F,	0x3460,
  /* GB+81 39 F8 35 */	0x3461,	0x3462,	0x3463,	0x3464,	0x3465,
  /* GB+81 39 F9 30 */	0x3466,	0x3467,	0x3468,	0x3469,	0x346A,
  /* GB+81 39 F9 35 */	0x346B,	0x346C,	0x346D,	0x346E,	0x346F,
  /* GB+81 39 FA 30 */	0x3470,	0x3471,	0x3472,	0x3474,	0x3475,
  /* GB+81 39 FA 35 */	0x3476,	0x3477,	0x3478,	0x3479,	0x347A,
  /* GB+81 39 FB 30 */	0x347B,	0x347C,	0x347D,	0x347E,	0x347F,
  /* GB+81 39 FB 35 */	0x3480,	0x3481,	0x3482,	0x3483,	0x3484,
  /* GB+81 39 FC 30 */	0x3485,	0x3486,	0x3487,	0x3488,	0x3489,
  /* GB+81 39 FC 35 */	0x348A,	0x348B,	0x348C,	0x348D,	0x348E,
  /* GB+81 39 FD 30 */	0x348F,	0x3490,	0x3491,	0x3492,	0x3493,
  /* GB+81 39 FD 35 */	0x3494,	0x3495,	0x3496,	0x3497,	0x3498,
  /* GB+81 39 FE 30 */	0x3499,	0x349A,	0x349B,	0x349C,	0x349D,
  /* GB+81 39 FE 35 */	0x349E,	0x349F,	0x34A0,	0x34A1,	0x34A2,
  /* GB+82 30 81 30 */	0x34A3,	0x34A4,	0x34A5,	0x34A6,	0x34A7,
  /* GB+82 30 81 35 */	0x34A8,	0x34A9,	0x34AA,	0x34AB,	0x34AC,
  /* GB+82 30 82 30 */	0x34AD,	0x34AE,	0x34AF,	0x34B0,	0x34B1,
  /* GB+82 30 82 35 */	0x34B2,	0x34B3,	0x34B4,	0x34B5,	0x34B6,
  /* GB+82 30 83 30 */	0x34B7,	0x34B8,	0x34B9,	0x34BA,	0x34BB,
  /* GB+82 30 83 35 */	0x34BC,	0x34BD,	0x34BE,	0x34BF,	0x34C0,
  /* GB+82 30 84 30 */	0x34C1,	0x34C2,	0x34C3,	0x34C4,	0x34C5,
  /* GB+82 30 84 35 */	0x34C6,	0x34C7,	0x34C8,	0x34C9,	0x34CA,
  /* GB+82 30 85 30 */	0x34CB,	0x34CC,	0x34CD,	0x34CE,	0x34CF,
  /* GB+82 30 85 35 */	0x34D0,	0x34D1,	0x34D2,	0x34D3,	0x34D4,
  /* GB+82 30 86 30 */	0x34D5,	0x34D6,	0x34D7,	0x34D8,	0x34D9,
  /* GB+82 30 86 35 */	0x34DA,	0x34DB,	0x34DC,	0x34DD,	0x34DE,
  /* GB+82 30 87 30 */	0x34DF,	0x34E0,	0x34E1,	0x34E2,	0x34E3,
  /* GB+82 30 87 35 */	0x34E4,	0x34E5,	0x34E6,	0x34E7,	0x34E8,
  /* GB+82 30 88 30 */	0x34E9,	0x34EA,	0x34EB,	0x34EC,	0x34ED,
  /* GB+82 30 88 35 */	0x34EE,	0x34EF,	0x34F0,	0x34F1,	0x34F2,
  /* GB+82 30 89 30 */	0x34F3,	0x34F4,	0x34F5,	0x34F6,	0x34F7,
  /* GB+82 30 89 35 */	0x34F8,	0x34F9,	0x34FA,	0x34FB,	0x34FC,
  /* GB+82 30 8A 30 */	0x34FD,	0x34FE,	0x34FF,	0x3500,	0x3501,
  /* GB+82 30 8A 35 */	0x3502,	0x3503,	0x3504,	0x3505,	0x3506,
  /* GB+82 30 8B 30 */	0x3507,	0x3508,	0x3509,	0x350A,	0x350B,
  /* GB+82 30 8B 35 */	0x350C,	0x350D,	0x350E,	0x350F,	0x3510,
  /* GB+82 30 8C 30 */	0x3511,	0x3512,	0x3513,	0x3514,	0x3515,
  /* GB+82 30 8C 35 */	0x3516,	0x3517,	0x3518,	0x3519,	0x351A,
  /* GB+82 30 8D 30 */	0x351B,	0x351C,	0x351D,	0x351E,	0x351F,
  /* GB+82 30 8D 35 */	0x3520,	0x3521,	0x3522,	0x3523,	0x3524,
  /* GB+82 30 8E 30 */	0x3525,	0x3526,	0x3527,	0x3528,	0x3529,
  /* GB+82 30 8E 35 */	0x352A,	0x352B,	0x352C,	0x352D,	0x352E,
  /* GB+82 30 8F 30 */	0x352F,	0x3530,	0x3531,	0x3532,	0x3533,
  /* GB+82 30 8F 35 */	0x3534,	0x3535,	0x3536,	0x3537,	0x3538,
  /* GB+82 30 90 30 */	0x3539,	0x353A,	0x353B,	0x353C,	0x353D,
  /* GB+82 30 90 35 */	0x353E,	0x353F,	0x3540,	0x3541,	0x3542,
  /* GB+82 30 91 30 */	0x3543,	0x3544,	0x3545,	0x3546,	0x3547,
  /* GB+82 30 91 35 */	0x3548,	0x3549,	0x354A,	0x354B,	0x354C,
  /* GB+82 30 92 30 */	0x354D,	0x354E,	0x354F,	0x3550,	0x3551,
  /* GB+82 30 92 35 */	0x3552,	0x3553,	0x3554,	0x3555,	0x3556,
  /* GB+82 30 93 30 */	0x3557,	0x3558,	0x3559,	0x355A,	0x355B,
  /* GB+82 30 93 35 */	0x355C,	0x355D,	0x355E,	0x355F,	0x3560,
  /* GB+82 30 94 30 */	0x3561,	0x3562,	0x3563,	0x3564,	0x3565,
  /* GB+82 30 94 35 */	0x3566,	0x3567,	0x3568,	0x3569,	0x356A,
  /* GB+82 30 95 30 */	0x356B,	0x356C,	0x356D,	0x356E,	0x356F,
  /* GB+82 30 95 35 */	0x3570,	0x3571,	0x3572,	0x3573,	0x3574,
  /* GB+82 30 96 30 */	0x3575,	0x3576,	0x3577,	0x3578,	0x3579,
  /* GB+82 30 96 35 */	0x357A,	0x357B,	0x357C,	0x357D,	0x357E,
  /* GB+82 30 97 30 */	0x357F,	0x3580,	0x3581,	0x3582,	0x3583,
  /* GB+82 30 97 35 */	0x3584,	0x3585,	0x3586,	0x3587,	0x3588,
  /* GB+82 30 98 30 */	0x3589,	0x358A,	0x358B,	0x358C,	0x358D,
  /* GB+82 30 98 35 */	0x358E,	0x358F,	0x3590,	0x3591,	0x3592,
  /* GB+82 30 99 30 */	0x3593,	0x3594,	0x3595,	0x3596,	0x3597,
  /* GB+82 30 99 35 */	0x3598,	0x3599,	0x359A,	0x359B,	0x359C,
  /* GB+82 30 9A 30 */	0x359D,	0x359F,	0x35A0,	0x35A1,	0x35A2,
  /* GB+82 30 9A 35 */	0x35A3,	0x35A4,	0x35A5,	0x35A6,	0x35A7,
  /* GB+82 30 9B 30 */	0x35A8,	0x35A9,	0x35AA,	0x35AB,	0x35AC,
  /* GB+82 30 9B 35 */	0x35AD,	0x35AE,	0x35AF,	0x35B0,	0x35B1,
  /* GB+82 30 9C 30 */	0x35B2,	0x35B3,	0x35B4,	0x35B5,	0x35B6,
  /* GB+82 30 9C 35 */	0x35B7,	0x35B8,	0x35B9,	0x35BA,	0x35BB,
  /* GB+82 30 9D 30 */	0x35BC,	0x35BD,	0x35BE,	0x35BF,	0x35C0,
  /* GB+82 30 9D 35 */	0x35C1,	0x35C2,	0x35C3,	0x35C4,	0x35C5,
  /* GB+82 30 9E 30 */	0x35C6,	0x35C7,	0x35C8,	0x35C9,	0x35CA,
  /* GB+82 30 9E 35 */	0x35CB,	0x35CC,	0x35CD,	0x35CE,	0x35CF,
  /* GB+82 30 9F 30 */	0x35D0,	0x35D1,	0x35D2,	0x35D3,	0x35D4,
  /* GB+82 30 9F 35 */	0x35D5,	0x35D6,	0x35D7,	0x35D8,	0x35D9,
  /* GB+82 30 A0 30 */	0x35DA,	0x35DB,	0x35DC,	0x35DD,	0x35DE,
  /* GB+82 30 A0 35 */	0x35DF,	0x35E0,	0x35E1,	0x35E2,	0x35E3,
  /* GB+82 30 A1 30 */	0x35E4,	0x35E5,	0x35E6,	0x35E7,	0x35E8,
  /* GB+82 30 A1 35 */	0x35E9,	0x35EA,	0x35EB,	0x35EC,	0x35ED,
  /* GB+82 30 A2 30 */	0x35EE,	0x35EF,	0x35F0,	0x35F1,	0x35F2,
  /* GB+82 30 A2 35 */	0x35F3,	0x35F4,	0x35F5,	0x35F6,	0x35F7,
  /* GB+82 30 A3 30 */	0x35F8,	0x35F9,	0x35FA,	0x35FB,	0x35FC,
  /* GB+82 30 A3 35 */	0x35FD,	0x35FE,	0x35FF,	0x3600,	0x3601,
  /* GB+82 30 A4 30 */	0x3602,	0x3603,	0x3604,	0x3605,	0x3606,
  /* GB+82 30 A4 35 */	0x3607,	0x3608,	0x3609,	0x360A,	0x360B,
  /* GB+82 30 A5 30 */	0x360C,	0x360D,	0x360F,	0x3610,	0x3611,
  /* GB+82 30 A5 35 */	0x3612,	0x3613,	0x3614,	0x3615,	0x3616,
  /* GB+82 30 A6 30 */	0x3617,	0x3618,	0x3619,	
  /* Contiguous area: GB+82 30 F2 38 .. GB+82 31 D4 37 */
  /* GB+82 30 F2 38 */				0x3919,	0x391A,
  /* GB+82 30 F3 30 */	0x391B,	0x391C,	0x391D,	0x391E,	0x391F,
  /* GB+82 30 F3 35 */	0x3920,	0x3921,	0x3922,	0x3923,	0x3924,
  /* GB+82 30 F4 30 */	0x3925,	0x3926,	0x3927,	0x3928,	0x3929,
  /* GB+82 30 F4 35 */	0x392A,	0x392B,	0x392C,	0x392D,	0x392E,
  /* GB+82 30 F5 30 */	0x392F,	0x3930,	0x3931,	0x3932,	0x3933,
  /* GB+82 30 F5 35 */	0x3934,	0x3935,	0x3936,	0x3937,	0x3938,
  /* GB+82 30 F6 30 */	0x3939,	0x393A,	0x393B,	0x393C,	0x393D,
  /* GB+82 30 F6 35 */	0x393E,	0x393F,	0x3940,	0x3941,	0x3942,
  /* GB+82 30 F7 30 */	0x3943,	0x3944,	0x3945,	0x3946,	0x3947,
  /* GB+82 30 F7 35 */	0x3948,	0x3949,	0x394A,	0x394B,	0x394C,
  /* GB+82 30 F8 30 */	0x394D,	0x394E,	0x394F,	0x3950,	0x3951,
  /* GB+82 30 F8 35 */	0x3952,	0x3953,	0x3954,	0x3955,	0x3956,
  /* GB+82 30 F9 30 */	0x3957,	0x3958,	0x3959,	0x395A,	0x395B,
  /* GB+82 30 F9 35 */	0x395C,	0x395D,	0x395E,	0x395F,	0x3960,
  /* GB+82 30 FA 30 */	0x3961,	0x3962,	0x3963,	0x3964,	0x3965,
  /* GB+82 30 FA 35 */	0x3966,	0x3967,	0x3968,	0x3969,	0x396A,
  /* GB+82 30 FB 30 */	0x396B,	0x396C,	0x396D,	0x396F,	0x3970,
  /* GB+82 30 FB 35 */	0x3971,	0x3972,	0x3973,	0x3974,	0x3975,
  /* GB+82 30 FC 30 */	0x3976,	0x3977,	0x3978,	0x3979,	0x397A,
  /* GB+82 30 FC 35 */	0x397B,	0x397C,	0x397D,	0x397E,	0x397F,
  /* GB+82 30 FD 30 */	0x3980,	0x3981,	0x3982,	0x3983,	0x3984,
  /* GB+82 30 FD 35 */	0x3985,	0x3986,	0x3987,	0x3988,	0x3989,
  /* GB+82 30 FE 30 */	0x398A,	0x398B,	0x398C,	0x398D,	0x398E,
  /* GB+82 30 FE 35 */	0x398F,	0x3990,	0x3991,	0x3992,	0x3993,
  /* GB+82 31 81 30 */	0x3994,	0x3995,	0x3996,	0x3997,	0x3998,
  /* GB+82 31 81 35 */	0x3999,	0x399A,	0x399B,	0x399C,	0x399D,
  /* GB+82 31 82 30 */	0x399E,	0x399F,	0x39A0,	0x39A1,	0x39A2,
  /* GB+82 31 82 35 */	0x39A3,	0x39A4,	0x39A5,	0x39A6,	0x39A7,
  /* GB+82 31 83 30 */	0x39A8,	0x39A9,	0x39AA,	0x39AB,	0x39AC,
  /* GB+82 31 83 35 */	0x39AD,	0x39AE,	0x39AF,	0x39B0,	0x39B1,
  /* GB+82 31 84 30 */	0x39B2,	0x39B3,	0x39B4,	0x39B5,	0x39B6,
  /* GB+82 31 84 35 */	0x39B7,	0x39B8,	0x39B9,	0x39BA,	0x39BB,
  /* GB+82 31 85 30 */	0x39BC,	0x39BD,	0x39BE,	0x39BF,	0x39C0,
  /* GB+82 31 85 35 */	0x39C1,	0x39C2,	0x39C3,	0x39C4,	0x39C5,
  /* GB+82 31 86 30 */	0x39C6,	0x39C7,	0x39C8,	0x39C9,	0x39CA,
  /* GB+82 31 86 35 */	0x39CB,	0x39CC,	0x39CD,	0x39CE,	0x39D1,
  /* GB+82 31 87 30 */	0x39D2,	0x39D3,	0x39D4,	0x39D5,	0x39D6,
  /* GB+82 31 87 35 */	0x39D7,	0x39D8,	0x39D9,	0x39DA,	0x39DB,
  /* GB+82 31 88 30 */	0x39DC,	0x39DD,	0x39DE,	0x39E0,	0x39E1,
  /* GB+82 31 88 35 */	0x39E2,	0x39E3,	0x39E4,	0x39E5,	0x39E6,
  /* GB+82 31 89 30 */	0x39E7,	0x39E8,	0x39E9,	0x39EA,	0x39EB,
  /* GB+82 31 89 35 */	0x39EC,	0x39ED,	0x39EE,	0x39EF,	0x39F0,
  /* GB+82 31 8A 30 */	0x39F1,	0x39F2,	0x39F3,	0x39F4,	0x39F5,
  /* GB+82 31 8A 35 */	0x39F6,	0x39F7,	0x39F8,	0x39F9,	0x39FA,
  /* GB+82 31 8B 30 */	0x39FB,	0x39FC,	0x39FD,	0x39FE,	0x39FF,
  /* GB+82 31 8B 35 */	0x3A00,	0x3A01,	0x3A02,	0x3A03,	0x3A04,
  /* GB+82 31 8C 30 */	0x3A05,	0x3A06,	0x3A07,	0x3A08,	0x3A09,
  /* GB+82 31 8C 35 */	0x3A0A,	0x3A0B,	0x3A0C,	0x3A0D,	0x3A0E,
  /* GB+82 31 8D 30 */	0x3A0F,	0x3A10,	0x3A11,	0x3A12,	0x3A13,
  /* GB+82 31 8D 35 */	0x3A14,	0x3A15,	0x3A16,	0x3A17,	0x3A18,
  /* GB+82 31 8E 30 */	0x3A19,	0x3A1A,	0x3A1B,	0x3A1C,	0x3A1D,
  /* GB+82 31 8E 35 */	0x3A1E,	0x3A1F,	0x3A20,	0x3A21,	0x3A22,
  /* GB+82 31 8F 30 */	0x3A23,	0x3A24,	0x3A25,	0x3A26,	0x3A27,
  /* GB+82 31 8F 35 */	0x3A28,	0x3A29,	0x3A2A,	0x3A2B,	0x3A2C,
  /* GB+82 31 90 30 */	0x3A2D,	0x3A2E,	0x3A2F,	0x3A30,	0x3A31,
  /* GB+82 31 90 35 */	0x3A32,	0x3A33,	0x3A34,	0x3A35,	0x3A36,
  /* GB+82 31 91 30 */	0x3A37,	0x3A38,	0x3A39,	0x3A3A,	0x3A3B,
  /* GB+82 31 91 35 */	0x3A3C,	0x3A3D,	0x3A3E,	0x3A3F,	0x3A40,
  /* GB+82 31 92 30 */	0x3A41,	0x3A42,	0x3A43,	0x3A44,	0x3A45,
  /* GB+82 31 92 35 */	0x3A46,	0x3A47,	0x3A48,	0x3A49,	0x3A4A,
  /* GB+82 31 93 30 */	0x3A4B,	0x3A4C,	0x3A4D,	0x3A4E,	0x3A4F,
  /* GB+82 31 93 35 */	0x3A50,	0x3A51,	0x3A52,	0x3A53,	0x3A54,
  /* GB+82 31 94 30 */	0x3A55,	0x3A56,	0x3A57,	0x3A58,	0x3A59,
  /* GB+82 31 94 35 */	0x3A5A,	0x3A5B,	0x3A5C,	0x3A5D,	0x3A5E,
  /* GB+82 31 95 30 */	0x3A5F,	0x3A60,	0x3A61,	0x3A62,	0x3A63,
  /* GB+82 31 95 35 */	0x3A64,	0x3A65,	0x3A66,	0x3A67,	0x3A68,
  /* GB+82 31 96 30 */	0x3A69,	0x3A6A,	0x3A6B,	0x3A6C,	0x3A6D,
  /* GB+82 31 96 35 */	0x3A6E,	0x3A6F,	0x3A70,	0x3A71,	0x3A72,
  /* GB+82 31 97 30 */	0x3A74,	0x3A75,	0x3A76,	0x3A77,	0x3A78,
  /* GB+82 31 97 35 */	0x3A79,	0x3A7A,	0x3A7B,	0x3A7C,	0x3A7D,
  /* GB+82 31 98 30 */	0x3A7E,	0x3A7F,	0x3A80,	0x3A81,	0x3A82,
  /* GB+82 31 98 35 */	0x3A83,	0x3A84,	0x3A85,	0x3A86,	0x3A87,
  /* GB+82 31 99 30 */	0x3A88,	0x3A89,	0x3A8A,	0x3A8B,	0x3A8C,
  /* GB+82 31 99 35 */	0x3A8D,	0x3A8E,	0x3A8F,	0x3A90,	0x3A91,
  /* GB+82 31 9A 30 */	0x3A92,	0x3A93,	0x3A94,	0x3A95,	0x3A96,
  /* GB+82 31 9A 35 */	0x3A97,	0x3A98,	0x3A99,	0x3A9A,	0x3A9B,
  /* GB+82 31 9B 30 */	0x3A9C,	0x3A9D,	0x3A9E,	0x3A9F,	0x3AA0,
  /* GB+82 31 9B 35 */	0x3AA1,	0x3AA2,	0x3AA3,	0x3AA4,	0x3AA5,
  /* GB+82 31 9C 30 */	0x3AA6,	0x3AA7,	0x3AA8,	0x3AA9,	0x3AAA,
  /* GB+82 31 9C 35 */	0x3AAB,	0x3AAC,	0x3AAD,	0x3AAE,	0x3AAF,
  /* GB+82 31 9D 30 */	0x3AB0,	0x3AB1,	0x3AB2,	0x3AB3,	0x3AB4,
  /* GB+82 31 9D 35 */	0x3AB5,	0x3AB6,	0x3AB7,	0x3AB8,	0x3AB9,
  /* GB+82 31 9E 30 */	0x3ABA,	0x3ABB,	0x3ABC,	0x3ABD,	0x3ABE,
  /* GB+82 31 9E 35 */	0x3ABF,	0x3AC0,	0x3AC1,	0x3AC2,	0x3AC3,
  /* GB+82 31 9F 30 */	0x3AC4,	0x3AC5,	0x3AC6,	0x3AC7,	0x3AC8,
  /* GB+82 31 9F 35 */	0x3AC9,	0x3ACA,	0x3ACB,	0x3ACC,	0x3ACD,
  /* GB+82 31 A0 30 */	0x3ACE,	0x3ACF,	0x3AD0,	0x3AD1,	0x3AD2,
  /* GB+82 31 A0 35 */	0x3AD3,	0x3AD4,	0x3AD5,	0x3AD6,	0x3AD7,
  /* GB+82 31 A1 30 */	0x3AD8,	0x3AD9,	0x3ADA,	0x3ADB,	0x3ADC,
  /* GB+82 31 A1 35 */	0x3ADD,	0x3ADE,	0x3ADF,	0x3AE0,	0x3AE1,
  /* GB+82 31 A2 30 */	0x3AE2,	0x3AE3,	0x3AE4,	0x3AE5,	0x3AE6,
  /* GB+82 31 A2 35 */	0x3AE7,	0x3AE8,	0x3AE9,	0x3AEA,	0x3AEB,
  /* GB+82 31 A3 30 */	0x3AEC,	0x3AED,	0x3AEE,	0x3AEF,	0x3AF0,
  /* GB+82 31 A3 35 */	0x3AF1,	0x3AF2,	0x3AF3,	0x3AF4,	0x3AF5,
  /* GB+82 31 A4 30 */	0x3AF6,	0x3AF7,	0x3AF8,	0x3AF9,	0x3AFA,
  /* GB+82 31 A4 35 */	0x3AFB,	0x3AFC,	0x3AFD,	0x3AFE,	0x3AFF,
  /* GB+82 31 A5 30 */	0x3B00,	0x3B01,	0x3B02,	0x3B03,	0x3B04,
  /* GB+82 31 A5 35 */	0x3B05,	0x3B06,	0x3B07,	0x3B08,	0x3B09,
  /* GB+82 31 A6 30 */	0x3B0A,	0x3B0B,	0x3B0C,	0x3B0D,	0x3B0E,
  /* GB+82 31 A6 35 */	0x3B0F,	0x3B10,	0x3B11,	0x3B12,	0x3B13,
  /* GB+82 31 A7 30 */	0x3B14,	0x3B15,	0x3B16,	0x3B17,	0x3B18,
  /* GB+82 31 A7 35 */	0x3B19,	0x3B1A,	0x3B1B,	0x3B1C,	0x3B1D,
  /* GB+82 31 A8 30 */	0x3B1E,	0x3B1F,	0x3B20,	0x3B21,	0x3B22,
  /* GB+82 31 A8 35 */	0x3B23,	0x3B24,	0x3B25,	0x3B26,	0x3B27,
  /* GB+82 31 A9 30 */	0x3B28,	0x3B29,	0x3B2A,	0x3B2B,	0x3B2C,
  /* GB+82 31 A9 35 */	0x3B2D,	0x3B2E,	0x3B2F,	0x3B30,	0x3B31,
  /* GB+82 31 AA 30 */	0x3B32,	0x3B33,	0x3B34,	0x3B35,	0x3B36,
  /* GB+82 31 AA 35 */	0x3B37,	0x3B38,	0x3B39,	0x3B3A,	0x3B3B,
  /* GB+82 31 AB 30 */	0x3B3C,	0x3B3D,	0x3B3E,	0x3B3F,	0x3B40,
  /* GB+82 31 AB 35 */	0x3B41,	0x3B42,	0x3B43,	0x3B44,	0x3B45,
  /* GB+82 31 AC 30 */	0x3B46,	0x3B47,	0x3B48,	0x3B49,	0x3B4A,
  /* GB+82 31 AC 35 */	0x3B4B,	0x3B4C,	0x3B4D,	0x3B4F,	0x3B50,
  /* GB+82 31 AD 30 */	0x3B51,	0x3B52,	0x3B53,	0x3B54,	0x3B55,
  /* GB+82 31 AD 35 */	0x3B56,	0x3B57,	0x3B58,	0x3B59,	0x3B5A,
  /* GB+82 31 AE 30 */	0x3B5B,	0x3B5C,	0x3B5D,	0x3B5E,	0x3B5F,
  /* GB+82 31 AE 35 */	0x3B60,	0x3B61,	0x3B62,	0x3B63,	0x3B64,
  /* GB+82 31 AF 30 */	0x3B65,	0x3B66,	0x3B67,	0x3B68,	0x3B69,
  /* GB+82 31 AF 35 */	0x3B6A,	0x3B6B,	0x3B6C,	0x3B6D,	0x3B6E,
  /* GB+82 31 B0 30 */	0x3B6F,	0x3B70,	0x3B71,	0x3B72,	0x3B73,
  /* GB+82 31 B0 35 */	0x3B74,	0x3B75,	0x3B76,	0x3B77,	0x3B78,
  /* GB+82 31 B1 30 */	0x3B79,	0x3B7A,	0x3B7B,	0x3B7C,	0x3B7D,
  /* GB+82 31 B1 35 */	0x3B7E,	0x3B7F,	0x3B80,	0x3B81,	0x3B82,
  /* GB+82 31 B2 30 */	0x3B83,	0x3B84,	0x3B85,	0x3B86,	0x3B87,
  /* GB+82 31 B2 35 */	0x3B88,	0x3B89,	0x3B8A,	0x3B8B,	0x3B8C,
  /* GB+82 31 B3 30 */	0x3B8D,	0x3B8E,	0x3B8F,	0x3B90,	0x3B91,
  /* GB+82 31 B3 35 */	0x3B92,	0x3B93,	0x3B94,	0x3B95,	0x3B96,
  /* GB+82 31 B4 30 */	0x3B97,	0x3B98,	0x3B99,	0x3B9A,	0x3B9B,
  /* GB+82 31 B4 35 */	0x3B9C,	0x3B9D,	0x3B9E,	0x3B9F,	0x3BA0,
  /* GB+82 31 B5 30 */	0x3BA1,	0x3BA2,	0x3BA3,	0x3BA4,	0x3BA5,
  /* GB+82 31 B5 35 */	0x3BA6,	0x3BA7,	0x3BA8,	0x3BA9,	0x3BAA,
  /* GB+82 31 B6 30 */	0x3BAB,	0x3BAC,	0x3BAD,	0x3BAE,	0x3BAF,
  /* GB+82 31 B6 35 */	0x3BB0,	0x3BB1,	0x3BB2,	0x3BB3,	0x3BB4,
  /* GB+82 31 B7 30 */	0x3BB5,	0x3BB6,	0x3BB7,	0x3BB8,	0x3BB9,
  /* GB+82 31 B7 35 */	0x3BBA,	0x3BBB,	0x3BBC,	0x3BBD,	0x3BBE,
  /* GB+82 31 B8 30 */	0x3BBF,	0x3BC0,	0x3BC1,	0x3BC2,	0x3BC3,
  /* GB+82 31 B8 35 */	0x3BC4,	0x3BC5,	0x3BC6,	0x3BC7,	0x3BC8,
  /* GB+82 31 B9 30 */	0x3BC9,	0x3BCA,	0x3BCB,	0x3BCC,	0x3BCD,
  /* GB+82 31 B9 35 */	0x3BCE,	0x3BCF,	0x3BD0,	0x3BD1,	0x3BD2,
  /* GB+82 31 BA 30 */	0x3BD3,	0x3BD4,	0x3BD5,	0x3BD6,	0x3BD7,
  /* GB+82 31 BA 35 */	0x3BD8,	0x3BD9,	0x3BDA,	0x3BDB,	0x3BDC,
  /* GB+82 31 BB 30 */	0x3BDD,	0x3BDE,	0x3BDF,	0x3BE0,	0x3BE1,
  /* GB+82 31 BB 35 */	0x3BE2,	0x3BE3,	0x3BE4,	0x3BE5,	0x3BE6,
  /* GB+82 31 BC 30 */	0x3BE7,	0x3BE8,	0x3BE9,	0x3BEA,	0x3BEB,
  /* GB+82 31 BC 35 */	0x3BEC,	0x3BED,	0x3BEE,	0x3BEF,	0x3BF0,
  /* GB+82 31 BD 30 */	0x3BF1,	0x3BF2,	0x3BF3,	0x3BF4,	0x3BF5,
  /* GB+82 31 BD 35 */	0x3BF6,	0x3BF7,	0x3BF8,	0x3BF9,	0x3BFA,
  /* GB+82 31 BE 30 */	0x3BFB,	0x3BFC,	0x3BFD,	0x3BFE,	0x3BFF,
  /* GB+82 31 BE 35 */	0x3C00,	0x3C01,	0x3C02,	0x3C03,	0x3C04,
  /* GB+82 31 BF 30 */	0x3C05,	0x3C06,	0x3C07,	0x3C08,	0x3C09,
  /* GB+82 31 BF 35 */	0x3C0A,	0x3C0B,	0x3C0C,	0x3C0D,	0x3C0E,
  /* GB+82 31 C0 30 */	0x3C0F,	0x3C10,	0x3C11,	0x3C12,	0x3C13,
  /* GB+82 31 C0 35 */	0x3C14,	0x3C15,	0x3C16,	0x3C17,	0x3C18,
  /* GB+82 31 C1 30 */	0x3C19,	0x3C1A,	0x3C1B,	0x3C1C,	0x3C1D,
  /* GB+82 31 C1 35 */	0x3C1E,	0x3C1F,	0x3C20,	0x3C21,	0x3C22,
  /* GB+82 31 C2 30 */	0x3C23,	0x3C24,	0x3C25,	0x3C26,	0x3C27,
  /* GB+82 31 C2 35 */	0x3C28,	0x3C29,	0x3C2A,	0x3C2B,	0x3C2C,
  /* GB+82 31 C3 30 */	0x3C2D,	0x3C2E,	0x3C2F,	0x3C30,	0x3C31,
  /* GB+82 31 C3 35 */	0x3C32,	0x3C33,	0x3C34,	0x3C35,	0x3C36,
  /* GB+82 31 C4 30 */	0x3C37,	0x3C38,	0x3C39,	0x3C3A,	0x3C3B,
  /* GB+82 31 C4 35 */	0x3C3C,	0x3C3D,	0x3C3E,	0x3C3F,	0x3C40,
  /* GB+82 31 C5 30 */	0x3C41,	0x3C42,	0x3C43,	0x3C44,	0x3C45,
  /* GB+82 31 C5 35 */	0x3C46,	0x3C47,	0x3C48,	0x3C49,	0x3C4A,
  /* GB+82 31 C6 30 */	0x3C4B,	0x3C4C,	0x3C4D,	0x3C4E,	0x3C4F,
  /* GB+82 31 C6 35 */	0x3C50,	0x3C51,	0x3C52,	0x3C53,	0x3C54,
  /* GB+82 31 C7 30 */	0x3C55,	0x3C56,	0x3C57,	0x3C58,	0x3C59,
  /* GB+82 31 C7 35 */	0x3C5A,	0x3C5B,	0x3C5C,	0x3C5D,	0x3C5E,
  /* GB+82 31 C8 30 */	0x3C5F,	0x3C60,	0x3C61,	0x3C62,	0x3C63,
  /* GB+82 31 C8 35 */	0x3C64,	0x3C65,	0x3C66,	0x3C67,	0x3C68,
  /* GB+82 31 C9 30 */	0x3C69,	0x3C6A,	0x3C6B,	0x3C6C,	0x3C6D,
  /* GB+82 31 C9 35 */	0x3C6F,	0x3C70,	0x3C71,	0x3C72,	0x3C73,
  /* GB+82 31 CA 30 */	0x3C74,	0x3C75,	0x3C76,	0x3C77,	0x3C78,
  /* GB+82 31 CA 35 */	0x3C79,	0x3C7A,	0x3C7B,	0x3C7C,	0x3C7D,
  /* GB+82 31 CB 30 */	0x3C7E,	0x3C7F,	0x3C80,	0x3C81,	0x3C82,
  /* GB+82 31 CB 35 */	0x3C83,	0x3C84,	0x3C85,	0x3C86,	0x3C87,
  /* GB+82 31 CC 30 */	0x3C88,	0x3C89,	0x3C8A,	0x3C8B,	0x3C8C,
  /* GB+82 31 CC 35 */	0x3C8D,	0x3C8E,	0x3C8F,	0x3C90,	0x3C91,
  /* GB+82 31 CD 30 */	0x3C92,	0x3C93,	0x3C94,	0x3C95,	0x3C96,
  /* GB+82 31 CD 35 */	0x3C97,	0x3C98,	0x3C99,	0x3C9A,	0x3C9B,
  /* GB+82 31 CE 30 */	0x3C9C,	0x3C9D,	0x3C9E,	0x3C9F,	0x3CA0,
  /* GB+82 31 CE 35 */	0x3CA1,	0x3CA2,	0x3CA3,	0x3CA4,	0x3CA5,
  /* GB+82 31 CF 30 */	0x3CA6,	0x3CA7,	0x3CA8,	0x3CA9,	0x3CAA,
  /* GB+82 31 CF 35 */	0x3CAB,	0x3CAC,	0x3CAD,	0x3CAE,	0x3CAF,
  /* GB+82 31 D0 30 */	0x3CB0,	0x3CB1,	0x3CB2,	0x3CB3,	0x3CB4,
  /* GB+82 31 D0 35 */	0x3CB5,	0x3CB6,	0x3CB7,	0x3CB8,	0x3CB9,
  /* GB+82 31 D1 30 */	0x3CBA,	0x3CBB,	0x3CBC,	0x3CBD,	0x3CBE,
  /* GB+82 31 D1 35 */	0x3CBF,	0x3CC0,	0x3CC1,	0x3CC2,	0x3CC3,
  /* GB+82 31 D2 30 */	0x3CC4,	0x3CC5,	0x3CC6,	0x3CC7,	0x3CC8,
  /* GB+82 31 D2 35 */	0x3CC9,	0x3CCA,	0x3CCB,	0x3CCC,	0x3CCD,
  /* GB+82 31 D3 30 */	0x3CCE,	0x3CCF,	0x3CD0,	0x3CD1,	0x3CD2,
  /* GB+82 31 D3 35 */	0x3CD3,	0x3CD4,	0x3CD5,	0x3CD6,	0x3CD7,
  /* GB+82 31 D4 30 */	0x3CD8,	0x3CD9,	0x3CDA,	0x3CDB,	0x3CDC,
  /* GB+82 31 D4 35 */	0x3CDD,	0x3CDE,	0x3CDF,	
  /* Contiguous area: GB+82 32 AF 33 .. GB+82 32 C9 36 */
  /* GB+82 32 AF 33 */				0x4057,	0x4058,
  /* GB+82 32 AF 35 */	0x4059,	0x405A,	0x405B,	0x405C,	0x405D,
  /* GB+82 32 B0 30 */	0x405E,	0x405F,	0x4060,	0x4061,	0x4062,
  /* GB+82 32 B0 35 */	0x4063,	0x4064,	0x4065,	0x4066,	0x4067,
  /* GB+82 32 B1 30 */	0x4068,	0x4069,	0x406A,	0x406B,	0x406C,
  /* GB+82 32 B1 35 */	0x406D,	0x406E,	0x406F,	0x4070,	0x4071,
  /* GB+82 32 B2 30 */	0x4072,	0x4073,	0x4074,	0x4075,	0x4076,
  /* GB+82 32 B2 35 */	0x4077,	0x4078,	0x4079,	0x407A,	0x407B,
  /* GB+82 32 B3 30 */	0x407C,	0x407D,	0x407E,	0x407F,	0x4080,
  /* GB+82 32 B3 35 */	0x4081,	0x4082,	0x4083,	0x4084,	0x4085,
  /* GB+82 32 B4 30 */	0x4086,	0x4087,	0x4088,	0x4089,	0x408A,
  /* GB+82 32 B4 35 */	0x408B,	0x408C,	0x408D,	0x408E,	0x408F,
  /* GB+82 32 B5 30 */	0x4090,	0x4091,	0x4092,	0x4093,	0x4094,
  /* GB+82 32 B5 35 */	0x4095,	0x4096,	0x4097,	0x4098,	0x4099,
  /* GB+82 32 B6 30 */	0x409A,	0x409B,	0x409C,	0x409D,	0x409E,
  /* GB+82 32 B6 35 */	0x409F,	0x40A0,	0x40A1,	0x40A2,	0x40A3,
  /* GB+82 32 B7 30 */	0x40A4,	0x40A5,	0x40A6,	0x40A7,	0x40A8,
  /* GB+82 32 B7 35 */	0x40A9,	0x40AA,	0x40AB,	0x40AC,	0x40AD,
  /* GB+82 32 B8 30 */	0x40AE,	0x40AF,	0x40B0,	0x40B1,	0x40B2,
  /* GB+82 32 B8 35 */	0x40B3,	0x40B4,	0x40B5,	0x40B6,	0x40B7,
  /* GB+82 32 B9 30 */	0x40B8,	0x40B9,	0x40BA,	0x40BB,	0x40BC,
  /* GB+82 32 B9 35 */	0x40BD,	0x40BE,	0x40BF,	0x40C0,	0x40C1,
  /* GB+82 32 BA 30 */	0x40C2,	0x40C3,	0x40C4,	0x40C5,	0x40C6,
  /* GB+82 32 BA 35 */	0x40C7,	0x40C8,	0x40C9,	0x40CA,	0x40CB,
  /* GB+82 32 BB 30 */	0x40CC,	0x40CD,	0x40CE,	0x40CF,	0x40D0,
  /* GB+82 32 BB 35 */	0x40D1,	0x40D2,	0x40D3,	0x40D4,	0x40D5,
  /* GB+82 32 BC 30 */	0x40D6,	0x40D7,	0x40D8,	0x40D9,	0x40DA,
  /* GB+82 32 BC 35 */	0x40DB,	0x40DC,	0x40DD,	0x40DE,	0x40DF,
  /* GB+82 32 BD 30 */	0x40E0,	0x40E1,	0x40E2,	0x40E3,	0x40E4,
  /* GB+82 32 BD 35 */	0x40E5,	0x40E6,	0x40E7,	0x40E8,	0x40E9,
  /* GB+82 32 BE 30 */	0x40EA,	0x40EB,	0x40EC,	0x40ED,	0x40EE,
  /* GB+82 32 BE 35 */	0x40EF,	0x40F0,	0x40F1,	0x40F2,	0x40F3,
  /* GB+82 32 BF 30 */	0x40F4,	0x40F5,	0x40F6,	0x40F7,	0x40F8,
  /* GB+82 32 BF 35 */	0x40F9,	0x40FA,	0x40FB,	0x40FC,	0x40FD,
  /* GB+82 32 C0 30 */	0x40FE,	0x40FF,	0x4100,	0x4101,	0x4102,
  /* GB+82 32 C0 35 */	0x4103,	0x4104,	0x4105,	0x4106,	0x4107,
  /* GB+82 32 C1 30 */	0x4108,	0x4109,	0x410A,	0x410B,	0x410C,
  /* GB+82 32 C1 35 */	0x410D,	0x410E,	0x410F,	0x4110,	0x4111,
  /* GB+82 32 C2 30 */	0x4112,	0x4113,	0x4114,	0x4115,	0x4116,
  /* GB+82 32 C2 35 */	0x4117,	0x4118,	0x4119,	0x411A,	0x411B,
  /* GB+82 32 C3 30 */	0x411C,	0x411D,	0x411E,	0x411F,	0x4120,
  /* GB+82 32 C3 35 */	0x4121,	0x4122,	0x4123,	0x4124,	0x4125,
  /* GB+82 32 C4 30 */	0x4126,	0x4127,	0x4128,	0x4129,	0x412A,
  /* GB+82 32 C4 35 */	0x412B,	0x412C,	0x412D,	0x412E,	0x412F,
  /* GB+82 32 C5 30 */	0x4130,	0x4131,	0x4132,	0x4133,	0x4134,
  /* GB+82 32 C5 35 */	0x4135,	0x4136,	0x4137,	0x4138,	0x4139,
  /* GB+82 32 C6 30 */	0x413A,	0x413B,	0x413C,	0x413D,	0x413E,
  /* GB+82 32 C6 35 */	0x413F,	0x4140,	0x4141,	0x4142,	0x4143,
  /* GB+82 32 C7 30 */	0x4144,	0x4145,	0x4146,	0x4147,	0x4148,
  /* GB+82 32 C7 35 */	0x4149,	0x414A,	0x414B,	0x414C,	0x414D,
  /* GB+82 32 C8 30 */	0x414E,	0x414F,	0x4150,	0x4151,	0x4152,
  /* GB+82 32 C8 35 */	0x4153,	0x4154,	0x4155,	0x4156,	0x4157,
  /* GB+82 32 C9 30 */	0x4158,	0x4159,	0x415A,	0x415B,	0x415C,
  /* GB+82 32 C9 35 */	0x415D,	0x415E,	
  /* Contiguous area: GB+82 32 F8 38 .. GB+82 33 A3 38 */
  /* GB+82 32 F8 38 */				0x4338,	0x4339,
  /* GB+82 32 F9 30 */	0x433A,	0x433B,	0x433C,	0x433D,	0x433E,
  /* GB+82 32 F9 35 */	0x433F,	0x4340,	0x4341,	0x4342,	0x4343,
  /* GB+82 32 FA 30 */	0x4344,	0x4345,	0x4346,	0x4347,	0x4348,
  /* GB+82 32 FA 35 */	0x4349,	0x434A,	0x434B,	0x434C,	0x434D,
  /* GB+82 32 FB 30 */	0x434E,	0x434F,	0x4350,	0x4351,	0x4352,
  /* GB+82 32 FB 35 */	0x4353,	0x4354,	0x4355,	0x4356,	0x4357,
  /* GB+82 32 FC 30 */	0x4358,	0x4359,	0x435A,	0x435B,	0x435C,
  /* GB+82 32 FC 35 */	0x435D,	0x435E,	0x435F,	0x4360,	0x4361,
  /* GB+82 32 FD 30 */	0x4362,	0x4363,	0x4364,	0x4365,	0x4366,
  /* GB+82 32 FD 35 */	0x4367,	0x4368,	0x4369,	0x436A,	0x436B,
  /* GB+82 32 FE 30 */	0x436C,	0x436D,	0x436E,	0x436F,	0x4370,
  /* GB+82 32 FE 35 */	0x4371,	0x4372,	0x4373,	0x4374,	0x4375,
  /* GB+82 33 81 30 */	0x4376,	0x4377,	0x4378,	0x4379,	0x437A,
  /* GB+82 33 81 35 */	0x437B,	0x437C,	0x437D,	0x437E,	0x437F,
  /* GB+82 33 82 30 */	0x4380,	0x4381,	0x4382,	0x4383,	0x4384,
  /* GB+82 33 82 35 */	0x4385,	0x4386,	0x4387,	0x4388,	0x4389,
  /* GB+82 33 83 30 */	0x438A,	0x438B,	0x438C,	0x438D,	0x438E,
  /* GB+82 33 83 35 */	0x438F,	0x4390,	0x4391,	0x4392,	0x4393,
  /* GB+82 33 84 30 */	0x4394,	0x4395,	0x4396,	0x4397,	0x4398,
  /* GB+82 33 84 35 */	0x4399,	0x439A,	0x439B,	0x439C,	0x439D,
  /* GB+82 33 85 30 */	0x439E,	0x439F,	0x43A0,	0x43A1,	0x43A2,
  /* GB+82 33 85 35 */	0x43A3,	0x43A4,	0x43A5,	0x43A6,	0x43A7,
  /* GB+82 33 86 30 */	0x43A8,	0x43A9,	0x43AA,	0x43AB,	0x43AD,
  /* GB+82 33 86 35 */	0x43AE,	0x43AF,	0x43B0,	0x43B2,	0x43B3,
  /* GB+82 33 87 30 */	0x43B4,	0x43B5,	0x43B6,	0x43B7,	0x43B8,
  /* GB+82 33 87 35 */	0x43B9,	0x43BA,	0x43BB,	0x43BC,	0x43BD,
  /* GB+82 33 88 30 */	0x43BE,	0x43BF,	0x43C0,	0x43C1,	0x43C2,
  /* GB+82 33 88 35 */	0x43C3,	0x43C4,	0x43C5,	0x43C6,	0x43C7,
  /* GB+82 33 89 30 */	0x43C8,	0x43C9,	0x43CA,	0x43CB,	0x43CC,
  /* GB+82 33 89 35 */	0x43CD,	0x43CE,	0x43CF,	0x43D0,	0x43D1,
  /* GB+82 33 8A 30 */	0x43D2,	0x43D3,	0x43D4,	0x43D5,	0x43D6,
  /* GB+82 33 8A 35 */	0x43D7,	0x43D8,	0x43D9,	0x43DA,	0x43DB,
  /* GB+82 33 8B 30 */	0x43DC,	0x43DE,	0x43DF,	0x43E0,	0x43E1,
  /* GB+82 33 8B 35 */	0x43E2,	0x43E3,	0x43E4,	0x43E5,	0x43E6,
  /* GB+82 33 8C 30 */	0x43E7,	0x43E8,	0x43E9,	0x43EA,	0x43EB,
  /* GB+82 33 8C 35 */	0x43EC,	0x43ED,	0x43EE,	0x43EF,	0x43F0,
  /* GB+82 33 8D 30 */	0x43F1,	0x43F2,	0x43F3,	0x43F4,	0x43F5,
  /* GB+82 33 8D 35 */	0x43F6,	0x43F7,	0x43F8,	0x43F9,	0x43FA,
  /* GB+82 33 8E 30 */	0x43FB,	0x43FC,	0x43FD,	0x43FE,	0x43FF,
  /* GB+82 33 8E 35 */	0x4400,	0x4401,	0x4402,	0x4403,	0x4404,
  /* GB+82 33 8F 30 */	0x4405,	0x4406,	0x4407,	0x4408,	0x4409,
  /* GB+82 33 8F 35 */	0x440A,	0x440B,	0x440C,	0x440D,	0x440E,
  /* GB+82 33 90 30 */	0x440F,	0x4410,	0x4411,	0x4412,	0x4413,
  /* GB+82 33 90 35 */	0x4414,	0x4415,	0x4416,	0x4417,	0x4418,
  /* GB+82 33 91 30 */	0x4419,	0x441A,	0x441B,	0x441C,	0x441D,
  /* GB+82 33 91 35 */	0x441E,	0x441F,	0x4420,	0x4421,	0x4422,
  /* GB+82 33 92 30 */	0x4423,	0x4424,	0x4425,	0x4426,	0x4427,
  /* GB+82 33 92 35 */	0x4428,	0x4429,	0x442A,	0x442B,	0x442C,
  /* GB+82 33 93 30 */	0x442D,	0x442E,	0x442F,	0x4430,	0x4431,
  /* GB+82 33 93 35 */	0x4432,	0x4433,	0x4434,	0x4435,	0x4436,
  /* GB+82 33 94 30 */	0x4437,	0x4438,	0x4439,	0x443A,	0x443B,
  /* GB+82 33 94 35 */	0x443C,	0x443D,	0x443E,	0x443F,	0x4440,
  /* GB+82 33 95 30 */	0x4441,	0x4442,	0x4443,	0x4444,	0x4445,
  /* GB+82 33 95 35 */	0x4446,	0x4447,	0x4448,	0x4449,	0x444A,
  /* GB+82 33 96 30 */	0x444B,	0x444C,	0x444D,	0x444E,	0x444F,
  /* GB+82 33 96 35 */	0x4450,	0x4451,	0x4452,	0x4453,	0x4454,
  /* GB+82 33 97 30 */	0x4455,	0x4456,	0x4457,	0x4458,	0x4459,
  /* GB+82 33 97 35 */	0x445A,	0x445B,	0x445C,	0x445D,	0x445E,
  /* GB+82 33 98 30 */	0x445F,	0x4460,	0x4461,	0x4462,	0x4463,
  /* GB+82 33 98 35 */	0x4464,	0x4465,	0x4466,	0x4467,	0x4468,
  /* GB+82 33 99 30 */	0x4469,	0x446A,	0x446B,	0x446C,	0x446D,
  /* GB+82 33 99 35 */	0x446E,	0x446F,	0x4470,	0x4471,	0x4472,
  /* GB+82 33 9A 30 */	0x4473,	0x4474,	0x4475,	0x4476,	0x4477,
  /* GB+82 33 9A 35 */	0x4478,	0x4479,	0x447A,	0x447B,	0x447C,
  /* GB+82 33 9B 30 */	0x447D,	0x447E,	0x447F,	0x4480,	0x4481,
  /* GB+82 33 9B 35 */	0x4482,	0x4483,	0x4484,	0x4485,	0x4486,
  /* GB+82 33 9C 30 */	0x4487,	0x4488,	0x4489,	0x448A,	0x448B,
  /* GB+82 33 9C 35 */	0x448C,	0x448D,	0x448E,	0x448F,	0x4490,
  /* GB+82 33 9D 30 */	0x4491,	0x4492,	0x4493,	0x4494,	0x4495,
  /* GB+82 33 9D 35 */	0x4496,	0x4497,	0x4498,	0x4499,	0x449A,
  /* GB+82 33 9E 30 */	0x449B,	0x449C,	0x449D,	0x449E,	0x449F,
  /* GB+82 33 9E 35 */	0x44A0,	0x44A1,	0x44A2,	0x44A3,	0x44A4,
  /* GB+82 33 9F 30 */	0x44A5,	0x44A6,	0x44A7,	0x44A8,	0x44A9,
  /* GB+82 33 9F 35 */	0x44AA,	0x44AB,	0x44AC,	0x44AD,	0x44AE,
  /* GB+82 33 A0 30 */	0x44AF,	0x44B0,	0x44B1,	0x44B2,	0x44B3,
  /* GB+82 33 A0 35 */	0x44B4,	0x44B5,	0x44B6,	0x44B7,	0x44B8,
  /* GB+82 33 A1 30 */	0x44B9,	0x44BA,	0x44BB,	0x44BC,	0x44BD,
  /* GB+82 33 A1 35 */	0x44BE,	0x44BF,	0x44C0,	0x44C1,	0x44C2,
  /* GB+82 33 A2 30 */	0x44C3,	0x44C4,	0x44C5,	0x44C6,	0x44C7,
  /* GB+82 33 A2 35 */	0x44C8,	0x44C9,	0x44CA,	0x44CB,	0x44CC,
  /* GB+82 33 A3 30 */	0x44CD,	0x44CE,	0x44CF,	0x44D0,	0x44D1,
  /* GB+82 33 A3 35 */	0x44D2,	0x44D3,	0x44D4,	0x44D5,	
  /* Contiguous area: GB+82 33 C9 32 .. GB+82 33 E8 37 */
  /* GB+82 33 C9 32 */			0x464D,	0x464E,	0x464F,
  /* GB+82 33 C9 35 */	0x4650,	0x4651,	0x4652,	0x4653,	0x4654,
  /* GB+82 33 CA 30 */	0x4655,	0x4656,	0x4657,	0x4658,	0x4659,
  /* GB+82 33 CA 35 */	0x465A,	0x465B,	0x465C,	0x465D,	0x465E,
  /* GB+82 33 CB 30 */	0x465F,	0x4660,	0x4662,	0x4663,	0x4664,
  /* GB+82 33 CB 35 */	0x4665,	0x4666,	0x4667,	0x4668,	0x4669,
  /* GB+82 33 CC 30 */	0x466A,	0x466B,	0x466C,	0x466D,	0x466E,
  /* GB+82 33 CC 35 */	0x466F,	0x4670,	0x4671,	0x4672,	0x4673,
  /* GB+82 33 CD 30 */	0x4674,	0x4675,	0x4676,	0x4677,	0x4678,
  /* GB+82 33 CD 35 */	0x4679,	0x467A,	0x467B,	0x467C,	0x467D,
  /* GB+82 33 CE 30 */	0x467E,	0x467F,	0x4680,	0x4681,	0x4682,
  /* GB+82 33 CE 35 */	0x4683,	0x4684,	0x4685,	0x4686,	0x4687,
  /* GB+82 33 CF 30 */	0x4688,	0x4689,	0x468A,	0x468B,	0x468C,
  /* GB+82 33 CF 35 */	0x468D,	0x468E,	0x468F,	0x4690,	0x4691,
  /* GB+82 33 D0 30 */	0x4692,	0x4693,	0x4694,	0x4695,	0x4696,
  /* GB+82 33 D0 35 */	0x4697,	0x4698,	0x4699,	0x469A,	0x469B,
  /* GB+82 33 D1 30 */	0x469C,	0x469D,	0x469E,	0x469F,	0x46A0,
  /* GB+82 33 D1 35 */	0x46A1,	0x46A2,	0x46A3,	0x46A4,	0x46A5,
  /* GB+82 33 D2 30 */	0x46A6,	0x46A7,	0x46A8,	0x46A9,	0x46AA,
  /* GB+82 33 D2 35 */	0x46AB,	0x46AC,	0x46AD,	0x46AE,	0x46AF,
  /* GB+82 33 D3 30 */	0x46B0,	0x46B1,	0x46B2,	0x46B3,	0x46B4,
  /* GB+82 33 D3 35 */	0x46B5,	0x46B6,	0x46B7,	0x46B8,	0x46B9,
  /* GB+82 33 D4 30 */	0x46BA,	0x46BB,	0x46BC,	0x46BD,	0x46BE,
  /* GB+82 33 D4 35 */	0x46BF,	0x46C0,	0x46C1,	0x46C2,	0x46C3,
  /* GB+82 33 D5 30 */	0x46C4,	0x46C5,	0x46C6,	0x46C7,	0x46C8,
  /* GB+82 33 D5 35 */	0x46C9,	0x46CA,	0x46CB,	0x46CC,	0x46CD,
  /* GB+82 33 D6 30 */	0x46CE,	0x46CF,	0x46D0,	0x46D1,	0x46D2,
  /* GB+82 33 D6 35 */	0x46D3,	0x46D4,	0x46D5,	0x46D6,	0x46D7,
  /* GB+82 33 D7 30 */	0x46D8,	0x46D9,	0x46DA,	0x46DB,	0x46DC,
  /* GB+82 33 D7 35 */	0x46DD,	0x46DE,	0x46DF,	0x46E0,	0x46E1,
  /* GB+82 33 D8 30 */	0x46E2,	0x46E3,	0x46E4,	0x46E5,	0x46E6,
  /* GB+82 33 D8 35 */	0x46E7,	0x46E8,	0x46E9,	0x46EA,	0x46EB,
  /* GB+82 33 D9 30 */	0x46EC,	0x46ED,	0x46EE,	0x46EF,	0x46F0,
  /* GB+82 33 D9 35 */	0x46F1,	0x46F2,	0x46F3,	0x46F4,	0x46F5,
  /* GB+82 33 DA 30 */	0x46F6,	0x46F7,	0x46F8,	0x46F9,	0x46FA,
  /* GB+82 33 DA 35 */	0x46FB,	0x46FC,	0x46FD,	0x46FE,	0x46FF,
  /* GB+82 33 DB 30 */	0x4700,	0x4701,	0x4702,	0x4703,	0x4704,
  /* GB+82 33 DB 35 */	0x4705,	0x4706,	0x4707,	0x4708,	0x4709,
  /* GB+82 33 DC 30 */	0x470A,	0x470B,	0x470C,	0x470D,	0x470E,
  /* GB+82 33 DC 35 */	0x470F,	0x4710,	0x4711,	0x4712,	0x4713,
  /* GB+82 33 DD 30 */	0x4714,	0x4715,	0x4716,	0x4717,	0x4718,
  /* GB+82 33 DD 35 */	0x4719,	0x471A,	0x471B,	0x471C,	0x471D,
  /* GB+82 33 DE 30 */	0x471E,	0x471F,	0x4720,	0x4721,	0x4722,
  /* GB+82 33 DE 35 */	0x4724,	0x4725,	0x4726,	0x4727,	0x4728,
  /* GB+82 33 DF 30 */	0x472A,	0x472B,	0x472C,	0x472D,	0x472E,
  /* GB+82 33 DF 35 */	0x472F,	0x4730,	0x4731,	0x4732,	0x4733,
  /* GB+82 33 E0 30 */	0x4734,	0x4735,	0x4736,	0x4737,	0x4738,
  /* GB+82 33 E0 35 */	0x4739,	0x473A,	0x473B,	0x473C,	0x473D,
  /* GB+82 33 E1 30 */	0x473E,	0x473F,	0x4740,	0x4741,	0x4742,
  /* GB+82 33 E1 35 */	0x4743,	0x4744,	0x4745,	0x4746,	0x4747,
  /* GB+82 33 E2 30 */	0x4748,	0x4749,	0x474A,	0x474B,	0x474C,
  /* GB+82 33 E2 35 */	0x474D,	0x474E,	0x474F,	0x4750,	0x4751,
  /* GB+82 33 E3 30 */	0x4752,	0x4753,	0x4754,	0x4755,	0x4756,
  /* GB+82 33 E3 35 */	0x4757,	0x4758,	0x4759,	0x475A,	0x475B,
  /* GB+82 33 E4 30 */	0x475C,	0x475D,	0x475E,	0x475F,	0x4760,
  /* GB+82 33 E4 35 */	0x4761,	0x4762,	0x4763,	0x4764,	0x4765,
  /* GB+82 33 E5 30 */	0x4766,	0x4767,	0x4768,	0x4769,	0x476A,
  /* GB+82 33 E5 35 */	0x476B,	0x476C,	0x476D,	0x476E,	0x476F,
  /* GB+82 33 E6 30 */	0x4770,	0x4771,	0x4772,	0x4773,	0x4774,
  /* GB+82 33 E6 35 */	0x4775,	0x4776,	0x4777,	0x4778,	0x4779,
  /* GB+82 33 E7 30 */	0x477A,	0x477B,	0x477D,	0x477E,	0x477F,
  /* GB+82 33 E7 35 */	0x4780,	0x4781,	0x4782,	0x4783,	0x4784,
  /* GB+82 33 E8 30 */	0x4785,	0x4786,	0x4787,	0x4788,	0x4789,
  /* GB+82 33 E8 35 */	0x478A,	0x478B,	0x478C,	
  /* Contiguous area: GB+82 34 96 39 .. GB+82 34 A1 30 */
  /* GB+82 34 96 39 */					0x4948,
  /* GB+82 34 97 30 */	0x4949,	0x494A,	0x494B,	0x494C,	0x494D,
  /* GB+82 34 97 35 */	0x494E,	0x494F,	0x4950,	0x4951,	0x4952,
  /* GB+82 34 98 30 */	0x4953,	0x4954,	0x4955,	0x4956,	0x4957,
  /* GB+82 34 98 35 */	0x4958,	0x4959,	0x495A,	0x495B,	0x495C,
  /* GB+82 34 99 30 */	0x495D,	0x495E,	0x495F,	0x4960,	0x4961,
  /* GB+82 34 99 35 */	0x4962,	0x4963,	0x4964,	0x4965,	0x4966,
  /* GB+82 34 9A 30 */	0x4967,	0x4968,	0x4969,	0x496A,	0x496B,
  /* GB+82 34 9A 35 */	0x496C,	0x496D,	0x496E,	0x496F,	0x4970,
  /* GB+82 34 9B 30 */	0x4971,	0x4972,	0x4973,	0x4974,	0x4975,
  /* GB+82 34 9B 35 */	0x4976,	0x4977,	0x4978,	0x4979,	0x497B,
  /* GB+82 34 9C 30 */	0x497C,	0x497E,	0x497F,	0x4980,	0x4981,
  /* GB+82 34 9C 35 */	0x4984,	0x4987,	0x4988,	0x4989,	0x498A,
  /* GB+82 34 9D 30 */	0x498B,	0x498C,	0x498D,	0x498E,	0x498F,
  /* GB+82 34 9D 35 */	0x4990,	0x4991,	0x4992,	0x4993,	0x4994,
  /* GB+82 34 9E 30 */	0x4995,	0x4996,	0x4997,	0x4998,	0x4999,
  /* GB+82 34 9E 35 */	0x499A,	0x499C,	0x499D,	0x499E,	0x49A0,
  /* GB+82 34 9F 30 */	0x49A1,	0x49A2,	0x49A3,	0x49A4,	0x49A5,
  /* GB+82 34 9F 35 */	0x49A6,	0x49A7,	0x49A8,	0x49A9,	0x49AA,
  /* GB+82 34 A0 30 */	0x49AB,	0x49AC,	0x49AD,	0x49AE,	0x49AF,
  /* GB+82 34 A0 35 */	0x49B0,	0x49B1,	0x49B2,	0x49B3,	0x49B4,
  /* GB+82 34 A1 30 */	0x49B5,	
  /* Contiguous area: GB+82 34 E7 34 .. GB+82 35 8F 32 */
  /* GB+82 34 E7 34 */					0x4C78,
  /* GB+82 34 E7 35 */	0x4C79,	0x4C7A,	0x4C7B,	0x4C7C,	0x4C7D,
  /* GB+82 34 E8 30 */	0x4C7E,	0x4C7F,	0x4C80,	0x4C81,	0x4C82,
  /* GB+82 34 E8 35 */	0x4C83,	0x4C84,	0x4C85,	0x4C86,	0x4C87,
  /* GB+82 34 E9 30 */	0x4C88,	0x4C89,	0x4C8A,	0x4C8B,	0x4C8C,
  /* GB+82 34 E9 35 */	0x4C8D,	0x4C8E,	0x4C8F,	0x4C90,	0x4C91,
  /* GB+82 34 EA 30 */	0x4C92,	0x4C93,	0x4C94,	0x4C95,	0x4C96,
  /* GB+82 34 EA 35 */	0x4C97,	0x4C98,	0x4C99,	0x4C9A,	0x4C9B,
  /* GB+82 34 EB 30 */	0x4C9C,	0x4C9D,	0x4C9E,	0x4CA4,	0x4CA5,
  /* GB+82 34 EB 35 */	0x4CA6,	0x4CA7,	0x4CA8,	0x4CA9,	0x4CAA,
  /* GB+82 34 EC 30 */	0x4CAB,	0x4CAC,	0x4CAD,	0x4CAE,	0x4CAF,
  /* GB+82 34 EC 35 */	0x4CB0,	0x4CB1,	0x4CB2,	0x4CB3,	0x4CB4,
  /* GB+82 34 ED 30 */	0x4CB5,	0x4CB6,	0x4CB7,	0x4CB8,	0x4CB9,
  /* GB+82 34 ED 35 */	0x4CBA,	0x4CBB,	0x4CBC,	0x4CBD,	0x4CBE,
  /* GB+82 34 EE 30 */	0x4CBF,	0x4CC0,	0x4CC1,	0x4CC2,	0x4CC3,
  /* GB+82 34 EE 35 */	0x4CC4,	0x4CC5,	0x4CC6,	0x4CC7,	0x4CC8,
  /* GB+82 34 EF 30 */	0x4CC9,	0x4CCA,	0x4CCB,	0x4CCC,	0x4CCD,
  /* GB+82 34 EF 35 */	0x4CCE,	0x4CCF,	0x4CD0,	0x4CD1,	0x4CD2,
  /* GB+82 34 F0 30 */	0x4CD3,	0x4CD4,	0x4CD5,	0x4CD6,	0x4CD7,
  /* GB+82 34 F0 35 */	0x4CD8,	0x4CD9,	0x4CDA,	0x4CDB,	0x4CDC,
  /* GB+82 34 F1 30 */	0x4CDD,	0x4CDE,	0x4CDF,	0x4CE0,	0x4CE1,
  /* GB+82 34 F1 35 */	0x4CE2,	0x4CE3,	0x4CE4,	0x4CE5,	0x4CE6,
  /* GB+82 34 F2 30 */	0x4CE7,	0x4CE8,	0x4CE9,	0x4CEA,	0x4CEB,
  /* GB+82 34 F2 35 */	0x4CEC,	0x4CED,	0x4CEE,	0x4CEF,	0x4CF0,
  /* GB+82 34 F3 30 */	0x4CF1,	0x4CF2,	0x4CF3,	0x4CF4,	0x4CF5,
  /* GB+82 34 F3 35 */	0x4CF6,	0x4CF7,	0x4CF8,	0x4CF9,	0x4CFA,
  /* GB+82 34 F4 30 */	0x4CFB,	0x4CFC,	0x4CFD,	0x4CFE,	0x4CFF,
  /* GB+82 34 F4 35 */	0x4D00,	0x4D01,	0x4D02,	0x4D03,	0x4D04,
  /* GB+82 34 F5 30 */	0x4D05,	0x4D06,	0x4D07,	0x4D08,	0x4D09,
  /* GB+82 34 F5 35 */	0x4D0A,	0x4D0B,	0x4D0C,	0x4D0D,	0x4D0E,
  /* GB+82 34 F6 30 */	0x4D0F,	0x4D10,	0x4D11,	0x4D12,	0x4D1A,
  /* GB+82 34 F6 35 */	0x4D1B,	0x4D1C,	0x4D1D,	0x4D1E,	0x4D1F,
  /* GB+82 34 F7 30 */	0x4D20,	0x4D21,	0x4D22,	0x4D23,	0x4D24,
  /* GB+82 34 F7 35 */	0x4D25,	0x4D26,	0x4D27,	0x4D28,	0x4D29,
  /* GB+82 34 F8 30 */	0x4D2A,	0x4D2B,	0x4D2C,	0x4D2D,	0x4D2E,
  /* GB+82 34 F8 35 */	0x4D2F,	0x4D30,	0x4D31,	0x4D32,	0x4D33,
  /* GB+82 34 F9 30 */	0x4D34,	0x4D35,	0x4D36,	0x4D37,	0x4D38,
  /* GB+82 34 F9 35 */	0x4D39,	0x4D3A,	0x4D3B,	0x4D3C,	0x4D3D,
  /* GB+82 34 FA 30 */	0x4D3E,	0x4D3F,	0x4D40,	0x4D41,	0x4D42,
  /* GB+82 34 FA 35 */	0x4D43,	0x4D44,	0x4D45,	0x4D46,	0x4D47,
  /* GB+82 34 FB 30 */	0x4D48,	0x4D49,	0x4D4A,	0x4D4B,	0x4D4C,
  /* GB+82 34 FB 35 */	0x4D4D,	0x4D4E,	0x4D4F,	0x4D50,	0x4D51,
  /* GB+82 34 FC 30 */	0x4D52,	0x4D53,	0x4D54,	0x4D55,	0x4D56,
  /* GB+82 34 FC 35 */	0x4D57,	0x4D58,	0x4D59,	0x4D5A,	0x4D5B,
  /* GB+82 34 FD 30 */	0x4D5C,	0x4D5D,	0x4D5E,	0x4D5F,	0x4D60,
  /* GB+82 34 FD 35 */	0x4D61,	0x4D62,	0x4D63,	0x4D64,	0x4D65,
  /* GB+82 34 FE 30 */	0x4D66,	0x4D67,	0x4D68,	0x4D69,	0x4D6A,
  /* GB+82 34 FE 35 */	0x4D6B,	0x4D6C,	0x4D6D,	0x4D6E,	0x4D6F,
  /* GB+82 35 81 30 */	0x4D70,	0x4D71,	0x4D72,	0x4D73,	0x4D74,
  /* GB+82 35 81 35 */	0x4D75,	0x4D76,	0x4D77,	0x4D78,	0x4D79,
  /* GB+82 35 82 30 */	0x4D7A,	0x4D7B,	0x4D7C,	0x4D7D,	0x4D7E,
  /* GB+82 35 82 35 */	0x4D7F,	0x4D80,	0x4D81,	0x4D82,	0x4D83,
  /* GB+82 35 83 30 */	0x4D84,	0x4D85,	0x4D86,	0x4D87,	0x4D88,
  /* GB+82 35 83 35 */	0x4D89,	0x4D8A,	0x4D8B,	0x4D8C,	0x4D8D,
  /* GB+82 35 84 30 */	0x4D8E,	0x4D8F,	0x4D90,	0x4D91,	0x4D92,
  /* GB+82 35 84 35 */	0x4D93,	0x4D94,	0x4D95,	0x4D96,	0x4D97,
  /* GB+82 35 85 30 */	0x4D98,	0x4D99,	0x4D9A,	0x4D9B,	0x4D9C,
  /* GB+82 35 85 35 */	0x4D9D,	0x4D9E,	0x4D9F,	0x4DA0,	0x4DA1,
  /* GB+82 35 86 30 */	0x4DA2,	0x4DA3,	0x4DA4,	0x4DA5,	0x4DA6,
  /* GB+82 35 86 35 */	0x4DA7,	0x4DA8,	0x4DA9,	0x4DAA,	0x4DAB,
  /* GB+82 35 87 30 */	0x4DAC,	0x4DAD,	0x4DAF,	0x4DB0,	0x4DB1,
  /* GB+82 35 87 35 */	0x4DB2,	0x4DB3,	0x4DB4,	0x4DB5,	0x4DB6,
  /* GB+82 35 88 30 */	0x4DB7,	0x4DB8,	0x4DB9,	0x4DBA,	0x4DBB,
  /* GB+82 35 88 35 */	0x4DBC,	0x4DBD,	0x4DBE,	0x4DBF,	0x4DC0,
  /* GB+82 35 89 30 */	0x4DC1,	0x4DC2,	0x4DC3,	0x4DC4,	0x4DC5,
  /* GB+82 35 89 35 */	0x4DC6,	0x4DC7,	0x4DC8,	0x4DC9,	0x4DCA,
  /* GB+82 35 8A 30 */	0x4DCB,	0x4DCC,	0x4DCD,	0x4DCE,	0x4DCF,
  /* GB+82 35 8A 35 */	0x4DD0,	0x4DD1,	0x4DD2,	0x4DD3,	0x4DD4,
  /* GB+82 35 8B 30 */	0x4DD5,	0x4DD6,	0x4DD7,	0x4DD8,	0x4DD9,
  /* GB+82 35 8B 35 */	0x4DDA,	0x4DDB,	0x4DDC,	0x4DDD,	0x4DDE,
  /* GB+82 35 8C 30 */	0x4DDF,	0x4DE0,	0x4DE1,	0x4DE2,	0x4DE3,
  /* GB+82 35 8C 35 */	0x4DE4,	0x4DE5,	0x4DE6,	0x4DE7,	0x4DE8,
  /* GB+82 35 8D 30 */	0x4DE9,	0x4DEA,	0x4DEB,	0x4DEC,	0x4DED,
  /* GB+82 35 8D 35 */	0x4DEE,	0x4DEF,	0x4DF0,	0x4DF1,	0x4DF2,
  /* GB+82 35 8E 30 */	0x4DF3,	0x4DF4,	0x4DF5,	0x4DF6,	0x4DF7,
  /* GB+82 35 8E 35 */	0x4DF8,	0x4DF9,	0x4DFA,	0x4DFB,	0x4DFC,
  /* GB+82 35 8F 30 */	0x4DFD,	0x4DFE,	0x4DFF,	
  /* Contiguous area: GB+83 36 C7 39 .. GB+83 36 CF 39 */
  /* GB+83 36 C7 39 */					0xE76C,
  /* GB+83 36 C8 30 */	0xE7C8,	0xE7E7,	0xE7E8,	0xE7E9,	0xE7EA,
  /* GB+83 36 C8 35 */	0xE7EB,	0xE7EC,	0xE7ED,	0xE7EE,	0xE7EF,
  /* GB+83 36 C9 30 */	0xE7F0,	0xE7F1,	0xE7F2,	0xE7F3,	0xE815,
  /* GB+83 36 C9 35 */	0xE819,	0xE81A,	0xE81B,	0xE81C,	0xE81D,
  /* GB+83 36 CA 30 */	0xE81F,	0xE820,	0xE821,	0xE822,	0xE823,
  /* GB+83 36 CA 35 */	0xE824,	0xE825,	0xE827,	0xE828,	0xE829,
  /* GB+83 36 CB 30 */	0xE82A,	0xE82D,	0xE82E,	0xE82F,	0xE830,
  /* GB+83 36 CB 35 */	0xE833,	0xE834,	0xE835,	0xE836,	0xE837,
  /* GB+83 36 CC 30 */	0xE838,	0xE839,	0xE83A,	0xE83C,	0xE83D,
  /* GB+83 36 CC 35 */	0xE83E,	0xE83F,	0xE840,	0xE841,	0xE842,
  /* GB+83 36 CD 30 */	0xE844,	0xE845,	0xE846,	0xE847,	0xE848,
  /* GB+83 36 CD 35 */	0xE849,	0xE84A,	0xE84B,	0xE84C,	0xE84D,
  /* GB+83 36 CE 30 */	0xE84E,	0xE84F,	0xE850,	0xE851,	0xE852,
  /* GB+83 36 CE 35 */	0xE853,	0xE856,	0xE857,	0xE858,	0xE859,
  /* GB+83 36 CF 30 */	0xE85A,	0xE85B,	0xE85C,	0xE85D,	0xE85E,
  /* GB+83 36 CF 35 */	0xE85F,	0xE860,	0xE861,	0xE862,	0xE863,
  /* Contiguous area: GB+84 30 85 35 .. GB+84 30 9C 37 */
  /* GB+84 30 85 35 */	0xF92D,	0xF92E,	0xF92F,	0xF930,	0xF931,
  /* GB+84 30 86 30 */	0xF932,	0xF933,	0xF934,	0xF935,	0xF936,
  /* GB+84 30 86 35 */	0xF937,	0xF938,	0xF939,	0xF93A,	0xF93B,
  /* GB+84 30 87 30 */	0xF93C,	0xF93D,	0xF93E,	0xF93F,	0xF940,
  /* GB+84 30 87 35 */	0xF941,	0xF942,	0xF943,	0xF944,	0xF945,
  /* GB+84 30 88 30 */	0xF946,	0xF947,	0xF948,	0xF949,	0xF94A,
  /* GB+84 30 88 35 */	0xF94B,	0xF94C,	0xF94D,	0xF94E,	0xF94F,
  /* GB+84 30 89 30 */	0xF950,	0xF951,	0xF952,	0xF953,	0xF954,
  /* GB+84 30 89 35 */	0xF955,	0xF956,	0xF957,	0xF958,	0xF959,
  /* GB+84 30 8A 30 */	0xF95A,	0xF95B,	0xF95C,	0xF95D,	0xF95E,
  /* GB+84 30 8A 35 */	0xF95F,	0xF960,	0xF961,	0xF962,	0xF963,
  /* GB+84 30 8B 30 */	0xF964,	0xF965,	0xF966,	0xF967,	0xF968,
  /* GB+84 30 8B 35 */	0xF969,	0xF96A,	0xF96B,	0xF96C,	0xF96D,
  /* GB+84 30 8C 30 */	0xF96E,	0xF96F,	0xF970,	0xF971,	0xF972,
  /* GB+84 30 8C 35 */	0xF973,	0xF974,	0xF975,	0xF976,	0xF977,
  /* GB+84 30 8D 30 */	0xF978,	0xF97A,	0xF97B,	0xF97C,	0xF97D,
  /* GB+84 30 8D 35 */	0xF97E,	0xF97F,	0xF980,	0xF981,	0xF982,
  /* GB+84 30 8E 30 */	0xF983,	0xF984,	0xF985,	0xF986,	0xF987,
  /* GB+84 30 8E 35 */	0xF988,	0xF989,	0xF98A,	0xF98B,	0xF98C,
  /* GB+84 30 8F 30 */	0xF98D,	0xF98E,	0xF98F,	0xF990,	0xF991,
  /* GB+84 30 8F 35 */	0xF992,	0xF993,	0xF994,	0xF996,	0xF997,
  /* GB+84 30 90 30 */	0xF998,	0xF999,	0xF99A,	0xF99B,	0xF99C,
  /* GB+84 30 90 35 */	0xF99D,	0xF99E,	0xF99F,	0xF9A0,	0xF9A1,
  /* GB+84 30 91 30 */	0xF9A2,	0xF9A3,	0xF9A4,	0xF9A5,	0xF9A6,
  /* GB+84 30 91 35 */	0xF9A7,	0xF9A8,	0xF9A9,	0xF9AA,	0xF9AB,
  /* GB+84 30 92 30 */	0xF9AC,	0xF9AD,	0xF9AE,	0xF9AF,	0xF9B0,
  /* GB+84 30 92 35 */	0xF9B1,	0xF9B2,	0xF9B3,	0xF9B4,	0xF9B5,
  /* GB+84 30 93 30 */	0xF9B6,	0xF9B7,	0xF9B8,	0xF9B9,	0xF9BA,
  /* GB+84 30 93 35 */	0xF9BB,	0xF9BC,	0xF9BD,	0xF9BE,	0xF9BF,
  /* GB+84 30 94 30 */	0xF9C0,	0xF9C1,	0xF9C2,	0xF9C3,	0xF9C4,
  /* GB+84 30 94 35 */	0xF9C5,	0xF9C6,	0xF9C7,	0xF9C8,	0xF9C9,
  /* GB+84 30 95 30 */	0xF9CA,	0xF9CB,	0xF9CC,	0xF9CD,	0xF9CE,
  /* GB+84 30 95 35 */	0xF9CF,	0xF9D0,	0xF9D1,	0xF9D2,	0xF9D3,
  /* GB+84 30 96 30 */	0xF9D4,	0xF9D5,	0xF9D6,	0xF9D7,	0xF9D8,
  /* GB+84 30 96 35 */	0xF9D9,	0xF9DA,	0xF9DB,	0xF9DC,	0xF9DD,
  /* GB+84 30 97 30 */	0xF9DE,	0xF9DF,	0xF9E0,	0xF9E1,	0xF9E2,
  /* GB+84 30 97 35 */	0xF9E3,	0xF9E4,	0xF9E5,	0xF9E6,	0xF9E8,
  /* GB+84 30 98 30 */	0xF9E9,	0xF9EA,	0xF9EB,	0xF9EC,	0xF9ED,
  /* GB+84 30 98 35 */	0xF9EE,	0xF9EF,	0xF9F0,	0xF9F2,	0xF9F3,
  /* GB+84 30 99 30 */	0xF9F4,	0xF9F5,	0xF9F6,	0xF9F7,	0xF9F8,
  /* GB+84 30 99 35 */	0xF9F9,	0xF9FA,	0xF9FB,	0xF9FC,	0xF9FD,
  /* GB+84 30 9A 30 */	0xF9FE,	0xF9FF,	0xFA00,	0xFA01,	0xFA02,
  /* GB+84 30 9A 35 */	0xFA03,	0xFA04,	0xFA05,	0xFA06,	0xFA07,
  /* GB+84 30 9B 30 */	0xFA08,	0xFA09,	0xFA0A,	0xFA0B,	0xFA10,
  /* GB+84 30 9B 35 */	0xFA12,	0xFA15,	0xFA16,	0xFA17,	0xFA19,
  /* GB+84 30 9C 30 */	0xFA1A,	0xFA1B,	0xFA1C,	0xFA1D,	0xFA1E,
  /* GB+84 30 9C 35 */	0xFA22,	0xFA25,	0xFA26,	
  /* Contiguous area: GB+84 31 85 38 .. GB+84 31 A2 33 */
  /* GB+84 31 85 38 */				0xFE32,	0xFE45,
  /* GB+84 31 86 30 */	0xFE46,	0xFE47,	0xFE48,	0xFE53,	0xFE58,
  /* GB+84 31 86 35 */	0xFE67,	0xFE6C,	0xFE6D,	0xFE6E,	0xFE6F,
  /* GB+84 31 87 30 */	0xFE70,	0xFE71,	0xFE72,	0xFE73,	0xFE74,
  /* GB+84 31 87 35 */	0xFE75,	0xFE76,	0xFE77,	0xFE78,	0xFE79,
  /* GB+84 31 88 30 */	0xFE7A,	0xFE7B,	0xFE7C,	0xFE7D,	0xFE7E,
  /* GB+84 31 88 35 */	0xFE7F,	0xFE80,	0xFE81,	0xFE82,	0xFE83,
  /* GB+84 31 89 30 */	0xFE84,	0xFE85,	0xFE86,	0xFE87,	0xFE88,
  /* GB+84 31 89 35 */	0xFE89,	0xFE8A,	0xFE8B,	0xFE8C,	0xFE8D,
  /* GB+84 31 8A 30 */	0xFE8E,	0xFE8F,	0xFE90,	0xFE91,	0xFE92,
  /* GB+84 31 8A 35 */	0xFE93,	0xFE94,	0xFE95,	0xFE96,	0xFE97,
  /* GB+84 31 8B 30 */	0xFE98,	0xFE99,	0xFE9A,	0xFE9B,	0xFE9C,
  /* GB+84 31 8B 35 */	0xFE9D,	0xFE9E,	0xFE9F,	0xFEA0,	0xFEA1,
  /* GB+84 31 8C 30 */	0xFEA2,	0xFEA3,	0xFEA4,	0xFEA5,	0xFEA6,
  /* GB+84 31 8C 35 */	0xFEA7,	0xFEA8,	0xFEA9,	0xFEAA,	0xFEAB,
  /* GB+84 31 8D 30 */	0xFEAC,	0xFEAD,	0xFEAE,	0xFEAF,	0xFEB0,
  /* GB+84 31 8D 35 */	0xFEB1,	0xFEB2,	0xFEB3,	0xFEB4,	0xFEB5,
  /* GB+84 31 8E 30 */	0xFEB6,	0xFEB7,	0xFEB8,	0xFEB9,	0xFEBA,
  /* GB+84 31 8E 35 */	0xFEBB,	0xFEBC,	0xFEBD,	0xFEBE,	0xFEBF,
  /* GB+84 31 8F 30 */	0xFEC0,	0xFEC1,	0xFEC2,	0xFEC3,	0xFEC4,
  /* GB+84 31 8F 35 */	0xFEC5,	0xFEC6,	0xFEC7,	0xFEC8,	0xFEC9,
  /* GB+84 31 90 30 */	0xFECA,	0xFECB,	0xFECC,	0xFECD,	0xFECE,
  /* GB+84 31 90 35 */	0xFECF,	0xFED0,	0xFED1,	0xFED2,	0xFED3,
  /* GB+84 31 91 30 */	0xFED4,	0xFED5,	0xFED6,	0xFED7,	0xFED8,
  /* GB+84 31 91 35 */	0xFED9,	0xFEDA,	0xFEDB,	0xFEDC,	0xFEDD,
  /* GB+84 31 92 30 */	0xFEDE,	0xFEDF,	0xFEE0,	0xFEE1,	0xFEE2,
  /* GB+84 31 92 35 */	0xFEE3,	0xFEE4,	0xFEE5,	0xFEE6,	0xFEE7,
  /* GB+84 31 93 30 */	0xFEE8,	0xFEE9,	0xFEEA,	0xFEEB,	0xFEEC,
  /* GB+84 31 93 35 */	0xFEED,	0xFEEE,	0xFEEF,	0xFEF0,	0xFEF1,
  /* GB+84 31 94 30 */	0xFEF2,	0xFEF3,	0xFEF4,	0xFEF5,	0xFEF6,
  /* GB+84 31 94 35 */	0xFEF7,	0xFEF8,	0xFEF9,	0xFEFA,	0xFEFB,
  /* GB+84 31 95 30 */	0xFEFC,	0xFEFD,	0xFEFE,	0xFEFF,	0xFF00,
  /* GB+84 31 95 35 */	0xFF5F,	0xFF60,	0xFF61,	0xFF62,	0xFF63,
  /* GB+84 31 96 30 */	0xFF64,	0xFF65,	0xFF66,	0xFF67,	0xFF68,
  /* GB+84 31 96 35 */	0xFF69,	0xFF6A,	0xFF6B,	0xFF6C,	0xFF6D,
  /* GB+84 31 97 30 */	0xFF6E,	0xFF6F,	0xFF70,	0xFF71,	0xFF72,
  /* GB+84 31 97 35 */	0xFF73,	0xFF74,	0xFF75,	0xFF76,	0xFF77,
  /* GB+84 31 98 30 */	0xFF78,	0xFF79,	0xFF7A,	0xFF7B,	0xFF7C,
  /* GB+84 31 98 35 */	0xFF7D,	0xFF7E,	0xFF7F,	0xFF80,	0xFF81,
  /* GB+84 31 99 30 */	0xFF82,	0xFF83,	0xFF84,	0xFF85,	0xFF86,
  /* GB+84 31 99 35 */	0xFF87,	0xFF88,	0xFF89,	0xFF8A,	0xFF8B,
  /* GB+84 31 9A 30 */	0xFF8C,	0xFF8D,	0xFF8E,	0xFF8F,	0xFF90,
  /* GB+84 31 9A 35 */	0xFF91,	0xFF92,	0xFF93,	0xFF94,	0xFF95,
  /* GB+84 31 9B 30 */	0xFF96,	0xFF97,	0xFF98,	0xFF99,	0xFF9A,
  /* GB+84 31 9B 35 */	0xFF9B,	0xFF9C,	0xFF9D,	0xFF9E,	0xFF9F,
  /* GB+84 31 9C 30 */	0xFFA0,	0xFFA1,	0xFFA2,	0xFFA3,	0xFFA4,
  /* GB+84 31 9C 35 */	0xFFA5,	0xFFA6,	0xFFA7,	0xFFA8,	0xFFA9,
  /* GB+84 31 9D 30 */	0xFFAA,	0xFFAB,	0xFFAC,	0xFFAD,	0xFFAE,
  /* GB+84 31 9D 35 */	0xFFAF,	0xFFB0,	0xFFB1,	0xFFB2,	0xFFB3,
  /* GB+84 31 9E 30 */	0xFFB4,	0xFFB5,	0xFFB6,	0xFFB7,	0xFFB8,
  /* GB+84 31 9E 35 */	0xFFB9,	0xFFBA,	0xFFBB,	0xFFBC,	0xFFBD,
  /* GB+84 31 9F 30 */	0xFFBE,	0xFFBF,	0xFFC0,	0xFFC1,	0xFFC2,
  /* GB+84 31 9F 35 */	0xFFC3,	0xFFC4,	0xFFC5,	0xFFC6,	0xFFC7,
  /* GB+84 31 A0 30 */	0xFFC8,	0xFFC9,	0xFFCA,	0xFFCB,	0xFFCC,
  /* GB+84 31 A0 35 */	0xFFCD,	0xFFCE,	0xFFCF,	0xFFD0,	0xFFD1,
  /* GB+84 31 A1 30 */	0xFFD2,	0xFFD3,	0xFFD4,	0xFFD5,	0xFFD6,
  /* GB+84 31 A1 35 */	0xFFD7,	0xFFD8,	0xFFD9,	0xFFDA,	0xFFDB,
  /* GB+84 31 A2 30 */	0xFFDC,	0xFFDD,	0xFFDE,	0xFFDF,	
};


/* Definitions used in the body of the `gconv' function.  */
#define CHARSET_NAME		"GB18030//"
#define FROM_LOOP		from_gb18030
#define TO_LOOP			to_gb18030
#define DEFINE_INIT		1
#define DEFINE_FINI		1
#define MIN_NEEDED_FROM		1
#define MAX_NEEDED_FROM		4
#define MIN_NEEDED_TO		4


/* First define the conversion function from GB18030 to UCS4.  */
#define MIN_NEEDED_INPUT	MIN_NEEDED_FROM
#define MAX_NEEDED_INPUT	MAX_NEEDED_FROM
#define MIN_NEEDED_OUTPUT	MIN_NEEDED_TO
#define LOOPFCT			FROM_LOOP
#define BODY \
  {									      \
    uint32_t ch = *inptr;						      \
									      \
    if (ch <= 0x7f)							      \
      ++inptr;								      \
    else								      \
      if (ch < 0x81 || ch > 0xfe)					      \
	{								      \
	  /* This is illegal.  */					      \
	  STANDARD_FROM_LOOP_ERR_HANDLER (1);				      \
	}								      \
      else								      \
	{								      \
	  /* Two or four byte character.  First test whether the next	      \
	     byte is also available.  */				      \
	  uint32_t ch2;							      \
	  unsigned long int idx;					      \
									      \
	  if (inptr + 1 >= inend)					      \
	    {								      \
	      /* The second byte is not available.  Store the		      \
		 intermediate result.  */				      \
	      result = __GCONV_INCOMPLETE_INPUT;			      \
	      break;							      \
	    }								      \
									      \
	  ch2 = inptr[1];						      \
									      \
	  /* All second bytes of a multibyte character must be >= 0x30,	      \
						   != 0x7F and <= 0xFE */     \
	  if (ch2 < 0x30 || ch2 == 0x7F || ch2 > 0xFE)			      \
	    STANDARD_FROM_LOOP_ERR_HANDLER (2);				      \
									      \
	  if (ch2 >= 0x30 && ch2 <= 0x39)				      \
	    {								      \
	      /* A four-byte character */				      \
	      uint32_t    ch3;						      \
	      uint32_t    ch4;						      \
	      indextbl_t  g2u;						      \
									      \
	      if (inptr + 3 >= inend)					      \
	 	{							      \
		  /* Not all bytes are available.  Store		      \
		     the intermediate result.  */			      \
		  result = __GCONV_INCOMPLETE_INPUT;			      \
		  break;						      \
		}							      \
									      \
	      ch3 = inptr[2];						      \
									      \
	      if (ch3 < 0x81 || ch3 > 0xfe)				      \
		{							      \
		  /* This is an illegal character.  */			      \
		  STANDARD_FROM_LOOP_ERR_HANDLER (3);			      \
		}							      \
									      \
	      ch4 = inptr[3];						      \
									      \
	      if (ch4 < 0x30 || ch4 > 0x39)				      \
		{							      \
		  /* This is an illegal character.  */			      \
		  STANDARD_FROM_LOOP_ERR_HANDLER (4);			      \
		}							      \
									      \
	      idx = (((ch - 0x81) * 10 + (ch2 - 0x30)) * 126		      \
		      + ch3 - 0x81) * 10 + ch4 - 0x30;			      \
									      \
	      if (idx <= 0x99F9)					      \
		{							      \
		  /* GB+81308130 - GB+8431A439 */			      \
		  g2u = __gb18030_to_ucs_index[idx >> 8];		      \
									      \
		  if ((idx & 0xFF) >= g2u.tblbegin &&			      \
		      (idx & 0xFF) <= g2u.tblend)			      \
		    ch = __gb18030_4byte_to_ucs[idx - g2u.tbloffset];	      \
		  else							      \
		    ch = g2u.algoffset + (idx & 0xFF);			      \
		}							      \
	      else if (idx >= 0x2E248 && idx <= 0x12E247)		      \
		/* GB+90308130 - GB+E3329A35 */				      \
		ch = idx - 0x1E248;					      \
	      else							      \
		ch = 0;							      \
									      \
	      if (ch == 0 && *inptr != '\0')				      \
		{							      \
		  /* This is an illegal character.  */			      \
		  STANDARD_FROM_LOOP_ERR_HANDLER (4);			      \
		}							      \
									      \
	      inptr += 4;						      \
	    }								      \
	  else if (__builtin_expect (ch2 >= 0x40, 1))			      \
	    {								      \
	      /* A two-byte character */				      \
									      \
	      /* Check for User-defined areas */			      \
	      if (ch >= 0xAA && ch <= 0xAF && ch2 >= 0xA1)		      \
		/* UDA 1: 0xAAA1 - 0xAAFE (564/0) */			      \
		ch = 0xE000 + (ch - 0xAA) * 94 + (ch2 - 0xA1);		      \
	      else if (ch >= 0xF8 && ch <= 0xFE && ch2 >= 0xA1)		      \
		/* UDA 2: 0xF8A1 - 0xFEFE (658/0)  */			      \
		ch = 0xE234 + (ch - 0xF8) * 94 + (ch2 - 0xA1);		      \
	      else if (ch >= 0xA1 && ch <= 0xA7 && ch2 <= 0xA0)		      \
		/* UDA 3: 0xA140 - 0xA7A0 (672/0) */			      \
		ch = 0xE4C6 + (ch - 0xA1) * 96 + (ch2 - 0x40)		      \
			    - ((ch2 >= 0x80) ? 1 : 0);			      \
	      else							      \
		{							      \
		  /* Use the mapping table */				      \
									      \
		  idx = (ch - 0x81) * 190 + (ch2 - 0x40) 		      \
					- ((ch2 >= 0x80) ? 1 : 0);	      \
									      \
		  if (ch >= 0xA1 && ch <= 0xA7)				      \
		    idx -= (ch - 0xA0) * 96;				      \
		  if (ch > 0xA7)					      \
		    idx -= 672;						      \
		  if (ch >= 0xAA && ch <= 0xAF)				      \
		    idx -= (ch - 0xAA) * 94;				      \
		  if (ch > 0xaf)					      \
		    idx -= 564;						      \
		  if (ch >= 0xf8)					      \
		    idx -= (ch - 0xF8) * 94;				      \
									      \
		  ch = __gb18030_2byte_to_ucs[idx];			      \
		}							      \
									      \
	      inptr += 2;						      \
	    }								      \
	  else								      \
	    {								      \
	      /* This is an illegal character.  */			      \
	      STANDARD_FROM_LOOP_ERR_HANDLER (2);			      \
	    }							      	      \
	}								      \
									      \
    *((uint32_t *) outptr) = ch;					      \
    outptr += sizeof (uint32_t);					      \
  }
#define LOOP_NEED_FLAGS
#define ONEBYTE_BODY \
  {									      \
    if (c < 0x80)							      \
      return c;								      \
    else								      \
      return WEOF;							      \
  }
#include <iconv/loop.c>


/* Next, define the other direction.  */
#define MIN_NEEDED_INPUT	MIN_NEEDED_TO
#define MIN_NEEDED_OUTPUT	MIN_NEEDED_FROM
#define MAX_NEEDED_OUTPUT	MAX_NEEDED_FROM
#define LOOPFCT			TO_LOOP
#define BODY \
  {									      \
    uint32_t ch = *((const uint32_t *) inptr);				      \
									      \
    if (ch <= L'\x7f')							      \
      /* It's plain ASCII.  */						      \
      *outptr++ = (unsigned char) ch;					      \
    else								      \
      {									      \
	/* Returns the bytesize of the GB18030 character */		      \
	unsigned long int 	idx = 0;				      \
	indextbl_t		u2g;					      \
	unsigned char		gbch[4] = "\0\0\0\0";			      \
	const unsigned char	*cp = "";				      \
	int len = 2;	/* This is the most common case.  */		      \
	if (ch <= 0xD7FF || (ch >= 0xE766 && ch <= 0xFFFD))		      \
	  {								      \
	    u2g = __ucs_to_gb18030_index[ch >> 8];			      \
	    if ((ch & 0xFF) >= u2g.tblbegin && (ch & 0xFF) <= u2g.tblend)     \
	      {								      \
		/* Use mapping table (2-byte or 4-byte GB18030) */	      \
		cp = __ucs_to_gb18030[ch - u2g.tbloffset];		      \
									      \
		if (!(cp[0] & 0x80))					      \
		  {							      \
		    /* 4-byte GB18030 stored in a special compact format */   \
		    gbch[0] = 0x81;					      \
		    gbch[1] = 0x30 + (cp[0] >> 3);			      \
		    if (cp[0] >= 0x70)					      \
		      {							      \
		        gbch[0] += 3;					      \
		        gbch[1] -= 14;					      \
		      }							      \
		    else if (cp[0] >= 0x60)				      \
		      {							      \
		        gbch[0] += 2;					      \
		        gbch[1] -= 6;					      \
		      }							      \
		    else if (cp[0] >= 0x30)				      \
		      {							      \
		        gbch[0] += 1;					      \
		        gbch[1] -= 6;					      \
		      }							      \
		    else if (gbch[1] >= 0x31)				      \
		      gbch[1] += 5;					      \
									      \
		    gbch[2] = 0x81 + ((cp[0] & 0x7) << 4 | cp[1] >> 4);	      \
		    gbch[3] = 0x30 | (cp[1] & 0xF);			      \
		    cp = gbch;						      \
		    len = 4;						      \
	    	  }							      \
	      }								      \
	    else /* Use algorithm (4-byte GB18030) */			      \
	      {								      \
		idx = u2g.algoffset + (ch & 0xFF);			      \
		/* Yikes, my index table could not cover one special case */  \
		if (ch >= 0x49B8 && ch <= 0x49FF)			      \
		  idx -= 11;						      \
		len = 4;						      \
	      }								      \
	  }								      \
	else if (ch >= 0xE000 && ch <= 0xE765)				      \
	  {								      \
	    /* User-defined areas in GB18030 (2-byte) */		      \
	    if (ch <= 0xE233)						      \
	      idx = 0xAAA1 + (((ch - 0xE000) / 94) << 8) + (ch - 0xE000) % 94; \
	    else if (ch <= 0xE4C5)					      \
	      idx = 0xF8A1 + (((ch - 0xE234) / 94) << 8) + (ch - 0xE234) % 94; \
	    else							      \
	      {								      \
		idx = 0xA140 + (((ch - 0xE4C6) / 96) << 8) + (ch - 0xE4C6) % 96; \
		/* Skip the gap at 0x7F */				      \
		if ((idx & 0xFF) >= 0x7F)				      \
		  idx++;						      \
	      }								      \
	    gbch[0] = (unsigned char)(idx >> 8);			      \
	    gbch[1] = (unsigned char)(idx & 0xFF);			      \
	    cp = gbch;							      \
          }								      \
	else if (ch >= 0x10000 && ch <= 0x10FFFF)			      \
          {								      \
	    idx = ch + 0x1E248;						      \
	    len = 4;							      \
          }								      \
	else								      \
	  len = 0;							      \
									      \
	if (__builtin_expect (len, 2) == 0				      \
	    || (len == 2 && __builtin_expect (cp[0], '\1') == '\0'))	      \
	  {								      \
	    /* Illegal character.  */					      \
	    STANDARD_TO_LOOP_ERR_HANDLER (4);				      \
	  }								      \
									      \
	if (len == 2)							      \
	  {								      \
	    /* See whether there is enough room for the second byte we	      \
	       write.  */						      \
	    if (cp[1] != '\0' && __builtin_expect (outptr + 1 >= outend, 0))  \
	      {								      \
		/* We have not enough room.  */				      \
		result = __GCONV_FULL_OUTPUT;				      \
		break;							      \
	      }								      \
									      \
	    *outptr++ = cp[0];						      \
	    if (cp[1] != '\0')						      \
	      *outptr++ = cp[1];					      \
	  }								      \
	else /* len == 4 */						      \
	  {								      \
	    /* See whether there is enough room for all four bytes we	      \
	       write.  */						      \
	    if (__builtin_expect (outptr + 3 >= outend, 0))		      \
	      {								      \
		/* We have not enough room.  */				      \
		result = __GCONV_FULL_OUTPUT;				      \
		break;							      \
	      }								      \
									      \
	    if (cp[0] && cp[1] && cp[2] && cp[3])			      \
	      {								      \
		outptr[0] = cp[0];					      \
		outptr[1] = cp[1];					      \
		outptr[2] = cp[2];					      \
		outptr[3] = cp[3];					      \
	      }								      \
	    else							      \
	      {								      \
		outptr[3] = (unsigned char)(idx % 10) + 0x30;		      \
		idx /= 10;						      \
		outptr[2] = (unsigned char)(idx % 126) + 0x81;		      \
		idx /= 126;						      \
		outptr[1] = (unsigned char)(idx % 10) + 0x30;		      \
		outptr[0] = (unsigned char)(idx / 10) + 0x81;		      \
	      }								      \
	    outptr += 4;						      \
	  }								      \
      }									      \
									      \
    inptr += 4;								      \
  }
#define LOOP_NEED_FLAGS
#include <iconv/loop.c>


/* Now define the toplevel functions.  */
#include <iconv/skeleton.c>
